@@ -19,7 +19,7 @@
 
 #include "mailthreaderagent.h"
 
-int main( int argc, char **argv ) 
+int main( int argc, char **argv )
 {
-  return Akonadi::AgentBase::init<MailThreaderAgent>( argc, argv ); 
-}
\ No newline at end of file
+  return Akonadi::ResourceBase::init<MailThreaderAgent>( argc, argv );
+}
