@@ -18,8 +18,8 @@
 */
 
 
-#ifndef AKONADI_DATAENGINE_H
-#define AKONADI_DATAENGINE_H
+#ifndef AKONADIENGINE_H
+#define AKONADIENGINE_H
 
 #include <plasma/dataengine.h>
 
@@ -32,7 +32,7 @@ class AkonadiEngine : public Plasma::DataEngine
   Q_OBJECT
 
   public:
-    AkonadiEngine( QObject* parent, const QStringList& args );
+    AkonadiEngine( QObject* parent, const QVariantList& args );
     ~AkonadiEngine();
 
   private slots:
