@@ -17,10 +17,11 @@
     02110-1301, USA.
 */
 
+#include "collectionmodel.h"
+
 #include "collection.h"
 #include "collectionstatusjob.h"
 #include "collectionlistjob.h"
-#include "collectionmodel.h"
 #include "collectionmodifyjob.h"
 #include "itemstorejob.h"
 #include "itemappendjob.h"
@@ -31,6 +32,7 @@
 #include <kiconloader.h>
 #include <kcomponentdata.h>
 #include <klocale.h>
+#include <kurl.h>
 
 #include <QtCore/QDebug>
 #include <QtCore/QHash>
@@ -64,6 +66,7 @@ class CollectionModel::Private
     void listDone( KJob* );
     void editDone( KJob* );
     void appendDone( KJob* );
+    void collectionsChanged( const Akonadi::Collection::List &cols );
 
     void updateSupportedMimeTypes( Collection col )
     {
@@ -106,11 +109,16 @@ void CollectionModel::Private::collectionChanged( const Akonadi::Collection &col
     else
       newParent = collections.value( newParentId );
     CollectionListJob *job = new CollectionListJob( newParent, CollectionListJob::Recursive, session );
+    mParent->connect( job, SIGNAL(collectionsReceived(Akonadi::Collection::List)),
+                      mParent, SLOT(collectionsChanged(Akonadi::Collection::List)) );
     mParent->connect( job, SIGNAL( result( KJob* ) ),
                     mParent, SLOT( listDone( KJob* ) ) );
+
   }
   else { // It's a simple change
     CollectionListJob *job = new CollectionListJob( collection, CollectionListJob::Local, session );
+    mParent->connect( job, SIGNAL(collectionsReceived(Akonadi::Collection::List)),
+                      mParent, SLOT(collectionsChanged(Akonadi::Collection::List)) );
     mParent->connect( job, SIGNAL( result( KJob* ) ),
                     mParent, SLOT( listDone( KJob* ) ) );
   }
@@ -121,7 +129,7 @@ void CollectionModel::Private::updateDone( KJob *job )
 {
   if ( job->error() ) {
     // TODO: handle job errors
-    kWarning() << k_funcinfo << "Job error: " << job->errorString() << endl;
+    kWarning() <<"Job error:" << job->errorString();
   } else {
     CollectionStatusJob *csjob = static_cast<CollectionStatusJob*>( job );
     Collection result = csjob->collection();
@@ -132,7 +140,7 @@ void CollectionModel::Private::updateDone( KJob *job )
 void CollectionModel::Private::collectionStatusChanged( int collection, const Akonadi::CollectionStatus & status )
 {
   if ( !collections.contains( collection ) )
-    kWarning() << k_funcinfo << "Got status response for non-existing collection: " << collection << endl;
+    kWarning() <<"Got status response for non-existing collection:" << collection;
   else {
     collections[ collection ].setStatus( status );
 
@@ -147,38 +155,6 @@ void CollectionModel::Private::listDone( KJob *job )
 {
   if ( job->error() ) {
     qWarning() << "Job error: " << job->errorString() << endl;
-  } else {
-    Collection::List _collections = static_cast<CollectionListJob*>( job )->collections();
-
-    // update model
-    foreach( Collection col, _collections ) {
-      if ( collections.contains( col.id() ) ) {
-        // collection already known
-        col.setStatus( collections.value( col.id() ).status() );
-        collections[ col.id() ] = col;
-        QModelIndex startIndex = mParent->indexForId( col.id() );
-        QModelIndex endIndex = mParent->indexForId( col.id(), mParent->columnCount( mParent->parent( startIndex ) ) - 1 );
-        emit mParent->dataChanged( startIndex, endIndex );
-        continue;
-      }
-      collections.insert( col.id(), col );
-      QModelIndex parentIndex = mParent->indexForId( col.parent() );
-      if ( parentIndex.isValid() || col.parent() == Collection::root().id() ) {
-        mParent->beginInsertRows( parentIndex, mParent->rowCount( parentIndex ), mParent->rowCount( parentIndex ) );
-        childCollections[ col.parent() ].append( col.id() );
-        mParent->endInsertRows();
-      } else {
-        childCollections[ col.parent() ].append( col.id() );
-      }
-
-      updateSupportedMimeTypes( col );
-
-      // start a status job for every collection to get message counts, etc.
-      if ( fetchStatus && col.type() != Collection::VirtualParent ) {
-        CollectionStatusJob* csjob = new CollectionStatusJob( col, session );
-        mParent->connect( csjob, SIGNAL(result(KJob*)), mParent, SLOT(updateDone(KJob*)) );
-      }
-    }
   }
 }
 
@@ -192,11 +168,43 @@ void CollectionModel::Private::editDone( KJob * job )
 void CollectionModel::Private::appendDone(KJob * job)
 {
   if ( job->error() ) {
-    kWarning() << "Append failed: " << job->errorString() << endl;
+    kWarning() <<"Append failed:" << job->errorString();
     // TODO: error handling
   }
 }
 
+void CollectionModel::Private::collectionsChanged( const Collection::List &cols )
+{
+  foreach( Collection col, cols ) {
+    if ( collections.contains( col.id() ) ) {
+      // collection already known
+      col.setStatus( collections.value( col.id() ).status() );
+      collections[ col.id() ] = col;
+      QModelIndex startIndex = mParent->indexForId( col.id() );
+      QModelIndex endIndex = mParent->indexForId( col.id(), mParent->columnCount( mParent->parent( startIndex ) ) - 1 );
+      emit mParent->dataChanged( startIndex, endIndex );
+      continue;
+    }
+    collections.insert( col.id(), col );
+    QModelIndex parentIndex = mParent->indexForId( col.parent() );
+    if ( parentIndex.isValid() || col.parent() == Collection::root().id() ) {
+      mParent->beginInsertRows( parentIndex, mParent->rowCount( parentIndex ), mParent->rowCount( parentIndex ) );
+      childCollections[ col.parent() ].append( col.id() );
+      mParent->endInsertRows();
+    } else {
+      childCollections[ col.parent() ].append( col.id() );
+    }
+
+    updateSupportedMimeTypes( col );
+
+    // start a status job for every collection to get message counts, etc.
+    if ( fetchStatus && col.type() != Collection::VirtualParent ) {
+      CollectionStatusJob* csjob = new CollectionStatusJob( col, session );
+      mParent->connect( csjob, SIGNAL(result(KJob*)), mParent, SLOT(updateDone(KJob*)) );
+    }
+  }
+}
+
 
 CollectionModel::CollectionModel( QObject * parent ) :
     QAbstractItemModel( parent ),
@@ -206,6 +214,7 @@ CollectionModel::CollectionModel( QObject * parent ) :
 
   // start a list job
   CollectionListJob *job = new CollectionListJob( Collection::root(), CollectionListJob::Recursive, d->session );
+  connect( job, SIGNAL(collectionsReceived(Akonadi::Collection::List)), SLOT(collectionsChanged(Akonadi::Collection::List)) );
   connect( job, SIGNAL(result(KJob*)), SLOT(listDone(KJob*)) );
 
   // monitor collection changes
@@ -346,7 +355,7 @@ int CollectionModel::rowCount( const QModelIndex & parent ) const
 QVariant CollectionModel::headerData( int section, Qt::Orientation orientation, int role ) const
 {
   if ( section == 0 && orientation == Qt::Horizontal && role == Qt::DisplayRole )
-    return i18n( "Name" );
+    return i18nc( "@title:column, name of a thing", "Name" );
   return QAbstractItemModel::headerData( section, orientation, role );
 }
 
@@ -363,7 +372,7 @@ bool CollectionModel::removeRowFromModel( int row, const QModelIndex & parent )
     list = d->childCollections.value( Collection::root().id() );
   }
   if ( row < 0 || row  >= list.size() ) {
-    kWarning() << k_funcinfo << "Index out of bounds: " << row << " parent: " << parentCol.id() << endl;
+    kWarning() <<"Index out of bounds:" << row <<" parent:" << parentCol.id();
     return false;
   }
 
@@ -534,6 +543,7 @@ bool CollectionModel::dropMimeData(const QMimeData * data, Qt::DropAction action
     return false;
 
   // data contains an url list
+  bool success = false;
   KUrl::List urls = KUrl::List::fromMimeData( data );
   foreach( KUrl url, urls ) {
     if ( Collection::urlIsValid( url ) )
@@ -543,7 +553,13 @@ bool CollectionModel::dropMimeData(const QMimeData * data, Qt::DropAction action
         CollectionModifyJob *job = new CollectionModifyJob( col, d->session );
         job->setParent( parentCol );
         connect( job, SIGNAL(result(KJob*)), SLOT(appendDone(KJob*)) );
-        return job->exec();
+        job->exec();
+        if ( !job->exec() ) {
+          success = false;
+          break;
+        } else {
+          success = true; // continue, there might be other urls
+        }
       }
       else { // TODO A Copy Collection Job
         return false;
@@ -551,12 +567,18 @@ bool CollectionModel::dropMimeData(const QMimeData * data, Qt::DropAction action
     }
     else if ( Item::urlIsValid( url ) )
     {
+      // TODO Extract mimetype from url and check if collection accepts it
       DataReference ref = Item::fromUrl( url );
       if (action == Qt::MoveAction) {
         ItemStoreJob *job = new ItemStoreJob( Item( ref ), d->session );
         job->setCollection( parentCol );
         connect( job, SIGNAL(result(KJob*)), SLOT(appendDone(KJob*)) );
-        return job->exec();
+        if ( !job->exec() ) {
+          success = false;
+          break;
+        } else {
+          success = true; // continue, there might be other urls
+        }
       }
       else if ( action == Qt::CopyAction ) {
       // TODO Wait for a job allowing to copy on server side.
@@ -567,7 +589,7 @@ bool CollectionModel::dropMimeData(const QMimeData * data, Qt::DropAction action
     }
   }
 
-  return false;
+  return success;
 }
 
 Collection CollectionModel::collectionForId(int id) const
