@@ -25,9 +25,11 @@
 #include "kcrash.h"
 #include "resourceadaptor.h"
 #include "collectionsync.h"
+#include "itemsync.h"
 #include "monitor_p.h"
 #include "resourcescheduler.h"
 #include "tracerinterface.h"
+#include "xdgbasedirs.h"
 
 #include <libakonadi/collectionlistjob.h>
 #include <libakonadi/itemfetchjob.h>
@@ -97,6 +99,10 @@ class ResourceBase::Private
     void slotSynchronizeCollection( const Collection &col );
     void slotCollectionListDone( KJob *job );
 
+    void slotItemSyncDone( KJob *job );
+
+    void slotPercent( KJob* job, unsigned long percent );
+
     QString defaultReadyMessage() const;
     QString defaultSyncingMessage() const;
     QString defaultErrorMessage() const;
@@ -117,7 +123,7 @@ class ResourceBase::Private
 
     Session *session;
     Monitor *monitor;
-    QHash<Akonadi::Job*, QDBusMessage> pendingReplys;
+    QHash<Akonadi::Job*, QDBusMessage> pendingReplies;
 
     bool online;
 
@@ -212,18 +218,18 @@ class ResourceBase::Private
 QString ResourceBase::Private::defaultReadyMessage() const
 {
   if ( online )
-    return i18n( "Ready" );
-  return i18n( "Offline" );
+    return i18nc( "@info:status, application ready for work", "Ready" );
+  return i18nc( "@info:status", "Offline" );
 }
 
 QString ResourceBase::Private::defaultSyncingMessage() const
 {
-  return tr( "Syncing..." );
+  return i18nc( "@info:status", "Syncing..." );
 }
 
 QString ResourceBase::Private::defaultErrorMessage() const
 {
-  return tr( "Error!" );
+  return i18nc( "@info:status", "Error!" );
 }
 
 ResourceBase::ResourceBase( const QString & id )
@@ -245,7 +251,7 @@ ResourceBase::ResourceBase( const QString & id )
 
   d->mId = id;
 
-  d->mSettings = new QSettings( QString::fromLatin1( "%1/.akonadi/resource_config_%2" ).arg( QDir::homePath(), id ), QSettings::IniFormat );
+  d->mSettings = new QSettings( QString::fromLatin1( "%1/resource_config_%2" ).arg( XdgBaseDirs::saveDir( "config", QLatin1String( "akonadi" ) ), id ), QSettings::IniFormat );
 
   const QString name = d->mSettings->value( QLatin1String( "Resource/Name" ) ).toString();
   if ( !name.isEmpty() )
@@ -257,7 +263,7 @@ ResourceBase::ResourceBase( const QString & id )
   d->monitor = new Monitor( this );
   d->monitor->fetchCollection( d->online );
   if ( d->online )
-    d->monitor->addFetchPart( Item::PartAll );
+    d->monitor->fetchAllParts();
 
   connect( d->monitor, SIGNAL( itemAdded( const Akonadi::Item&, const Akonadi::Collection& ) ),
            this, SLOT( slotItemAdded( const Akonadi::Item&, const Akonadi::Collection& ) ) );
@@ -424,11 +430,13 @@ QString ResourceBase::parseArguments( int argc, char **argv )
   }
 
   sAppName = qstrdup( identifier.toLatin1().constData() );
-  KCmdLineArgs::init( argc, argv, sAppName, 0, ki18n("Akonadi Resource"),"0.1" ,
-                      ki18n("Akonadi Resource") );
+  KCmdLineArgs::init( argc, argv, sAppName, 0,
+                      ki18nc("@title, application name", "Akonadi Resource"), "0.1",
+                      ki18nc("@title, application description", "Akonadi Resource") );
 
   KCmdLineOptions options;
-  options.add("identifier <argument>", ki18n("Resource identifier"));
+  options.add("identifier <argument>",
+              ki18nc("@label, commandline option", "Resource identifier"));
   KCmdLineArgs::addCmdLineOptions( options );
 
   return identifier;
@@ -450,7 +458,7 @@ void ResourceBase::quit()
 
   d->mSettings->sync();
 
-  QCoreApplication::exit( 0 );
+  QTimer::singleShot( 0, QCoreApplication::instance(), SLOT( quit() ) );
 }
 
 void ResourceBase::aboutToQuit()
@@ -502,7 +510,7 @@ Session* ResourceBase::session()
 bool ResourceBase::deliverItem(Akonadi::Job * job, const QDBusMessage & msg)
 {
   msg.setDelayedReply( true );
-  d->pendingReplys.insert( job, msg.createReply() );
+  d->pendingReplies.insert( job, msg.createReply() );
   connect( job, SIGNAL(result(KJob*)), SLOT(slotDeliveryDone(KJob*)) );
   return false;
 }
@@ -519,10 +527,32 @@ void ResourceBase::itemChanged( const Item &item, const QStringList &partIdentif
   Q_UNUSED( partIdentifiers );
 }
 
+void ResourceBase::itemRemoved( const DataReference &ref )
+{
+  Q_UNUSED( ref );
+}
+
+void ResourceBase::collectionAdded( const Collection &collection, const Collection &parent )
+{
+  Q_UNUSED( collection );
+  Q_UNUSED( parent );
+}
+
+void ResourceBase::collectionChanged( const Collection &collection )
+{
+  Q_UNUSED( collection );
+}
+
+void ResourceBase::collectionRemoved( int id, const QString &remoteId )
+{
+  Q_UNUSED( id );
+  Q_UNUSED( remoteId );
+}
+
 void ResourceBase::Private::slotDeliveryDone(KJob * job)
 {
-  Q_ASSERT( pendingReplys.contains( static_cast<Akonadi::Job*>( job ) ) );
-  QDBusMessage reply = pendingReplys.take( static_cast<Akonadi::Job*>( job ) );
+  Q_ASSERT( pendingReplies.contains( static_cast<Akonadi::Job*>( job ) ) );
+  QDBusMessage reply = pendingReplies.take( static_cast<Akonadi::Job*>( job ) );
   if ( job->error() ) {
     mParent->error( QLatin1String( "Error while creating item: " ) + job->errorString() );
     reply << false;
@@ -595,7 +625,7 @@ void ResourceBase::Private::slotReplayNextItem()
 void ResourceBase::Private::slotReplayItemAdded( KJob *job )
 {
   if ( job->error() ) {
-    mParent->error( i18n( "Unable to fetch item in replay mode." ) );
+    mParent->error( i18nc( "@info", "Unable to fetch item in replay mode." ) );
   } else {
     ItemCollectionFetchJob *fetchJob = qobject_cast<ItemCollectionFetchJob*>( job );
 
@@ -611,7 +641,7 @@ void ResourceBase::Private::slotReplayItemAdded( KJob *job )
 void ResourceBase::Private::slotReplayItemChanged( KJob *job )
 {
   if ( job->error() ) {
-    mParent->error( i18n( "Unable to fetch item in replay mode." ) );
+    mParent->error( i18nc( "@info", "Unable to fetch item in replay mode." ) );
   } else {
     ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob*>( job );
 
@@ -628,12 +658,12 @@ void ResourceBase::Private::slotReplayItemChanged( KJob *job )
 void ResourceBase::Private::slotReplayCollectionAdded( KJob *job )
 {
   if ( job->error() ) {
-    mParent->error( i18n( "Unable to fetch collection in replay mode." ) );
+    mParent->error( i18nc( "@info", "Unable to fetch collection in replay mode." ) );
   } else {
     CollectionListJob *listJob = qobject_cast<CollectionListJob*>( job );
 
     if ( listJob->collections().count() == 0 )
-      mParent->error( i18n( "Unable to fetch collection in replay mode." ) );
+      mParent->error( i18nc( "@info", "Unable to fetch collection in replay mode." ) );
     else
       mParent->collectionAdded( listJob->collections().first(), listJob->collections().at( 1 ) );
   }
@@ -644,12 +674,12 @@ void ResourceBase::Private::slotReplayCollectionAdded( KJob *job )
 void ResourceBase::Private::slotReplayCollectionChanged( KJob *job )
 {
   if ( job->error() ) {
-    mParent->error( i18n( "Unable to fetch collection in replay mode." ) );
+    mParent->error( i18nc( "@info", "Unable to fetch collection in replay mode." ) );
   } else {
     CollectionListJob *listJob = qobject_cast<CollectionListJob*>( job );
 
     if ( listJob->collections().count() <= 1 )
-      mParent->error( i18n( "Unable to fetch collection in replay mode." ) );
+      mParent->error( i18nc( "@info", "Unable to fetch collection in replay mode." ) );
     else {
       mParent->collectionChanged( listJob->collections().first() );
     }
@@ -745,7 +775,7 @@ void ResourceBase::changesCommitted(const DataReference & ref)
 bool ResourceBase::requestItemDelivery(int uid, const QString & remoteId, const QStringList &parts )
 {
   if ( !isOnline() ) {
-    error( i18n( "Cannot fetch item in offline mode." ) );
+    error( i18nc( "@info", "Cannot fetch item in offline mode." ) );
     return false;
   }
 
@@ -819,7 +849,7 @@ void ResourceBase::Private::slotSynchronizeCollection( const Collection &col )
   QStringList contentTypes = currentCollection.contentTypes();
   contentTypes.removeAll( Collection::collectionMimeType() );
   if ( !contentTypes.isEmpty() ) {
-    mParent->changeStatus( Syncing, i18n( "Syncing collection '%1'", currentCollection.name() ) );
+    mParent->changeStatus( Syncing, i18nc( "@info:status", "Syncing collection '%1'", currentCollection.name() ) );
     mParent->synchronizeCollection( currentCollection );
     return;
   }
@@ -856,6 +886,36 @@ void ResourceBase::Private::slotCollectionListDone( KJob *job )
   // TODO: error handling
 }
 
+void ResourceBase::itemsRetrieved(const Item::List & items)
+{
+  ItemSync *syncer = new ItemSync( currentCollection(), session() );
+  connect( syncer, SIGNAL(percent(KJob*,unsigned long)), SLOT(slotPercent(KJob*,unsigned long)) );
+  connect( syncer, SIGNAL(result(KJob*)), SLOT(slotItemSyncDone(KJob*)) );
+  syncer->setRemoteItems( items );
+}
+
+void ResourceBase::itemsRetrievedIncremental(const Item::List & changedItems, const Item::List & removedItems)
+{
+  ItemSync *syncer = new ItemSync( currentCollection(), session() );
+  connect( syncer, SIGNAL(percent(KJob*,unsigned long)), SLOT(slotPercent(KJob*,unsigned long)) );
+  connect( syncer, SIGNAL(result(KJob*)), SLOT(slotItemSyncDone(KJob*)) );
+  syncer->setRemoteItems( changedItems, removedItems );
+}
+
+void ResourceBase::Private::slotItemSyncDone( KJob *job )
+{
+  if ( job->error() ) {
+    mParent->error( job->errorString() );
+  }
+  mParent->changeStatus( Ready );
+  scheduler->taskDone();
+}
+
+void ResourceBase::Private::slotPercent( KJob *job, unsigned long percent )
+{
+  Q_UNUSED( job );
+  mParent->changeProgress( percent );
+}
 
 #include "resource.moc"
 #include "resourcebase.moc"
