@@ -23,15 +23,21 @@
 #include <libakonadi/collection.h>
 #include <libakonadi/itemappendjob.h>
 
+#include <QTime>
+
 class ItemDumper : public QObject
 {
   Q_OBJECT
   public:
-    ItemDumper( const QString &path, const QString &filename, const QString &mimetype );
+    ItemDumper( const QString &path, const QString &filename, const QString &mimetype, int count );
 
   private Q_SLOTS:
     void done(KJob* job);
 
+  private:
+    QTime mTime;
+    int mJobCount;
+
 };
 
 
