@@ -26,8 +26,10 @@ class ItemFetchTest : public QObject
 {
   Q_OBJECT
   private slots:
+    void initTestCase();
     void testFetch();
     void testIlleagalFetch();
+    void testMultipartFetch();
 };
 
 
