@@ -28,7 +28,7 @@ namespace Akonadi {
 class SerializerPluginMail : public ItemSerializerPlugin
 {
 public:
-    void deserialize( Item& item, const QString& label, QIODevice& data );
+    bool deserialize( Item& item, const QString& label, QIODevice& data );
     void serialize( const Item& item, const QString& label, QIODevice& data );
     QStringList parts( const Item &item ) const;
 };
