@@ -17,18 +17,20 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#include "agentmanager.h"
+
+#include "agentmanageradaptor.h"
+#include "processcontrol.h"
+#include "serverinterface.h"
+#include "xdgbasedirs.h"
+
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
 #include <QtCore/QFileSystemWatcher>
 #include <QtCore/QSettings>
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusError>
-
-#include <akonadi-prefix.h> // for AKONADIDIR
-
-#include "agentmanager.h"
-#include "agentmanageradaptor.h"
-#include "processcontrol.h"
+#include <QtCore/QDebug>
 
 AgentManager::AgentManager( QObject *parent )
   : QObject( parent )
@@ -47,11 +49,15 @@ AgentManager::AgentManager( QObject *parent )
 
   readPluginInfos();
 
-  QFileSystemWatcher *watcher = new QFileSystemWatcher( this );
-  watcher->addPath( pluginInfoPath() );
+  QStringList pathList = pluginInfoPathList();
 
-  connect( watcher, SIGNAL( directoryChanged( const QString& ) ),
-           this, SLOT( updatePluginInfos() ) );
+  foreach ( QString path, pathList ) {
+    QFileSystemWatcher *watcher = new QFileSystemWatcher( this );
+    watcher->addPath( path );
+
+    connect( watcher, SIGNAL( directoryChanged( const QString& ) ),
+             this, SLOT( updatePluginInfos() ) );
+  }
 
   load();
 }
@@ -73,7 +79,9 @@ void AgentManager::cleanup()
 
   mInstances.clear();
 
-  mStorageController->setCrashPolicy( Akonadi::ProcessControl::StopOnCrash );
+  org::kde::Akonadi::Server *serverIface = new org::kde::Akonadi::Server( "org.kde.Akonadi", "/Server",
+                                                                          QDBusConnection::sessionBus(), this );
+  serverIface->quit();
 
   delete mStorageController;
   mStorageController = 0;
@@ -173,7 +181,7 @@ QString AgentManager::createAgentInstance( const QString &identifier )
   QStringList arguments;
   arguments << "--identifier" << agentIdentifier;
 
-  const QString executable = mPluginInfos[ identifier ].exec;
+  const QString executable = Akonadi::XdgBaseDirs::findExecutableFile( mPluginInfos[ identifier ].exec );
   mInstances[ agentIdentifier ].controller->start( executable, arguments );
 
   save();
@@ -328,9 +336,19 @@ void AgentManager::readPluginInfos()
 {
   mPluginInfos.clear();
 
-  QDir directory( pluginInfoPath(), "*.desktop" );
+  QStringList pathList = pluginInfoPathList();
 
+  foreach ( QString path, pathList ) {
+      QDir directory( path, "*.desktop" );
+      readPluginInfos( directory );
+  }
+}
+
+void AgentManager::readPluginInfos( const QDir& directory )
+{
   QStringList files = directory.entryList();
+  qDebug() << "PLUGINS: " << directory;
+  qDebug() << "PLUGINS: " << files;
   for ( int i = 0; i < files.count(); ++i ) {
     const QString fileName = directory.absoluteFilePath( files[ i ] );
 
@@ -366,34 +384,34 @@ void AgentManager::readPluginInfos()
       continue;
     }
 
-
+  qDebug() << "PLUGINS inserting: " << identifier;
     mPluginInfos.insert( identifier, info );
   }
 }
 
-QString AgentManager::pluginInfoPath()
+QStringList AgentManager::pluginInfoPathList()
 {
-  return QString( "%1/share/apps/akonadi/agents" ).arg( AKONADIDIR );
+  return Akonadi::XdgBaseDirs::findAllResourceDirs( "data", QLatin1String( "akonadi/agents" ) );
 }
 
-QString AgentManager::configPath()
+QString AgentManager::configPath( bool writeable )
 {
-  const QString homePath = QDir::homePath();
-  const QString akonadiHomeDir = QString( "%1/%2" ).arg( homePath, ".akonadi" );
+  const QString configFile =
+    Akonadi::XdgBaseDirs::findResourceFile( "config", QLatin1String( "akonadi/agentsrc" ) );
 
-  if ( !QDir( akonadiHomeDir ).exists() ) {
-    QDir dir;
-    dir.mkdir( akonadiHomeDir );
-  }
+  if ( !writeable && !configFile.isEmpty() )
+    return configFile;
 
-  return akonadiHomeDir + "/agentsrc";
+  const QString configDir = Akonadi::XdgBaseDirs::saveDir( "config", "akonadi" );
+
+  return configDir + QLatin1String( "/agentsrc" );
 }
 
 void AgentManager::load()
 {
   mInstanceInfos.clear();
 
-  QSettings file( configPath(), QSettings::IniFormat );
+  QSettings file( configPath( false ), QSettings::IniFormat );
   file.beginGroup( "InstanceCounters" );
 
   QStringList entries = file.childGroups();
@@ -457,7 +475,7 @@ void AgentManager::load()
     QStringList arguments;
     arguments << "--identifier" << instanceIdentifier;
 
-    const QString executable = mPluginInfos[ agentType ].exec;
+    const QString executable = Akonadi::XdgBaseDirs::findExecutableFile( mPluginInfos[ agentType ].exec );
     mInstances[ instanceIdentifier ].controller->start( executable, arguments );
 
     file.endGroup();
@@ -468,7 +486,7 @@ void AgentManager::load()
 
 void AgentManager::save()
 {
-  QSettings file( configPath(), QSettings::IniFormat );
+  QSettings file( configPath( true ), QSettings::IniFormat );
 
   file.clear();
   file.beginGroup( "InstanceCounters" );
