@@ -113,7 +113,7 @@ class DefaultNormalViewFormatter::SummaryVisitor : public TreeNodeVisitor
             if( !node->description().isEmpty() )
             {
                 text += QString("<div dir=\"%1\">").arg(Utils::stripTags(Utils::directionOf(node->description())));
-                text += i18n("<b>Description:</b> %1<br><br>", node->description());
+                text += i18n("<b>Description:</b> %1<br /><br />", node->description());
                 text += "</div>\n"; // /description
             }
 
@@ -244,7 +244,7 @@ QString DefaultNormalViewFormatter::formatArticle(const Article& article, IconOp
 
         //text += QString("<hr><div><a href=\"%1\">%2</a> (%3, %4)</div>").arg(url).arg(url).arg(lengthStr).arg(type);
    // }
-    //kDebug() << text << endl;
+    //kDebug() << text;
     return text;
 }
 
@@ -430,7 +430,7 @@ QString DefaultCombinedViewFormatter::formatArticle(const Article& article, Icon
         text += "\">" + i18n( "Complete Story" ) + "</a></p>";
     }
     text += "</div>";
-    //kDebug() << text << endl;
+    //kDebug() << text;
     return text;
 }
 
