@@ -88,23 +88,25 @@ ArticleViewer::ArticleViewer(QWidget *parent)
              this, SLOT(slotCompleted()));
 
     KParts::BrowserExtension* ext = m_part->browserExtension();
-    connect(ext, SIGNAL(popupMenu (KXMLGUIClient*, QPoint, KUrl, KParts::URLArgs, KParts::BrowserExtension::PopupFlags, mode_t)),
-             this, SLOT(slotPopupMenu(KXMLGUIClient*, QPoint, KUrl, KParts::URLArgs, KParts::BrowserExtension::PopupFlags, mode_t)));
+    connect(ext, SIGNAL(popupMenu (KXMLGUIClient*, QPoint, KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments, KParts::BrowserExtension::PopupFlags, mode_t)),
+             this, SLOT(slotPopupMenu(KXMLGUIClient*, QPoint, KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments, KParts::BrowserExtension::PopupFlags, mode_t)));
 
-    connect( ext, SIGNAL(openUrlRequestDelayed(KUrl, KParts::URLArgs)),
-             this, SLOT(slotOpenUrlRequestDelayed(KUrl, KParts::URLArgs )) );
+    connect( ext, SIGNAL(openUrlRequestDelayed(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)),
+             this, SLOT(slotOpenUrlRequestDelayed(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)) );
 
-    connect(ext, SIGNAL(createNewWindow(KUrl, KParts::URLArgs)),
-            this, SLOT(slotCreateNewWindow(KUrl, KParts::URLArgs)));
+    connect( ext, SIGNAL(createNewWindow(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)),
+             this, SLOT(slotCreateNewWindow(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)) );
 
     connect(ext, SIGNAL(createNewWindow(KUrl,
-            KParts::URLArgs,
+            KParts::OpenUrlArguments,
+            KParts::BrowserArguments
             KParts::WindowArgs,
-            KParts::ReadOnlyPart*)),
+            KParts::ReadOnlyPart**)),
             this, SLOT(slotCreateNewWindow(KUrl,
-                         KParts::URLArgs,
+                         KParts::OpenUrlArguments,
+                         KParts::BrowserArguments
                          KParts::WindowArgs,
-                         KParts::ReadOnlyPart*)));
+                         KParts::ReadOnlyPart**)));
 
     QAction* action = 0;
     action = KStandardAction::print(this, SLOT(slotPrint()), m_part->actionCollection());
@@ -172,10 +174,11 @@ int ArticleViewer::pointsToPixel(int pointSize) const
     return ( pointSize * m_part->view()->logicalDpiY() + 36 ) / 72 ;
 }
 
-void ArticleViewer::slotOpenUrlRequestDelayed(const KUrl& url, const KParts::URLArgs& args)
+void ArticleViewer::slotOpenUrlRequestDelayed(const KUrl& url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& browserArgs)
 {
     OpenUrlRequest req(url);
     req.setArgs(args);
+    req.setBrowserArgs(browserArgs);
     req.setOptions(OpenUrlRequest::NewTab);
 
     if (m_part->button() == Qt::LeftButton)
@@ -210,30 +213,33 @@ void ArticleViewer::slotOpenUrlRequestDelayed(const KUrl& url, const KParts::URL
     emit signalOpenUrlRequest(req);
 }
 
-void ArticleViewer::slotCreateNewWindow(const KUrl& url, const KParts::URLArgs& args)
+void ArticleViewer::slotCreateNewWindow(const KUrl& url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& browserArgs)
 {
     OpenUrlRequest req(url);
     req.setArgs(args);
+    req.setBrowserArgs(browserArgs);
     req.setOptions(OpenUrlRequest::NewTab);
 
     emit signalOpenUrlRequest(req);
 }
 
 void ArticleViewer::slotCreateNewWindow(const KUrl& url,
-                                       const KParts::URLArgs& args,
+                                       const KParts::OpenUrlArguments& args,
+                                       const KParts::BrowserArguments& browserArgs,
                                        const KParts::WindowArgs& /*windowArgs*/,
-                                       KParts::ReadOnlyPart*& part)
+                                       KParts::ReadOnlyPart** part)
 {
     OpenUrlRequest req;
     req.setUrl(url);
     req.setArgs(args);
+    req.setBrowserArgs(browserArgs);
     req.setOptions(OpenUrlRequest::NewTab);
 
     emit signalOpenUrlRequest(req);
-    part = req.part();
+    *part = req.part();
 }
 
-void ArticleViewer::slotPopupMenu(KXMLGUIClient*, const QPoint& p, const KUrl& kurl, const KParts::URLArgs&, KParts::BrowserExtension::PopupFlags kpf, mode_t)
+void ArticleViewer::slotPopupMenu(KXMLGUIClient*, const QPoint& p, const KUrl& kurl, const KParts::OpenUrlArguments&, const KParts::BrowserArguments&, KParts::BrowserExtension::PopupFlags kpf, mode_t)
 {
     const bool isLink = (kpf & KParts::BrowserExtension::ShowNavigationItems) == 0;
     const bool isSelection = (kpf & KParts::BrowserExtension::ShowTextSelectionItems) != 0;
@@ -282,7 +288,8 @@ void ArticleViewer::slotCopyLinkAddress()
     if(m_url.isEmpty()) return;
     QClipboard *cb = QApplication::clipboard();
     cb->setText(m_url.prettyUrl(), QClipboard::Clipboard);
-    cb->setText(m_url.prettyUrl(), QClipboard::Selection);
+    // don't set url to selection as it's a no-no according to a fd.o spec
+    //cb->setText(m_url.prettyUrl(), QClipboard::Selection);
 }
 
 void ArticleViewer::slotSelectionChanged()
@@ -427,7 +434,7 @@ void ArticleViewer::renderContent(const QString& text)
     m_part->closeUrl();
     m_currentText = text;
     beginWriting();
-    //kDebug() << text << endl;
+    //kDebug() << text;
     m_part->write(text);
     endWriting();
 }
@@ -450,7 +457,7 @@ void ArticleViewer::beginWriting()
 void ArticleViewer::endWriting()
 {
     m_part->write(m_htmlFooter);
-    //kDebug() << m_htmlFooter << endl;
+    //kDebug() << m_htmlFooter;
     m_part->end();
 }
 
@@ -545,9 +552,9 @@ void ArticleViewer::slotUpdateCombinedView()
             ++num;
         }
     }
-    kDebug() << "Combined view rendering: (" << num << " articles):\n" << "generating HTML: " << spent.elapsed() << "ms " << endl;
+    kDebug() <<"Combined view rendering: (" << num <<" articles):" <<"generating HTML:" << spent.elapsed() <<"ms";
     renderContent(text);
-    kDebug() << "HTML rendering: " << spent.elapsed() << "ms" << endl;
+    kDebug() <<"HTML rendering:" << spent.elapsed() <<"ms";
 }
 
 void ArticleViewer::slotArticlesUpdated(TreeNode* /*node*/, const QList<Article>& /*list*/)
@@ -567,8 +574,8 @@ void ArticleViewer::slotArticlesRemoved(TreeNode* /*node*/, const QList<Article>
 /* testingtesting :)
 void ArticleViewer::slotPopupMenu(KXMLGUIClient*, const QPoint& p, const KUrl& kurl, const KParts::URLArgs&, KParts::BrowserExtension::PopupFlags, mode_t)
 {
-    kDebug() << m_link << endl;
-    kDebug() << kurl.url() << endl;
+    kDebug() << m_link;
+    kDebug() << kurl.url();
 }*/
 
 
@@ -674,10 +681,12 @@ bool ArticleViewerPart::closeUrl()
     return KHTMLPart::closeUrl();
 }
 
-void ArticleViewerPart::urlSelected(const QString &url, int button, int state, const QString &_target, KParts::URLArgs args)
+bool ArticleViewerPart::urlSelected(const QString &url, int button, int state, const QString &_target,
+                                    const KParts::OpenUrlArguments& args,
+                                    const KParts::BrowserArguments& browserArgs)
 {
     m_button = button;
-    KHTMLPart::urlSelected(url,button,state,_target,args);
+    return KHTMLPart::urlSelected(url,button,state,_target,args,browserArgs);
 #ifdef __GNUC__
 #warning port disable_introduction
 #endif
