@@ -24,7 +24,7 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include "selectioncontroller.h"
+#include "mainwidget.h"
 #include "actionmanagerimpl.h"
 #include "addfeeddialog.h"
 #include "articlelistview.h"
@@ -40,13 +40,14 @@
 #include "folder.h"
 #include "framemanager.h"
 #include "kernel.h"
-#include "mainwidget.h"
 #include "notificationmanager.h"
 #include "openurlrequest.h"
 #include "propertiesdialog.h"
 #include "progressmanager.h"
 #include "searchbar.h"
+#include "selectioncontroller.h"
 //#include "speechclient.h"
+#include "subscriptionlistmodel.h"
 #include "subscriptionlistview.h"
 #include "tabwidget.h"
 #include "treenode.h"
@@ -151,10 +152,10 @@ Akregator::MainWidget::~MainWidget()
     // should be no risk to do the cleanups now
     if (!m_shuttingDown)
     {
-        kDebug() << "Akregator::MainWidget::~MainWidget(): slotOnShutdown() wasn't called. Calling it now." << endl;
+        kDebug() <<"Akregator::MainWidget::~MainWidget(): slotOnShutdown() wasn't called. Calling it now.";
         slotOnShutdown();
     }
-    kDebug() << "Akregator::MainWidget::~MainWidget(): leaving" << endl;
+    kDebug() <<"Akregator::MainWidget::~MainWidget(): leaving";
 }
 
 Akregator::MainWidget::MainWidget( Part *part, QWidget *parent, ActionManagerImpl* actionManager, const char *name)
@@ -256,10 +257,16 @@ Akregator::MainWidget::MainWidget( Part *part, QWidget *parent, ActionManagerImp
     m_selectionController->setFeedSelector( m_feedListView );
     m_selectionController->setFeedList( m_feedList );
 
-    connect( m_selectionController, SIGNAL( currentSubscriptionChanged( Akregator::TreeNode* ) ), 
+    FolderExpansionHandler* expansionHandler = new FolderExpansionHandler( this );
+        connect( m_feedListView, SIGNAL( expanded( QModelIndex ) ), expansionHandler, SLOT( itemExpanded( QModelIndex ) ) );
+        connect( m_feedListView, SIGNAL( collapsed( QModelIndex ) ), expansionHandler, SLOT( itemCollapsed( QModelIndex ) ) );
+
+    m_selectionController->setFolderExpansionHandler( expansionHandler );
+
+    connect( m_selectionController, SIGNAL( currentSubscriptionChanged( Akregator::TreeNode* ) ),
              this, SLOT( slotNodeSelected( Akregator::TreeNode* ) ) );
 
-    connect( m_selectionController, SIGNAL( currentArticleChanged( Akregator::Article ) ), 
+    connect( m_selectionController, SIGNAL( currentArticleChanged( Akregator::Article ) ),
              this, SLOT( slotArticleSelected( Akregator::Article ) ) );
 
     connect( m_selectionController, SIGNAL( articleDoubleClicked( Akregator::Article ) ),
@@ -271,7 +278,7 @@ Akregator::MainWidget::MainWidget( Part *part, QWidget *parent, ActionManagerImp
     connect( m_articleListView, SIGNAL(signalMouseButtonPressed(int, const Akregator::Article&, const QPoint &, int)),
              this, SLOT(slotMouseButtonPressed(int, const Akregator::Article&, const QPoint &, int)));
 
-    
+
     connect( m_part, SIGNAL(signalSettingsChanged()),
              m_articleListView, SLOT(slotPaletteOrFontChanged()));
 
@@ -287,8 +294,8 @@ Akregator::MainWidget::MainWidget( Part *part, QWidget *parent, ActionManagerImp
     connect( m_articleViewer, SIGNAL(signalOpenUrlRequest(Akregator::OpenUrlRequest&)),
              Kernel::self()->frameManager(), SLOT(slotOpenUrlRequest(Akregator::OpenUrlRequest&)) );
 
-    connect( m_articleViewer->part()->browserExtension(), SIGNAL(mouseOverInfo(const KFileItem *)),
-             this, SLOT(slotMouseOverInfo(const KFileItem *)) );
+    connect( m_articleViewer->part()->browserExtension(), SIGNAL(mouseOverInfo(const KFileItem&)),
+             this, SLOT(slotMouseOverInfo(const KFileItem&)) );
 
     connect( m_part, SIGNAL(signalSettingsChanged()),
              m_articleViewer, SLOT(slotPaletteOrFontChanged()));
@@ -675,9 +682,9 @@ void Akregator::MainWidget::slotNodeSelected(TreeNode* node)
 
     if (node)
     {
-        kDebug() << "node selected: " << node->title() << endl;
-        kDebug() << "unread: " << node->unread() << endl;
-        kDebug() << "total: " << node->totalCount() << endl;
+        kDebug() <<"node selected:" << node->title();
+        kDebug() <<"unread:" << node->unread();
+        kDebug() <<"total:" << node->totalCount();
     }
 
     if (m_displayingAboutPage)
@@ -726,7 +733,7 @@ void Akregator::MainWidget::slotFeedAdd()
 
     TreeNode* lastChild = group->children().last();
 
-    addFeed(QString::null, lastChild, group, false);
+    addFeed(QString::null, lastChild, group, false);	//krazy:exclude=nullstrassign for old broken gcc
 }
 
 void Akregator::MainWidget::addFeed(const QString& url, TreeNode *after, Folder* parent, bool autoExec)
@@ -893,7 +900,7 @@ void Akregator::MainWidget::slotFetchingStopped()
 {
     m_mainFrame->slotSetState(Frame::Completed);
     m_actionManager->action("feed_stop")->setEnabled(false);
-    m_mainFrame->slotSetStatusText(QString::null);
+    m_mainFrame->slotSetStatusText(QString());
 }
 
 void Akregator::MainWidget::slotFeedFetched(Feed *feed)
@@ -950,7 +957,7 @@ void Akregator::MainWidget::slotArticleSelected(const Akregator::Article& articl
     KToggleAction* maai = static_cast<KToggleAction*>(m_actionManager->action("article_set_status_important"));
     maai->setChecked(article.keep());
 
-    kDebug() << "selected: " << article.guid() << endl;
+    kDebug() <<"selected:" << article.guid();
 
     m_articleViewer->showArticle( article );
 }
@@ -1048,7 +1055,8 @@ void Akregator::MainWidget::slotCopyLinkAddress()
         link = article.link().url();
         QClipboard *cb = QApplication::clipboard();
         cb->setText(link, QClipboard::Clipboard);
-        cb->setText(link, QClipboard::Selection);
+        // don't set url to selection as it's a no-no according to a fd.o spec
+        //cb->setText(link, QClipboard::Selection);
     }
 }
 
@@ -1115,7 +1123,7 @@ void Akregator::MainWidget::slotArticleDelete()
             job->start();
         }
 
-        Q_FOREACH( Akregator::Feed* i, feeds ) 
+        Q_FOREACH( Akregator::Feed* i, feeds )
             i->setNotificationMode(true);
 
         if ( m_selectionController->selectedSubscription() )
@@ -1224,9 +1232,9 @@ void Akregator::MainWidget::slotSetCurrentArticleReadDelayed()
     job->start();
 }
 
-void Akregator::MainWidget::slotMouseOverInfo(const KFileItem* const kifi)
+void Akregator::MainWidget::slotMouseOverInfo(const KFileItem& kifi)
 {
-    m_mainFrame->slotSetStatusText( kifi ? kifi->url().prettyUrl() : QString());
+    m_mainFrame->slotSetStatusText( kifi.isNull() ? QString() : kifi.url().prettyUrl() );
 }
 
 void Akregator::MainWidget::readProperties(const KConfigGroup &config)
