@@ -17,12 +17,18 @@
 //  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 
+// local includes
+#include "formatfactory.h"
+#include "inputformat.h"
+#include "kabcclient.h"
+#include "outputformat.h"
+
 // standard includes
 #include <iostream>
 #include <sstream>
 
 // Qt includes
-#include <QFileInfo>
+#include <QtCore/QFileInfo>
 
 // KDE includes
 #include <kaboutdata.h>
@@ -30,12 +36,6 @@
 #include <kcmdlineargs.h>
 #include <klocalizedstring.h>
 
-// local includes
-#include "formatfactory.h"
-#include "inputformat.h"
-#include "kabcclient.h"
-#include "outputformat.h"
-
 static const char version[] = "0.8.1";
 
 bool checkForFormatHelp(KCmdLineArgs* args, FormatFactory* factory);
@@ -125,7 +125,6 @@ int main(int argc, char** argv)
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
 
     qInstallMsgHandler(avoidQPixmapWarning);
-    //KApplication::disableAutoDcopRegistration();
     bool gui = args->getOption("input-format") == "dialog";
     KApplication app(gui);
     qInstallMsgHandler(0);
@@ -431,9 +430,9 @@ int handleKABC2Mutt(int argc, char** argv)
 
     KCmdLineOptions kabc2muttCmdLineOptions;
 
-    kabc2muttCmdLineOptions.add("query <substring>", ki18n("Only show contacts where name or address matches <substring>"));
+    kabc2muttCmdLineOptions.add("query <substring>", ki18n("Only show contacts where name or address matches <placeholder>substring</placeholder>"));
 
-    kabc2muttCmdLineOptions.add("format <format>", ki18n("Default format is 'alias'. 'query' returns email<tab>name<tab>, "
+    kabc2muttCmdLineOptions.add("format <format>", ki18n("Default format is 'alias'. 'query' returns email[tab]name[tab], "
                "as needed by mutt's query_command"), "alias");
 
     kabc2muttCmdLineOptions.add("alternate-key-format", ki18n("Default key format is 'JohDoe', this option turns it into 'jdoe'"));
