@@ -44,9 +44,9 @@
 #include <kcal/calendarresources.h>
 #include <kcal/resourcelocal.h>
 
-#include <QDateTime>
-#include <QFile>
-#include <QFileInfo>
+#include <QtCore/QDateTime>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
 
 #include <stdlib.h>
 #include <iostream>
@@ -208,18 +208,18 @@ int main( int argc, char *argv[] )
    */
   if ( args->isSet( "event" ) ) {
     variables.setUseEvents( true );
-    kDebug() << "main | parse options | use Events" << endl;
+    kDebug() <<"main | parse options | use Events";
   }
   if ( args->isSet( "todo" ) ) {
     variables.setUseTodos( true );
-    kDebug() << "main | parse options | use To-dos" << endl;
+    kDebug() <<"main | parse options | use To-dos";
     cout << i18n( "Sorry, To-dos are not working yet." ).toLocal8Bit().data()
          << endl;
     return 1;
   }
   if ( args->isSet( "journal" ) ) {
     variables.setUseJournals( true );
-    kDebug() << "main | parse options | use Journals" << endl;
+    kDebug() <<"main | parse options | use Journals";
     cout << i18n( "Sorry, Journals are not working yet." ).toLocal8Bit().data()
          << endl;
     return 1;
@@ -229,7 +229,7 @@ int main( int argc, char *argv[] )
        !args->isSet( "todo" ) &&
        !args->isSet( "journal" ) ) {
     variables.setUseEvents( true );
-    kDebug() << "main | parse options | use Events (Default)" << endl;
+    kDebug() <<"main | parse options | use Events (Default)";
   }
 
   /*
@@ -240,19 +240,19 @@ int main( int argc, char *argv[] )
     option = args->getOption( "export-type" );
 
     if ( option.toUpper() == "HTML" ) {
-      kDebug() << "main | export-type | Export to HTML" << endl;
+      kDebug() <<"main | export-type | Export to HTML";
       variables.setExportType( ExportTypeHTML );
     } else if ( option.toUpper() == "HTMLMONTH" ) {
-      kDebug() << "main | export-type | Export to HTML by Month" << endl;
+      kDebug() <<"main | export-type | Export to HTML by Month";
       variables.setExportType( ExportTypeMonthHTML );
     } else if ( option.toUpper() == "CSV" ) {
-      kDebug() << "main | export-type | Export to CSV" << endl;
+      kDebug() <<"main | export-type | Export to CSV";
       variables.setExportType( ExportTypeCSV );
     } else if ( option.toUpper() == "TEXT" ) {
-      kDebug() << "main | export-type | Export to TEXT (default)" << endl;
+      kDebug() <<"main | export-type | Export to TEXT (default)";
       variables.setExportType( ExportTypeText );
     } else if ( option.toUpper() == "SHORT" ) {
-      kDebug() << "main | export-type | Export to TEXT-SHORT" << endl;
+      kDebug() <<"main | export-type | Export to TEXT-SHORT";
       variables.setExportType( ExportTypeTextShort );
     } else {
       cout << i18n( "Invalid Export Type Specified: %1",
@@ -268,10 +268,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "export-file" ) ) {
     option = args->getOption( "export-file" );
 
-    kDebug() << "main | parse options | "
-              << "Export File: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Export File:"
+             << "(" << option << ")";
 
     variables.setExportFile( option );
   }
@@ -282,9 +281,8 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "view" ) ) {
     view = true;
 
-    kDebug() << "main | parse options | "
-              << "Mode: (Print incidences)"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Mode: (Print incidences)";
   }
 
   /*
@@ -294,9 +292,8 @@ int main( int argc, char *argv[] )
     view = false;
     add = true;
 
-    kDebug() << "main | parse options | "
-              << "Mode: (Add incidence)"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Mode: (Add incidence)";
   }
 
   /*
@@ -306,9 +303,8 @@ int main( int argc, char *argv[] )
     view = false;
     change = true;
 
-    kDebug() << "main | parse options | "
-              << "Mode: (Change incidence)"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Mode: (Change incidence)";
   }
 
   /*
@@ -318,9 +314,8 @@ int main( int argc, char *argv[] )
     view = false;
     del = true;
 
-    kDebug() << "main | parse options | "
-              << "Mode: (Delete incidence)"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Mode: (Delete incidence)";
   }
 
   /*
@@ -330,9 +325,8 @@ int main( int argc, char *argv[] )
     view = false;
     create = true;
 
-    kDebug() << "main | parse options | "
-              << "Calendar File: (Create)"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Calendar File: (Create)";
   }
 
   /*
@@ -341,10 +335,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "summary" ) ) {
     option = args->getOption( "summary" );
 
-    kDebug() << "main | parse options | "
-              << "Summary: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Summary:"
+             << "(" << option << ")";
 
     variables.setSummary( option );
   }
@@ -355,10 +348,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "description" ) ) {
     option = args->getOption( "description" );
 
-    kDebug() << "main | parse options | "
-              << "Description: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Description:"
+             << "(" << option << ")";
 
     variables.setDescription( option );
   }
@@ -369,10 +361,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "location" ) ) {
     option = args->getOption( "location" );
 
-    kDebug() << "main | parse options | "
-              << "Location: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Location:"
+             << "(" << option << ")";
 
     variables.setLocation( option );
   }
@@ -381,9 +372,8 @@ int main( int argc, char *argv[] )
    * Show next happening and exit
    */
   if ( args->isSet( "next" ) ) {
-    kDebug() << "main | parse options | "
-              << "Show next incidence only"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Show next incidence only";
 
     variables.setNext( true );
   }
@@ -394,10 +384,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "uid" ) ) {
     option = args->getOption( "uid" );
 
-    kDebug() << "main | parse options | "
-              << "incidence UID: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "incidence UID:"
+             << "(" << option << ")";
 
     variables.setUID( option );
   }
@@ -408,10 +397,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "date" ) ) {
     option = args->getOption( "date" );
 
-    kDebug() << "main | parse options | "
-              << "Start date before conversion: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Start date before conversion:"
+             << "(" << option << ")";
 
     startdate = QDate::fromString( option, Qt::ISODate );
     if ( !startdate.isValid() ) {
@@ -420,10 +408,9 @@ int main( int argc, char *argv[] )
            << endl;
       return 1;
     }
-    kDebug() << "main | parse options | "
-              << "Start date after conversion: "
-              << "(" << startdate.toString() << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Start date after conversion:"
+             << "(" << startdate.toString() << ")";
   }
 
   /*
@@ -432,10 +419,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "time" ) ) {
     option = args->getOption( "time" );
 
-    kDebug() << "main | parse options | "
-              << "Start time before conversion : "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Start time before conversion :"
+             << "(" << option << ")";
 
     if ( option.toUpper() != "FLOAT" ) {
       starttime = QTime::fromString( option, Qt::ISODate );
@@ -445,15 +431,13 @@ int main( int argc, char *argv[] )
              << endl;
         return 1;
       }
-      kDebug() << "main | parse options | "
-                << "Start time after conversion: "
-                << "(" << starttime.toString() << ")"
-                << endl;
+      kDebug() << "main | parse options |"
+               << "Start time after conversion:"
+               << "(" << starttime.toString() << ")";
     } else {
       variables.setFloating( true );
-      kDebug() << "main | parse options | "
-                << "Floating event time specified"
-                << endl;
+      kDebug() << "main | parse options |"
+               << "Floating event time specified";
     }
   }
 
@@ -463,10 +447,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "end-date" ) ) {
     option = args->getOption( "end-date" );
 
-    kDebug() << "main | parse options | "
-              << "End date before conversion: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "End date before conversion:"
+             << "(" << option << ")";
 
     enddate = QDate::fromString( option, Qt::ISODate );
     if ( !enddate.isValid() ) {
@@ -475,10 +458,9 @@ int main( int argc, char *argv[] )
            << endl;
       return 1;
     }
-    kDebug() << "main | parse options | "
-              << "End date after conversion: "
-              << "(" << enddate.toString() << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "End date after conversion:"
+             << "(" << enddate.toString() << ")";
   }
 
   /*
@@ -488,9 +470,8 @@ int main( int argc, char *argv[] )
     bool ok;
 
     option = args->getOption( "show-next" );
-    kDebug() << "main | parse options | "
-              << "Show " << option << " days ahead"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Show" << option << "days ahead";
     variables.setDaysCount( option.toInt( &ok, 10 ) );
 
     if ( !ok ) {
@@ -502,10 +483,9 @@ int main( int argc, char *argv[] )
 
     enddate = startdate;
     enddate = enddate.addDays( variables.getDaysCount() );
-    kDebug() << "main | parse options | "
-              << "End date after conversion: "
-              << "(" << enddate.toString() << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "End date after conversion:"
+             << "(" << enddate.toString() << ")";
   }
 
   /*
@@ -514,10 +494,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "end-time" ) ) {
     option = args->getOption( "end-time" );
 
-    kDebug() << "main | parse options | "
-              << "End time before conversion: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "End time before conversion:"
+             << "(" << option << ")";
 
     if ( option.toUpper() != "FLOAT" ) {
       endtime = QTime::fromString( option, Qt::ISODate );
@@ -528,15 +507,13 @@ int main( int argc, char *argv[] )
         return 1;
       }
 
-      kDebug() << "main | parse options | "
-                << "End time after conversion: "
-                << "(" << endtime.toString() << ")"
-                << endl;
+      kDebug() << "main | parse options |"
+               << "End time after conversion:"
+               << "(" << endtime.toString() << ")";
     } else {
       variables.setFloating( true );
-      kDebug() << "main | parse options | "
-                << "Floating event time specified"
-                << endl;
+      kDebug() << "main | parse options |"
+               << "Floating event time specified";
     }
   }
 
@@ -547,10 +524,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "epoch-start" ) ) {
     option = args->getOption( "epoch-start" );
 
-    kDebug() << "main | parse options | "
-              << "Epoch start: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Epoch start:"
+             << "(" << option << ")";
 
     epochstart = ( time_t ) option.toULong( 0, 10 );
   }
@@ -562,10 +538,9 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "epoch-end" ) ) {
     option = args->getOption( "epoch-end" );
 
-    kDebug() << "main | parse options | "
-              << "Epoch end: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "Epoch end:"
+             << "(" << option << ")";
 
     epochend = ( time_t ) option.toULong( 0, 10 );
   }
@@ -582,10 +557,9 @@ int main( int argc, char *argv[] )
     option = args->getOption( "import" );
     variables.setImportFile( option );
 
-    kDebug() << "main | parse options | "
-              << "importing file from: "
-              << "(" << option << ")"
-              << endl;
+    kDebug() << "main | parse options |"
+             << "importing file from:"
+             << "(" << option << ")";
   }
 
   KonsoleKalendar *konsolekalendar = new KonsoleKalendar( &variables );
@@ -617,9 +591,8 @@ int main( int argc, char *argv[] )
 
     if ( create ) {
 
-      kDebug() << "main | createcalendar | "
-                << "check if calendar file already exists"
-                << endl;
+      kDebug() << "main | createcalendar |"
+               << "check if calendar file already exists";
 
       if ( remote ) {
         cout << i18n( "Attempting to create a remote file %1" ,
@@ -688,14 +661,12 @@ int main( int argc, char *argv[] )
   if ( !args->isSet( "end-date" ) && !args->isSet( "show-next" ) &&
        args->isSet( "date" ) ) {
     enddate = startdate;
-    kDebug() << "main | datetimestamp | "
-              << "setting enddate to startdate"
-              << endl;
+    kDebug() << "main | datetimestamp |"
+             << "setting enddate to startdate";
   } else if ( args->isSet( "end-date" ) && !args->isSet( "date" ) ) {
     startdate = enddate;
-    kDebug() << "main | datetimestamp | "
-              << "setting startdate to enddate"
-              << endl;
+    kDebug() << "main | datetimestamp |"
+             << "setting startdate to enddate";
   }
 
   // NOTE: If neither date nor end-date specified, then event will be today.
@@ -706,15 +677,13 @@ int main( int argc, char *argv[] )
   if ( !args->isSet( "end-time" ) && !args->isSet( "epoch-end" ) ) {
     if ( args->isSet( "time" ) ) {
       endtime = starttime.addSecs( 60 * 60 );  // end is 1 hour after start
-      kDebug() << "main | datetimestamp | "
-                << "setting endtime 1 hour after starttime"
-                << endl;
+      kDebug() << "main | datetimestamp |"
+               << "setting endtime 1 hour after starttime";
     } else if ( args->isSet( "epoch-start" ) ) {
       startdatetime = epochs.epoch2QDateTime( epochstart );
       enddatetime = startdatetime.addSecs( 60 * 60 );
-      kDebug() << "main | datetimestamp | "
-                << "setting endtime 1 hour after epochstart"
-                << endl;
+      kDebug() << "main | datetimestamp |"
+               << "setting endtime 1 hour after epochstart";
     }
   }
 
@@ -724,15 +693,13 @@ int main( int argc, char *argv[] )
   if ( !args->isSet( "time" ) && !args->isSet( "epoch-start" ) ) {
     if ( args->isSet( "end-time" ) ) {
       starttime = endtime.addSecs( -60 * 60 );  // start is 1 hour before end
-      kDebug() << "main | datetimestamp | "
-                << "setting starttime 1 hour before endtime"
-                << endl;
+      kDebug() << "main | datetimestamp |"
+               << "setting starttime 1 hour before endtime";
     } else if ( args->isSet( "epoch-end" ) ) {
       enddatetime = epochs.epoch2QDateTime( epochend );
       startdatetime = enddatetime.addSecs( -60 * 60 );
-      kDebug() << "main | datetimestamp | "
-                << "setting starttime 1 before after epochend"
-                << endl;
+      kDebug() << "main | datetimestamp |"
+               << "setting starttime 1 before after epochend";
     }
   }
 
@@ -742,30 +709,26 @@ int main( int argc, char *argv[] )
        !args->isSet( "end-time" ) && !args->isSet( "epoch-end" ) ) {
     // set default start date/time
     startdatetime = QDateTime::QDateTime( startdate, starttime );
-    kDebug() << "main | datetimestamp | "
-              << "setting startdatetime from "
-              << "default startdate (today) and starttime"
-              << endl;
+    kDebug() << "main | datetimestamp |"
+             << "setting startdatetime from"
+             << "default startdate (today) and starttime";
     // set default end date/time
     enddatetime = QDateTime::QDateTime( enddate, endtime );
-    kDebug() << "main | datetimestamp | "
-              << "setting enddatetime from "
-              << "default enddate (today) and endtime"
-              << endl;
+    kDebug() << "main | datetimestamp |"
+             << "setting enddatetime from"
+             << "default enddate (today) and endtime";
   }
 
   // Set startdatetime, enddatetime if still necessary
   if ( startdatetime.isNull() ) {
     startdatetime = QDateTime::QDateTime( startdate, starttime );
-    kDebug() << "main | datetimestamp | "
-              << "setting startdatetime from startdate and starttime"
-              << endl;
+    kDebug() << "main | datetimestamp |"
+             << "setting startdatetime from startdate and starttime";
   }
   if ( enddatetime.isNull() ) {
     enddatetime = QDateTime::QDateTime( enddate, endtime );
-    kDebug() << "main | datetimestamp | "
-              << "setting enddatetime from enddate and endtime"
-              << endl;
+    kDebug() << "main | datetimestamp |"
+             << "setting enddatetime from enddate and endtime";
   }
 
   // Float check for add mode:
@@ -774,9 +737,8 @@ int main( int argc, char *argv[] )
     if ( !args->isSet( "time" )        && !args->isSet( "end-time" ) &&
          !args->isSet( "epoch-start" ) && !args->isSet( "epoch-end" ) ) {
       variables.setFloating( true );
-      kDebug() << "main | floatingcheck | "
-                << "turn-on floating event"
-                << endl;
+      kDebug() << "main | floatingcheck |"
+               << "turn-on floating event";
     }
   }
 
@@ -796,11 +758,9 @@ int main( int argc, char *argv[] )
 
   // Some more debug prints
   kDebug() << "main | datetimestamp | StartDate="
-            << startdatetime.toString( Qt::TextDate )
-            << endl;
+           << startdatetime.toString( Qt::TextDate );
   kDebug() << "main | datetimestamp | EndDate="
-            << enddatetime.toString( Qt::TextDate )
-            << endl;
+           << enddatetime.toString( Qt::TextDate );
 
   /***************************************************************************
    * Sanity checks                                                           *
@@ -855,9 +815,8 @@ int main( int argc, char *argv[] )
   if ( add ) {
     if ( !konsolekalendar->isEvent( startdatetime, enddatetime,
                                      variables.getSummary() ) ) {
-      kDebug() << "main | modework | "
-                << "calling addEvent()"
-                << endl;
+      kDebug() << "main | modework |"
+               << "calling addEvent()";
       konsolekalendar->addEvent();
     } else {
       cout << i18n(
@@ -868,9 +827,8 @@ int main( int argc, char *argv[] )
   }
 
   if ( change ) {
-    kDebug() << "main | modework | "
-              << "calling changeEvent()"
-              << endl;
+    kDebug() << "main | modework |"
+             << "calling changeEvent()";
     if ( !variables.isUID() ) {
       cout << i18n( "Missing event UID: "
                     "use --uid command line option" ).toLocal8Bit().data()
@@ -882,15 +840,13 @@ int main( int argc, char *argv[] )
            << endl;
       return 1;
     }
-    kDebug() << "main | modework | "
-              << "successful changeEvent()"
-              << endl;
+    kDebug() << "main | modework |"
+             << "successful changeEvent()";
   }
 
   if ( del ) {
-    kDebug() << "main | modework | "
-              << "calling deleteEvent()"
-              << endl;
+    kDebug() << "main | modework |"
+             << "calling deleteEvent()";
     if ( !variables.isUID() ) {
       cout << i18n( "Missing event UID: "
                     "use --uid command line option" ).toLocal8Bit().data()
@@ -902,15 +858,13 @@ int main( int argc, char *argv[] )
            << endl;
       return 1;
     }
-    kDebug() << "main | modework | "
-              << "successful deleteEvent()"
-              << endl;
+    kDebug() << "main | modework |"
+             << "successful deleteEvent()";
   }
 
   if ( view ) {
-    kDebug() << "main | modework | "
-              << "calling showInstance() to view events"
-              << endl;
+    kDebug() << "main | modework |"
+             << "calling showInstance() to view events";
     if ( !konsolekalendar->showInstance() ) {
       cout << i18n( "Cannot open specified export file: %1" ,
          variables.getExportFile() ).toLocal8Bit().data()
@@ -924,8 +878,7 @@ int main( int argc, char *argv[] )
   calendarResource->close();
   delete calendarResource;
 
-  kDebug() << "main | exiting"
-            << endl;
+  kDebug() << "main | exiting";
 
   return 0;
 }
