@@ -22,43 +22,34 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include <q3buttongroup.h>
 #include <QCheckBox>
 
+#include <QBoxLayout>
+#include <QButtonGroup>
+#include <QEvent>
+#include <QFrame>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QKeyEvent>
 #include <QLabel>
 #include <QLayout>
-#include <q3listbox.h>
-#include <q3listview.h>
+#include <QList>
 #include <QPushButton>
-#include <q3signal.h>
-#include <QString>
 #include <QTextEdit>
 #include <QToolButton>
 
-//Added by qt3to4:
-#include <QGridLayout>
-#include <QKeyEvent>
-#include <QEvent>
-#include <QFrame>
-#include <QBoxLayout>
-#include <QList>
-#include <QVBoxLayout>
-
-#include <kacceleratormanager.h>
-#include <k3activelabel.h>
-#include <kapplication.h>
-#include <kcombobox.h>
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kdialog.h>
-#include <kiconloader.h>
-#include <kinputdialog.h>
-#include <klineedit.h>
-#include <k3listview.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kseparator.h>
-#include <kvbox.h>
+#include <KAcceleratorManager>
+#include <KApplication>
+#include <KComboBox>
+#include <KConfig>
+#include <KDebug>
+#include <KIconLoader>
+#include <KInputDialog>
+#include <KLineEdit>
+#include <KLocale>
+#include <KMessageBox>
+#include <KSeparator>
+#include <KVBox>
 
 #include "addresseditwidget.h"
 
@@ -102,11 +93,13 @@ AddressEditWidget::AddressEditWidget( QWidget *parent, const char *name )
            SLOT( updateAddressEdit() ) );
   layout->addWidget( mTypeCombo );
 
-  mAddressField = new K3ActiveLabel( this );
+  mAddressField = new QLabel( this );
   mAddressField->setFrameStyle( QFrame::Panel | QFrame::Sunken );
   mAddressField->setMinimumHeight( 20 );
   mAddressField->setAlignment( Qt::AlignTop );
-  mAddressField->setAcceptRichText( false );
+  mAddressField->setTextFormat( Qt::PlainText );
+  mAddressField->setTextInteractionFlags( 
+    Qt::TextSelectableByKeyboard | Qt::TextSelectableByMouse );
   layout->addWidget( mAddressField );
 
   mEditButton = new QPushButton( i18nc( "street/postal", "&Edit Addresses..." ), this );
@@ -228,16 +221,16 @@ void AddressEditWidget::updateAddressEdit()
   bool block = signalsBlocked();
   blockSignals( true );
 
-  mAddressField->setPlainText( "" );
+  mAddressField->setText( "" );
 
   if ( it != mAddressList.end() ) {
     KABC::Address a = *it;
     if ( !a.isEmpty() ) {
       if ( a.type() & KABC::Address::Work && mAddressee.realName() != mAddressee.organization() ) {
-        mAddressField->setPlainText( a.formattedAddress( mAddressee.realName(),
+        mAddressField->setText( a.formattedAddress( mAddressee.realName(),
                                    mAddressee.organization() ) );
       } else {
-        mAddressField->setPlainText( a.formattedAddress( mAddressee.realName() ) );
+        mAddressField->setText( a.formattedAddress( mAddressee.realName() ) );
       }
     }
   }
@@ -246,8 +239,7 @@ void AddressEditWidget::updateAddressEdit()
 }
 
 AddressEditDialog::AddressEditDialog( const KABC::Address::List &list,
-                                      int selected, QWidget *parent,
-                                      const char *name )
+                                      int selected, QWidget *parent )
   : KDialog(parent),
     mPreviousAddress( 0 )
 {
@@ -262,6 +254,7 @@ AddressEditDialog::AddressEditDialog( const KABC::Address::List &list,
 
   QGridLayout *topLayout = new QGridLayout( page );
   topLayout->setSpacing( spacingHint() );
+  topLayout->setMargin( 0 );
 
   mTypeCombo = new AddressTypeCombo( mAddressList, page );
   topLayout->addWidget( mTypeCombo, 0, 0, 1, 2 );
@@ -270,7 +263,7 @@ AddressEditDialog::AddressEditDialog( const KABC::Address::List &list,
   label->setAlignment( Qt::AlignTop | Qt::AlignLeft );
   topLayout->addWidget( label, 1, 0 );
   mStreetTextEdit = new QTextEdit( page );
-  mStreetTextEdit->setTextFormat( Qt::PlainText );
+  mStreetTextEdit->setAcceptRichText( false );
   label->setBuddy( mStreetTextEdit );
   topLayout->addWidget( mStreetTextEdit, 1, 1 );
 
@@ -601,23 +594,29 @@ AddressTypeDialog::AddressTypeDialog( KABC::Address::Type type, QWidget *parent
   QWidget *page = new QWidget(this);
   setMainWidget( page );
   QVBoxLayout *layout = new QVBoxLayout( page );
+  layout->setSpacing( KDialog::spacingHint() );
+  layout->setMargin( 0 );
 
   QGroupBox *box  = new QGroupBox( i18nc( "street/postal", "Address Types" ), page );
   layout->addWidget( box );
   mGroup = new QButtonGroup( box );
   mGroup->setExclusive ( false );
 
-  QHBoxLayout *buttonLayout = new QHBoxLayout( box );
+  QGridLayout *buttonLayout = new QGridLayout( box );
 
   mTypeList = KABC::Address::typeList();
   mTypeList.removeAll( KABC::Address::Pref );
 
   KABC::Address::TypeList::ConstIterator it;
   int i = 0;
+  int row = 0;
   for ( it = mTypeList.begin(); it != mTypeList.end(); ++it, ++i ) {
     QCheckBox *cb = new QCheckBox( KABC::Address::typeLabel( *it ), box );
     cb->setChecked( type & mTypeList[ i ] );
-    buttonLayout->addWidget( cb );
+    buttonLayout->addWidget( cb, row, i%3 );
+   
+    if( i%3 == 2 )
+        ++row;
     mGroup->addButton( cb );
   }
 }
