@@ -25,18 +25,17 @@
 
 #include <QLabel>
 #include <QLayout>
-#include <q3listbox.h>
 #include <QPushButton>
 #include <QTabWidget>
 #include <QTextEdit>
 #include <QToolButton>
 
-//Added by qt3to4:
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QGridLayout>
 
 #include <kabc/resource.h>
+#include <kabc/resourceabc.h>
 #include <kabc/stdaddressbook.h>
 #include <kacceleratormanager.h>
 #include <kconfig.h>
@@ -73,7 +72,7 @@ AddresseeEditorWidget::AddresseeEditorWidget( QWidget *parent )
   : AddresseeEditorBase( parent ),
     mBlockSignals( false ), mReadOnly( false )
 {
-  kDebug(5720) << "AddresseeEditorWidget()" << endl;
+  kDebug(5720) <<"AddresseeEditorWidget()";
 
   initGUI();
   mCategorySelectDialog = 0;
@@ -87,17 +86,29 @@ AddresseeEditorWidget::AddresseeEditorWidget( QWidget *parent )
 
 AddresseeEditorWidget::~AddresseeEditorWidget()
 {
-  kDebug(5720) << "~AddresseeEditorWidget()" << endl;
+  kDebug(5720) <<"~AddresseeEditorWidget()";
 }
 
 void AddresseeEditorWidget::setAddressee( const KABC::Addressee &addr )
 {
   if ( mAddressee.uid() == addr.uid() )
-	  return;
-
+    return;
   mAddressee = addr;
 
-  bool readOnly = ( !addr.resource() ? false : addr.resource()->readOnly() );
+  bool readOnly = false;
+  if ( KABC::Resource *res = addr.resource() ) {
+    if ( res->readOnly() ) {
+      readOnly = true;
+
+    //HACK: some resources have finer access control than "generic" resources
+    } else if ( res->inherits( "KPIM::ResourceAbc" ) ) {
+      KABC::ResourceABC *resAbc = static_cast<KABC::ResourceABC *>( res );
+
+      QString subresource = resAbc->uidToResourceMap()[ addr.uid() ];
+      if ( !subresource.isEmpty() )
+        readOnly |= !resAbc->subresourceWritable( subresource );
+    }
+  }
   setReadOnly( readOnly );
 
   load();
@@ -116,6 +127,8 @@ void AddresseeEditorWidget::textChanged( const QString& )
 void AddresseeEditorWidget::initGUI()
 {
   QVBoxLayout *layout = new QVBoxLayout( this );
+  layout->setMargin( 0 );
+  layout->setSpacing( KDialog::spacingHint() );
 
   mTabWidget = new QTabWidget( this );
   layout->addWidget( mTabWidget );
@@ -147,8 +160,8 @@ void AddresseeEditorWidget::setupTab1()
 
   // Person icon
   label = new QLabel( tab1 );
-  label->setPixmap( KIconLoader::global()->loadIcon( "personal", K3Icon::Desktop,
-                                                      K3Icon::SizeMedium ) );
+  label->setPixmap( KIconLoader::global()->loadIcon( "personal", KIconLoader::Desktop,
+                                                      KIconLoader::SizeMedium ) );
   layout->addWidget( label, 0, 0, 2, 1);
 
   // First name
@@ -203,7 +216,7 @@ void AddresseeEditorWidget::setupTab1()
   // Phone numbers (upper right)
   label = new QLabel( tab1 );
   label->setPixmap( KIconLoader::global()->loadIcon( "kaddressbook",
-                    K3Icon::Desktop, K3Icon::SizeMedium ) );
+                    KIconLoader::Desktop, KIconLoader::SizeMedium ) );
   layout->addWidget( label, 0, 3, 2, 1 );
 
   mPhoneEditWidget = new PhoneEditWidget( tab1 );
@@ -216,8 +229,8 @@ void AddresseeEditorWidget::setupTab1()
   //////////////////////////////////////
   // Addresses (lower left)
   label = new QLabel( tab1 );
-  label->setPixmap( KIconLoader::global()->loadIcon( "kfm_home", K3Icon::Desktop,
-                                                     K3Icon::SizeMedium ) );
+  label->setPixmap( KIconLoader::global()->loadIcon( "go-home", KIconLoader::Desktop,
+                                                     KIconLoader::SizeMedium ) );
   layout->addWidget( label, 5, 0, 2, 1);
 
   mAddressEditWidget = new AddressEditWidget( tab1 );
@@ -227,8 +240,8 @@ void AddresseeEditorWidget::setupTab1()
   //////////////////////////////////////
   // Email / Web (lower right)
   label = new QLabel( tab1 );
-  label->setPixmap( KIconLoader::global()->loadIcon( "email", K3Icon::Desktop,
-                                                     K3Icon::SizeMedium ) );
+  label->setPixmap( KIconLoader::global()->loadIcon( "email", KIconLoader::Desktop,
+                                                     KIconLoader::SizeMedium ) );
   layout->addWidget( label, 5, 3, 2, 1);
 
   mEmailWidget = new EmailEditWidget( tab1 );
@@ -239,39 +252,35 @@ void AddresseeEditorWidget::setupTab1()
   bar = new KSeparator( Qt::Horizontal, tab1 );
   layout->addWidget( bar, 7, 3, 1, 4 );
 
-  QHBoxLayout *homePageLayout = new QHBoxLayout();
-  homePageLayout->setSpacing( 7 );
-  homePageLayout->setMargin( 11 );
-
   label = new QLabel( tab1 );
-  label->setPixmap( KIconLoader::global()->loadIcon( "homepage", K3Icon::Desktop,
-                                                     K3Icon::SizeMedium ) );
-  homePageLayout->addWidget( label );
+  label->setPixmap( KIconLoader::global()->loadIcon( "homepage", KIconLoader::Desktop,
+                                                     KIconLoader::SizeMedium ) );
+  layout->addWidget( label, 9, 3, 1, 2, Qt::AlignTop );
+
+  QGridLayout *gridLayout = new QGridLayout;
+  gridLayout->setSpacing( 7 );
+  gridLayout->setMargin( 11 );
 
   label = new QLabel( i18nc( "<urlLabel>:", "%1:", KABC::Addressee::urlLabel() ), tab1 );
+
   mURLEdit = new KLineEdit( tab1 );
   connect( mURLEdit, SIGNAL( textChanged( const QString& ) ),
            SLOT( textChanged( const QString& ) ) );
   label->setBuddy( mURLEdit );
-  homePageLayout->addWidget( label );
-  homePageLayout->addWidget( mURLEdit );
-  layout->addLayout( homePageLayout, 8, 3, 1, 4 );
+  gridLayout->addWidget( label, 0, 0 );
+  gridLayout->addWidget( mURLEdit, 0, 1 );
 
-  QHBoxLayout *blogLayout = new QHBoxLayout();
-  blogLayout->setSpacing( 7 );
-  blogLayout->setMargin( 11 );
   label = new QLabel( i18n( "Blog feed:" ), tab1 );
-  blogLayout->addWidget( label );
   mBlogEdit = new KLineEdit( tab1 );
-  blogLayout->addWidget( mBlogEdit );
+  gridLayout->addWidget( label, 1, 0 );
+  gridLayout->addWidget( mBlogEdit, 1, 1 );
   connect( mBlogEdit, SIGNAL( textChanged( const QString & ) ),
            SLOT( textChanged( const QString & ) ) );
   label->setBuddy( mBlogEdit );
-  layout->addLayout( blogLayout, 9, 4, 1, 3 );
 
-  mIMWidget = new IMEditWidget( tab1, mAddressee );
+  mIMWidget = new IMEditWidget( tab1, mAddressee, gridLayout );
   connect( mIMWidget, SIGNAL( modified() ), SLOT( emitModified() ) );
-  layout->addWidget( mIMWidget, 10, 4, 1, 3 );
+  layout->addLayout( gridLayout, 8, 4, 3, 3 );
 
   layout->addItem( new QSpacerItem( 50, 0 ), 0, 6 );
 
@@ -319,8 +328,8 @@ void AddresseeEditorWidget::setupTab2()
 
   // Department
   label = new QLabel( tab2 );
-  label->setPixmap( KIconLoader::global()->loadIcon( "folder", K3Icon::Desktop,
-                                                     K3Icon::SizeMedium ) );
+  label->setPixmap( KIconLoader::global()->loadIcon( "folder", KIconLoader::Desktop,
+                                                     KIconLoader::SizeMedium ) );
   layout->addWidget( label, 0, 0, 2, 1 );
 
   label = new QLabel( i18n( "Department:" ), tab2 );
@@ -378,8 +387,8 @@ void AddresseeEditorWidget::setupTab2()
   // Personal info
 
   label = new QLabel( tab2 );
-  label->setPixmap( KIconLoader::global()->loadIcon( "personal", K3Icon::Desktop,
-                                                     K3Icon::SizeMedium ) );
+  label->setPixmap( KIconLoader::global()->loadIcon( "personal", KIconLoader::Desktop,
+                                                     KIconLoader::SizeMedium ) );
   layout->addWidget( label, 4, 0, 2, 1);
 
   label = new QLabel( i18n( "Nickname:" ), tab2 );
@@ -400,7 +409,7 @@ void AddresseeEditorWidget::setupTab2()
 
   label = new QLabel( i18n( "Birthdate:" ), tab2 );
   layout->addWidget( label, 4, 3 );
-  mBirthdayPicker = new KDateEdit( tab2 );
+  mBirthdayPicker = new KPIM::KDateEdit( tab2 );
   connect( mBirthdayPicker, SIGNAL( dateChanged( const QDate& ) ),
            SLOT( dateChanged( const QDate& ) ) );
   connect( mBirthdayPicker, SIGNAL( textChanged( const QString& ) ),
@@ -410,7 +419,7 @@ void AddresseeEditorWidget::setupTab2()
 
   label = new QLabel( i18n( "Anniversary:" ), tab2 );
   layout->addWidget( label, 5, 3 );
-  mAnniversaryPicker = new KDateEdit( tab2 );
+  mAnniversaryPicker = new KPIM::KDateEdit( tab2 );
   connect( mAnniversaryPicker, SIGNAL( dateChanged( const QDate& ) ),
            SLOT( dateChanged( const QDate& ) ) );
   connect( mAnniversaryPicker, SIGNAL( textChanged( const QString& ) ),
@@ -469,9 +478,11 @@ void AddresseeEditorWidget::setupAdditionalTabs()
   }
 
   // query the layout update
-  Q3DictIterator<ContactEditorTabPage> it( mTabPages );
-  for ( ; it.current(); ++it )
-    it.current()->updateLayout();
+  QHashIterator<QString, ContactEditorTabPage*> it( mTabPages );
+  while ( it.hasNext() ) {
+    it.next();
+    it.value()->updateLayout();
+  }
 }
 
 void AddresseeEditorWidget::setupCustomFieldsTabs()
@@ -502,7 +513,7 @@ void AddresseeEditorWidget::setupCustomFieldsTabs()
 
 void AddresseeEditorWidget::load()
 {
-  kDebug(5720) << "AddresseeEditorWidget::load()" << endl;
+  kDebug(5720) <<"AddresseeEditorWidget::load()";
 
   // Block signals in case anything tries to emit modified
   // CS: This doesn't seem to work.
@@ -538,6 +549,10 @@ void AddresseeEditorWidget::load()
 
   mRoleEdit->setText( mAddressee.role() );
   mOrgEdit->setText( mAddressee.organization() );
+  mDepartmentEdit->setText( mAddressee.department() );
+  // compatibility with older versions
+  if ( mAddressee.department().isEmpty() )
+    mDepartmentEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-Department" ) );
   mURLEdit->setUrl( mAddressee.url() );
   mURLEdit->home( false );
   mBlogEdit->setUrl( mAddressee.custom( "KADDRESSBOOK", "BlogFeed" ) );
@@ -560,14 +575,15 @@ void AddresseeEditorWidget::load()
   mSpouseEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-SpousesName" ) );
   mManagerEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-ManagersName" ) );
   mAssistantEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-AssistantsName" ) );
-  mDepartmentEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-Department" ) );
   mOfficeEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-Office" ) );
   mProfessionEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-Profession" ) );
   mTitleEdit->setText( mAddressee.title() );
 
-  Q3DictIterator<ContactEditorTabPage> it( mTabPages );
-  for ( ; it.current(); ++it )
-    it.current()->loadContact( &mAddressee );
+  QHashIterator<QString, ContactEditorTabPage*> it( mTabPages );
+  while ( it.hasNext() ) {
+    it.next();
+    it.value()->loadContact( &mAddressee );
+  }
 
   blockSignals( block );
   mBlockSignals = false;
@@ -581,6 +597,7 @@ void AddresseeEditorWidget::save()
 
   mAddressee.setRole( mRoleEdit->text() );
   mAddressee.setOrganization( mOrgEdit->text() );
+  mAddressee.setDepartment( mDepartmentEdit->text() );
   mAddressee.setUrl( KUrl( mURLEdit->text().trimmed() ) );
   if ( !mBlogEdit->text().isEmpty() )
     mAddressee.insertCustom( "KADDRESSBOOK", "BlogFeed", mBlogEdit->text() );
@@ -616,10 +633,6 @@ void AddresseeEditorWidget::save()
   else
     mAddressee.removeCustom( "KADDRESSBOOK", "X-AssistantsName" );
 
-  if ( !mDepartmentEdit->text().isEmpty() )
-    mAddressee.insertCustom( "KADDRESSBOOK", "X-Department", mDepartmentEdit->text() );
-  else
-    mAddressee.removeCustom( "KADDRESSBOOK", "X-Department" );
   if ( !mOfficeEdit->text().isEmpty() )
     mAddressee.insertCustom( "KADDRESSBOOK", "X-Office", mOfficeEdit->text() );
   else
@@ -666,9 +679,11 @@ void AddresseeEditorWidget::save()
         ++addressIter )
     mAddressee.insertAddress( *addressIter );
 
-  Q3DictIterator<ContactEditorTabPage> it( mTabPages );
-  for ( ; it.current(); ++it )
-    it.current()->storeContact( &mAddressee );
+  QHashIterator<QString, ContactEditorTabPage*> it( mTabPages );
+  while ( it.hasNext() ) {
+    it.next();
+    it.value()->storeContact( &mAddressee );
+  }
 
   mDirty = false;
 }
@@ -882,9 +897,11 @@ void AddresseeEditorWidget::setReadOnly( bool readOnly )
   mAnniversaryPicker->setEnabled( !readOnly );
   mNoteEdit->setReadOnly( mReadOnly );
 
-  Q3DictIterator<ContactEditorTabPage> it( mTabPages );
-  for ( ; it.current(); ++it )
-    it.current()->setReadOnly( readOnly );
+  QHashIterator<QString, ContactEditorTabPage*> it( mTabPages );
+  while ( it.hasNext() ) {
+    it.next();
+    it.value()->setReadOnly( readOnly );
+  }
 }
 
 #include "addresseeeditorwidget.moc"
