@@ -22,15 +22,13 @@
 
 #include "distributionlistwidget.h"
 
-#include <q3buttongroup.h>
-#include <q3button.h>
+#include <QButtonGroup>
 #include <QComboBox>
+#include <QGroupBox>
 #include <QLabel>
 #include <QLayout>
-#include <q3listview.h>
 #include <QPushButton>
 #include <QRadioButton>
-//Added by qt3to4:
 #include <QGridLayout>
 #include <QKeyEvent>
 #include <QEvent>
@@ -117,12 +115,12 @@ class DeletePressedCatcher : public QObject
     DistributionListWidget *mWidget;
 };
 
-class ContactItem : public Q3ListViewItem
+class ContactItem : public QTreeWidgetItem
 {
   public:
     ContactItem( DistributionListView *parent, const KABC::Addressee &addressee,
                const QString &email = QString() ) :
-      Q3ListViewItem( parent ),
+      QTreeWidgetItem( parent ),
       mAddressee( addressee ),
       mEmail( email )
     {
@@ -146,12 +144,6 @@ class ContactItem : public Q3ListViewItem
       return mEmail;
     }
 
-  protected:
-    bool acceptDrop( const QMimeSource* ) const
-    {
-      return true;
-    }
-
   private:
     KABC::Addressee mAddressee;
     QString mEmail;
@@ -159,13 +151,10 @@ class ContactItem : public Q3ListViewItem
 
 DistributionListWidget::DistributionListWidget( KAB::Core *core, QWidget *parent )
   : KAB::ExtensionWidget( core, parent )
-#ifndef KDEPIM_NEW_DISTRLISTS
-  , mManager( 0 )
-#endif
 {
   QGridLayout *topLayout = new QGridLayout( this );
   topLayout->setSpacing( KDialog::spacingHint() );
-  topLayout->setMargin( KDialog::marginHint() );
+  topLayout->setMargin( 0 );
 
   mNameCombo = new QComboBox( this );
   topLayout->addWidget( mNameCombo, 0, 0 );
@@ -184,17 +173,15 @@ DistributionListWidget::DistributionListWidget( KAB::Core *core, QWidget *parent
   connect( mRemoveListButton, SIGNAL( clicked() ), SLOT( removeList() ) );
 
   mContactView = new DistributionListView( this );
-  mContactView->addColumn( i18n( "Name" ) );
-  mContactView->addColumn( i18n( "Email" ) );
-  mContactView->addColumn( i18n( "Use Preferred" ) );
+  mContactView->setHeaderLabels( QStringList() << i18n( "Name" )
+      << i18n( "Email" ) << i18n( "Use Preferred" ) );
   mContactView->setEnabled( false );
   mContactView->setAllColumnsShowFocus( true );
-  mContactView->setFullWidth( true );
   topLayout->addWidget( mContactView, 1, 0, 1, 4 );
-  connect( mContactView, SIGNAL( selectionChanged() ),
+  connect( mContactView, SIGNAL( itemSelectionChanged() ),
            SLOT( selectionContactViewChanged() ) );
-  connect( mContactView, SIGNAL( dropped( QDropEvent*, Q3ListViewItem* ) ),
-           SLOT( dropped( QDropEvent*, Q3ListViewItem* ) ) );
+  connect( mContactView, SIGNAL( dropped( QDropEvent* ) ),
+           SLOT( dropped( QDropEvent* ) ) );
 
   mAddContactButton = new QPushButton( i18n( "Add Contact" ), this );
   mAddContactButton->setEnabled( false );
@@ -212,51 +199,34 @@ DistributionListWidget::DistributionListWidget( KAB::Core *core, QWidget *parent
   topLayout->addWidget( mRemoveContactButton, 2, 3 );
   connect( mRemoveContactButton, SIGNAL( clicked() ), SLOT( removeContact() ) );
 
-#ifdef KDEPIM_NEW_DISTRLISTS
   // When contacts are changed, update both distr list combo and contents of displayed distr list
   connect( core, SIGNAL( contactsUpdated() ),
            this, SLOT( updateNameCombo() ) );
-#else
-  mManager = new KABC::DistributionListManager( core->addressBook() );
-
-  connect( KABC::DistributionListWatcher::self(), SIGNAL( changed() ),
-           this, SLOT( updateNameCombo() ) );
-#endif
 
   connect( core->addressBook(), SIGNAL( addressBookChanged( AddressBook* ) ),
            this, SLOT( updateNameCombo() ) );
 
+#ifndef KDEPIM_NEW_DISTRLISTS
+  connect( this, SIGNAL( modified() ), core, SLOT( setModified() ) );
+#endif
+
   updateNameCombo();
 
   QObject *catcher = new DeletePressedCatcher( this );
   installEventFilter( catcher );
   mContactView->installEventFilter( catcher );
 
-  mContactView->restoreLayout( KGlobal::config().data(), "DistributionListViewColumns" );
-
   KAcceleratorManager::manage( this );
 }
 
 DistributionListWidget::~DistributionListWidget()
 {
-#ifndef KDEPIM_NEW_DISTRLISTS
-  delete mManager;
-#endif
-
-  mContactView->saveLayout( KGlobal::config().data(), "DistributionListViewColumns" );
-}
-
-void DistributionListWidget::save()
-{
-#ifndef KDEPIM_NEW_DISTRLISTS
-  mManager->save();
-#endif
 }
 
 void DistributionListWidget::selectionContactViewChanged()
 {
   ContactItem *contactItem =
-                  static_cast<ContactItem *>( mContactView->selectedItem() );
+                  static_cast<ContactItem *>( mContactView->currentItem() );
   bool state = contactItem;
 
   mChangeEmailButton->setEnabled( state );
@@ -268,7 +238,7 @@ bool DistributionListWidget::alreadyExists( const QString& distrListName ) const
 #ifdef KDEPIM_NEW_DISTRLISTS
   return core()->distributionListNames().contains( distrListName );
 #else
-  return mManager->listNames().contains( distrListName );
+  return core()->addressBook()->findDistributionListByName( distrListName ) != 0;
 #endif
 }
 
@@ -298,14 +268,21 @@ void DistributionListWidget::createList()
   core()->addressBook()->insertAddressee( dist );
 
 #else
-  new KABC::DistributionList( mManager, newName );
+  KABC::Resource* resource = core()->requestResource( this );
+  if ( !resource )
+    return;
+
+  core()->addressBook()->createDistributionList( newName, resource );
   changed();
 
   updateNameCombo();
 #endif
 
   // Select the new one in the list
-  mNameCombo->setItemText( mNameCombo->currentIndex(), newName );
+  int index = mNameCombo->findText( newName );
+  if ( index != -1 )
+    mNameCombo->setCurrentIndex( index );
+
   // Display the contents of the list we just selected (well, it's empty)
   updateContactView();
 }
@@ -335,13 +312,17 @@ void DistributionListWidget::editList()
 
   changed( dist );
 #else
-  KABC::DistributionList *list = mManager->list( oldName );
-  list->setName( newName );
-  updateNameCombo();
+  KABC::DistributionList *list = core()->addressBook()->findDistributionListByName( oldName );
+  if ( list ) {
+    list->setName( newName );
+    updateNameCombo();
+  }
 #endif
 
   // Select the new name in the list (updateNameCombo couldn't know we wanted that one)
-  mNameCombo->setItemText( mNameCombo->currentIndex(), newName );
+  int index = mNameCombo->findText( newName );
+  if ( index != -1 )
+    mNameCombo->setCurrentIndex( index );
   // Display the contents of the list we just selected
   updateContactView();
 }
@@ -364,12 +345,15 @@ void DistributionListWidget::removeList()
   emit deleted( QStringList( dist.uid() ) );
   core()->addressBook()->removeAddressee( dist );
 #else
-  mManager->remove( mManager->list( mNameCombo->currentText() ) );
-  mNameCombo->removeItem( mNameCombo->currentIndex() );
+  KABC::DistributionList* list = core()->addressBook()->findDistributionListByName( mNameCombo->currentText() );
+  if ( list ) {
+    core()->addressBook()->removeDistributionList( list );
+    mNameCombo->removeItem( mNameCombo->currentIndex() );
 
-  updateContactView();
+    updateContactView();
 
-  changed();
+    changed();
+  }
 #endif
 }
 
@@ -379,11 +363,11 @@ void DistributionListWidget::addContact()
   KPIM::DistributionList dist = KPIM::DistributionList::findByName(
     core()->addressBook(), mNameCombo->currentText() );
   if ( dist.isEmpty() ) { // not found
-    kDebug(5720) << k_funcinfo << mNameCombo->currentText() << " not found" << endl;
+    kDebug(5720) << mNameCombo->currentText() <<" not found";
     return;
   }
 #else
-  KABC::DistributionList *list = mManager->list( mNameCombo->currentText() );
+  KABC::DistributionList *list = core()->addressBook()->findDistributionListByName( mNameCombo->currentText() );
   if ( !list )
     return;
   KABC::DistributionList& dist = *list;
@@ -411,14 +395,14 @@ void DistributionListWidget::removeContact()
   if ( dist.isEmpty() ) // not found
     return;
 #else
-  KABC::DistributionList *list = mManager->list( mNameCombo->currentText() );
+  KABC::DistributionList *list = core()->addressBook()->findDistributionListByName( mNameCombo->currentText() );
   if ( !list )
     return;
   KABC::DistributionList& dist = *list;
 #endif
 
   ContactItem *contactItem =
-                    static_cast<ContactItem *>( mContactView->selectedItem() );
+                    static_cast<ContactItem *>( mContactView->currentItem() );
   if ( !contactItem )
     return;
 
@@ -441,14 +425,14 @@ void DistributionListWidget::changeEmail()
   if ( dist.isEmpty() ) // not found
     return;
 #else
-  KABC::DistributionList *list = mManager->list( mNameCombo->currentText() );
+  KABC::DistributionList *list = core()->addressBook()->findDistributionListByName( mNameCombo->currentText() );
   if ( !list )
     return;
   KABC::DistributionList& dist = *list;
 #endif
 
   ContactItem *contactItem =
-                    static_cast<ContactItem *>( mContactView->selectedItem() );
+                    static_cast<ContactItem *>( mContactView->currentItem() );
   if ( !contactItem )
     return;
 
@@ -481,7 +465,7 @@ void DistributionListWidget::updateContactView()
       core()->addressBook(), mNameCombo->currentText() );
   isListSelected = !dist.isEmpty();
 #else
-  KABC::DistributionList *list = mManager->list( mNameCombo->currentText() );
+  KABC::DistributionList *list = core()->addressBook()->findDistributionListByName( mNameCombo->currentText() );
   isListSelected = list != 0;
 #endif
   if ( !isListSelected ) {
@@ -500,14 +484,16 @@ void DistributionListWidget::updateContactView()
 #ifdef KDEPIM_NEW_DISTRLISTS
   const KPIM::DistributionList::Entry::List entries = dist.entries( core()->addressBook() );
   KPIM::DistributionList::Entry::List::ConstIterator it;
+  for ( it = entries.begin(); it != entries.end(); ++it, ++entryCount )
+    new ContactItem( mContactView, (*it).addressee, (*it).email );
 #else
   const KABC::DistributionList::Entry::List entries = list->entries();
   KABC::DistributionList::Entry::List::ConstIterator it;
-#endif
   for ( it = entries.begin(); it != entries.end(); ++it, ++entryCount )
     new ContactItem( mContactView, (*it).addressee(), (*it).email() );
+#endif
 
-  bool state = mContactView->selectedItem() != 0;
+  bool state = mContactView->currentItem() != 0;
   mChangeEmailButton->setEnabled( state );
   mRemoveContactButton->setEnabled( state );
 
@@ -521,11 +507,11 @@ void DistributionListWidget::updateNameCombo()
 #ifdef KDEPIM_NEW_DISTRLISTS
   const QStringList names = core()->distributionListNames();
 #else
-  mManager->load();
-  const QStringList names = mManager->listNames();
+  const QStringList names = core()->addressBook()->allDistributionListNames();
 #endif
   mNameCombo->addItems( names );
-  mNameCombo->setCurrentIndex( qMin( pos, (int)names.count() - 1 ) );
+  if ( pos != -1  && mNameCombo->count() > 0 )
+    mNameCombo->setCurrentIndex( qMin( pos, (int)names.count() - 1 ) );
 
   updateContactView();
 }
@@ -541,7 +527,7 @@ void DistributionListWidget::dropEvent( QDropEvent *e )
   if ( dist.isEmpty() )
     return;
 #else
-  KABC::DistributionList *list = mManager->list( mNameCombo->currentText() );
+  KABC::DistributionList *list = core()->addressBook()->findDistributionListByName( mNameCombo->currentText() );
   if ( !list )
     return;
   KABC::DistributionList& dist = *list;
@@ -549,7 +535,7 @@ void DistributionListWidget::dropEvent( QDropEvent *e )
 
   const QMimeData *md = e->mimeData();
   KABC::Addressee::List lst;
-  if ( KVCardDrag::fromMimeData( md, lst ) ) {
+  if ( KPIM::KVCardDrag::fromMimeData( md, lst ) ) {
 
     for ( KABC::Addressee::List::ConstIterator it = lst.begin(); it != lst.end(); ++it )
       dist.insertEntry( *it );
@@ -579,7 +565,7 @@ QString DistributionListWidget::identifier() const
   return "distribution_list_editor";
 }
 
-void DistributionListWidget::dropped( QDropEvent *e, Q3ListViewItem* )
+void DistributionListWidget::dropped( QDropEvent *e )
 {
   dropEvent( e );
 }
@@ -592,16 +578,16 @@ void DistributionListWidget::changed( const KABC::Addressee& dist )
 #else
 void DistributionListWidget::changed()
 {
-  save();
+  emit modified();
 }
 #endif
 
 DistributionListView::DistributionListView( QWidget *parent )
-  : K3ListView( parent )
+  : QTreeWidget( parent )
 {
-  setDragEnabled( true );
-  setAcceptDrops( true );
+  setDragDropMode( DragDrop );
   setAllColumnsShowFocus( true );
+  setRootIsDecorated( false );
 }
 
 void DistributionListView::dragEnterEvent( QDragEnterEvent* e )
@@ -609,22 +595,16 @@ void DistributionListView::dragEnterEvent( QDragEnterEvent* e )
   e->setAccepted( e->mimeData()->hasText() );
 }
 
-void DistributionListView::viewportDragMoveEvent( QDragMoveEvent *e )
+void DistributionListView::dragMoveEvent( QDragMoveEvent *e )
 {
   e->setAccepted( e->mimeData()->hasText() );
 }
 
-void DistributionListView::viewportDropEvent( QDropEvent *e )
-{
-  emit dropped( e, 0 );
-}
-
 void DistributionListView::dropEvent( QDropEvent *e )
 {
-  emit dropped( e, 0 );
+  emit dropped( e );
 }
 
-
 EmailSelector::EmailSelector( const QStringList &emails,
                               const QString &current, QWidget *parent )
   : KDialog( parent )
@@ -637,29 +617,38 @@ EmailSelector::EmailSelector( const QStringList &emails,
   setMainWidget( topFrame );
   QBoxLayout *topLayout = new QVBoxLayout( topFrame );
 
-  mButtonGroup = new Q3ButtonGroup( 1, Qt::Horizontal, i18n("Email Addresses"),
-                                   topFrame );
-  mButtonGroup->setRadioButtonExclusive( true );
-  topLayout->addWidget( mButtonGroup );
+  QGroupBox *group = new QGroupBox( i18n( "Email Addresses" ), topFrame );
+  topLayout->addWidget( group );
+  group->setLayout( new QVBoxLayout() );
+  group->layout()->setMargin( KDialog::marginHint() );
+  group->layout()->setSpacing( KDialog::spacingHint() );
 
-  QRadioButton *button = new QRadioButton( i18n("Preferred address"), mButtonGroup );
-  button->setDown( true );
+  mButtonGroup = new QButtonGroup( this );
+  mButtonGroup->setExclusive( true );
+
+  QRadioButton *button = new QRadioButton( i18n("Preferred address"), group );
+  mButtonGroup->addButton( button, 0 );
+  group->layout()->addWidget( button );
+  button->setChecked( true );
   mEmailMap.insert( mButtonGroup->id( button ), "" );
 
+  int id = 0;
   QStringList::ConstIterator it;
   for ( it = emails.begin(); it != emails.end(); ++it ) {
-    button = new QRadioButton( *it, mButtonGroup );
+    button = new QRadioButton( *it, group );
+    mButtonGroup->addButton( button, ++id );
+    group->layout()->addWidget( button );
     mEmailMap.insert( mButtonGroup->id( button ), *it );
     if ( (*it) == current )
-      button->setDown( true );
+      button->setChecked( true );
   }
 }
 
 QString EmailSelector::selected() const
 {
-  QAbstractButton *button = mButtonGroup->selected();
-  if ( button )
-    return mEmailMap[ mButtonGroup->id( button ) ];
+  int id = mButtonGroup->checkedId();
+  if ( id >= 0 )
+    return mEmailMap[ id ];
 
   return QString();
 }
@@ -669,7 +658,7 @@ QString EmailSelector::getEmail( const QStringList &emails,
 {
   EmailSelector dlg( emails, current, parent );
   if(dlg.exec())
-  { 
+  {
      canceled = false;
      return dlg.selected();
   }
