@@ -26,9 +26,7 @@
 #include <QFile>
 #include <QLayout>
 #include <QRegExp>
-#include <q3vbox.h>
 #include <QSplitter>
-//Added by qt3to4:
 #include <QVBoxLayout>
 #include <QList>
 #include <QHBoxLayout>
@@ -56,6 +54,7 @@
 #include <kstatusbar.h>
 #include <kstandardaction.h>
 #include <KStandardGuiItem>
+#include <kundostack.h>
 #include <kxmlguiclient.h>
 #include <ktoolbar.h>
 #include <libkdepim/addresseeview.h>
@@ -109,7 +108,7 @@ KABCore::KABCore( KXMLGUIClient *client, bool readWrite, QWidget *parent,
   if ( file.isEmpty() ) {
     mAddressBook = KABC::StdAddressBook::self( true );
   } else {
-    kDebug(5720) << "KABCore(): document '" << file << "'" << endl;
+    kDebug(5720) <<"KABCore(): document '" << file <<"'";
     mAddressBook = KABC::StdAddressBook::self( true );
     /*
     mAddressBook = new KABC::AddressBook;
@@ -121,8 +120,6 @@ KABCore::KABCore( KXMLGUIClient *client, bool readWrite, QWidget *parent,
   }
   mAddressBook->setErrorHandler( new KABC::GuiErrorHandler( mWidget ) );
 
-  mAddressBook->addCustomField( i18n( "Department" ), KABC::Field::Organization,
-                                "X-Department", "KADDRESSBOOK" );
   mAddressBook->addCustomField( i18n( "Profession" ), KABC::Field::Organization,
                                 "X-Profession", "KADDRESSBOOK" );
   mAddressBook->addCustomField( i18n( "Assistant's Name" ), KABC::Field::Organization,
@@ -182,8 +179,10 @@ KABCore::KABCore( KXMLGUIClient *client, bool readWrite, QWidget *parent,
 
   mAddressBookService = new KAddressBookService( this );
 
-  mCommandHistory = new K3CommandHistory( actionCollection(), true );
-  connect( mCommandHistory, SIGNAL( commandExecuted(K3Command *) ),
+  mCommandHistory = new KUndoStack( this );
+  mCommandHistory->createUndoAction( actionCollection() );
+  mCommandHistory->createRedoAction( actionCollection() );
+  connect( mCommandHistory, SIGNAL( indexChanged( int ) ),
            mSearchManager, SLOT( reload() ) );
 
   mSearchManager->reload();
@@ -431,7 +430,7 @@ void KABCore::deleteContacts( const QStringList &uids )
       return;
 
     DeleteCommand *command = new DeleteCommand( mAddressBook, uids );
-    mCommandHistory->addCommand( command );
+    mCommandHistory->push( command );
 
     // now if we deleted anything, refresh
     setContactSelected( QString() );
@@ -457,7 +456,7 @@ void KABCore::cutContacts()
 
   if ( uidList.size() > 0 ) {
     CutCommand *command = new CutCommand( mAddressBook, uidList );
-    mCommandHistory->addCommand( command );
+    mCommandHistory->push( command );
 
     setModified( true );
   }
@@ -484,7 +483,7 @@ void KABCore::pasteContacts( KABC::Addressee::List &list )
     (*it).setResource( resource );
 
   PasteCommand *command = new PasteCommand( this, list );
-  mCommandHistory->addCommand( command );
+  mCommandHistory->push( command );
 
   setModified( true );
 }
@@ -508,10 +507,10 @@ void KABCore::mergeContacts()
   }
 
   DeleteCommand *command = new DeleteCommand( mAddressBook, uids );
-  mCommandHistory->addCommand( command );
+  mCommandHistory->push( command );
 
   EditCommand *editCommand = new EditCommand( mAddressBook, origAddr, addr );
-  mCommandHistory->addCommand( editCommand );
+  mCommandHistory->push( editCommand );
 
   mSearchManager->reload();
 }
@@ -593,7 +592,7 @@ void KABCore::contactModified( const KABC::Addressee &addr )
     command = new EditCommand( mAddressBook, origAddr, addr );
   }
 
-  mCommandHistory->addCommand( command );
+  mCommandHistory->push( command );
 
   setContactSelected( addr.uid() );
   setModified( true );
@@ -658,9 +657,9 @@ void KABCore::importVCard( const KUrl &url )
   mXXPortManager->importVCard( url );
 }
 
-void KABCore::importVCard( const QString &vCardURL )
+void KABCore::importVCardFromData( const QString &vCard )
 {
-  mXXPortManager->importVCard( vCardURL );
+  mXXPortManager->importVCardFromData( vCard );
 }
 
 void KABCore::editContact( const QString &uid )
@@ -678,7 +677,7 @@ void KABCore::editContact( const QString &uid )
 
   KABC::Addressee addr = mAddressBook->findByUid( localUID );
   if ( !addr.isEmpty() ) {
-    AddresseeEditorDialog *dialog = mEditorDict.find( addr.uid() );
+    AddresseeEditorDialog *dialog = mEditorDict.value( addr.uid() );
     if ( !dialog ) {
 
       if ( addr.resource() && !addr.resource()->readOnly() )
@@ -791,7 +790,7 @@ void KABCore::extensionModified( const KABC::Addressee::List &list )
         command = new EditCommand( mAddressBook, origAddr, *it );
 
       mCommandHistory->blockSignals( true );
-      mCommandHistory->addCommand( command );
+      mCommandHistory->push( command );
       mCommandHistory->blockSignals( false );
     }
 
@@ -802,7 +801,7 @@ void KABCore::extensionModified( const KABC::Addressee::List &list )
 void KABCore::extensionDeleted( const QStringList &uidList )
 {
   DeleteCommand *command = new DeleteCommand( mAddressBook, uidList );
-  mCommandHistory->addCommand( command );
+  mCommandHistory->push( command );
 
   // now if we deleted anything, refresh
   setContactSelected( QString() );
@@ -1083,7 +1082,7 @@ void KABCore::initActions()
   action->setText( i18n( "&New Contact..." ) );
   connect(action, SIGNAL(triggered(bool)), SLOT( newContact() ));
   action->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_N));
-  action->setWhatsThis( i18n( "Create a new contact<p>You will be presented with a dialog where you can add all data about a person, including addresses and phone numbers." ) );
+  action->setWhatsThis( i18n( "Create a new contact<p>You will be presented with a dialog where you can add all data about a person, including addresses and phone numbers.</p>" ) );
 
   mActionMailVCard = coll->addAction( "file_mail_vcard" );
   mActionMailVCard->setIcon( KIcon("mail_post_to") );
@@ -1100,7 +1099,7 @@ void KABCore::initActions()
   mActionEditAddressee->setIcon( KIcon("edit") );
   mActionEditAddressee->setText( i18n( "&Edit Contact..." ) );
   connect(mActionEditAddressee, SIGNAL(triggered(bool) ), SLOT( editContact() ));
-  mActionEditAddressee->setWhatsThis( i18n( "Edit a contact<p>You will be presented with a dialog where you can change all data about a person, including addresses and phone numbers." ) );
+  mActionEditAddressee->setWhatsThis( i18n( "Edit a contact<p>You will be presented with a dialog where you can change all data about a person, including addresses and phone numbers.</p>" ) );
 
   mActionMerge = coll->addAction( "edit_merge" );
   mActionMerge->setText( i18n( "&Merge Contacts" ) );
@@ -1130,7 +1129,7 @@ void KABCore::initActions()
   mActionStoreAddresseeIn->setIcon( KIcon("kaddressbook") );
   mActionStoreAddresseeIn->setText( i18n( "St&ore Contact In..." ) );
   connect(mActionStoreAddresseeIn, SIGNAL(triggered(bool) ), SLOT( storeContactIn() ));
-  mActionStoreAddresseeIn->setWhatsThis( i18n( "Store a contact in a different Addressbook<p>You will be presented with a dialog where you can select a new storage place for this contact." ) );
+  mActionStoreAddresseeIn->setWhatsThis( i18n( "Store a contact in a different Addressbook<p>You will be presented with a dialog where you can select a new storage place for this contact.</p>" ) );
 
   // settings menu
   mActionJumpBar = coll->add<KToggleAction>( "options_show_jump_bar" );
@@ -1163,13 +1162,13 @@ void KABCore::initActions()
   action->setIcon( KIcon( "edit-find" ) );
   action->setText( i18n( "&Lookup Addresses in LDAP Directory..." ) );
   connect(action, SIGNAL(triggered(bool)), SLOT( openLDAPDialog() ));
-  action->setWhatsThis( i18n( "Search for contacts on a LDAP server<p>You will be presented with a dialog, where you can search for contacts and select the ones you want to add to your local address book." ) );
+  action->setWhatsThis( i18n( "Search for contacts on a LDAP server<p>You will be presented with a dialog, where you can search for contacts and select the ones you want to add to your local address book.</p>" ) );
 
   mActionWhoAmI = coll->addAction( "edit_set_personal" );
   mActionWhoAmI->setIcon( KIcon("personal") );
   mActionWhoAmI->setText( i18n( "Set as Personal Contact Data" ) );
   connect(mActionWhoAmI, SIGNAL(triggered(bool) ), SLOT( setWhoAmI() ));
-  mActionWhoAmI->setWhatsThis( i18n( "Set the personal contact<p>The data of this contact will be used in many other KDE applications, so you do not have to input your personal data several times." ) );
+  mActionWhoAmI->setWhatsThis( i18n( "Set the personal contact<p>The data of this contact will be used in many other KDE applications, so you do not have to input your personal data several times.</p>" ) );
 
   mActionCategories = coll->addAction( "edit_set_categories" );
   mActionCategories->setText( i18n( "Select Categories..." ) );
@@ -1181,7 +1180,7 @@ void KABCore::initActions()
   clearLocation->setText( i18n( "Clear Search Bar" ) );
   connect(clearLocation, SIGNAL(triggered(bool) ), SLOT( slotClearSearchBar() ));
   clearLocation->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_L));
-  clearLocation->setWhatsThis( i18n( "Clear Search Bar<p>"
+  clearLocation->setWhatsThis( i18n( "Clear Search Bar<br /><br />"
 				     "Clears the content of the quick search bar." ) );
 
   clipboardDataChanged();
