@@ -24,7 +24,6 @@
 #include <QFile>
 #include <QLayout>
 #include <QStackedWidget>
-//Added by qt3to4:
 #include <QHBoxLayout>
 #include <QDropEvent>
 #include <kselectaction.h>
@@ -61,8 +60,6 @@ ViewManager::ViewManager( KAB::Core *core, QWidget *parent, const char *name )
   initGUI();
   initActions();
 
-  mViewDict.setAutoDelete( true );
-
   createViewFactories();
 }
 
@@ -78,6 +75,7 @@ void ViewManager::restoreSettings()
   QString activeViewName = KABPrefs::instance()->currentView();
 
   mActionSelectView->setItems( mViewNameList );
+  mActionSelectView->setCurrentItem( mViewNameList.indexOf( activeViewName ) );
 
   // Filter
   mFilterList = Filter::restore( mCore->config(), "Filter" );
@@ -86,10 +84,11 @@ void ViewManager::restoreSettings()
 
   // Tell the views to reread their config, since they may have
   // been modified by global settings
-  Q3DictIterator<KAddressBookView> it( mViewDict );
-  for ( it.toFirst(); it.current(); ++it ) {
-    KConfigGroup group( mCore->config(), it.currentKey() );
-    it.current()->readConfig( group );
+  QHashIterator<QString, KAddressBookView* > it( mViewDict );
+  while ( it.hasNext() ) {
+    it.next();
+    KConfigGroup group( mCore->config(), it.key() );
+    it.value()->readConfig( group );
   }
 
   setActiveView( activeViewName );
@@ -99,10 +98,11 @@ void ViewManager::restoreSettings()
 
 void ViewManager::saveSettings()
 {
-  Q3DictIterator<KAddressBookView> it( mViewDict );
-  for ( it.toFirst(); it.current(); ++it ) {
-    KConfigGroup group( mCore->config(), it.currentKey() );
-    (*it)->writeConfig( group );
+  QHashIterator<QString, KAddressBookView*> it( mViewDict );
+  while ( it.hasNext() ) {
+    it.next();
+    KConfigGroup group( mCore->config(), it.key() );
+    it.value()->writeConfig( group );
   }
 
   Filter::save( mCore->config(), "Filter", mFilterList );
@@ -183,12 +183,18 @@ void ViewManager::setFirstSelected( bool selected )
 
 void ViewManager::unloadViews()
 {
-  mViewDict.clear();
+  while ( mViewDict.count() ) {
+    KAddressBookView *view = *(mViewDict.begin());
+    mViewDict.remove( mViewDict.key( view ) );
+    delete view;
+  }
   mActiveView = 0;
 }
 
 void ViewManager::setActiveView( const QString &name )
 {
+  kDebug() << "entering ViewManager::setActiveView";
+
   KAddressBookView *view = 0;
 
   // Check that this isn't the same as the current active view
@@ -200,17 +206,17 @@ void ViewManager::setActiveView( const QString &name )
   // we can't find it, it means it hasn't been instantiated, so we will
   // create it on demand.
 
-  view = mViewDict.find( name );
+  view = mViewDict.value( name );
 
   // Check if we found the view. If we didn't, then we need to create it
-  if ( view == 0 ) {
+  if ( !view ) {
     KConfig *config = mCore->config();
     KConfigGroup group( config, name );
     QString type = group.readEntry( "Type", "Table" );
 
-    kDebug(5720) << "ViewManager::setActiveView: creating view - " << name << endl;
+    kDebug(5720) <<"ViewManager::setActiveView: creating view -" << name;
 
-    ViewFactory *factory = mViewFactoryDict.find( type );
+    ViewFactory *factory = mViewFactoryDict.value( type );
     if ( factory )
       view = factory->view( mCore, mViewWidgetStack );
 
@@ -256,7 +262,7 @@ void ViewManager::setActiveView( const QString &name )
     mActiveView->refresh();
 
   } else
-    kDebug(5720) << "ViewManager::setActiveView: unable to find view\n";
+    kDebug(5720) <<"ViewManager::setActiveView: unable to find view";
 }
 
 void ViewManager::refreshView( const QString &uid )
@@ -270,7 +276,7 @@ void ViewManager::editView()
   if ( !mActiveView )
     return;
 
-  ViewFactory *factory = mViewFactoryDict.find( mActiveView->type() );
+  ViewFactory *factory = mViewFactoryDict.value( mActiveView->type() );
   ViewConfigureWidget *wdg = 0;
 
   if ( factory ) {
@@ -322,7 +328,9 @@ void ViewManager::deleteView()
     KConfig *config = mCore->config();
     config->deleteGroup( mActiveView->windowTitle() );
 
+    KAddressBookView *view = mViewDict[ mActiveView->windowTitle() ];
     mViewDict.remove( mActiveView->windowTitle() );
+    delete view;
     mActiveView = 0;
 
     // we are in an invalid state now, but that should be fixed after
@@ -401,14 +409,14 @@ void ViewManager::createViewFactories()
     KLibFactory *factory = KLibLoader::self()->factory( (*it)->library().toLatin1() );
 
     if ( !factory ) {
-      kDebug(5720) << "ViewManager::createViewFactories(): Factory creation failed" << endl;
+      kDebug(5720) <<"ViewManager::createViewFactories(): Factory creation failed";
       continue;
     }
 
     ViewFactory *viewFactory = static_cast<ViewFactory*>( factory );
 
     if ( !viewFactory ) {
-      kDebug(5720) << "ViewManager::createViewFactories(): Cast failed" << endl;
+      kDebug(5720) <<"ViewManager::createViewFactories(): Cast failed";
       continue;
     }
 
@@ -418,7 +426,7 @@ void ViewManager::createViewFactories()
 
 void ViewManager::dropped( QDropEvent *e )
 {
-  kDebug(5720) << "ViewManager::dropped: got a drop event" << endl;
+  kDebug(5720) <<"ViewManager::dropped: got a drop event";
 
   // don't allow drops from our own drags
   if ( e->source() == this )
@@ -439,10 +447,10 @@ void ViewManager::dropped( QDropEvent *e )
       }
     } else if ( c == 1 )
       emit urlDropped( *it );
-  } else if ( KVCardDrag::canDecode( md ) ) {
+  } else if ( KPIM::KVCardDrag::canDecode( md ) ) {
     KABC::Addressee::List list;
 
-    KVCardDrag::fromMimeData( md, list );
+    KPIM::KVCardDrag::fromMimeData( md, list );
 
     KABC::Addressee::List::ConstIterator it;
     for ( it = list.begin(); it != list.end(); ++it ) {
@@ -465,7 +473,7 @@ void ViewManager::startDrag()
   if (  uidList.isEmpty() )
     return;
 
-  kDebug(5720) << "ViewManager::startDrag: starting to drag" << endl;
+  kDebug(5720) <<"ViewManager::startDrag: starting to drag";
 
   QStringList::ConstIterator it;
   for ( it = uidList.begin(); it != uidList.end(); ++it )
@@ -477,7 +485,7 @@ void ViewManager::startDrag()
 
   // Text should be first as the default format. If an application explicitly requests vcard, it will still get it.
   mimeData->setText( AddresseeUtil::addresseesToEmails( addrList ) );
-  KVCardDrag::populateMimeData( mimeData, addrList );
+  KPIM::KVCardDrag::populateMimeData( mimeData, addrList );
 
 
   KTempDir tempDir;
@@ -502,7 +510,7 @@ void ViewManager::startDrag()
     }
   }
 
-  drag->setPixmap( KIconLoader::global()->loadIcon( "vcard", K3Icon::Desktop ) );
+  drag->setPixmap( KIconLoader::global()->loadIcon( "vcard", KIconLoader::Desktop ) );
   drag->start();
 }
 
@@ -606,7 +614,7 @@ void ViewManager::initActions()
   action->setIcon( KIcon("search-filter") );
   action->setText( i18n( "Edit &Filters..." ) );
   connect(action, SIGNAL(triggered(bool) ), SLOT( configureFilters() ));
-  action->setWhatsThis( i18n( "Edit the contact filters<p>You will be presented with a dialog, where you can add, remove and edit filters." ) );
+  action->setWhatsThis( i18n( "Edit the contact filters<p>You will be presented with a dialog, where you can add, remove and edit filters.</p>" ) );
 }
 
 void ViewManager::initGUI()
