@@ -29,7 +29,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
-#include <kstaticdeleter.h>
+#include <k3staticdeleter.h>
 #include <kconfig.h>
 #include <kaboutdata.h>
 #include <kio/netaccess.h>
@@ -47,6 +47,7 @@
 #include "alarmresources.h"
 #include "calendarcompat.h"
 #include "daemon.h"
+#include "eventlistmodel.h"
 #include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
@@ -61,8 +62,8 @@ QString AlarmCalendar::icalProductId()
 }
 
 static const QString displayCalendarName = QLatin1String("displaying.ics");
-static KStaticDeleter<AlarmCalendar> resourceCalendarDeleter;   // ensure that the calendar destructor is called
-static KStaticDeleter<AlarmCalendar> displayCalendarDeleter;    // ensure that the calendar destructor is called
+static K3StaticDeleter<AlarmCalendar> resourceCalendarDeleter;   // ensure that the calendar destructor is called
+static K3StaticDeleter<AlarmCalendar> displayCalendarDeleter;    // ensure that the calendar destructor is called
 
 AlarmCalendar* AlarmCalendar::mResourcesCalendar = 0;
 AlarmCalendar* AlarmCalendar::mDisplayCalendar = 0;
@@ -113,7 +114,7 @@ AlarmCalendar* AlarmCalendar::displayCalendarOpen()
 {
 	if (mDisplayCalendar->open())
 		return mDisplayCalendar;
-	kError(5950) << "AlarmCalendar::displayCalendarOpen(): open error\n";
+	kError(5950) <<"AlarmCalendar::displayCalendarOpen(): open error";
 	return 0;
 }
 
@@ -193,7 +194,7 @@ bool AlarmCalendar::open()
 		return true;
 	if (mCalType == RESOURCES)
 	{
-		kDebug(5950) << "AlarmCalendar::open(RESOURCES)" << endl;
+		kDebug(5950) <<"AlarmCalendar::open(RESOURCES)";
 		mCalendar = AlarmResources::instance();
 		load();
 	}
@@ -202,13 +203,13 @@ bool AlarmCalendar::open()
 		if (!mUrl.isValid())
 			return false;
 
-		kDebug(5950) << "AlarmCalendar::open(" << mUrl.prettyUrl() << ")\n";
+		kDebug(5950) <<"AlarmCalendar::open(" << mUrl.prettyUrl() <<")";
 		if (!mCalendar)
 			mCalendar = new CalendarLocal(Preferences::timeZone(true));
 
 		// Check for file's existence, assuming that it does exist when uncertain,
 		// to avoid overwriting it.
-		if (!KIO::NetAccess::exists(mUrl, true, MainWindow::mainMainWindow())
+		if (!KIO::NetAccess::exists(mUrl, KIO::NetAccess::SourceSide, MainWindow::mainMainWindow())
 		||  load() == 0)
 		{
 			// The calendar file doesn't yet exist, or it's zero length, so create a new one
@@ -245,7 +246,7 @@ int AlarmCalendar::load()
 {
 	if (mCalType == RESOURCES)
 	{
-		kDebug(5950) << "AlarmCalendar::load(RESOURCES)" << endl;
+		kDebug(5950) <<"AlarmCalendar::load(RESOURCES)";
 		static_cast<AlarmResources*>(mCalendar)->load();
 	}
 	else
@@ -254,15 +255,15 @@ int AlarmCalendar::load()
 			return -2;
 		CalendarLocal* calendar = static_cast<CalendarLocal*>(mCalendar);
 
-		kDebug(5950) << "AlarmCalendar::load(" << mUrl.prettyUrl() << ")\n";
+		kDebug(5950) <<"AlarmCalendar::load(" << mUrl.prettyUrl() <<")";
 		QString tmpFile;
 		if (!KIO::NetAccess::download(mUrl, tmpFile, MainWindow::mainMainWindow()))
 		{
-			kError(5950) << "AlarmCalendar::load(): Download failure" << endl;
-			KMessageBox::error(0, i18n("Cannot download calendar:\n%1", mUrl.prettyUrl()));
+			kError(5950) <<"AlarmCalendar::load(): Download failure";
+			KMessageBox::error(0, i18nc("@info", "Cannot download calendar: <filename>%1</filename>", mUrl.prettyUrl()));
 			return -1;
 		}
-		kDebug(5950) << "AlarmCalendar::load(): --- Downloaded to " << tmpFile << endl;
+		kDebug(5950) <<"AlarmCalendar::load(): --- Downloaded to" << tmpFile;
 		calendar->setTimeSpec(Preferences::timeZone(true));
 		if (!calendar->load(tmpFile))
 		{
@@ -273,8 +274,8 @@ int AlarmCalendar::load()
 			KFileItem fi(uds, mUrl);
 			if (!fi.size())
 				return 0;     // file is zero length
-			kError(5950) << "AlarmCalendar::load(): Error loading calendar file '" << tmpFile << "'" << endl;
-			KMessageBox::error(0, i18n("Error loading calendar:\n%1\n\nPlease fix or delete the file.", mUrl.prettyUrl()));
+			kError(5950) <<"AlarmCalendar::load(): Error loading calendar file '" << tmpFile <<"'";
+			KMessageBox::error(0, i18nc("@info", "<para>Error loading calendar:</para><para><filename>%1</filename></para><para>Please fix or delete the file.</para>", mUrl.prettyUrl()));
 			// load() could have partially populated the calendar, so clear it out
 			calendar->close();
 			delete mCalendar;
@@ -299,12 +300,12 @@ bool AlarmCalendar::reload()
 		return false;
 	if (mCalType == RESOURCES)
 	{
-		kDebug(5950) << "AlarmCalendar::reload(RESOURCES)" << endl;
+		kDebug(5950) <<"AlarmCalendar::reload(RESOURCES)";
 		return mCalendar->reload();
 	}
 	else
 	{
-		kDebug(5950) << "AlarmCalendar::reload(): " << mUrl.prettyUrl() << endl;
+		kDebug(5950) <<"AlarmCalendar::reload():" << mUrl.prettyUrl();
 		close();
 		return open();
 	}
@@ -320,7 +321,7 @@ bool AlarmCalendar::saveCal(const QString& newFile)
 		return false;
 	if (mCalType == RESOURCES)
 	{
-		kDebug(5950) << "AlarmCalendar::saveCal(RESOURCES)" << endl;
+		kDebug(5950) <<"AlarmCalendar::saveCal(RESOURCES)";
 		mCalendar->save();    // this emits signals resourceSaved(ResourceCalendar*)
 	}
 	else
@@ -328,14 +329,14 @@ bool AlarmCalendar::saveCal(const QString& newFile)
 		if (!mOpen && newFile.isNull())
 			return false;
 
-		kDebug(5950) << "AlarmCalendar::saveCal(\"" << newFile << "\", " << mEventType << ")\n";
+		kDebug(5950) <<"AlarmCalendar::saveCal(\"" << newFile <<"\"," << mEventType <<")";
 		QString saveFilename = newFile.isNull() ? mLocalFile : newFile;
 		if (mCalType == LOCAL_VCAL  &&  newFile.isNull()  &&  mUrl.isLocalFile())
 			saveFilename = mICalUrl.path();
 		if (!static_cast<CalendarLocal*>(mCalendar)->save(saveFilename, new ICalFormat))
 		{
-			kError(5950) << "AlarmCalendar::saveCal(" << saveFilename << "): failed.\n";
-			KMessageBox::error(0, i18n("Failed to save calendar to\n'%1'", mICalUrl.prettyUrl()));
+			kError(5950) <<"AlarmCalendar::saveCal(" << saveFilename <<"): failed.";
+			KMessageBox::error(0, i18nc("@info", "Failed to save calendar to <filename>%1</filename>", mICalUrl.prettyUrl()));
 			return false;
 		}
 
@@ -343,8 +344,8 @@ bool AlarmCalendar::saveCal(const QString& newFile)
 		{
 			if (!KIO::NetAccess::upload(saveFilename, mICalUrl, MainWindow::mainMainWindow()))
 			{
-				kError(5950) << "AlarmCalendar::saveCal(" << saveFilename << "): upload failed.\n";
-				KMessageBox::error(0, i18n("Cannot upload calendar to\n'%1'", mICalUrl.prettyUrl()));
+				kError(5950) <<"AlarmCalendar::saveCal(" << saveFilename <<"): upload failed.";
+				KMessageBox::error(0, i18nc("@info", "Cannot upload calendar to <filename>%1</filename>", mICalUrl.prettyUrl()));
 				return false;
 			}
 		}
@@ -430,7 +431,7 @@ void AlarmCalendar::slotResourceLoaded(AlarmResource* resource, bool success)
 */
 void AlarmCalendar::reloadFromCache(const QString& resourceID)
 {
-	kDebug(5950) << "AlarmCalendar::reloadFromCache(" << resourceID << ")\n";
+	kDebug(5950) <<"AlarmCalendar::reloadFromCache(" << resourceID <<")";
 	if (mCalendar  &&  mCalType == RESOURCES)
 	{
 		AlarmResource* resource = static_cast<AlarmResources*>(mCalendar)->resourceWithId(resourceID);
@@ -450,7 +451,7 @@ void AlarmCalendar::slotDaemonRegistered(bool newStatus)
 	resources->inhibitDefaultReload(true, newStatus);
 	if (!newStatus)
 	{
-		kDebug(5950) << "AlarmCalendar::slotDaemonRegistered(false): reload resources" << endl;
+		kDebug(5950) <<"AlarmCalendar::slotDaemonRegistered(false): reload resources";
 		resources->loadIfNotReloaded();    // reload any resources which need to be downloaded
 	}
 }
@@ -465,18 +466,18 @@ void AlarmCalendar::slotDaemonRegistered(bool newStatus)
 bool AlarmCalendar::importAlarms(QWidget* parent, AlarmResource* resource)
 {
 	KUrl url = KFileDialog::getOpenUrl(KUrl("filedialog:///importalarms"),
-	                                   QString::fromLatin1("*.vcs *.ics|%1").arg(i18n("Calendar Files")), parent);
+	                                   QString::fromLatin1("*.vcs *.ics|%1").arg(i18nc("@info/plain", "Calendar Files")), parent);
 	if (url.isEmpty())
 	{
-		kError(5950) << "AlarmCalendar::importAlarms(): Empty URL" << endl;
+		kError(5950) <<"AlarmCalendar::importAlarms(): Empty URL";
 		return false;
 	}
 	if (!url.isValid())
 	{
-		kDebug(5950) << "AlarmCalendar::importAlarms(): Invalid URL" << endl;
+		kDebug(5950) <<"AlarmCalendar::importAlarms(): Invalid URL";
 		return false;
 	}
-	kDebug(5950) << "AlarmCalendar::importAlarms(" << url.prettyUrl() << ")" << endl;
+	kDebug(5950) <<"AlarmCalendar::importAlarms(" << url.prettyUrl() <<")";
 
 	bool success = true;
 	QString filename;
@@ -486,8 +487,8 @@ bool AlarmCalendar::importAlarms(QWidget* parent, AlarmResource* resource)
 		filename = url.path();
 		if (!KStandardDirs::exists(filename))
 		{
-			kDebug(5950) << "AlarmCalendar::importAlarms(): File '" << url.prettyUrl() << "' not found" << endl;
-			KMessageBox::error(parent, i18n("Could not load calendar '%1'.", url.prettyUrl()));
+			kDebug(5950) <<"AlarmCalendar::importAlarms(): File '" << url.prettyUrl() <<"' not found";
+			KMessageBox::error(parent, i18nc("@info", "Could not load calendar <filename>%1</filename>.", url.prettyUrl()));
 			return false;
 		}
 	}
@@ -495,11 +496,11 @@ bool AlarmCalendar::importAlarms(QWidget* parent, AlarmResource* resource)
 	{
 		if (!KIO::NetAccess::download(url, filename, MainWindow::mainMainWindow()))
 		{
-			kError(5950) << "AlarmCalendar::importAlarms(): Download failure" << endl;
-			KMessageBox::error(parent, i18n("Cannot download calendar:\n%1", url.prettyUrl()));
+			kError(5950) <<"AlarmCalendar::importAlarms(): Download failure";
+			KMessageBox::error(parent, i18nc("@info", "Cannot download calendar: <filename>%1</filename>", url.prettyUrl()));
 			return false;
 		}
-		kDebug(5950) << "--- Downloaded to " << filename << endl;
+		kDebug(5950) <<"--- Downloaded to" << filename;
 	}
 
 	// Read the calendar and add its alarms to the current calendars
@@ -507,8 +508,8 @@ bool AlarmCalendar::importAlarms(QWidget* parent, AlarmResource* resource)
 	success = cal.load(filename);
 	if (!success)
 	{
-		kDebug(5950) << "AlarmCalendar::importAlarms(): error loading calendar '" << filename << "'" << endl;
-		KMessageBox::error(parent, i18n("Could not load calendar '%1'.", url.prettyUrl()));
+		kDebug(5950) <<"AlarmCalendar::importAlarms(): error loading calendar '" << filename <<"'";
+		KMessageBox::error(parent, i18nc("@info", "Could not load calendar <filename>%1</filename>.", url.prettyUrl()));
 	}
 	else
 	{
@@ -519,6 +520,7 @@ bool AlarmCalendar::importAlarms(QWidget* parent, AlarmResource* resource)
 		AlarmResource* activeRes   = 0;
 		AlarmResource* archivedRes = 0;
 		AlarmResource* templateRes = 0;
+		Event::List newEvents;
 		Event::List events = cal.rawEvents();
 		for (int i = 0, end = events.count();  i < end;  ++i)
 		{
@@ -571,14 +573,20 @@ bool AlarmCalendar::importAlarms(QWidget* parent, AlarmResource* resource)
 			// Give the event a new ID and add it to the resources
 			newev->setUid(KCalEvent::uid(CalFormat::createUniqueId(), type));
 			if (resources->addEvent(newev, *res))
+			{
 				saveRes = true;
+				newEvents += newev;
+			}
 			else
 				success = false;
 		}
 
 		// Save the resources if they have been modified
 		if (saveRes)
+		{
 			resources->save();
+			EventListModel::alarms()->addEvents(newEvents);
+		}
 	}
 	if (!local)
 		KIO::NetAccess::removeTempFile(filename);
@@ -733,7 +741,7 @@ Event* AlarmCalendar::modifyEvent(const QString& oldEventId, KAEvent& newEvent)
 	bool noNewId = newId.isEmpty();
 	if (!noNewId  &&  oldEventId == newId)
 	{
-		kError(5950) << "AlarmCalendar::modifyEvent(): same IDs" << endl;
+		kError(5950) <<"AlarmCalendar::modifyEvent(): same IDs";
 		return 0;
 	}
 	if (!mOpen)
@@ -826,7 +834,7 @@ bool AlarmCalendar::deleteEvent(const QString& eventID, bool saveit)
 Event* AlarmCalendar::createKCalEvent(const KAEvent& ev, const QString& baseID, bool original, bool cancelCancelledDefer) const
 {
 	if (mCalType != RESOURCES)
-		kFatal(5950) << "AlarmCalendar::createKCalEvent(KAEvent): invalid for display calendar" << endl;
+		kFatal(5950) <<"AlarmCalendar::createKCalEvent(KAEvent): invalid for display calendar";
 	// If the event exists in the calendar, we want to keep any custom
 	// properties. So copy the calendar KCal::Event to base the new one on.
 	QString id = baseID.isEmpty() ? ev.id() : baseID;
@@ -871,11 +879,12 @@ KAEvent AlarmCalendar::templateEvent(const QString& templateName)
 * Return all events in the calendar which contain alarms.
 * Optionally the event type can be filtered, using an OR of event types.
 */
-Event::List AlarmCalendar::events(KCalEvent::Status type)
+Event::List AlarmCalendar::events(AlarmResource* resource, KCalEvent::Status type)
 {
-	if (!mCalendar)
-		return Event::List();
-	Event::List list = mCalendar->rawEvents();
+	Event::List list;
+	if (!mCalendar  ||  resource && mCalType != RESOURCES)
+		return list;
+	list = resource ? AlarmResources::instance()->rawEvents(resource) : mCalendar->rawEvents();
 	for (int i = 0;  i < list.count();  )
 	{
 		Event* event = list[i];
@@ -894,7 +903,7 @@ Event::List AlarmCalendar::events(KCalEvent::Status type)
 */
 Event::List AlarmCalendar::eventsWithAlarms(const KDateTime& from, const KDateTime& to, KCalEvent::Status type)
 {
-	kDebug(5950) << "AlarmCalendar::eventsWithAlarms(" << from << " - " << to << ")\n";
+	kDebug(5950) <<"AlarmCalendar::eventsWithAlarms(" << from <<" -" << to <<")";
 	Event::List evnts;
 	if (!mCalendar)
 		return evnts;
@@ -937,7 +946,7 @@ Event::List AlarmCalendar::eventsWithAlarms(const KDateTime& from, const KDateTi
 						}
 						// Adjust the 'from' date/time and find the next recurrence at or after it
 						KDateTime pre = from.addSecs(-offset - 1);
-						if (e->floats()  &&  pre.time() < Preferences::startOfDay())
+						if (e->allDay()  &&  pre.time() < Preferences::startOfDay())
 							pre = pre.addDays(-1);    // today's recurrence (if today recurs) is still to come
 						dt = e->recurrence()->getNextDateTime(pre);
 						if (!dt.isValid())
@@ -949,8 +958,8 @@ Event::List AlarmCalendar::eventsWithAlarms(const KDateTime& from, const KDateTi
 					dt = alarm->time();
 				if (dt >= from  &&  dt <= to)
 				{
-					kDebug(5950) << "AlarmCalendar::events() '" << e->summary()
-					              << "': " << dt << endl;
+					kDebug(5950) <<"AlarmCalendar::events() '" << e->summary()
+					              << "':" << dt;
 					evnts.append(e);
 					break;
 				}
