@@ -47,7 +47,10 @@ class EmailAddressList : public QList<KCal::Person>
 		EmailAddressList() : QList<KCal::Person>() { }
 		EmailAddressList(const QList<KCal::Person>& list)  { operator=(list); }
 		EmailAddressList& operator=(const QList<KCal::Person>&);
+		operator QStringList() const;
 		QString join(const QString& separator) const;
+	private:
+		QString address(int index) const;
 };
 
 
@@ -60,7 +63,7 @@ class KAAlarmEventBase
 		QString            message() const             { return (mActionType == T_MESSAGE || mActionType == T_EMAIL) ? mText : QString(); }
 		QString            fileName() const            { return (mActionType == T_FILE) ? mText : QString(); }
 		QString            command() const             { return (mActionType == T_COMMAND) ? mText : QString(); }
-		QString            emailFromKMail() const      { return mEmailFromKMail; }
+		uint               emailFromId() const         { return mEmailFromIdentity; }
 		const EmailAddressList& emailAddresses() const { return mEmailAddresses; }
 		QString            emailAddresses(const QString& sep) const  { return mEmailAddresses.join(sep); }
 		const QString&     emailSubject() const        { return mEmailSubject; }
@@ -104,7 +107,7 @@ class KAAlarmEventBase
 		QColor             mBgColour;         // background colour of alarm message
 		QColor             mFgColour;         // foreground colour of alarm message, or invalid for default
 		QFont              mFont;             // font of alarm message (ignored if mDefaultFont true)
-		QString            mEmailFromKMail;   // KMail identity for email 'From' field, or empty
+		uint               mEmailFromIdentity;// standard email identity uoid for 'From' field, or empty
 		EmailAddressList   mEmailAddresses;   // ATTENDEE: addresses to send email to
 		QString            mEmailSubject;     // SUMMARY: subject line of email
 		QStringList        mEmailAttachments; // ATTACH: email attachment file names
@@ -112,9 +115,9 @@ class KAAlarmEventBase
 		float              mFadeVolume;       // initial volume for sound file, or < 0 for no fade
 		int                mFadeSeconds;      // fade time for sound file, or 0 if none
 		Type               mActionType;       // alarm action type
-		int                mRepeatCount;      // simple repetition count (excluding the first time)
-		int                mRepeatInterval;   // simple repetition interval (minutes)
-		int                mNextRepeat;       // repetition count of next due repetition
+		int                mRepeatCount;      // sub-repetition count (excluding the first time)
+		int                mRepeatInterval;   // sub-repetition interval (minutes)
+		int                mNextRepeat;       // repetition count of next due sub-repetition
 		int                mLateCancel;       // how many minutes late will cancel the alarm, or 0 for no cancellation
 		bool               mAutoClose;        // whether to close the alarm window after the late-cancel period
 		bool               mCommandScript;    // the command text is a script, not a shell command line
@@ -311,11 +314,11 @@ class KAEvent : public KAAlarmEventBase
 		                            { set(dt, filename, bg, fg, f, FILE, lateCancel, flags); }
 		void               setCommand(const QDate&, const QString& command, int lateCancel, int flags, const QString& logfile = QString());
 		void               setCommand(const KDateTime&, const QString& command, int lateCancel, int flags, const QString& logfile = QString());
-		void               setEmail(const QDate&, const QString& from, const EmailAddressList&, const QString& subject,
+		void               setEmail(const QDate&, uint from, const EmailAddressList&, const QString& subject,
 		                            const QString& message, const QStringList& attachments, int lateCancel, int flags);
-		void               setEmail(const KDateTime&, const QString& from, const EmailAddressList&, const QString& subject,
+		void               setEmail(const KDateTime&, uint from, const EmailAddressList&, const QString& subject,
 		                            const QString& message, const QStringList& attachments, int lateCancel, int flags);
-		void               setEmail(const QString& from, const EmailAddressList&, const QString& subject, const QStringList& attachments);
+		void               setEmail(uint from, const EmailAddressList&, const QString& subject, const QStringList& attachments);
 		void               setAudioFile(const QString& filename, float volume, float fadeVolume, int fadeSeconds);
 		void               setTemplate(const QString& name, int afterTime = -1);
 		void               setActions(const QString& pre, const QString& post)   { mPreAction = pre;  mPostAction = post;  mUpdated = true; }
@@ -398,7 +401,6 @@ class KAEvent : public KAAlarmEventBase
 		KARecurrence*      recurrence() const             { return mRecurrence; }
 		int                recurInterval() const;    // recurrence period in units of the recurrence period type (minutes, days, etc)
 		int                longestRecurrenceInterval() const    { return mRecurrence ? mRecurrence->longestInterval() : 0; }
-		bool               mayOccurDuringWork() const;
 		QString            recurrenceText(bool brief = false) const;
 		QString            repetitionText(bool brief = false) const;
 		int                remainingRecurrences() const   { return mRemainingRecurrences; }
@@ -458,8 +460,9 @@ class KAEvent : public KAAlarmEventBase
 		KARecurrence::Type checkRecur() const;
 		OccurType          nextRecurrence(const KDateTime& preDateTime, DateTime& result, int& remainingCount) const;
 		OccurType          previousRecurrence(const KDateTime& afterDateTime, DateTime& result) const;
-		KCal::Alarm*       initKcalAlarm(KCal::Event*, const DateTime&, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
-		KCal::Alarm*       initKcalAlarm(KCal::Event*, int startOffsetSecs, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
+		KCal::Alarm*       initKCalAlarm(KCal::Event*, const DateTime&, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
+		KCal::Alarm*       initKCalAlarm(KCal::Event*, int startOffsetSecs, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
+		static DateTime    readDateTime(const KCal::Event*, bool dateOnly, DateTime& start);
 		static void        readAlarms(const KCal::Event*, void* alarmMap);
 		static void        readAlarm(const KCal::Alarm*, AlarmData&);
 		inline void        set_deferral(DeferType);
@@ -479,7 +482,7 @@ class KAEvent : public KAAlarmEventBase
 		int                mDisplayingFlags;  // type of alarm which is currently being displayed
 		int                mReminderMinutes;  // how long in advance reminder is to be, or 0 if none
 		int                mArchiveReminderMinutes;  // original reminder period if now expired, or 0 if none
-		int                mDeferDefaultMinutes; // default number of minutes for deferral dialogue, or 0 to select time control
+		int                mDeferDefaultMinutes; // default number of minutes for deferral dialog, or 0 to select time control
 		int                mRevision;         // SEQUENCE: revision number of the original alarm, or 0
 		KARecurrence*      mRecurrence;       // RECUR: recurrence specification, or 0 if none
 		int                mRemainingRecurrences; // remaining number of alarm recurrences including initial time, -1 to repeat indefinitely
