@@ -131,7 +131,7 @@ bool Daemon::checkDBusResult(const char* funcname)
 	QDBusError err = mDBusDaemon->lastError();
 	if (!err.isValid())
 		return true;    // no error
-	kError(5950) << "Daemon: " << funcname << "() D-Bus call failed: " << err.message() << endl;
+	kError(5950) << "Daemon:" << funcname << "() D-Bus call failed:" << err.message();
 	return false;
 }
 
@@ -141,7 +141,7 @@ bool Daemon::checkDBusResult(const char* funcname)
 */
 bool Daemon::start()
 {
-	kDebug(5950) << "Daemon::start()\n";
+	kDebug(5950) << "Daemon::start()";
 	updateRegisteredStatus();
 	switch (mStatus)
 	{
@@ -155,13 +155,13 @@ bool Daemon::start()
 			if (execStr.isEmpty())
 			{
 				if (!mNotFoundShown)
-					KMessageBox::error(0, i18n("Alarm daemon not found."));
+					KMessageBox::error(0, i18nc("@info", "Alarm daemon not found."));
 				mNotFoundShown = true;
-				kError() << "Daemon::startApp(): " DAEMON_APP_NAME " not found" << endl;
+				kError() << "Daemon::startApp():" DAEMON_APP_NAME" not found";
 				return false;
 			}
 			KToolInvocation::kdeinitExec(execStr);
-			kDebug(5950) << "Daemon::start(): Alarm daemon started" << endl;
+			kDebug(5950) << "Daemon::start(): Alarm daemon started";
 			mStartTimeout = 5000/startCheckInterval + 1;    // check daemon status for 5 seconds before giving up
 			mStartTimer = new QTimer(mInstance);
 			connect(mStartTimer, SIGNAL(timeout()), mInstance, SLOT(checkIfStarted()));
@@ -198,7 +198,7 @@ bool Daemon::registerWith(bool reregister)
 		return true;
 
 	bool disabledIfStopped = theApp()->alarmsDisabledIfStopped();
-	kDebug(5950) << (reregister ? "Daemon::reregisterWith(): " : "Daemon::registerWith(): ") << (disabledIfStopped ? "NO_START" : "COMMAND_LINE") << endl;
+	kDebug(5950) << (reregister ?"Daemon::reregisterWith():" :"Daemon::registerWith():") << (disabledIfStopped ?"NO_START" :"COMMAND_LINE");
 	bool result;
 	if (reregister)
 	{
@@ -227,7 +227,7 @@ bool Daemon::registerWith(bool reregister)
 */
 void Daemon::registrationResult(bool reregister, int result)
 {
-	kDebug(5950) << "Daemon::registrationResult(" << reregister << ")\n";
+	kDebug(5950) << "Daemon::registrationResult(" << reregister << ")";
 	delete mRegisterTimer;
 	mRegisterTimer = 0;
 	bool firstTime = !mInitialised;
@@ -240,15 +240,15 @@ void Daemon::registrationResult(bool reregister, int result)
 			// We've successfully registered with the daemon, but the daemon can't
 			// find the KAlarm executable so won't be able to restart KAlarm if
 			// KAlarm exits.
-			kError(5950) << "Daemon::registrationResult(" << reregister << "): registerApp D-Bus call: " << KGlobal::mainComponent().aboutData()->appName() << " not found\n";
-			KMessageBox::error(0, i18n("Alarms will be disabled if you stop KAlarm.\n"
-			                           "(Installation or configuration error: %1 cannot locate %2 executable.)",
+			kError(5950) << "Daemon::registrationResult(" << reregister << "): registerApp D-Bus call:" << KGlobal::mainComponent().aboutData()->appName() << " not found";
+			KMessageBox::error(0, i18nc("@info", "Alarms will be disabled if you stop <application>KAlarm</application>.<br />"
+			                           "(Installation or configuration error: <command>%1</command> cannot locate <command>%2</command> executable.)",
 			                            QLatin1String(DAEMON_APP_NAME),
 			                            KGlobal::mainComponent().aboutData()->appName()));
 			break;
 		case KAlarmd::FAILURE:
 		default:
-			kError(5950) << "Daemon::registrationResult(" << reregister << "): registerApp D-Bus call failed -> " << result << endl;
+			kError(5950) << "Daemon::registrationResult(" << reregister << "): registerApp D-Bus call failed ->" << result;
 			if (!reregister)
 			{
 				if (mStatus == REGISTERED)
@@ -256,7 +256,8 @@ void Daemon::registrationResult(bool reregister, int result)
 				if (!mRegisterFailMsg)
 				{
 					mRegisterFailMsg = true;
-					KMessageBox::error(0, i18n("Cannot enable alarms:\nFailed to register with Alarm Daemon (%1)",
+					KMessageBox::error(0, i18nc("@info", "Cannot enable alarms:<br />"
+					                            "Failed to register with <application>Alarm Daemon</application> (<command>%1</command>)",
 					                            QLatin1String(DAEMON_APP_NAME)));
 				}
 			}
@@ -275,7 +276,7 @@ void Daemon::registrationResult(bool reregister, int result)
 		// The alarm daemon has loaded the calendar
 		setStatus(REGISTERED);
 		mRegisterFailMsg = false;
-		kDebug(5950) << "Daemon::start(): daemon startup complete" << endl;
+		kDebug(5950) << "Daemon::start(): daemon startup complete";
 	}
 }
 
@@ -304,8 +305,8 @@ void Daemon::checkIfStarted()
 	mStartTimer = 0;
 	if (err)
 	{
-		kError(5950) << "Daemon::checkIfStarted(): failed to start daemon" << endl;
-		KMessageBox::error(0, i18n("Cannot enable alarms:\nFailed to start Alarm Daemon (%1)", QLatin1String(DAEMON_APP_NAME)));
+		kError(5950) << "Daemon::checkIfStarted(): failed to start daemon";
+		KMessageBox::error(0, i18nc("@info", "Cannot enable alarms:<br />Failed to start <application>Alarm Daemon</application> (<command>%1</command>)", QLatin1String(DAEMON_APP_NAME)));
 	}
 }
 
@@ -344,7 +345,7 @@ void Daemon::updateRegisteredStatus(bool timeout)
 		}
 	}
 	if (mStatus != oldStatus)
-		kDebug(5950) << "Daemon::updateRegisteredStatus() -> " << (mStatus==STOPPED?"STOPPED":mStatus==RUNNING?"RUNNING":mStatus==READY?"READY":mStatus==REGISTERED?"REGISTERED":"??") << endl;
+		kDebug(5950) << "Daemon::updateRegisteredStatus() ->" << (mStatus==STOPPED?"STOPPED":mStatus==RUNNING?"RUNNING":mStatus==READY?"READY":mStatus==REGISTERED?"REGISTERED":"??");
 }
 
 /******************************************************************************
@@ -378,7 +379,7 @@ void Daemon::connectRegistered(QObject* receiver, const char* slot)
 */
 bool Daemon::stop()
 {
-	kDebug(5950) << "Daemon::stop()" << endl;
+	kDebug(5950) << "Daemon::stop()";
 	if (!isDaemonRegistered())
 		return true;
 	daemonDBus()->quit();
@@ -392,7 +393,7 @@ bool Daemon::stop()
 */
 bool Daemon::reset()
 {
-	kDebug(5950) << "Daemon::reset()" << endl;
+	kDebug(5950) << "Daemon::reset()";
 	if (!isDaemonRegistered())
 		return false;
 	daemonDBus()->resetResource(QString());
@@ -404,7 +405,7 @@ bool Daemon::reset()
 */
 void Daemon::reload()
 {
-	kDebug(5950) << "Daemon::reload()\n";
+	kDebug(5950) << "Daemon::reload()";
 	daemonDBus()->reloadResource(QString());
 	checkDBusResult("reloadResource");
 }
@@ -414,10 +415,10 @@ void Daemon::reload()
 */
 void Daemon::reloadResource(const QString& resourceID)
 {
-	kDebug(5950) << "Daemon::reloadResource(" << resourceID << ")\n";
+	kDebug(5950) << "Daemon::reloadResource(" << resourceID << ")";
 	daemonDBus()->reloadResource(resourceID);
 	if (!checkDBusResult("reloadResource"))
-		kError(5950) << "Daemon::reloadResource(): reloadResource(" << resourceID << ") D-Bus send failed" << endl;
+		kError(5950) << "Daemon::reloadResource(): reloadResource(" << resourceID << ") D-Bus send failed";
 }
 
 /******************************************************************************
@@ -435,19 +436,19 @@ void Daemon::enableCalendar(bool enable)
 */
 void Daemon::enableAutoStart(bool enable)
 {
-	// Tell the alarm daemon in case it is running.
-	daemonDBus()->enableAutoStart(enable);
-	if (!checkDBusResult("enableAutoStart"))
-#ifdef __GNUC__
-#warning Check that false is returned if daemon is not running
-#endif
+	if (isDaemonRegistered())
 	{
-		// Failure - the daemon probably isn't running, so rewrite its config file for it
-		KConfig adconfig(KStandardDirs::locate("config", DAEMON_APP_NAME"rc"));
-		KConfigGroup config(&adconfig, DAEMON_AUTOSTART_SECTION);
-		config.writeEntry(DAEMON_AUTOSTART_KEY, enable);
-		config.sync();
+		// Tell the alarm daemon since it seems to be running.
+		daemonDBus()->enableAutoStart(enable);
+		if (checkDBusResult("enableAutoStart"))
+			return;
 	}
+	// Failure - the daemon probably isn't running, so rewrite its config file for it
+	kDebug(5950) << "Daemon::enableAutoStart(" << enable << "): write config";
+	KConfig adconfig(KStandardDirs::locate("config", DAEMON_APP_NAME"rc"));
+	KConfigGroup config(&adconfig, DAEMON_AUTOSTART_SECTION);
+	config.writeEntry(DAEMON_AUTOSTART_KEY, enable);
+	config.sync();
 }
 
 /******************************************************************************
@@ -476,7 +477,7 @@ void Daemon::calendarIsEnabled(bool enabled)
 */
 void Daemon::setAlarmsEnabled(bool enable)
 {
-	kDebug(5950) << "Daemon::setAlarmsEnabled(" << enable << ")\n";
+	kDebug(5950) << "Daemon::setAlarmsEnabled(" << enable << ")";
 	if (enable  &&  !checkIfRunning())
 	{
 		// The daemon is not running, so start it
@@ -685,7 +686,7 @@ void Daemon::eventHandled(const QString& eventId)
 */
 void Daemon::notifyEventHandled(const QString& eventId, bool reloadCal)
 {
-	kDebug(5950) << "Daemon::notifyEventHandled(" << eventId << (reloadCal ? "): reload" : ")") << endl;
+	kDebug(5950) << "Daemon::notifyEventHandled(" << eventId << (reloadCal ?"): reload" :")");
 	daemonDBus()->eventHandled(eventId, reloadCal);
 	checkDBusResult("eventHandled");
 }
@@ -716,7 +717,7 @@ bool Daemon::isDaemonRegistered()
 NotificationHandler::NotificationHandler()
 	: QObject()
 {
-	kDebug(5950) << "NotificationHandler::NotificationHandler()\n";
+	kDebug(5950) << "NotificationHandler::NotificationHandler()";
 	(void)new NotifyAdaptor(this);
 	QDBusConnection::sessionBus().registerObject(NOTIFY_DBUS_OBJECT, this);
 }
@@ -728,22 +729,22 @@ NotificationHandler::NotificationHandler()
 */
 void NotificationHandler::alarmDaemonUpdate(int calendarStatus)
 {
-	kDebug(5950) << "NotificationHandler::alarmDaemonUpdate(" << calendarStatus << ")\n";
+	kDebug(5950) << "NotificationHandler::alarmDaemonUpdate(" << calendarStatus << ")";
 	KAlarmd::CalendarStatus status = KAlarmd::CalendarStatus(calendarStatus);
 	bool enabled = false;
 	switch (status)
 	{
 		case KAlarmd::CALENDAR_UNAVAILABLE:
 			// Calendar is not available for monitoring
-			kDebug(5950) << "NotificationHandler::alarmDaemonUpdate(CALENDAR_UNAVAILABLE)\n";
+			kDebug(5950) << "NotificationHandler::alarmDaemonUpdate(CALENDAR_UNAVAILABLE)";
 			break;
 		case KAlarmd::CALENDAR_DISABLED:
 			// Calendar is available for monitoring but is not currently being monitored
-			kDebug(5950) << "NotificationHandler::alarmDaemonUpdate(DISABLE_CALENDAR)\n";
+			kDebug(5950) << "NotificationHandler::alarmDaemonUpdate(DISABLE_CALENDAR)";
 			break;
 		case KAlarmd::CALENDAR_ENABLED:
 			// Calendar is currently being monitored
-			kDebug(5950) << "NotificationHandler::alarmDaemonUpdate(ENABLE_CALENDAR)\n";
+			kDebug(5950) << "NotificationHandler::alarmDaemonUpdate(ENABLE_CALENDAR)";
 			enabled = true;
 			break;
 		default:
@@ -791,7 +792,7 @@ void NotificationHandler::cacheDownloaded(const QString& resourceID)
 =============================================================================*/
 
 AlarmEnableAction::AlarmEnableAction(QObject* parent)
-	: KToggleAction(i18n("Enable &Alarms"), parent),
+	: KToggleAction(i18nc("@action", "Enable &Alarms"), parent),
 	  mInitialised(false)
 {
 	setCheckedActual(false);    // set the correct text
@@ -803,7 +804,7 @@ AlarmEnableAction::AlarmEnableAction(QObject* parent)
 */
 void AlarmEnableAction::setCheckedActual(bool running)
 {
-	kDebug(5950) << "AlarmEnableAction::setCheckedActual(" << running << ")\n";
+	kDebug(5950) << "AlarmEnableAction::setCheckedActual(" << running << ")";
 	if (running != isChecked()  ||  !mInitialised)
 	{
 		KToggleAction::setChecked(running);
@@ -817,7 +818,7 @@ void AlarmEnableAction::setCheckedActual(bool running)
 */
 void AlarmEnableAction::setChecked(bool check)
 {
-	kDebug(5950) << "AlarmEnableAction::setChecked(" << check << ")\n";
+	kDebug(5950) << "AlarmEnableAction::setChecked(" << check << ")";
 	if (check != isChecked())
 	{
 		if (check)
