@@ -25,9 +25,6 @@
 #include <QtDBus>
 #include <kdebug.h>
 
-#include <kpimidentities/identitymanager.h>
-#include <kpimidentities/identity.h>
-
 #include "alarmcalendar.h"
 #include "daemon.h"
 #include "functions.h"
@@ -47,7 +44,7 @@ static const char* REQUEST_DBUS_OBJECT = "/kalarm";   // D-Bus object path of KA
 =============================================================================*/
 DBusHandler::DBusHandler()
 {
-	kDebug(5950) << "DBusHandler::DBusHandler()\n";
+	kDebug(5950) << "DBusHandler::DBusHandler()";
 	new KalarmAdaptor(this);
 	QDBusConnection::sessionBus().registerObject(REQUEST_DBUS_OBJECT, this);
 }
@@ -66,13 +63,13 @@ bool DBusHandler::triggerEvent(const QString& eventId)
 bool DBusHandler::scheduleMessage(const QString& message, const QString& startDateTime, int lateCancel, unsigned flags,
                                   const QString& bgColor, const QString& fgColor, const QString& font,
                                   const QString& audioUrl, int reminderMins, const QString& recurrence,
-                                  int repeatInterval, int repeatCount)
+                                  int subRepeatInterval, int subRepeatCount)
 {
 	KDateTime start;
 	KARecurrence recur;
-	if (!convertRecurrence(start, recur, startDateTime, recurrence))
+	if (!convertRecurrence(start, recur, startDateTime, recurrence, subRepeatInterval))
 		return false;
-	return scheduleMessage(message, start, lateCancel, flags, bgColor, fgColor, font, KUrl(audioUrl), reminderMins, recur, repeatInterval, repeatCount);
+	return scheduleMessage(message, start, lateCancel, flags, bgColor, fgColor, font, KUrl(audioUrl), reminderMins, recur, subRepeatInterval, subRepeatCount);
 }
 
 bool DBusHandler::scheduleMessage(const QString& message, const QString& startDateTime, int lateCancel, unsigned flags,
@@ -101,13 +98,13 @@ bool DBusHandler::scheduleMessage(const QString& message, const QString& startDa
 
 bool DBusHandler::scheduleFile(const QString& url, const QString& startDateTime, int lateCancel, unsigned flags, const QString& bgColor,
                                const QString& audioUrl, int reminderMins, const QString& recurrence,
-                               int repeatInterval, int repeatCount)
+                               int subRepeatInterval, int subRepeatCount)
 {
 	KDateTime start;
 	KARecurrence recur;
-	if (!convertRecurrence(start, recur, startDateTime, recurrence))
+	if (!convertRecurrence(start, recur, startDateTime, recurrence, subRepeatInterval))
 		return false;
-	return scheduleFile(KUrl(url), start, lateCancel, flags, bgColor, KUrl(audioUrl), reminderMins, recur, repeatInterval, repeatCount);
+	return scheduleFile(KUrl(url), start, lateCancel, flags, bgColor, KUrl(audioUrl), reminderMins, recur, subRepeatInterval, subRepeatCount);
 }
 
 bool DBusHandler::scheduleFile(const QString& url, const QString& startDateTime, int lateCancel, unsigned flags, const QString& bgColor,
@@ -131,13 +128,13 @@ bool DBusHandler::scheduleFile(const QString& url, const QString& startDateTime,
 }
 
 bool DBusHandler::scheduleCommand(const QString& commandLine, const QString& startDateTime, int lateCancel, unsigned flags,
-                                  const QString& recurrence, int repeatInterval, int repeatCount)
+                                  const QString& recurrence, int subRepeatInterval, int subRepeatCount)
 {
 	KDateTime start;
 	KARecurrence recur;
-	if (!convertRecurrence(start, recur, startDateTime, recurrence))
+	if (!convertRecurrence(start, recur, startDateTime, recurrence, subRepeatInterval))
 		return false;
-	return scheduleCommand(commandLine, start, lateCancel, flags, recur, repeatInterval, repeatCount);
+	return scheduleCommand(commandLine, start, lateCancel, flags, recur, subRepeatInterval, subRepeatCount);
 }
 
 bool DBusHandler::scheduleCommand(const QString& commandLine, const QString& startDateTime, int lateCancel, unsigned flags,
@@ -164,13 +161,13 @@ bool DBusHandler::scheduleCommand(const QString& commandLine, const QString& sta
 
 bool DBusHandler::scheduleEmail(const QString& fromID, const QString& addresses, const QString& subject, const QString& message,
                                 const QString& attachments, const QString& startDateTime, int lateCancel, unsigned flags,
-                                const QString& recurrence, int repeatInterval, int repeatCount)
+                                const QString& recurrence, int subRepeatInterval, int subRepeatCount)
 {
 	KDateTime start;
 	KARecurrence recur;
-	if (!convertRecurrence(start, recur, startDateTime, recurrence))
+	if (!convertRecurrence(start, recur, startDateTime, recurrence, subRepeatInterval))
 		return false;
-	return scheduleEmail(fromID, addresses, subject, message, attachments, start, lateCancel, flags, recur, repeatInterval, repeatCount);
+	return scheduleEmail(fromID, addresses, subject, message, attachments, start, lateCancel, flags, recur, subRepeatInterval, subRepeatCount);
 }
 
 bool DBusHandler::scheduleEmail(const QString& fromID, const QString& addresses, const QString& subject, const QString& message,
@@ -212,7 +209,7 @@ bool DBusHandler::editNew(const QString& templateName)
 bool DBusHandler::scheduleMessage(const QString& message, const KDateTime& start, int lateCancel, unsigned flags,
                                   const QString& bgColor, const QString& fgColor, const QString& fontStr,
                                   const KUrl& audioFile, int reminderMins, const KARecurrence& recurrence,
-                                  int repeatInterval, int repeatCount)
+                                  int subRepeatInterval, int subRepeatCount)
 {
 	unsigned kaEventFlags = convertStartFlags(start, flags);
 	QColor bg = convertBgColour(bgColor);
@@ -226,7 +223,7 @@ bool DBusHandler::scheduleMessage(const QString& message, const KDateTime& start
 		fg.setNamedColor(fgColor);
 		if (!fg.isValid())
 		{
-			kError(5950) << "D-Bus call: invalid foreground color: " << fgColor << endl;
+			kError(5950) << "D-Bus call: invalid foreground color:" << fgColor;
 			return false;
 		}
 	}
@@ -237,12 +234,12 @@ bool DBusHandler::scheduleMessage(const QString& message, const KDateTime& start
 	{
 		if (!font.fromString(fontStr))    // N.B. this doesn't do good validation
 		{
-			kError(5950) << "D-Bus call: invalid font: " << fontStr << endl;
+			kError(5950) << "D-Bus call: invalid font:" << fontStr;
 			return false;
 		}
 	}
 	return theApp()->scheduleEvent(KAEvent::MESSAGE, message, start, lateCancel, kaEventFlags, bg, fg, font,
-	                               audioFile.url(), -1, reminderMins, recurrence, repeatInterval, repeatCount);
+	                               audioFile.url(), -1, reminderMins, recurrence, subRepeatInterval, subRepeatCount);
 }
 
 /******************************************************************************
@@ -251,14 +248,14 @@ bool DBusHandler::scheduleMessage(const QString& message, const KDateTime& start
 bool DBusHandler::scheduleFile(const KUrl& file,
                                const KDateTime& start, int lateCancel, unsigned flags, const QString& bgColor,
                                const KUrl& audioFile, int reminderMins, const KARecurrence& recurrence,
-                               int repeatInterval, int repeatCount)
+                               int subRepeatInterval, int subRepeatCount)
 {
 	unsigned kaEventFlags = convertStartFlags(start, flags);
 	QColor bg = convertBgColour(bgColor);
 	if (!bg.isValid())
 		return false;
 	return theApp()->scheduleEvent(KAEvent::FILE, file.url(), start, lateCancel, kaEventFlags, bg, Qt::black, QFont(),
-	                               audioFile.url(), -1, reminderMins, recurrence, repeatInterval, repeatCount);
+	                               audioFile.url(), -1, reminderMins, recurrence, subRepeatInterval, subRepeatCount);
 }
 
 /******************************************************************************
@@ -266,11 +263,11 @@ bool DBusHandler::scheduleFile(const KUrl& file,
 */
 bool DBusHandler::scheduleCommand(const QString& commandLine,
                                   const KDateTime& start, int lateCancel, unsigned flags,
-                                  const KARecurrence& recurrence, int repeatInterval, int repeatCount)
+                                  const KARecurrence& recurrence, int subRepeatInterval, int subRepeatCount)
 {
 	unsigned kaEventFlags = convertStartFlags(start, flags);
 	return theApp()->scheduleEvent(KAEvent::COMMAND, commandLine, start, lateCancel, kaEventFlags, Qt::black, Qt::black, QFont(),
-	                               QString(), -1, 0, recurrence, repeatInterval, repeatCount);
+	                               QString(), -1, 0, recurrence, subRepeatInterval, subRepeatCount);
 }
 
 /******************************************************************************
@@ -279,14 +276,16 @@ bool DBusHandler::scheduleCommand(const QString& commandLine,
 bool DBusHandler::scheduleEmail(const QString& fromID, const QString& addresses, const QString& subject,
                                 const QString& message, const QString& attachments,
                                 const KDateTime& start, int lateCancel, unsigned flags,
-                                const KARecurrence& recurrence, int repeatInterval, int repeatCount)
+                                const KARecurrence& recurrence, int subRepeatInterval, int subRepeatCount)
 {
 	unsigned kaEventFlags = convertStartFlags(start, flags);
+	uint senderId = 0;
 	if (!fromID.isEmpty())
 	{
-		if (KAMail::identityManager()->identityForName(fromID).isNull())
+		senderId = KAMail::identityUoid(fromID);
+		if (!senderId)
 		{
-			kError(5950) << "D-Bus call scheduleEmail(): unknown sender ID: " << fromID << endl;
+			kError(5950) << "D-Bus call scheduleEmail(): unknown sender ID:" << fromID;
 			return false;
 		}
 	}
@@ -294,23 +293,23 @@ bool DBusHandler::scheduleEmail(const QString& fromID, const QString& addresses,
 	QString bad = KAMail::convertAddresses(addresses, addrs);
 	if (!bad.isEmpty())
 	{
-		kError(5950) << "D-Bus call scheduleEmail(): invalid email addresses: " << bad << endl;
+		kError(5950) << "D-Bus call scheduleEmail(): invalid email addresses:" << bad;
 		return false;
 	}
 	if (addrs.isEmpty())
 	{
-		kError(5950) << "D-Bus call scheduleEmail(): no email address\n";
+		kError(5950) << "D-Bus call scheduleEmail(): no email address";
 		return false;
 	}
 	QStringList atts;
 	bad = KAMail::convertAttachments(attachments, atts);
 	if (!bad.isEmpty())
 	{
-		kError(5950) << "D-Bus call scheduleEmail(): invalid email attachment: " << bad << endl;
+		kError(5950) << "D-Bus call scheduleEmail(): invalid email attachment:" << bad;
 		return false;
 	}
 	return theApp()->scheduleEvent(KAEvent::EMAIL, message, start, lateCancel, kaEventFlags, Qt::black, Qt::black, QFont(),
-	                               QString(), -1, 0, recurrence, repeatInterval, repeatCount, fromID, addrs, subject, atts);
+	                               QString(), -1, 0, recurrence, subRepeatInterval, subRepeatCount, senderId, addrs, subject, atts);
 }
 
 
@@ -367,9 +366,9 @@ KDateTime DBusHandler::convertDateTime(const QString& dateTime, const KDateTime&
 	if (error  ||  !result.isValid())
 	{
 		if (!defaultDt.isValid())
-			kError(5950) << "D-Bus call: invalid start date/time: '" << dateTime << "'" << endl;
+			kError(5950) << "D-Bus call: invalid start date/time: '" << dateTime << "'";
 		else
-			kError(5950) << "D-Bus call: invalid recurrence end date/time: '" << dateTime << "'" << endl;
+			kError(5950) << "D-Bus call: invalid recurrence end date/time: '" << dateTime << "'";
 	}
 	return result;
 }
@@ -404,17 +403,25 @@ QColor DBusHandler::convertBgColour(const QString& bgColor)
 		return Preferences::defaultBgColour();
 	QColor bg(bgColor);
 	if (!bg.isValid())
-			kError(5950) << "D-Bus call: invalid background color: " << bgColor << endl;
+			kError(5950) << "D-Bus call: invalid background color:" << bgColor;
 	return bg;
 }
 
 bool DBusHandler::convertRecurrence(KDateTime& start, KARecurrence& recurrence, 
-                                    const QString& startDateTime, const QString& icalRecurrence)
+                                    const QString& startDateTime, const QString& icalRecurrence,
+				    int& subRepeatInterval)
 {
 	start = convertDateTime(startDateTime);
 	if (!start.isValid())
 		return false;
-	return recurrence.set(icalRecurrence);
+	if (!recurrence.set(icalRecurrence))
+		return false;
+	if (subRepeatInterval  &&  recurrence.type() == KARecurrence::NO_RECUR)
+	{
+		subRepeatInterval = 0;
+		kWarning(5950) << "D-Bus call: no recurrence specified, so sub-repetition ignored";
+	}
+	return true;
 }
 
 bool DBusHandler::convertRecurrence(KDateTime& start, KARecurrence& recurrence, const QString& startDateTime,
@@ -435,12 +442,12 @@ bool DBusHandler::convertRecurrence(KDateTime& start, KARecurrence& recurrence,
 	KDateTime end = convertDateTime(endDateTime, start);
 	if (end.isDateOnly()  &&  !start.isDateOnly())
 	{
-		kError(5950) << "D-Bus call: alarm is date-only, but recurrence end is date/time" << endl;
+		kError(5950) << "D-Bus call: alarm is date-only, but recurrence end is date/time";
 		return false;
 	}
 	if (!end.isDateOnly()  &&  start.isDateOnly())
 	{
-		kError(5950) << "D-Bus call: alarm is timed, but recurrence end is date-only" << endl;
+		kError(5950) << "D-Bus call: alarm is timed, but recurrence end is date-only";
 		return false;
 	}
 	return convertRecurrence(recurrence, start, recurType, recurInterval, 0, end);
@@ -459,7 +466,7 @@ bool DBusHandler::convertRecurrence(KARecurrence& recurrence, const KDateTime& s
 		case YEARLY:    type = KARecurrence::ANNUAL_DATE;  break;
 			break;
 		default:
-			kError(5950) << "D-Bus call: invalid repeat type: " << recurType << endl;
+			kError(5950) << "D-Bus call: invalid recurrence type:" << recurType;
 			return false;
 	}
 	recurrence.set(type, recurInterval, recurCount, start, end);
