@@ -27,6 +27,8 @@
 #include <kiconloader.h>
 #include <kdebug.h>
 
+#include "resources/alarmresource.h"
+#include "resources/alarmresources.h"
 #include "resources/kcalendar.h"
 #include "alarmcalendar.h"
 #include "alarmtext.h"
@@ -57,7 +59,7 @@ EventListModel* EventListModel::alarms()
 		mAlarmInstance = new EventListModel(static_cast<KCalEvent::Status>(KCalEvent::ACTIVE | KCalEvent::ARCHIVED));
 		Preferences::connect(SIGNAL(archivedColourChanged(const QColor&)), mAlarmInstance, SLOT(slotUpdateArchivedColour(const QColor&)));
 		Preferences::connect(SIGNAL(disabledColourChanged(const QColor&)), mAlarmInstance, SLOT(slotUpdateDisabledColour(const QColor&)));
-		Preferences::connect(SIGNAL(workTimeChanged(const QTime&, const QTime&, const QBitArray&)), mAlarmInstance, SLOT(:slotUpdateWorkingHours()));
+		Preferences::connect(SIGNAL(workTimeChanged(const QTime&, const QTime&, const QBitArray&)), mAlarmInstance, SLOT(slotUpdateWorkingHours()));
 	}
 	return mAlarmInstance;
 }
@@ -78,7 +80,7 @@ EventListModel::EventListModel(KCalEvent::Status status, QObject* parent)
 	// We need to store the list so that when deletions occur, the deleted alarm's
 	// position in the list can be determined.
 	mEvents = AlarmCalendar::resources()->events(mStatus);
-for(int x=0; x<mEvents.count(); ++x)kDebug()<<"Event "<<(void*)mEvents[x]<<endl;
+for(int x=0; x<mEvents.count(); ++x)kDebug()<<"Event"<<(void*)mEvents[x];
 	if (!mTextIcon)
 	{
 		mTextIcon    = new QPixmap(SmallIcon("text"));
@@ -88,6 +90,7 @@ for(int x=0; x<mEvents.count(); ++x)kDebug()<<"Event "<<(void*)mEvents[x]<<endl;
 		mIconSize = mTextIcon->size().expandedTo(mFileIcon->size()).expandedTo(mCommandIcon->size()).expandedTo(mEmailIcon->size());
 	}
 	MinuteTimer::connect(this, SLOT(slotUpdateTimeTo()));
+	connect(AlarmResources::instance(), SIGNAL(resourceStatusChanged(AlarmResource*, AlarmResources::Change)), SLOT(slotResourceStatusChanged(AlarmResource*, AlarmResources::Change)));
 }
 
 int EventListModel::rowCount(const QModelIndex& parent) const
@@ -133,11 +136,15 @@ QVariant EventListModel::data(const QModelIndex& index, int role) const
 		default:
 			break;
 	}
+	bool resourceColour = false;
 	switch (column)
 	{
 		case TimeColumn:
 			switch (role)
 			{
+				case Qt::BackgroundRole:
+					resourceColour = true;
+					break;
 				case Qt::DisplayRole:
 				{
 					DateTime due = event.expired() ? event.startDateTime() : event.displayDateTime();
@@ -146,7 +153,7 @@ QVariant EventListModel::data(const QModelIndex& index, int role) const
 				case SortRole:
 				{
 					DateTime due = event.expired() ? event.startDateTime() : event.displayDateTime();
-					return due.isValid() ? KDateTime(due).toUtc().dateTime()
+					return due.isValid() ? due.effectiveKDateTime().toUtc().dateTime()
 					                     : QDateTime(QDate(9999,12,31), QTime(0,0,0));
 				}
 				default:
@@ -156,6 +163,9 @@ QVariant EventListModel::data(const QModelIndex& index, int role) const
 		case TimeToColumn:
 			switch (role)
 			{
+				case Qt::BackgroundRole:
+					resourceColour = true;
+					break;
 				case Qt::DisplayRole:
 					if (event.expired())
 						return QString();
@@ -175,6 +185,9 @@ QVariant EventListModel::data(const QModelIndex& index, int role) const
 		case RepeatColumn:
 			switch (role)
 			{
+				case Qt::BackgroundRole:
+					resourceColour = true;
+					break;
 				case Qt::DisplayRole:
 					return repeatText(event);
 				case Qt::TextAlignmentRole:
@@ -207,10 +220,6 @@ QVariant EventListModel::data(const QModelIndex& index, int role) const
 					v.setValue(*eventIcon(event));
 					return v;
 				}
-case Qt::BackgroundRole:
-if (event.action() == KAEvent::COMMAND)
-	return QColor(Qt::red);
-break;
 				case Qt::TextAlignmentRole:
 					return Qt::AlignHCenter;
 				case Qt::SizeHintRole:
@@ -229,6 +238,9 @@ break;
 		case TextColumn:
 			switch (role)
 			{
+				case Qt::BackgroundRole:
+					resourceColour = true;
+					break;
 				case Qt::DisplayRole:
 				case SortRole:
 					return AlarmText::summary(event, 1);
@@ -241,6 +253,9 @@ break;
 		case TemplateNameColumn:
 			switch (role)
 			{
+				case Qt::BackgroundRole:
+					resourceColour = true;
+					break;
 				case Qt::DisplayRole:
 					return event.templateName();
 				case SortRole:
@@ -250,6 +265,13 @@ break;
 		default:
 			break;
 	}
+
+	if (resourceColour)
+	{
+		AlarmResource* resource = AlarmResources::instance()->resourceForIncidence(event.id());
+		if (resource  &&  resource->colour().isValid())
+			return resource->colour();
+	}
 	return QVariant();
 }
 
@@ -274,19 +296,19 @@ QVariant EventListModel::headerData(int section, Qt::Orientation orientation, in
 			switch (section)
 			{
 				case TimeColumn:
-					return i18n("Time");
+					return i18nc("@title:column", "Time");
 				case TimeToColumn:
-					return i18n("Time To");
+					return i18nc("@title:column", "Time To");
 				case RepeatColumn:
-					return i18n("Repeat");
+					return i18nc("@title:column", "Repeat");
 				case ColourColumn:
 					return QString();
 				case TypeColumn:
 					return QString();
 				case TextColumn:
-					return i18n("Message, File or Command");
+					return i18nc("@title:column", "Message, File or Command");
 				case TemplateNameColumn:
-					return i18n("Name");
+					return i18nc("@title:column Template name", "Name");
 			}
 		}
 		else if (role == Qt::WhatsThisRole)
@@ -317,7 +339,7 @@ void EventListModel::slotUpdateTimeTo()
 */
 void EventListModel::slotUpdateArchivedColour(const QColor&)
 {
-kDebug(5950)<<"EventListModel::slotUpdateArchivedColour()"<<endl;
+	kDebug(5950) << "EventListModel::slotUpdateArchivedColour()";
 	int firstRow = -1;
 	for (int row = 0, end = mEvents.count();  row < end;  ++row)
 	{
@@ -344,7 +366,7 @@ kDebug(5950)<<"EventListModel::slotUpdateArchivedColour()"<<endl;
 */
 void EventListModel::slotUpdateDisabledColour(const QColor&)
 {
-kDebug(5950)<<"EventListModel::slotUpdateDisabledColour()"<<endl;
+	kDebug(5950) << "EventListModel::slotUpdateDisabledColour()";
 	int firstRow = -1;
 	for (int row = 0, end = mEvents.count();  row < end;  ++row)
 	{
@@ -373,14 +395,14 @@ kDebug(5950)<<"EventListModel::slotUpdateDisabledColour()"<<endl;
 */
 void EventListModel::slotUpdateWorkingHours()
 {
-kDebug(5950)<<"EventListModel::slotUpdateWorkingHours()"<<endl;
+	kDebug(5950) << "EventListModel::slotUpdateWorkingHours()";
 	int firstRow = -1;
 	for (int row = 0, end = mEvents.count();  row < end;  ++row)
 	{
 		if (KAEvent(mEvents[row]).workTimeOnly())
 		{
 			// For efficiency, emit a single signal for each group
-			// of consecutive archived alarms, rather than a separate
+			// of consecutive alarms to update, rather than a separate
 			// signal for each alarm.
 			if (firstRow < 0)
 				firstRow = row;
@@ -399,6 +421,116 @@ kDebug(5950)<<"EventListModel::slotUpdateWorkingHours()"<<endl;
 	}
 }
 
+/******************************************************************************
+* Called when a resource status has changed.
+*/
+void EventListModel::slotResourceStatusChanged(AlarmResource* resource, AlarmResources::Change change)
+{
+	bool added = false;
+	switch (change)
+	{
+		case AlarmResources::Added:
+			kDebug(5950) << "EventListModel::slotResourceStatusChanged(Added)";
+			added = true;
+			break;
+		case AlarmResources::Deleted:
+			kDebug(5950) << "EventListModel::slotResourceStatusChanged(Deleted)";
+			removeResource(resource);
+			return;
+		case AlarmResources::Location:
+			kDebug(5950) << "EventListModel::slotResourceStatusChanged(Location)";
+			removeResource(resource);
+			added = true;
+			break;
+		case AlarmResources::Enabled:
+			if (resource->isActive())
+				added = true;
+			else
+				removeResource(resource);
+			break;
+		case AlarmResources::Colour:
+		{
+			kDebug(5950) << "EventListModel::slotResourceStatusChanged(Colour)";
+			AlarmResources* resources = AlarmResources::instance();
+			int firstRow = -1;
+			for (int row = 0, end = mEvents.count();  row < end;  ++row)
+			{
+				if (resources->resource(mEvents[row]) == resource)
+				{
+					// For efficiency, emit a single signal for each group
+					// of consecutive alarms for the resource, rather than a separate
+					// signal for each alarm.
+					if (firstRow < 0)
+						firstRow = row;
+				}
+				else if (firstRow >= 0)
+				{
+					emit dataChanged(index(firstRow, 0), index(row - 1, ColumnCount - 1));
+					firstRow = -1;
+				}
+			}
+			if (firstRow >= 0)
+				emit dataChanged(index(firstRow, 0), index(mEvents.count() - 1, ColumnCount - 1));
+			return;
+		}
+		case AlarmResources::ReadOnly:
+			return;
+	}
+
+	if (added)
+	{
+		KCal::Event::List list = AlarmCalendar::resources()->events(resource, mStatus);
+		if (!list.isEmpty())
+		{
+			int row = mEvents.count();
+			beginInsertRows(QModelIndex(), row, row + list.count() - 1);
+			mEvents += list;
+			endInsertRows();
+		}
+	}
+}
+
+/******************************************************************************
+* Remove a resource's events from the list.
+* This has to be called before the resource is actually deleted. If not, timer
+* based updates can occur between the resource being deleted and
+* slotResourceStatusChanged(Deleted) being triggered, leading to crashes when
+* data from the resource's events is fetched.
+*/
+void EventListModel::removeResource(AlarmResource* resource)
+{
+	kDebug(5950) << "EventListModel::removeResource()";
+	AlarmResources* resources = AlarmResources::instance();
+	int lastRow = -1;
+	for (int row = mEvents.count();  --row >= 0; )
+	{
+		AlarmResource* r = resources->resource(mEvents[row]);
+		if (!r  ||  r == resource)
+		{
+			// For efficiency, delete each group of consecutive
+			// alarms for the resource, rather than deleting each
+			// alarm separately.
+			if (lastRow < 0)
+				lastRow = row;
+		}
+		else if (lastRow >= 0)
+		{
+			beginRemoveRows(QModelIndex(), row + 1, lastRow);
+			while (lastRow > row)
+				mEvents.removeAt(lastRow--);
+			endRemoveRows();
+			lastRow = -1;
+		}
+	}
+	if (lastRow >= 0)
+	{
+		beginRemoveRows(QModelIndex(), 0, lastRow);
+		while (lastRow >= 0)
+			mEvents.removeAt(lastRow--);
+		endRemoveRows();
+	}
+}
+
 /******************************************************************************
 * Reload the event list.
 */
@@ -457,6 +589,21 @@ void EventListModel::addEvent(KCal::Event* event)
 	endInsertRows();
 }
 
+/******************************************************************************
+* Add an event to the list.
+*/
+void EventListModel::addEvents(const KCal::Event::List& events)
+{
+	KCal::Event::List evs;
+	for (int i = 0, count = events.count();  i < count;  ++i)
+		if (KAEvent(events[i]).category() & mStatus)
+			evs += events[i];
+	int row = mEvents.count();
+	beginInsertRows(QModelIndex(), row, row + evs.count() - 1);
+	mEvents += evs;
+	endInsertRows();
+}
+
 /******************************************************************************
 * Remove an event from the list.
 */
@@ -517,7 +664,7 @@ KCal::Event* EventListModel::event(const QModelIndex& index)
 QString EventListModel::alarmTimeText(const DateTime& dateTime) const
 {
 	if (!dateTime.isValid())
-		return i18n("Never");
+		return i18nc("@info Alarm never occurs", "Never");
 	KLocale* locale = KGlobal::locale();
 	KDateTime kdt = dateTime.effectiveKDateTime().toTimeSpec(Preferences::timeZone());
 	QString dateTimeText = locale->formatDate(kdt.date(), KLocale::ShortDate);
@@ -554,13 +701,13 @@ QString EventListModel::alarmTimeText(const DateTime& dateTime) const
 QString EventListModel::timeToAlarmText(const DateTime& dateTime) const
 {
 	if (!dateTime.isValid())
-		return i18n("Never");
+		return i18nc("@info Alarm never occurs", "Never");
 	KDateTime now = KDateTime::currentUtcDateTime();
 	if (dateTime.isDateOnly())
 	{
 		int days = now.date().daysTo(dateTime.date());
 		// xgettext: no-c-format
-		return i18nc("n days", " %1d ", days);
+		return i18nc("@info n days", " %1d ", days);
 	}
 	int mins = (now.secsTo(dateTime.effectiveKDateTime()) + 59) / 60;
 	if (mins < 0)
@@ -569,10 +716,10 @@ QString EventListModel::timeToAlarmText(const DateTime& dateTime) const
 	minutes[0] = (mins%60) / 10 + '0';
 	minutes[1] = (mins%60) % 10 + '0';
 	if (mins < 24*60)
-		return i18nc("hours:minutes", " %1:%2 ", mins/60, minutes);
+		return i18nc("@info hours:minutes", " %1:%2 ", mins/60, minutes);
 	int days = mins / (24*60);
 	mins = mins % (24*60);
-	return i18nc("days hours:minutes", " %1d %2:%3 ", days, mins/60, minutes);
+	return i18nc("@info days hours:minutes", " %1d %2:%3 ", days, mins/60, minutes);
 }
 
 /******************************************************************************
@@ -648,21 +795,21 @@ QString EventListModel::whatsThisText(int column) const
 	switch (column)
 	{
 		case TimeColumn:
-			return i18n("Next scheduled date and time of the alarm");
+			return i18nc("@info:whatsthis", "Next scheduled date and time of the alarm");
 		case TimeToColumn:
-			return i18n("How long until the next scheduled trigger of the alarm");
+			return i18nc("@info:whatsthis", "How long until the next scheduled trigger of the alarm");
 		case RepeatColumn:
-			return i18n("How often the alarm recurs");
+			return i18nc("@info:whatsthis", "How often the alarm recurs");
 		case ColourColumn:
-			return i18n("Background color of alarm message");
+			return i18nc("@info:whatsthis", "Background color of alarm message");
 		case TypeColumn:
-			return i18n("Alarm type (message, file, command or email)");
+			return i18nc("@info:whatsthis", "Alarm type (message, file, command or email)");
 		case TextColumn:
-			return i18n("Alarm message text, URL of text file to display, command to execute, or email subject line");
+			return i18nc("@info:whatsthis", "Alarm message text, URL of text file to display, command to execute, or email subject line");
 		case TemplateNameColumn:
-			return i18n("Name of the alarm template");
+			return i18nc("@info:whatsthis", "Name of the alarm template");
 		default:
-			return i18n("List of scheduled alarms");
+			return i18nc("@info:whatsthis", "List of scheduled alarms");
 	}
 }
 
@@ -691,3 +838,8 @@ KCal::Event* EventListFilterModel::event(int row) const
 {
 	return static_cast<EventListModel*>(sourceModel())->event(mapToSource(index(row, 0)));
 }
+
+void EventListFilterModel::slotDataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight)
+{
+	emit dataChanged(mapFromSource(topLeft), mapFromSource(bottomRight));
+}
