@@ -47,6 +47,7 @@
 #include <kactioncollection.h>
 #include <kglobal.h>
 #include <klocale.h>
+#include <kstandarddirs.h>
 #include <ksystemtimezone.h>
 #include <KStandardGuiItem>
 #include <kstandardshortcut.h>
@@ -72,12 +73,15 @@ QDBusInterface* korgInterface = 0;
 
 const char*   KORG_DBUS_WINDOW  = "MainWindow_1";
 const char*   KMAIL_DBUS_WINDOW = "kmail_mainwindow1";
-static const char* KMAIL_DBUS_SERVICE = "org.kde.kmail";
-static const char* KORG_DBUS_SERVICE = "org.kde.korganizer";
-static const char* KORG_DBUS_IFACE   = "org.kde.korganizer.Korganizer";
-static const char* KORG_DBUS_OBJECT  = "/";    // D-Bus object path of KOrganizer's notification interface
+const char*   KMAIL_DBUS_SERVICE = "org.kde.kmail";
+const char*   KORG_DBUS_SERVICE = "org.kde.korganizer";
+const char*   KORG_DBUS_IFACE   = "org.kde.korganizer.Korganizer";
+const char*   KORG_DBUS_OBJECT  = "/";    // D-Bus object path of KOrganizer's notification interface
 const QString KORGANIZER_UID    = QString::fromLatin1("-korg");
 
+const char*   ALARM_OPTS_FILE        = "alarmopts";
+const char*   DONT_SHOW_ERRORS_GROUP = "DontShowErrors";
+
 bool sendToKOrganizer(const KAEvent&);
 bool deleteFromKOrganizer(const QString& eventID);
 bool runKOrganizer();
@@ -88,6 +92,9 @@ QString uidKOrganizer(const QString& eventID);
 namespace KAlarm
 {
 
+void doEditNewAlarm(EditAlarmDlg*);
+
+
 /******************************************************************************
 *  Display a main window with the specified event selected.
 */
@@ -118,18 +125,6 @@ MainWindow* displayMainWindowSelected(const QString& eventID)
 	return win;
 }
 
-/******************************************************************************
-* Create a New Alarm QAction.
-*/
-QAction* createNewAlarmAction(const QString& label, KActionCollection* actions, const QString& name)
-{
-	QAction* action = actions->addAction(name);
-	action->setIcon(KIcon(QLatin1String("document-new")));
-	action->setText(label);
-	action->setShortcuts(KStandardShortcut::openNew());
-	return action;
-}
-
 /******************************************************************************
 * Create a New From Template QAction.
 */
@@ -147,7 +142,7 @@ TemplateMenuAction* createNewFromTemplateAction(const QString& label, KActionCol
 */
 UpdateStatus addEvent(KAEvent& event, AlarmResource* resource, QWidget* msgParent, int options, bool showKOrgErr)
 {
-	kDebug(5950) << "KAlarm::addEvent(): " << event.id() << endl;
+	kDebug(5950) << "KAlarm::addEvent():" << event.id();
 	UpdateStatus status = UPDATE_OK;
 	if (!theApp()->checkCalendarDaemon())    // ensure calendar is open and daemon started
 		status = UPDATE_FAILED;
@@ -185,7 +180,7 @@ UpdateStatus addEvent(KAEvent& event, AlarmResource* resource, QWidget* msgParen
 */
 UpdateStatus addEvents(QList<KAEvent>& events, QWidget* msgParent, bool allowKOrgUpdate, bool showKOrgErr)
 {
-	kDebug(5950) << "KAlarm::addEvents(" << events.count() << ")\n";
+	kDebug(5950) << "KAlarm::addEvents(" << events.count() << ")";
 	if (events.isEmpty())
 		return UPDATE_OK;
 	int warnErr = 0;
@@ -199,7 +194,7 @@ UpdateStatus addEvents(QList<KAEvent>& events, QWidget* msgParent, bool allowKOr
 		resource = AlarmResources::instance()->destination(KCalEvent::ACTIVE, msgParent);
 		if (!resource)
 		{
-			kDebug(5950) << "KAlarm::addEvents(): no resource" << endl;
+			kDebug(5950) << "KAlarm::addEvents(): no resource";
 			status = UPDATE_FAILED;
 		}
 	}
@@ -252,7 +247,7 @@ UpdateStatus addEvents(QList<KAEvent>& events, QWidget* msgParent, bool allowKOr
 */
 bool addArchivedEvent(KAEvent& event, AlarmResource* resource)
 {
-	kDebug(5950) << "KAlarm::addArchivedEvent(" << event.id() << ")\n";
+	kDebug(5950) << "KAlarm::addArchivedEvent(" << event.id() << ")";
 	KAEvent oldEvent = event;     // so that we can reinstate the event if there's an error
 	bool archiving = (event.category() == KCalEvent::ACTIVE);
 	if (archiving)
@@ -288,7 +283,7 @@ bool addArchivedEvent(KAEvent& event, AlarmResource* resource)
 */
 UpdateStatus addTemplate(KAEvent& event, AlarmResource* resource, QWidget* msgParent)
 {
-	kDebug(5950) << "KAlarm::addTemplate(): " << event.id() << endl;
+	kDebug(5950) << "KAlarm::addTemplate():" << event.id();
 	UpdateStatus status = UPDATE_OK;
 
 	// Add the template to the calendar file
@@ -319,7 +314,7 @@ UpdateStatus addTemplate(KAEvent& event, AlarmResource* resource, QWidget* msgPa
 */
 UpdateStatus modifyEvent(KAEvent& oldEvent, const KAEvent& newEvent, QWidget* msgParent, bool showKOrgErr)
 {
-	kDebug(5950) << "KAlarm::modifyEvent(): '" << oldEvent.id() << endl;
+	kDebug(5950) << "KAlarm::modifyEvent(): '" << oldEvent.id();
 
 	UpdateStatus status = UPDATE_OK;
 	if (!newEvent.valid())
@@ -354,6 +349,9 @@ UpdateStatus modifyEvent(KAEvent& oldEvent, const KAEvent& newEvent, QWidget* ms
 					status = UPDATE_KORG_ERR;
 			}
 
+			// Remove "Don't show error messages again" for the old alarm
+			setDontShowErrors(oldId);
+
 			// Update the window lists
 			EventListModel::alarms()->updateEvent(oldKcalEvent, kcalEvent);
 		}
@@ -373,7 +371,7 @@ UpdateStatus modifyEvent(KAEvent& oldEvent, const KAEvent& newEvent, QWidget* ms
 */
 UpdateStatus updateEvent(KAEvent& event, QWidget* msgParent, bool archiveOnDelete, bool incRevision)
 {
-	kDebug(5950) << "KAlarm::updateEvent(): " << event.id() << endl;
+	kDebug(5950) << "KAlarm::updateEvent():" << event.id();
 
 	if (!event.valid())
 		deleteEvent(event, archiveOnDelete);
@@ -430,7 +428,7 @@ UpdateStatus deleteEvent(KAEvent& event, bool archive, QWidget* msgParent, bool
 
 UpdateStatus deleteEvents(QList<KAEvent>& events, bool archive, QWidget* msgParent, bool showKOrgErr)
 {
-	kDebug(5950) << "KAlarm::deleteEvents(" << events.count() << ")\n";
+	kDebug(5950) << "KAlarm::deleteEvents(" << events.count() << ")";
 	if (events.isEmpty())
 		return UPDATE_OK;
 	int warnErr = 0;
@@ -463,12 +461,18 @@ UpdateStatus deleteEvents(QList<KAEvent>& events, bool archive, QWidget* msgPare
 			}
 			if (archive  &&  event.toBeArchived())
 				addArchivedEvent(event);     // this changes the event ID to an archived ID
+#ifdef __GNUC__
+#warning Prevent calendar being saved for each addArchivedEvent()
+#endif
 		}
 		if (!cal->deleteEvent(id, false))   // don't save calendar after deleting
 		{
 			status = UPDATE_ERROR;
 			++warnErr;
 		}
+
+		// Remove "Don't show error messages again" for this alarm
+		setDontShowErrors(id);
 	}
 
 	if (warnErr == events.count())
@@ -488,7 +492,7 @@ UpdateStatus deleteEvents(QList<KAEvent>& events, bool archive, QWidget* msgPare
 */
 UpdateStatus deleteTemplates(const QStringList& eventIDs, QWidget* msgParent)
 {
-	kDebug(5950) << "KAlarm::deleteTemplates(" << eventIDs.count() << ")\n";
+	kDebug(5950) << "KAlarm::deleteTemplates(" << eventIDs.count() << ")";
 	if (eventIDs.isEmpty())
 		return UPDATE_OK;
 	int warnErr = 0;
@@ -527,7 +531,7 @@ UpdateStatus deleteTemplates(const QStringList& eventIDs, QWidget* msgParent)
 */
 void deleteDisplayEvent(const QString& eventID)
 {
-	kDebug(5950) << "KAlarm::deleteDisplayEvent(" << eventID << ")\n";
+	kDebug(5950) << "KAlarm::deleteDisplayEvent(" << eventID << ")";
 	AlarmCalendar* cal = AlarmCalendar::displayCalendarOpen();
 	if (cal)
 		cal->deleteEvent(eventID, true);   // save calendar after deleting
@@ -548,7 +552,7 @@ UpdateStatus reactivateEvent(KAEvent& event, AlarmResource* resource, QWidget* m
 
 UpdateStatus reactivateEvents(QList<KAEvent>& events, QStringList& ineligibleIDs, AlarmResource* resource, QWidget* msgParent, bool showKOrgErr)
 {
-	kDebug(5950) << "KAlarm::reactivateEvents(" << events.count() << ")\n";
+	kDebug(5950) << "KAlarm::reactivateEvents(" << events.count() << ")";
 	ineligibleIDs.clear();
 	if (events.isEmpty())
 		return UPDATE_OK;
@@ -559,7 +563,7 @@ UpdateStatus reactivateEvents(QList<KAEvent>& events, QStringList& ineligibleIDs
 		resource = AlarmResources::instance()->destination(KCalEvent::ACTIVE, msgParent);
 	if (!resource)
 	{
-		kDebug(5950) << "KAlarm::reactivateEvents(): no resource" << endl;
+		kDebug(5950) << "KAlarm::reactivateEvents(): no resource";
 		status = UPDATE_FAILED;
 		warnErr = events.count();
 	}
@@ -640,7 +644,7 @@ UpdateStatus reactivateEvents(QList<KAEvent>& events, QStringList& ineligibleIDs
 */
 UpdateStatus enableEvents(QList<KAEvent>& events, bool enable, QWidget* msgParent)
 {
-	kDebug(5950) << "KAlarm::enableEvents(" << events.count() << ")\n";
+	kDebug(5950) << "KAlarm::enableEvents(" << events.count() << ")";
 	if (events.isEmpty())
 		return UPDATE_OK;
 	UpdateStatus status = UPDATE_OK;
@@ -686,7 +690,7 @@ void purgeArchive(int purgeDays)
 {
 	if (purgeDays < 0)
 		return;
-	kDebug(5950) << "KAlarm::purgeArchive(" << purgeDays << ")\n";
+	kDebug(5950) << "KAlarm::purgeArchive(" << purgeDays << ")";
 	QDate cutoff = QDate::currentDate().addDays(-purgeDays);
 	AlarmResource* resource = AlarmResources::instance()->getStandardResource(AlarmResource::ARCHIVED);
 	if (!resource)
@@ -715,20 +719,20 @@ void displayUpdateError(QWidget* parent, UpdateStatus status, UpdateError code,
 		{
 			case ERR_ADD:
 			case ERR_MODIFY:
-				errmsg = (nAlarms > 1) ? i18n("Error saving alarms")
-				                       : i18n("Error saving alarm");
+				errmsg = (nAlarms > 1) ? i18nc("@info", "Error saving alarms")
+				                       : i18nc("@info", "Error saving alarm");
 				break;
 			case ERR_DELETE:
-				errmsg = (nAlarms > 1) ? i18n("Error deleting alarms")
-				                       : i18n("Error deleting alarm");
+				errmsg = (nAlarms > 1) ? i18nc("@info", "Error deleting alarms")
+				                       : i18nc("@info", "Error deleting alarm");
 				break;
 			case ERR_REACTIVATE:
-				errmsg = (nAlarms > 1) ? i18n("Error saving reactivated alarms")
-				                       : i18n("Error saving reactivated alarm");
+				errmsg = (nAlarms > 1) ? i18nc("@info", "Error saving reactivated alarms")
+				                       : i18nc("@info", "Error saving reactivated alarm");
 				break;
 			case ERR_TEMPLATE:
-				errmsg = (nAlarms > 1) ? i18n("Error saving alarm templates")
-				                       : i18n("Error saving alarm template");
+				errmsg = (nAlarms > 1) ? i18nc("@info", "Error saving alarm templates")
+				                       : i18nc("@info", "Error saving alarm template");
 				break;
 		}
 		KMessageBox::error(parent, errmsg);
@@ -747,15 +751,15 @@ void displayKOrgUpdateError(QWidget* parent, UpdateError code, int nAlarms)
 	{
 		case ERR_ADD:
 		case ERR_REACTIVATE:
-			errmsg = (nAlarms > 1) ? i18n("Unable to show alarms in KOrganizer")
-			                       : i18n("Unable to show alarm in KOrganizer");
+			errmsg = (nAlarms > 1) ? i18nc("@info", "Unable to show alarms in KOrganizer")
+			                       : i18nc("@info", "Unable to show alarm in KOrganizer");
 			break;
 		case ERR_MODIFY:
-			errmsg = i18n("Unable to update alarm in KOrganizer");
+			errmsg = i18nc("@info", "Unable to update alarm in KOrganizer");
 			break;
 		case ERR_DELETE:
-			errmsg = (nAlarms > 1) ? i18n("Unable to delete alarms from KOrganizer")
-			                       : i18n("Unable to delete alarm from KOrganizer");
+			errmsg = (nAlarms > 1) ? i18nc("@info", "Unable to delete alarms from KOrganizer")
+			                       : i18nc("@info", "Unable to delete alarm from KOrganizer");
 			break;
 		case ERR_TEMPLATE:
 			return;
@@ -763,102 +767,165 @@ void displayKOrgUpdateError(QWidget* parent, UpdateError code, int nAlarms)
 	KMessageBox::error(parent, errmsg);
 }
 
+/******************************************************************************
+* Execute a New Alarm dialog for the specified alarm type.
+*/
+void editNewAlarm(EditAlarmDlg::Type type, QWidget* parent)
+{
+	EditAlarmDlg* editDlg = EditAlarmDlg::create(false, type, true, parent);
+	doEditNewAlarm(editDlg);
+	delete editDlg;
+}
+
+/******************************************************************************
+* Execute a New Alarm dialog for the specified alarm type.
+*/
+void editNewAlarm(KAEvent::Action action, QWidget* parent, const AlarmText* text)
+{
+	bool setAction = false;
+	EditAlarmDlg::Type type;
+	switch (action)
+	{
+		case KAEvent::MESSAGE:
+		case KAEvent::FILE:
+			type = EditAlarmDlg::DISPLAY;
+			setAction = true;
+			break;
+		case KAEvent::COMMAND:
+			type = EditAlarmDlg::COMMAND;
+			break;
+		case KAEvent::EMAIL:
+			type = EditAlarmDlg::EMAIL;
+			break;
+	}
+	EditAlarmDlg* editDlg = EditAlarmDlg::create(false, type, true, parent);
+	if (setAction  ||  text)
+		editDlg->setAction(action, *text);
+	doEditNewAlarm(editDlg);
+	delete editDlg;
+}
+
 /******************************************************************************
 * Execute a New Alarm dialog, optionally either presetting it to the supplied
 * event, or setting the action and text.
 */
-void editNewAlarm(QWidget* parent, const KAEvent* preset, KAEvent::Action action, const AlarmText* text)
+void editNewAlarm(const KAEvent& preset, QWidget* parent)
 {
-	EditAlarmDlg editDlg(false, i18n("New Alarm"), parent, preset);
-	if (text)
-		editDlg.setAction(action, *text);
-	if (editDlg.exec() == QDialog::Accepted)
+	EditAlarmDlg* editDlg = EditAlarmDlg::create(false, preset, true, parent);
+	doEditNewAlarm(editDlg);
+	delete editDlg;
+}
+
+/******************************************************************************
+* Common code for editNewAlarm() variants.
+*/
+void doEditNewAlarm(EditAlarmDlg* editDlg)
+{
+	if (editDlg->exec() == QDialog::Accepted)
 	{
 		KAEvent event;
 		AlarmResource* resource;
-		editDlg.getEvent(event, resource);
+		editDlg->getEvent(event, resource);
 
 		// Add the alarm to the displayed lists and to the calendar file
-		if (addEvent(event, resource, &editDlg) == UPDATE_KORG_ERR)
-			displayKOrgUpdateError(&editDlg, ERR_ADD, 1);
+		if (addEvent(event, resource, editDlg) == UPDATE_KORG_ERR)
+			displayKOrgUpdateError(editDlg, ERR_ADD, 1);
 		Undo::saveAdd(event, resource);
 
-		outputAlarmWarnings(&editDlg, &event);
+		outputAlarmWarnings(editDlg, &event);
 	}
 }
 
 /******************************************************************************
-* Display the alarm edit dialogue to edit a new alarm, preset with a template.
+* Display the alarm edit dialog to edit a new alarm, preset with a template.
 */
 bool editNewAlarm(const QString& templateName, QWidget* parent)
 {
-	bool result = true;
 	if (!templateName.isEmpty())
 	{
 		KAEvent templateEvent = AlarmCalendar::resources()->templateEvent(templateName);
 		if (templateEvent.valid())
 		{
-			editNewAlarm(parent, &templateEvent);
+			editNewAlarm(templateEvent, parent);
 			return true;
 		}
-		kWarning(5950) << "KAlarm::editNewAlarm(" << templateName << "): template not found" << endl;
-		result = false;
+		kWarning(5950) << "KAlarm::editNewAlarm(" << templateName << "): template not found";
 	}
-	editNewAlarm(parent);
-	return result;
+	return false;
 }
 
 /******************************************************************************
 * Create a new template.
-* If 'preset' is non-zero, base the new template on an existing event or template.
 */
-void editNewTemplate(QWidget* parent, const KAEvent* preset)
+void editNewTemplate(EditAlarmDlg::Type type, QWidget* parent)
 {
-	EditAlarmDlg editDlg(true, i18n("New Alarm Template"), parent, preset);
-	if (editDlg.exec() == QDialog::Accepted)
+	EditAlarmDlg* editDlg = EditAlarmDlg::create(true, type, true, parent);
+	if (editDlg->exec() == QDialog::Accepted)
 	{
 		KAEvent event;
 		AlarmResource* resource;
-		editDlg.getEvent(event, resource);
+		editDlg->getEvent(event, resource);
 
 		// Add the template to the displayed lists and to the calendar file
-		addTemplate(event, resource, &editDlg);
+		addTemplate(event, resource, editDlg);
 		Undo::saveAdd(event, resource);
 	}
+	delete editDlg;
 }
 
 /******************************************************************************
-* Open the Edit Alarm dialogue to edit the specified alarm.
+* Create a new template, based on an existing event or template.
+*/
+void editNewTemplate(const KAEvent& preset, QWidget* parent)
+{
+	EditAlarmDlg* editDlg = EditAlarmDlg::create(true, preset, true, parent);
+	if (editDlg->exec() == QDialog::Accepted)
+	{
+		KAEvent event;
+		AlarmResource* resource;
+		editDlg->getEvent(event, resource);
+
+		// Add the template to the displayed lists and to the calendar file
+		addTemplate(event, resource, editDlg);
+		Undo::saveAdd(event, resource);
+	}
+	delete editDlg;
+}
+
+/******************************************************************************
+* Open the Edit Alarm dialog to edit the specified alarm.
 */
 void editAlarm(KAEvent& event, QWidget* parent)
 {
-	EditAlarmDlg editDlg(false, i18n("Edit Alarm"), parent, &event, EditAlarmDlg::RES_USE_EVENT_ID);
-	if (editDlg.exec() == QDialog::Accepted)
+	EditAlarmDlg* editDlg = EditAlarmDlg::create(false, event, false, parent, EditAlarmDlg::RES_USE_EVENT_ID);
+	if (editDlg->exec() == QDialog::Accepted)
 	{
 		KAEvent newEvent;
 		AlarmResource* resource;
-		bool changeDeferral = !editDlg.getEvent(newEvent, resource);
+		bool changeDeferral = !editDlg->getEvent(newEvent, resource);
 
 		// Update the event in the displays and in the calendar file
+		Undo::Event undo(event, resource);
 		if (changeDeferral)
 		{
 			// The only change has been to an existing deferral
-			if (updateEvent(newEvent, &editDlg, true, false) != UPDATE_OK)   // keep the same event ID
+			if (updateEvent(newEvent, editDlg, true, false) != UPDATE_OK)   // keep the same event ID
 				return;   // failed to save event
 		}
 		else
 		{
-			if (modifyEvent(event, newEvent, &editDlg) == UPDATE_KORG_ERR)
-				displayKOrgUpdateError(&editDlg, ERR_MODIFY, 1);
+			if (modifyEvent(event, newEvent, editDlg) == UPDATE_KORG_ERR)
+				displayKOrgUpdateError(editDlg, ERR_MODIFY, 1);
 		}
-		Undo::saveEdit(event, newEvent, resource);
+		Undo::saveEdit(undo, newEvent);
 
-		outputAlarmWarnings(&editDlg, &newEvent);
+		outputAlarmWarnings(editDlg, &newEvent);
 	}
+	delete editDlg;
 }
 
 /******************************************************************************
-* Display the alarm edit dialogue to edit a specified alarm.
+* Display the alarm edit dialog to edit a specified alarm.
 */
 bool editAlarm(const QString& eventID, QWidget* parent)
 {
@@ -866,13 +933,13 @@ bool editAlarm(const QString& eventID, QWidget* parent)
 	const KCal::Event* kcalEvent = resources->event(eventID);
 	if (!kcalEvent)
 	{
-		kError(5950) << "KAlarm::editAlarm(): event ID not found: " << eventID << endl;
+		kError(5950) << "KAlarm::editAlarm(): event ID not found:" << eventID;
 		return false;
 	}
 	AlarmResource* resource = resources->resource(kcalEvent);
 	if (!resource  ||  !resource->writable(kcalEvent))
 	{
-		kError(5950) << "KAlarm::editAlarm(" << eventID << "): read-only" << endl;
+		kError(5950) << "KAlarm::editAlarm(" << eventID << "): read-only";
 		return false;
 	}
 	switch (KCalEvent::status(kcalEvent))
@@ -881,7 +948,7 @@ bool editAlarm(const QString& eventID, QWidget* parent)
 		case KCalEvent::TEMPLATE:
 			break;
 		default:
-			kError(5950) << "KAlarm::editAlarm(" << eventID << "): event not active or template" << endl;
+			kError(5950) << "KAlarm::editAlarm(" << eventID << "): event not active or template";
 			return false;
 	}
 	KAEvent event(kcalEvent);
@@ -890,34 +957,35 @@ bool editAlarm(const QString& eventID, QWidget* parent)
 }
 
 /******************************************************************************
-* Open the Edit Alarm dialogue to edit the specified template.
+* Open the Edit Alarm dialog to edit the specified template.
 */
 void editTemplate(KAEvent& event, QWidget* parent)
 {
-	EditAlarmDlg editDlg(true, i18n("Edit Alarm Template"), parent, &event, EditAlarmDlg::RES_USE_EVENT_ID);
-	if (editDlg.exec() == QDialog::Accepted)
+	EditAlarmDlg* editDlg = EditAlarmDlg::create(true, event, false, parent, EditAlarmDlg::RES_USE_EVENT_ID);
+	if (editDlg->exec() == QDialog::Accepted)
 	{
 		KAEvent newEvent;
 		AlarmResource* resource;
-		editDlg.getEvent(newEvent, resource);
+		editDlg->getEvent(newEvent, resource);
 		QString id = event.id();
 		newEvent.setEventID(id);
 
 		// Update the event in the displays and in the calendar file
-		updateTemplate(newEvent, &editDlg);
-		Undo::saveEdit(event, newEvent, resource);
+		Undo::Event undo(event, resource);
+		updateTemplate(newEvent, editDlg);
+		Undo::saveEdit(undo, newEvent);
 	}
+	delete editDlg;
 }
 
 /******************************************************************************
-* Open the Edit Alarm dialogue to view the specified alarm (read-only).
+* Open the Edit Alarm dialog to view the specified alarm (read-only).
 */
 void viewAlarm(const KAEvent& event, QWidget* parent)
 {
-	EditAlarmDlg editDlg(false, (event.expired() ? i18n("Archived Alarm") + " [" + i18n("read-only") + ']'
-	                                             : i18n("View Alarm")),
-	                     parent, &event, EditAlarmDlg::RES_PROMPT, true);
-	editDlg.exec();
+	EditAlarmDlg* editDlg = EditAlarmDlg::create(false, event, false, parent, EditAlarmDlg::RES_PROMPT, true);
+	editDlg->exec();
+	delete editDlg;
 }
 
 /******************************************************************************
@@ -948,13 +1016,13 @@ void outputAlarmWarnings(QWidget* parent, const KAEvent* event)
 {
 	if (event  &&  event->action() == KAEvent::EMAIL
 	&&  Preferences::emailAddress().isEmpty())
-		KMessageBox::information(parent, i18nc("Please set the 'From' email address...",
-		                                       "%1\nPlease set it in the Preferences dialog.", KAMail::i18n_NeedFromEmailAddress()));
+		KMessageBox::information(parent, i18nc("@info Please set the 'From' email address...",
+		                                       "<para>%1</para><para>Please set it in the Preferences dialog.</para>", KAMail::i18n_NeedFromEmailAddress()));
 
 	if (!Daemon::monitoringAlarms())
 	{
-		if (KMessageBox::warningYesNo(parent, i18n("Alarms are currently disabled.\nDo you want to enable alarms now?"),
-		                              QString(), KGuiItem(i18n("Enable")), KGuiItem(i18n("Keep Disabled")),
+		if (KMessageBox::warningYesNo(parent, i18nc("@info", "<para>Alarms are currently disabled.</para><para>Do you want to enable alarms now?</para>"),
+		                              QString(), KGuiItem(i18nc("@action:button", "Enable")), KGuiItem(i18nc("@action:button", "Keep Disabled")),
 		                              QLatin1String("EditEnableAlarms"))
 		                == KMessageBox::Yes)
 			Daemon::setAlarmsEnabled();
@@ -967,7 +1035,7 @@ void outputAlarmWarnings(QWidget* parent, const KAEvent* event)
 */
 void resetDaemon()
 {
-	kDebug(5950) << "KAlarm::resetDaemon()" << endl;
+	kDebug(5950) << "KAlarm::resetDaemon()";
 	if (!resetDaemonQueued)
 	{
 		resetDaemonQueued = true;
@@ -986,7 +1054,7 @@ void resetDaemonIfQueued()
 {
 	if (resetDaemonQueued)
 	{
-		kDebug(5950) << "KAlarm::resetDaemonIfNeeded()" << endl;
+		kDebug(5950) << "KAlarm::resetDaemonIfNeeded()";
 		AlarmCalendar::resources()->reload();
 
 		// Close any message windows for alarms which are now disabled
@@ -1020,7 +1088,7 @@ QString runKMail(bool minimise)
 	QString dbusService = KMAIL_DBUS_SERVICE;
 	QString errmsg;
 	if (!runProgram(QLatin1String("kmail"), (minimise ? QLatin1String(KMAIL_DBUS_WINDOW) : QString()), dbusService, errmsg))
-		return i18n("Unable to start KMail\n(%1)", errmsg);
+		return i18nc("@info", "Unable to start <application>KMail</application><br />(<message>%1</message>)", errmsg);
 	return QString();
 }
 
@@ -1038,7 +1106,7 @@ bool runProgram(const QString& program, const QString& windowName, QString& dbus
 		// Program is not already running, so start it
 		if (KToolInvocation::startServiceByDesktopName(program, QString(), &errorMessage, &dbusService))
 		{
-			kError(5950) << "KAlarm::runProgram(): couldn't start " << program << " (" << errorMessage << ")\n";
+			kError(5950) << "KAlarm::runProgram(): couldn't start" << program << " (" << errorMessage << ")";
 			return false;
 		}
 		if (!windowName.isEmpty())
@@ -1050,17 +1118,85 @@ bool runProgram(const QString& program, const QString& windowName, QString& dbus
 #ifdef __GNUC__
 #warning Minimise window
 #endif
+//Call D-Bus app/MainWin showMinimized()???
 //			QDBusInterface iface(dbusService, DBUS_OBJECT, DBUS_IFACE);
 			QDBusInterface iface(dbusService, QString(), QString());
 			QDBusError err = iface.callWithArgumentList(QDBus::NoBlock, QLatin1String("minimize"), QList<QVariant>());
 			if (err.isValid())
-				kError(5950) << "KAlarm::runProgram(" << program << "): minimize D-Bus call failed: " << err.message() << endl;
+				kError(5950) << "KAlarm::runProgram(" << program << "): minimize D-Bus call failed:" << err.message();
 		}
 	}
 	errorMessage.clear();
 	return true;
 }
 
+/******************************************************************************
+* The "Don't show again" option for error messages is personal to the user on a
+* particular computer. For example, he may want to inhibit error messages only
+* on his laptop. So the status is not stored in the alarm calendar, but in the
+* user's local KAlarm data directory.
+******************************************************************************/
+
+/******************************************************************************
+* Return the Don't-show-again error message tags set for a specified alarm ID.
+*/
+QStringList dontShowErrors(const QString& eventId)
+{
+	if (eventId.isEmpty())
+		return QStringList();
+	KConfig config(KStandardDirs::locateLocal("appdata", ALARM_OPTS_FILE));
+	KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
+	return group.readEntry(eventId, QStringList());
+}
+
+/******************************************************************************
+* Check whether the specified Don't-show-again error message tag is set for an
+* alarm ID.
+*/
+bool dontShowErrors(const QString& eventId, const QString& tag)
+{
+	if (tag.isEmpty()  ||  eventId.isEmpty())
+		return false;
+	QStringList tags = dontShowErrors(eventId);
+	return tags.indexOf(tag) >= 0;
+}
+
+/******************************************************************************
+* Reset the Don't-show-again error message tags for an alarm ID.
+* If 'tags' is empty, the config entry is deleted.
+*/
+void setDontShowErrors(const QString& eventId, const QStringList& tags)
+{
+	if (eventId.isEmpty())
+		return;
+	KConfig config(KStandardDirs::locateLocal("appdata", ALARM_OPTS_FILE));
+	KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
+	if (tags.isEmpty())
+		group.deleteEntry(eventId);
+	else
+		group.writeEntry(eventId, tags);
+	group.sync();
+}
+
+/******************************************************************************
+* Set the specified Don't-show-again error message tag for an alarm ID.
+* Existing tags are unaffected.
+*/
+void setDontShowErrors(const QString& eventId, const QString& tag)
+{
+	if (tag.isEmpty()  ||  eventId.isEmpty())
+		return;
+	KConfig config(KStandardDirs::locateLocal("appdata", ALARM_OPTS_FILE));
+	KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
+	QStringList tags = group.readEntry(eventId, QStringList());
+	if (tags.indexOf(tag) < 0)
+	{
+		tags += tag;
+		group.writeEntry(eventId, tags);
+		group.sync();
+	}
+}
+
 /******************************************************************************
 *  Read the size for the specified window from the config file, for the
 *  current screen resolution.
@@ -1165,18 +1301,17 @@ FileType fileType(const QString& mimetype)
 	int slash = mimetype.indexOf(QLatin1Char('/'));
 	if (slash < 0)
 		return Unknown;
-	QString type = mimetype.mid(slash + 1);
-	const char* typel = type.toLatin1();
+	QByteArray type = mimetype.mid(slash + 1).toLatin1();
 	if (mimetype.startsWith(QLatin1String("application")))
 	{
 		for (int i = 0;  applicationTypes[i];  ++i)
-			if (!strcmp(typel, applicationTypes[i]))
+			if (!strcmp(type, applicationTypes[i]))
 				return TextApplication;
 	}
 	else if (mimetype.startsWith(QLatin1String("text")))
 	{
 		for (int i = 0;  formattedTextTypes[i];  ++i)
-			if (!strcmp(typel, formattedTextTypes[i]))
+			if (!strcmp(type, formattedTextTypes[i]))
 				return TextFormatted;
 		return TextPlain;
 	}
@@ -1184,7 +1319,7 @@ FileType fileType(const QString& mimetype)
 }
 
 /******************************************************************************
-* Display a modal dialogue to choose an existing file, initially highlighting
+* Display a modal dialog to choose an existing file, initially highlighting
 * any specified file.
 * @param initialFile The file to initially highlight - must be a full path name or URL.
 * @param defaultDir The directory to start in if @p initialFile is empty. If empty,
@@ -1209,7 +1344,7 @@ QString browseFile(const QString& caption, QString& defaultDir, const QString& i
 		return QString();
 	KUrl url = fileDlg.selectedUrl();
 	defaultDir = url.path();
-	return url.prettyUrl();
+	return (mode & KFile::LocalOnly) ? url.pathOrUrl() : url.prettyUrl();
 }
 
 /******************************************************************************
@@ -1242,13 +1377,13 @@ QString weekDayName(int day, const KLocale* locale)
 {
 	switch (day)
 	{
-		case 1: return ki18n("Monday").toString(locale);
-		case 2: return ki18n("Tuesday").toString(locale);
-		case 3: return ki18n("Wednesday").toString(locale);
-		case 4: return ki18n("Thursday").toString(locale);
-		case 5: return ki18n("Friday").toString(locale);
-		case 6: return ki18n("Saturday").toString(locale);
-		case 7: return ki18n("Sunday").toString(locale);
+		case 1: return ki18nc("Name of the weekday", "Monday").toString(locale);
+		case 2: return ki18nc("Name of the weekday", "Tuesday").toString(locale);
+		case 3: return ki18nc("Name of the weekday", "Wednesday").toString(locale);
+		case 4: return ki18nc("Name of the weekday", "Thursday").toString(locale);
+		case 5: return ki18nc("Name of the weekday", "Friday").toString(locale);
+		case 6: return ki18nc("Name of the weekday", "Saturday").toString(locale);
+		case 7: return ki18nc("Name of the weekday", "Sunday").toString(locale);
 	}
 	return QString();
 }
@@ -1372,9 +1507,9 @@ bool sendToKOrganizer(const KAEvent& event)
 			break;
 		case KAEvent::EMAIL:
 		{
-			QString from = event.emailFromKMail().isEmpty()
-			             ? Preferences::emailAddress()
-			             : KAMail::identityManager()->identityForName(event.emailFromKMail()).fullEmailAddr();
+			QString from = event.emailFromId()
+			             ? KAMail::identityManager()->identityForUoid(event.emailFromId()).fullEmailAddr()
+			             : Preferences::emailAddress();
 			AlarmText atext;
 			atext.setEmail(event.emailAddresses(", "), from, QString(), QString(), event.emailSubject(), QString());
 			kcalEvent->setSummary(atext.displayText());
@@ -1398,15 +1533,15 @@ bool sendToKOrganizer(const KAEvent& event)
 	QDBusReply<bool> reply = korgInterface->callWithArgumentList(QDBus::Block, QLatin1String("addIncidence"), args);
 	if (!reply.isValid())
 	{
-		kError(5950) << "sendToKOrganizer(): addIncidence(" << uid << ") D-Bus call failed: " << reply.error().message() << endl;
+		kError(5950) << "sendToKOrganizer(): addIncidence(" << uid << ") D-Bus call failed:" << reply.error().message();
 		return false;
 	}
 	if (!reply.value())
 	{
-		kError(5950) << "sendToKOrganizer(): addIncidence(" << uid << ") D-Bus call returned false" << endl;
+		kError(5950) << "sendToKOrganizer(): addIncidence(" << uid << ") D-Bus call returned false";
 		return false;
 	}
-	kDebug(5950) << "sendToKOrganizer(" << uid << "): success\n";
+	kDebug(5950) << "sendToKOrganizer(" << uid << "): success";
 	return true;
 }
 
@@ -1423,15 +1558,15 @@ bool deleteFromKOrganizer(const QString& eventID)
 	QDBusReply<bool> reply = korgInterface->callWithArgumentList(QDBus::Block, QLatin1String("deleteIncidence"), args);
 	if (!reply.isValid())
 	{
-		kError(5950) << "deleteFromKOrganizer(): deleteIncidence(" << newID << ") D-Bus call failed: " << reply.error().message() << endl;
+		kError(5950) << "deleteFromKOrganizer(): deleteIncidence(" << newID << ") D-Bus call failed:" << reply.error().message();
 		return false;
 	}
 	if (!reply.value())
 	{
-		kError(5950) << "deleteFromKOrganizer(): deleteIncidence(" << newID << ") D-Bus call returned false" << endl;
+		kError(5950) << "deleteFromKOrganizer(): deleteIncidence(" << newID << ") D-Bus call returned false";
 		return false;
 	}
-	kDebug(5950) << "deleteFromKOrganizer(" << newID << "): success\n";
+	kDebug(5950) << "deleteFromKOrganizer(" << newID << "): success";
 	return true;
 }
 
