@@ -31,6 +31,7 @@
 #include <kapplication.h>
 #include <kstandarddirs.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <ksystemtimezone.h>
 #include <kdatetime.h>
 #include <kdebug.h>
@@ -40,7 +41,6 @@
 #include <ktoolinvocation.h>
 
 #include "alarmguiiface.h"
-#include "notifyinterface.h"
 #include "resources/alarmresources.h"
 #include "alarmdaemon.moc"
 
@@ -58,8 +58,9 @@ const char* CLIENT_KEY       = "Client";
 const char* DCOP_OBJECT_KEY  = "DCOP object";
 const char* START_CLIENT_KEY = "Start";
 
-static const char* KALARM_DBUS_SERVICE = "org.kde.kalarm";
-static const char* NOTIFY_DBUS_OBJECT  = "/notify";    // D-Bus object path of KAlarm's notification interface
+static const char* KALARM_DBUS_SERVICE   = "org.kde.kalarm";
+static const char* NOTIFY_DBUS_OBJECT    = "/notify";    // D-Bus object path of KAlarm's notification interface
+static const char* NOTIFY_DBUS_INTERFACE = "org.kde.kalarm.notify";
 
 
 AlarmDaemon::EventsMap  AlarmDaemon::mEventsHandled;
@@ -75,7 +76,7 @@ AlarmDaemon::AlarmDaemon(bool autostart, QObject *parent)
 #endif
 	  mEnabled(true)
 {
-	kDebug(5900) << "AlarmDaemon::AlarmDaemon()" << endl;
+	kDebug(5900) <<"AlarmDaemon::AlarmDaemon()";
 	QDBusConnection::sessionBus().registerObject(DAEMON_DBUS_OBJECT, this, QDBusConnection::ExportScriptableSlots);
 	AlarmDaemon::readConfig();
 	enableAutoStart(true);    // switch autostart on whenever the program is run
@@ -115,7 +116,7 @@ AlarmDaemon::AlarmDaemon(bool autostart, QObject *parent)
 		autostart = group.readEntry("AutostartTray", false);
 		if (autostart)
 		{
-			kDebug(5900) << "AlarmDaemon::AlarmDaemon(): wait to autostart KAlarm\n";
+			kDebug(5900) <<"AlarmDaemon::AlarmDaemon(): wait to autostart KAlarm";
 			QTimer::singleShot(KALARM_AUTOSTART_TIMEOUT * 1000, this, SLOT(autostartKAlarm()));
 		}
 	}
@@ -139,14 +140,31 @@ AlarmDaemon::~AlarmDaemon()
 */
 void AlarmDaemon::quit()
 {
-	kDebug(5900) << "AlarmDaemon::quit()" << endl;
+	kDebug(5900) <<"AlarmDaemon::quit()";
 	exit(0);
 }
 
-OrgKdeKalarmNotifyInterface* AlarmDaemon::kalarmNotifyDBus()
+/******************************************************************************
+* Open the D-Bus connection to KAlarm's notification interface.
+*
+* IMPORTANT NOTE:
+*       QDBus calls need to be used directly instead of using the Qt
+*       auto-generated interface class. This is because the latter doesn't
+*       return errors, for example when the /notify object hasn't yet been
+*       created by KAlarm.
+*/
+QDBusInterface* AlarmDaemon::kalarmNotifyDBus()
 {
 	if (!mDBusNotify)
-		mDBusNotify = new org::kde::kalarm::notify(KALARM_DBUS_SERVICE, NOTIFY_DBUS_OBJECT, QDBusConnection::sessionBus());
+	{
+		mDBusNotify = new QDBusInterface(KALARM_DBUS_SERVICE, NOTIFY_DBUS_OBJECT, NOTIFY_DBUS_INTERFACE);
+		if (!mDBusNotify->isValid())
+		{
+			kError(5900) <<"AlarmDaemon: KAlarm D-Bus notification interface not available:" << mDBusNotify->lastError().message();
+			delete mDBusNotify;
+			mDBusNotify = 0;
+		}
+	}
 	return mDBusNotify;
 }
 
@@ -159,7 +177,7 @@ bool AlarmDaemon::checkDBusResult(const char* funcname)
 	QDBusError err = mDBusNotify->lastError();
 	if (!err.isValid())
 		return true;    // no error
-	kError(5950) << "AlarmDaemon: " << funcname << "() D-Bus call failed: " << err.message() << endl;
+	kError(5900) <<"AlarmDaemon:" << funcname <<"() D-Bus call failed:" << err.message();
 	return false;
 }
 
@@ -171,10 +189,10 @@ void AlarmDaemon::autostartKAlarm()
 #ifdef AUTOSTART_KALARM
 	if (mAlarmTimer)
 	{
-		kDebug(5900) << "AlarmDaemon::autostartKAlarm(): KAlarm already registered\n";
+		kDebug(5900) <<"AlarmDaemon::autostartKAlarm(): KAlarm already registered";
 		return;    // KAlarm has already registered with us
 	}
-	kDebug(5900) << "AlarmDaemon::autostartKAlarm(): starting KAlarm\n";
+	kDebug(5900) <<"AlarmDaemon::autostartKAlarm(): starting KAlarm";
 	QStringList args;
 	args << QLatin1String("--tray");
 	KToolInvocation::kdeinitExec(QLatin1String("kalarm"), args);
@@ -213,7 +231,7 @@ void AlarmDaemon::startMonitoring()
 */
 void AlarmDaemon::enable(bool enable)
 {
-	kDebug(5900) << "AlarmDaemon::enable()" << endl;
+	kDebug(5900) <<"AlarmDaemon::enable()";
 	mEnabled = enable;
 	notifyCalStatus();    // notify KAlarm
 }
@@ -229,7 +247,7 @@ void AlarmDaemon::resourceActive(const QString& id, bool active)
 	AlarmResource* resource = AlarmResources::instance()->resourceWithId(id);
 	if (resource  &&  active != resource->isActive())
 	{
-		kDebug(5900) << "AlarmDaemon::resourceActive(" << id << ", " << active << ")" << endl;
+		kDebug(5900) <<"AlarmDaemon::resourceActive(" << id <<"," << active <<")";
 		resource->setEnabled(active);
 		if (active)
 			reloadResource(resource, true);
@@ -243,7 +261,7 @@ void AlarmDaemon::resourceLocation(const QString& id, const QString& locn, const
 	AlarmResource* resource = AlarmResources::instance()->resourceWithId(id);
 	if (resource)
 	{
-		kDebug(5900) << "AlarmDaemon::resourceLocation(" << id << ", " << locn << ")" << endl;
+		kDebug(5900) <<"AlarmDaemon::resourceLocation(" << id <<"," << locn <<")";
 		resource->setLocation(locn, locn2);
 	}
 }
@@ -264,7 +282,7 @@ void AlarmDaemon::reloadResource(const QString& id, bool check, bool reset)
 	if (id.isEmpty())
 	{
 		// Reload all resources
-		kDebug(5900) << "AlarmDaemon::reloadResource(ALL)" << endl;
+		kDebug(5900) <<"AlarmDaemon::reloadResource(ALL)";
 		if (reset)
 			clearEventsHandled();
 		// Don't call reload() since that saves the calendar
@@ -272,12 +290,12 @@ void AlarmDaemon::reloadResource(const QString& id, bool check, bool reset)
 	}
 	else
 	{
-		kDebug(5900) << "AlarmDaemon::reloadResource(" << id << ")" << endl;
+		kDebug(5900) <<"AlarmDaemon::reloadResource(" << id <<")";
 		AlarmResource* resource = resources->resourceWithId(id);
 		if (resource  &&  resource->isActive())
 			reloadResource(resource, reset);
 		else
-			kError(5900) << "AlarmDaemon::reloadResource(" << id << "): active resource not found" << endl;
+			kError(5900) <<"AlarmDaemon::reloadResource(" << id <<"): active resource not found";
 	}
 }
 
@@ -287,7 +305,7 @@ void AlarmDaemon::reloadResource(const QString& id, bool check, bool reset)
 */
 void AlarmDaemon::reloadResource(AlarmResource* resource, bool reset)
 {
-	kDebug(5900) << "AlarmDaemon::reloadResource()" << endl;
+	kDebug(5900) <<"AlarmDaemon::reloadResource()";
 	if (reset)
 		clearEventsHandled(resource);
 	// Don't call reload() since that saves the calendar.
@@ -302,9 +320,12 @@ void AlarmDaemon::reloadResource(AlarmResource* resource, bool reset)
 */
 void AlarmDaemon::cacheDownloaded(AlarmResource* resource)
 {
-	kalarmNotifyDBus()->cacheDownloaded(resource->identifier());
-	checkDBusResult("cacheDownloaded");
-	kDebug(5900) << "AlarmDaemon::cacheDownloaded(" << resource->identifier() << ")\n";
+	if (kalarmNotifyDBus())
+	{
+		kalarmNotifyDBus()->call("cacheDownloaded", resource->identifier());
+		checkDBusResult("cacheDownloaded");
+		kDebug(5900) <<"AlarmDaemon::cacheDownloaded(" << resource->identifier() <<")";
+	}
 }
 
 /******************************************************************************
@@ -312,7 +333,7 @@ void AlarmDaemon::cacheDownloaded(AlarmResource* resource)
 */
 void AlarmDaemon::resourceLoaded(AlarmResource* res)
 {
-	kDebug(5900) << "Resource " << res->identifier() << " (" << res->resourceName() << ") loaded" << endl;
+	kDebug(5900) <<"Resource" << res->identifier() <<" (" << res->resourceName() <<") loaded";
 	clearEventsHandled(res, true);   // remove all its events which no longer exist from handled list
 	notifyCalStatus();       // notify KAlarm
 	setTimerStatus();
@@ -333,7 +354,7 @@ void AlarmDaemon::eventHandled(const QString& eventID, bool reload)
 	if (kapp->dcopClient()->senderId() != mClientName)
 		return;
 #endif
-	kDebug(5900) << "AlarmDaemon::eventHandled()" << (reload ? ": reload" : "") << endl;
+	kDebug(5900) <<"AlarmDaemon::eventHandled()" << (reload ?": reload" :"");
 	setEventHandled(eventID);
 	if (reload)
 	{
@@ -352,7 +373,7 @@ void AlarmDaemon::eventHandled(const QString& eventID, bool reload)
 */
 void AlarmDaemon::registerApp(const QString& appName, const QString& serviceName, const QString& dbusObject, bool startClient)
 {
-	kDebug(5900) << "AlarmDaemon::registerApp(" << appName << ", " << serviceName << ", " <<  dbusObject << ", " << startClient << ")" << endl;
+	kDebug(5900) <<"AlarmDaemon::registerApp(" << appName <<"," << serviceName <<"," <<  dbusObject <<"," << startClient <<")";
 	registerApp(appName, serviceName, dbusObject, startClient, true);
 }
 
@@ -365,7 +386,7 @@ void AlarmDaemon::registerApp(const QString& appName, const QString& serviceName
 */
 void AlarmDaemon::registerChange(const QString& appName, const QString& serviceName, bool startClient)
 {
-	kDebug(5900) << "AlarmDaemon::registerChange(" << serviceName << ", " << startClient << ")" << endl;
+	kDebug(5900) <<"AlarmDaemon::registerChange(" << serviceName <<"," << startClient <<")";
 	if (serviceName == mClientName)
 		registerApp(appName, mClientName, mClientDBusObj, startClient, false);
 }
@@ -379,7 +400,7 @@ void AlarmDaemon::registerChange(const QString& appName, const QString& serviceN
 */
 void AlarmDaemon::registerApp(const QString& appName, const QString& serviceName, const QString& dbusObject, bool startClient, bool init)
 {
-	kDebug(5900) << "AlarmDaemon::registerApp(" << appName << ", " << serviceName << ", " <<  dbusObject << ", " << startClient << ")" << endl;
+	kDebug(5900) <<"AlarmDaemon::registerApp(" << appName <<"," << serviceName <<"," <<  dbusObject <<"," << startClient <<")";
 	KAlarmd::RegisterResult result = KAlarmd::SUCCESS;
 	if (serviceName.isEmpty())
 		result = KAlarmd::FAILURE;
@@ -388,7 +409,7 @@ void AlarmDaemon::registerApp(const QString& appName, const QString& serviceName
 		QString exe = KStandardDirs::findExe(appName);
 		if (exe.isNull())
 		{
-			kError(5900) << "AlarmDaemon::registerApp(): '" << appName << "' not found" << endl;
+			kError(5900) <<"AlarmDaemon::registerApp(): '" << appName <<"' not found";
 			result = KAlarmd::NOT_FOUND;
 		}
 		mClientExe = exe;
@@ -414,9 +435,12 @@ void AlarmDaemon::registerApp(const QString& appName, const QString& serviceName
 	}
 
 	// Notify the client of whether the call succeeded.
-	kalarmNotifyDBus()->registered(false, result);
-	checkDBusResult("registered");
-	kDebug(5900) << "AlarmDaemon::registerApp() -> " << result << endl;
+	if (kalarmNotifyDBus())
+	{
+		kalarmNotifyDBus()->call("registered", false, result);
+		checkDBusResult("registered");
+	}
+	kDebug(5900) <<"AlarmDaemon::registerApp() ->" << result;
 }
 
 /******************************************************************************
@@ -424,7 +448,7 @@ void AlarmDaemon::registerApp(const QString& appName, const QString& serviceName
 */
 void AlarmDaemon::enableAutoStart(bool on, bool sync)
 {
-        kDebug(5900) << "AlarmDaemon::enableAutoStart(" << on << ")\n";
+        kDebug(5900) <<"AlarmDaemon::enableAutoStart(" << on <<")";
         KSharedConfig::Ptr config = KGlobal::config();
 	config->reparseConfiguration();
 	KConfigGroup group(config, DAEMON_AUTOSTART_SECTION);
@@ -440,7 +464,7 @@ void AlarmDaemon::enableAutoStart(bool on, bool sync)
 */
 void AlarmDaemon::checkAlarmsSlot()
 {
-	kDebug(5901) << "AlarmDaemon::checkAlarmsSlot()" << endl;
+	kDebug(5901) <<"AlarmDaemon::checkAlarmsSlot()";
 	if (mAlarmTimerSyncing)
 	{
 		// We've synched to the minute boundary. Now set timer to the check interval.
@@ -456,7 +480,7 @@ void AlarmDaemon::checkAlarmsSlot()
 			// Need to re-synch to 1 second past the minute
 			mAlarmTimer->start(interval * 1000);
 			mAlarmTimerSyncing = true;
-			kDebug(5900) << "Resynching alarm timer" << endl;
+			kDebug(5900) <<"Resynching alarm timer";
 		}
 		else
 			mAlarmTimerSyncCount = 10;
@@ -469,14 +493,14 @@ void AlarmDaemon::checkAlarmsSlot()
 */
 void AlarmDaemon::checkAlarms()
 {
-	kDebug(5901) << "AlarmDaemon::checkAlarms()" << endl;
+	kDebug(5901) <<"AlarmDaemon::checkAlarms()";
 	AlarmResources* resources = AlarmResources::instance();
 	if (!mEnabled  ||  !resources->loadedState(AlarmResource::ACTIVE))
 		return;
 
 	KDateTime now  = KDateTime::currentUtcDateTime();
 	KDateTime now1 = now.addSecs(1);
-	kDebug(5901) << "  To: " << now << endl;
+	kDebug(5901) <<"  To:" << now;
 	QList<KCal::Alarm*> alarms = resources->alarmsTo(now);
 	if (alarms.isEmpty())
 		return;
@@ -488,12 +512,39 @@ void AlarmDaemon::checkAlarms()
 			continue;   // either not an event, or the event has already been processed
 		eventsDone += event;
 		const QString& eventID = event->uid();
-		kDebug(5901) << "AlarmDaemon::checkAlarms(): event " << eventID  << endl;
+		kDebug(5901) <<"AlarmDaemon::checkAlarms(): event" << eventID;
 
 		// Check which of the alarms for this event are due.
 		// The times in 'alarmtimes' corresponding to due alarms are set.
 		// The times for non-due alarms are set invalid in 'alarmtimes'.
 		bool recurs = event->recurs();
+		QStringList flags = event->customProperty("KALARM", "FLAGS").split(QLatin1Char(';'), QString::SkipEmptyParts);
+		bool floats = flags.contains(QString::fromLatin1("DATE"));
+		KDateTime nextDateTime = event->dtStart();
+		nextDateTime.setDateOnly(floats);
+		if (recurs)
+		{
+			QString prop = event->customProperty("KALARM", "NEXTRECUR");
+			if (prop.length() >= 8)
+			{
+				// The next due recurrence time is specified
+				QDate d(prop.left(4).toInt(), prop.mid(4,2).toInt(), prop.mid(6,2).toInt());
+				if (d.isValid())
+				{
+					if (floats  &&  prop.length() == 8)
+						nextDateTime.setDate(d);
+					else if (!floats  &&  prop.length() == 15  &&  prop[8] == QChar('T'))
+					{
+						QTime t(prop.mid(9,2).toInt(), prop.mid(11,2).toInt(), prop.mid(13,2).toInt());
+						if (t.isValid())
+						{
+							nextDateTime.setDate(d);
+							nextDateTime.setTime(t);
+						}
+					}
+				}
+			}
+		}
 		QList<KDateTime> alarmtimes;
 		KCal::Alarm::List alarms = event->alarms();
 		for (KCal::Alarm::List::ConstIterator al = alarms.begin();  al != alarms.end();  ++al)
@@ -511,12 +562,24 @@ void AlarmDaemon::checkAlarms()
 					int offset = alarm->hasStartOffset() ? alarm->startOffset().asSeconds()
 					           : alarm->endOffset().asSeconds() + event->dtStart().secsTo(event->dtEnd());
 					if (offset)
-						dt1 = event->recurrence()->getPreviousDateTime(now1.addSecs(-offset));
+					{
+						dt1 = nextDateTime.addSecs(offset);
+						if (dt1 > now)
+							dt1 = KDateTime();
+					}
 				}
-				dt = alarm->previousRepetition(now1);   // get latest due repetition (if any)
-				if (!dt.isValid())
-					dt = dt1;
-				else if (dt1.isValid()  &&  dt1 > dt)
+				// Get latest due repetition, or the recurrence time if none
+				dt = nextDateTime;
+				if (nextDateTime <= now  &&  alarm->repeatCount() > 0)
+				{
+					int snoozeSecs = alarm->snoozeTime() * 60;
+					int repetition = nextDateTime.secsTo_long(now) / snoozeSecs;
+					if (repetition > alarm->repeatCount())
+						repetition = alarm->repeatCount();
+					dt = nextDateTime.addSecs(repetition * snoozeSecs);
+				}
+				if (!dt.isValid()  ||  dt > now
+				||  dt1.isValid()  &&  dt1 > dt)  // already tested dt1 <= now
 					dt = dt1;
 			}
 			alarmtimes.append(dt);
@@ -532,53 +595,44 @@ void AlarmDaemon::checkAlarms()
 */
 void AlarmDaemon::notifyEvent(const QString& eventID, const KCal::Event* event, const QList<KDateTime>& alarmtimes)
 {
-	kDebug(5900) << "AlarmDaemon::notifyEvent(" << eventID << "): notification type=" << mClientStart << endl;
+	kDebug(5900) <<"AlarmDaemon::notifyEvent(" << eventID <<"): notification type=" << mClientStart;
 	QString id = QLatin1String("ad:") + eventID;    // prefix to indicate that the notification if from the daemon
 
-	// Check if the client application is running and ready to receive notification
+	// Check if the client application is running, and if so, whether it is ready
+	// to receive notification (i.e. our D-Bus interface has been created).
 	bool registered = isClientRegistered();
-	bool ready = registered;
-	if (registered)
-	{
-		// It's running, but check if it has created our D-Bus interface yet
-#ifdef __GNUC__
-#warning Check if KAlarm D-Bus interface has been created yet
-#endif
-#if 0
-		DCOPCStringList objects = kapp->dcopClient()->remoteObjects(mClientName);
-		if (objects.indexOf(mClientDBusObj) < 0)
-			ready = false;
-#endif
-	}
-	if (!ready)
+	if (!registered  ||  !kalarmNotifyDBus())
 	{
 		// KAlarm is not running, or is not yet ready to receive notifications.
 		if (!mClientStart)
 		{
 			if (registered)
-				kDebug(5900) << "AlarmDaemon::notifyEvent(): client not ready\n";
+				kDebug(5900) <<"AlarmDaemon::notifyEvent(): client not ready";
 			else
-				kDebug(5900) << "AlarmDaemon::notifyEvent(): don't start client\n";
+				kDebug(5900) <<"AlarmDaemon::notifyEvent(): don't start client";
 			return;
 		}
 
 		// Start KAlarm, using the command line to specify the alarm
 		if (mClientExe.isEmpty())
 		{
-			kDebug(5900) << "AlarmDaemon::notifyEvent(): '" << mClientName << "' not found" << endl;
+			kDebug(5900) <<"AlarmDaemon::notifyEvent(): '" << mClientName <<"' not found";
 			return;
 		}
-		QStringList lst;
-		lst << "--handleEvent" << id;
-		QProcess::startDetached(mClientExe,lst);
-		kDebug(5900) << "AlarmDaemon::notifyEvent(): used command line" << endl;
+		QStringList args;
+		args << "--handleEvent" << id;
+		QProcess::startDetached(mClientExe, args);
+		kDebug(5900) <<"AlarmDaemon::notifyEvent(): used command line";
 	}
 	else
 	{
 		// Notify the client by telling it the event ID
-		kalarmNotifyDBus()->handleEvent(id);
-		if (!checkDBusResult("handleEvent"))
-			return;
+		if (kalarmNotifyDBus())
+		{
+			kalarmNotifyDBus()->call("handleEvent", id);
+			if (!checkDBusResult("handleEvent"))
+				return;
+		}
 	}
 	setEventPending(event, alarmtimes);
 }
@@ -604,16 +658,16 @@ void AlarmDaemon::setTimerStatus()
 	if (!mAlarmTimer->isActive()  &&  loaded)
 	{
 		// Timeout every minute.
-		// But first synchronise to one second after the minute boundary.
+		// But first synchronize to one second after the minute boundary.
 		int firstInterval = DAEMON_CHECK_INTERVAL + 1 - QTime::currentTime().second();
 		mAlarmTimer->start(1000 * firstInterval);
 		mAlarmTimerSyncing = (firstInterval != DAEMON_CHECK_INTERVAL);
-		kDebug(5900) << "Started alarm timer" << endl;
+		kDebug(5900) <<"Started alarm timer";
 	}
 	else if (mAlarmTimer->isActive()  &&  !loaded)
 	{
 		mAlarmTimer->stop();
-		kDebug(5900) << "Stopped alarm timer" << endl;
+		kDebug(5900) <<"Stopped alarm timer";
 	}
 }
 
@@ -629,9 +683,12 @@ void AlarmDaemon::notifyCalStatus()
 		bool unloaded = !AlarmResources::instance()->loadedState(AlarmResource::ACTIVE);   // if no resources are loaded
 		KAlarmd::CalendarStatus change = unloaded ? KAlarmd::CALENDAR_UNAVAILABLE
 		                               : mEnabled ? KAlarmd::CALENDAR_ENABLED : KAlarmd::CALENDAR_DISABLED;
-		kDebug(5900) << "AlarmDaemon::notifyCalStatus() sending:" << mClientName << " -> " << change << endl;
-		kalarmNotifyDBus()->alarmDaemonUpdate(change);
-		checkDBusResult("alarmDaemonUpdate");
+		kDebug(5900) <<"AlarmDaemon::notifyCalStatus() sending:" << mClientName <<" ->" << change;
+		if (kalarmNotifyDBus())
+		{
+			kalarmNotifyDBus()->call("alarmDaemonUpdate", change);
+			checkDBusResult("alarmDaemonUpdate");
+		}
 	}
 }
 
@@ -665,7 +722,7 @@ bool AlarmDaemon::eventHandled(const KCal::Event* event, const QList<KDateTime>&
 */
 void AlarmDaemon::setEventHandled(const QString& eventID)
 {
-	kDebug(5900) << "AlarmDaemon::setEventHandled(" << eventID << ")\n";
+	kDebug(5900) <<"AlarmDaemon::setEventHandled(" << eventID <<")";
 	// Remove it from the pending list, and add it to the handled list
 	EventsMap::Iterator it = mEventsPending.find(eventID);
 	if (it != mEventsPending.end())
@@ -683,7 +740,7 @@ void AlarmDaemon::setEventPending(const KCal::Event* event, const QList<KDateTim
 {
 	if (event)
 	{
-		kDebug(5900) << "AlarmDaemon::setEventPending(" << event->uid() << ")\n";
+		kDebug(5900) <<"AlarmDaemon::setEventPending(" << event->uid() <<")";
 		setEventInMap(mEventsPending, event->uid(), alarmtimes, event->revision());
 	}
 }
@@ -749,13 +806,13 @@ void AlarmDaemon::readConfig()
 	// Verify the configuration
 	mClientName.clear();
 	if (client.isEmpty()  ||  KStandardDirs::findExe(client).isNull())
-		kError(5900) << "AlarmDaemon::readConfig(): '" << client << "': client app not found\n";
+		kError(5900) <<"AlarmDaemon::readConfig(): '" << client <<"': client app not found";
 	else if (mClientDBusObj.isEmpty())
-		kError(5900) << "AlarmDaemon::readConfig(): no D-Bus object specified for '" << client << "'\n";
+		kError(5900) <<"AlarmDaemon::readConfig(): no D-Bus object specified for '" << client <<"'";
 	else
 	{
 		mClientName = client;
-		kDebug(5900) << "AlarmDaemon::readConfig(): client " << mClientName << endl;
+		kDebug(5900) <<"AlarmDaemon::readConfig(): client" << mClientName;
 	}
 
 	// Remove obsolete CheckInterval entry (if it exists)
