@@ -154,7 +154,7 @@ bool KARecurrence::init(RecurrenceRule::PeriodType recurType, int freq, int coun
 		}
 		mFeb29Type = feb29Type;
 	}
-	setStartDateTime(startdt);   // sets recurrence floating if date-only
+	setStartDateTime(startdt);   // sets recurrence all-day if date-only
 	return true;
 }
 
@@ -441,7 +441,7 @@ void KARecurrence::writeRecurrence(KCal::Recurrence& recur) const
 			rrule2->setRecurrenceType(RecurrenceRule::rYearly);
 			rrule2->setFrequency(freq);
 			rrule2->setStartDt(startDateTime());
-			rrule2->setFloats(floats());
+			rrule2->setAllDay(allDay());
 			if (!count)
 				rrule2->setEndDt(endDateTime());
 			if (mFeb29Type == Preferences::Feb29_Mar1)
@@ -488,7 +488,7 @@ void KARecurrence::writeRecurrence(KCal::Recurrence& recur) const
 						 * is not lost should the user later change the recurrence count.
 						 */
 						KDateTime end = endDateTime();
-kDebug()<<"29th recurrence: count="<<count<<", end date="<<end.toString()<<endl;
+kDebug()<<"29th recurrence: count="<<count<<", end date="<<end.toString();
 						int count1 = rrule1->durationTo(end)
 						             - (rrule1->recursOn(startDate(), startDateTime().timeSpec()) ? 0 : 1);
 						if (count1 > 0)
@@ -563,7 +563,7 @@ KDateTime KARecurrence::endDateTime() const
 	}
 	dt.setDate(d);
 	rrule->setStartDt(dt);
-	rrule->setFloats(floats());
+	rrule->setAllDay(allDay());
 	rrule->setFrequency(frequency());
 	rrule->setDuration(duration());
 	QList<int> ds;
