@@ -34,6 +34,7 @@
 #include "functions.h"
 #include "kalarmapp.h"
 #include "kamail.h"
+#include "newalarmaction.h"
 #include "prefdlg.h"
 #include "preferences.h"
 #include "resourceselector.h"
@@ -57,6 +58,7 @@
 #include <kmenu.h>
 #include <kaction.h>
 #include <kactioncollection.h>
+#include <kinputdialog.h>
 
 #include <kstandardaction.h>
 #include <kiconloader.h>
@@ -102,17 +104,14 @@ TemplateDlg*             MainWindow::mTemplateDlg = 0;
 
 // Collect these widget labels together to ensure consistent wording and
 // translations across different modules.
-QString MainWindow::i18n_a_ShowAlarmTimes()     { return i18n("Show &Alarm Times"); }
-QString MainWindow::i18n_t_ShowAlarmTime()      { return i18n("Show alarm &time"); }
-QString MainWindow::i18n_m_ShowAlarmTime()      { return i18n("Show alarm ti&me"); }
-QString MainWindow::i18n_o_ShowTimeToAlarms()   { return i18n("Show Time t&o Alarms"); }
-QString MainWindow::i18n_n_ShowTimeToAlarm()    { return i18n("Show time u&ntil alarm"); }
-QString MainWindow::i18n_l_ShowTimeToAlarm()    { return i18n("Show time unti&l alarm"); }
-QString MainWindow::i18n_ShowArchivedAlarms()   { return i18n("Show Archived Alarms"); }
-QString MainWindow::i18n_e_ShowArchivedAlarms() { return i18n("Show &Archived Alarms"); }
-QString MainWindow::i18n_HideArchivedAlarms()   { return i18n("Hide Archived Alarms"); }
-QString MainWindow::i18n_e_HideArchivedAlarms() { return i18n("Hide &Archived Alarms"); }
-QString MainWindow::i18n_r_ShowResources()      { return i18n("Show &Resources");}
+QString MainWindow::i18n_a_ShowAlarmTimes()        { return i18nc("@action", "Show &Alarm Times"); }
+QString MainWindow::i18n_chk_ShowAlarmTime()       { return i18nc("@option:check", "Show alarm time"); }
+QString MainWindow::i18n_o_ShowTimeToAlarms()      { return i18nc("@action", "Show Time t&o Alarms"); }
+QString MainWindow::i18n_chk_ShowTimeToAlarm()     { return i18nc("@option:check", "Show time until alarm"); }
+QString MainWindow::i18n_a_ShowArchivedAlarms()    { return i18nc("@action", "Show &Archived Alarms"); }
+QString MainWindow::i18n_chk_ShowArchivedAlarms()  { return i18nc("@option:check", "Show Archived Alarms"); }
+QString MainWindow::i18n_tip_ShowArchivedAlarms()  { return i18nc("@info:tooltip", "Show Archived Alarms"); }
+QString MainWindow::i18n_tip_HideArchivedAlarms()  { return i18nc("@info:tooltip", "Hide Archived Alarms"); }
 
 
 /******************************************************************************
@@ -136,7 +135,7 @@ MainWindow::MainWindow(bool restored)
 	  mShowTimeTo(Preferences::showTimeToAlarm()),
 	  mShown(false)
 {
-	kDebug(5950) << "MainWindow::MainWindow()\n";
+	kDebug(5950) << "MainWindow::MainWindow()";
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowModality(Qt::WindowModal);
 	setObjectName("MainWin");    // used by LikeBack
@@ -146,8 +145,6 @@ MainWindow::MainWindow(bool restored)
 		KConfigGroup config(KGlobal::config(), WINDOW_NAME);
 		mResourcesWidth = config.readEntry(QString::fromLatin1("Splitter %1").arg(KApplication::desktop()->width()), (int)0);
 	}
-	KConfigGroup config(KGlobal::config(), WINDOW_NAME);
-	QList<int> order = config.readEntry("ColumnOrder", QList<int>());
 
 	setAcceptDrops(true);         // allow drag-and-drop onto this window
 	if (!mShowTimeTo)
@@ -170,9 +167,8 @@ MainWindow::MainWindow(bool restored)
 	// Create the alarm list widget
 	mListFilterModel = new AlarmListFilterModel(EventListModel::alarms());
 	mListFilterModel->setStatusFilter(mShowArchived ? static_cast<KCalEvent::Status>(KCalEvent::ACTIVE | KCalEvent::ARCHIVED) : KCalEvent::ACTIVE);
-	mListView = new AlarmListView(mSplitter);
+	mListView = new AlarmListView(WINDOW_NAME, mSplitter);
 	mListView->setModel(mListFilterModel);
-	mListView->setColumnOrder(order);
 	mListView->selectTimeColumns(mShowTime, mShowTimeTo);
 	mListView->sortByColumn(mShowTime ? EventListModel::TimeColumn : EventListModel::TimeToColumn, Qt::AscendingOrder);
 	mListDelegate = new AlarmListDelegate(mListView);
@@ -180,21 +176,11 @@ MainWindow::MainWindow(bool restored)
 	connect(mListView->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&,const QItemSelection&)), SLOT(slotSelection()));
 	connect(mListView, SIGNAL(activated(const QModelIndex&)), SLOT(slotDoubleClicked(const QModelIndex&)));
 	connect(mListView, SIGNAL(rightButtonClicked(const QPoint&)), SLOT(slotRightButtonClicked(const QPoint&)));
-	connect(mListView->header(), SIGNAL(sectionMoved(int,int,int)), SLOT(columnsReordered()));
-#ifdef __GNUC__
-#warning Try to avoid reloading the entire list when resources change?
-#warning Model should be told to reload independently of resource selector?
-#endif
-//	connect(mResourceSelector, SIGNAL(resourcesChanged()), EventListModel::alarms(), SLOT(reload()));
-//	connect(resources, SIGNAL(calendarChanged()), EventListModel::alarms(), SLOT(reload()));
 	connect(resources, SIGNAL(resourceStatusChanged(AlarmResource*, AlarmResources::Change)),
 	                   SLOT(slotResourceStatusChanged(AlarmResource*, AlarmResources::Change)));
 	connect(mResourceSelector, SIGNAL(resized(const QSize&, const QSize&)), SLOT(resourcesResized()));
 	initActions();
 
-#ifdef __GNUC__
-#warning Does not save to correct group in config file
-#endif
 	setAutoSaveSettings(QLatin1String(WINDOW_NAME), true);    // save toolbars, window sizes etc.
 	mWindowList.append(this);
 	if (mWindowList.count() == 1  &&  Daemon::isDcopHandlerReady())
@@ -209,7 +195,7 @@ MainWindow::MainWindow(bool restored)
 
 MainWindow::~MainWindow()
 {
-	kDebug(5950) << "MainWindow::~MainWindow()\n";
+	kDebug(5950) << "MainWindow::~MainWindow()";
 	mWindowList.removeAt(mWindowList.indexOf(this));
 	if (theApp()->trayWindow())
 	{
@@ -355,7 +341,7 @@ void MainWindow::show()
 		// Show error message now that the main window has been displayed.
 		// Waiting until now lets the user easily associate the message with
 		// the main window which is faulty.
-		KMessageBox::error(this, i18n("Failure to create menus\n(perhaps %1 missing or corrupted)", QLatin1String(UI_FILE)));
+		KMessageBox::error(this, i18nc("@info", "Failure to create menus (perhaps <filename>%1</filename> missing or corrupted)", QLatin1String(UI_FILE)));
 		mMenuError = false;
 	}
 }
@@ -368,17 +354,6 @@ void MainWindow::hideEvent(QHideEvent* he)
 	MainWindowBase::hideEvent(he);
 }
 
-/******************************************************************************
-*  Called when the list's column order is changed.
-*  Save the new column order as the default the next time the program is run.
-*/
-void MainWindow::columnsReordered()
-{
-	KConfigGroup config(KGlobal::config(), WINDOW_NAME);
-	config.writeEntry("ColumnOrder", mListView->columnOrder());
-	config.sync();
-}
-
 /******************************************************************************
 *  Initialise the menu, toolbar and main window actions.
 */
@@ -386,36 +361,37 @@ void MainWindow::initActions()
 {
 	KActionCollection* actions = actionCollection();
 
-	mActionTemplates = new KAction(i18n("&Templates..."), this);
+	mActionTemplates = new KAction(i18nc("@action", "&Templates..."), this);
 	actions->addAction(QLatin1String("templates"), mActionTemplates);
 	connect(mActionTemplates, SIGNAL(triggered(bool)), SLOT(slotTemplates()));
 
-	mActionNew = KAlarm::createNewAlarmAction(i18n("&New..."), actions, QLatin1String("new"));
-	connect(mActionNew, SIGNAL(triggered(bool)), SLOT(slotNew()));
+	mActionNew = new NewAlarmAction(false, i18nc("@action", "&New"), this);
+	actions->addAction(QLatin1String("new"), mActionNew);
+	connect(mActionNew, SIGNAL(selected(EditAlarmDlg::Type)), SLOT(slotNew(EditAlarmDlg::Type)));
 
-	mActionNewFromTemplate = KAlarm::createNewFromTemplateAction(i18n("New &From Template"), actions, QLatin1String("newFromTempl"));
+	mActionNewFromTemplate = KAlarm::createNewFromTemplateAction(i18nc("@action", "New &From Template"), actions, QLatin1String("newFromTempl"));
 	connect(mActionNewFromTemplate, SIGNAL(selected(const KAEvent&)), SLOT(slotNewFromTemplate(const KAEvent&)));
 
-	mActionCreateTemplate = new KAction(i18n("Create Tem&plate..."), this);
+	mActionCreateTemplate = new KAction(i18nc("@action", "Create Tem&plate..."), this);
 	actions->addAction(QLatin1String("createTemplate"), mActionCreateTemplate);
 	connect(mActionCreateTemplate, SIGNAL(triggered(bool)), SLOT(slotNewTemplate()));
 
-	mActionCopy = new KAction(KIcon("edit-copy"), i18n("&Copy..."), this);
+	mActionCopy = new KAction(KIcon("edit-copy"), i18nc("@action", "&Copy..."), this);
 	actions->addAction(QLatin1String("copy"), mActionCopy);
 	mActionCopy->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Insert));
 	connect(mActionCopy, SIGNAL(triggered(bool)), SLOT(slotCopy()));
 
-	mActionModify = new KAction(KIcon("edit"), i18n("&Edit..."), this);
+	mActionModify = new KAction(KIcon("edit"), i18nc("@action", "&Edit..."), this);
 	actions->addAction(QLatin1String("modify"), mActionModify);
 	mActionModify->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_E));
 	connect(mActionModify, SIGNAL(triggered(bool)), SLOT(slotModify()));
 
-	mActionDelete = new KAction(KIcon("edit-delete"), i18n("&Delete"), this);
+	mActionDelete = new KAction(KIcon("edit-delete"), i18nc("@action", "&Delete"), this);
 	actions->addAction(QLatin1String("delete"), mActionDelete);
 	mActionDelete->setShortcut(QKeySequence(Qt::Key_Delete));
 	connect(mActionDelete, SIGNAL(triggered(bool)), SLOT(slotDelete()));
 
-	mActionReactivate = new KAction(i18n("Reac&tivate"), this);
+	mActionReactivate = new KAction(i18nc("@action", "Reac&tivate"), this);
 	actions->addAction(QLatin1String("undelete"), mActionReactivate);
 	mActionReactivate->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
 	connect(mActionReactivate, SIGNAL(triggered(bool)), SLOT(slotReactivate()));
@@ -425,7 +401,7 @@ void MainWindow::initActions()
 	mActionEnable->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_B));
 	connect(mActionEnable, SIGNAL(triggered(bool)), SLOT(slotEnable()));
 
-	mActionView = new KAction(KIcon("zoom-original"), i18n("&View"), this);
+	mActionView = new KAction(KIcon("zoom-original"), i18nc("@action", "&View"), this);
 	actions->addAction(QLatin1String("view"), mActionView);
 	mActionView->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_W));
 	connect(mActionView, SIGNAL(triggered(bool)), SLOT(slotView()));
@@ -440,28 +416,28 @@ void MainWindow::initActions()
 	mActionShowTimeTo->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_I));
 	connect(mActionShowTimeTo, SIGNAL(triggered(bool)), SLOT(slotShowTimeTo()));
 
-	mActionShowArchived = new KToggleAction(i18n_e_ShowArchivedAlarms(), this);
+	mActionShowArchived = new KToggleAction(i18n_a_ShowArchivedAlarms(), this);
 	actions->addAction(QLatin1String("showArchivedAlarms"), mActionShowArchived);
 	mActionShowArchived->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_P));
 	connect(mActionShowArchived, SIGNAL(triggered(bool)), SLOT(slotShowArchived()));
 
-	mActionToggleTrayIcon = new KToggleAction(i18n("Show in System &Tray"), this);
+	mActionToggleTrayIcon = new KToggleAction(i18nc("@action", "Show in System &Tray"), this);
 	actions->addAction(QLatin1String("showInSystemTray"), mActionToggleTrayIcon);
 	connect(mActionToggleTrayIcon, SIGNAL(triggered(bool)), SLOT(slotToggleTrayIcon()));
 
-	mActionToggleResourceSel = new KToggleAction(KIcon("view_choose"), i18n_r_ShowResources(), this);
+	mActionToggleResourceSel = new KToggleAction(i18nc("@action", "Show &Resources"), this);
 	actions->addAction(QLatin1String("showResources"), mActionToggleResourceSel);
 	connect(mActionToggleResourceSel, SIGNAL(triggered(bool)), SLOT(slotToggleResourceSelector()));
 
-	mActionImportAlarms = new KAction(i18n("Import &Alarms..."), this);
+	mActionImportAlarms = new KAction(i18nc("@action", "Import &Alarms..."), this);
 	actions->addAction(QLatin1String("importAlarms"), mActionImportAlarms);
 	connect(mActionImportAlarms, SIGNAL(triggered(bool)), SLOT(slotImportAlarms()));
 
-	mActionImportBirthdays = new KAction(i18n("Import &Birthdays..."), this);
+	mActionImportBirthdays = new KAction(i18nc("@action", "Import &Birthdays..."), this);
 	actions->addAction(QLatin1String("importBirthdays"), mActionImportBirthdays);
 	connect(mActionImportBirthdays, SIGNAL(triggered(bool)), SLOT(slotBirthdays()));
 
-	QAction* action = new KAction(KIcon("view-refresh"), i18n("&Refresh Alarms"), this);
+	QAction* action = new KAction(KIcon("view-refresh"), i18nc("@action", "&Refresh Alarms"), this);
 	actions->addAction(QLatin1String("refreshAlarms"), action);
 	connect(action, SIGNAL(triggered(bool)), SLOT(slotResetDaemon()));
 
@@ -568,7 +544,7 @@ void MainWindow::enableTemplateMenuItem(bool enable)
 */
 void MainWindow::refresh()
 {
-	kDebug(5950) << "MainWindow::refresh()\n";
+	kDebug(5950) << "MainWindow::refresh()";
 	EventListModel::alarms()->reload();
 }
 
@@ -578,7 +554,7 @@ void MainWindow::refresh()
 */
 void MainWindow::updateKeepArchived(int days)
 {
-	kDebug(5950) << "MainWindow::updateKeepArchived(" << (bool)days << ")" << endl;
+	kDebug(5950) << "MainWindow::updateKeepArchived(" << (bool)days << ")";
 	if (mShowArchived  &&  !days)
 		slotShowArchived();   // toggle Show Archived option setting
 	mActionShowArchived->setEnabled(days);
@@ -592,7 +568,7 @@ void MainWindow::updateKeepArchived(int days)
 */
 void MainWindow::updateTimeColumns(bool oldTime, bool oldTimeTo)
 {
-	kDebug(5950) << "MainWindow::updateShowAlarmTimes()\n";
+	kDebug(5950) << "MainWindow::updateShowAlarmTimes()";
 	bool newTime   = Preferences::showAlarmTime();
 	bool newTimeTo = Preferences::showTimeToAlarm();
 	if (!newTime  &&  !newTimeTo)
@@ -634,9 +610,9 @@ void MainWindow::selectEvent(const QString& eventID)
 /******************************************************************************
 *  Called when the New button is clicked to edit a new alarm to add to the list.
 */
-void MainWindow::slotNew()
+void MainWindow::slotNew(EditAlarmDlg::Type type)
 {
-	KAlarm::editNewAlarm(mListView);
+	KAlarm::editNewAlarm(type, mListView);
 }
 
 /******************************************************************************
@@ -645,7 +621,7 @@ void MainWindow::slotNew()
 */
 void MainWindow::slotNewFromTemplate(const KAEvent& tmplate)
 {
-	KAlarm::editNewAlarm(mListView, &tmplate);
+	KAlarm::editNewAlarm(tmplate, mListView);
 }
 
 /******************************************************************************
@@ -658,7 +634,7 @@ void MainWindow::slotNewTemplate()
 	if (kcalEvent)
 	{
 		KAEvent event(kcalEvent);
-		KAlarm::editNewTemplate(this, &event);
+		KAlarm::editNewTemplate(event, this);
 	}
 }
 
@@ -672,7 +648,7 @@ void MainWindow::slotCopy()
 	if (kcalEvent)
 	{
 		KAEvent event(kcalEvent);
-		KAlarm::editNewAlarm(this, &event);
+		KAlarm::editNewAlarm(event, this);
 	}
 }
 
@@ -722,10 +698,10 @@ void MainWindow::slotDelete()
 	if (Preferences::confirmAlarmDeletion())
 	{
 		int n = events.count();
-		if (KMessageBox::warningContinueCancel(this, i18np("Do you really want to delete the selected alarm?",
+		if (KMessageBox::warningContinueCancel(this, i18ncp("@info", "Do you really want to delete the selected alarm?",
 		                                                   "Do you really want to delete the %1 selected alarms?", n),
-		                                       i18np("Delete Alarm", "Delete Alarms", n),
-		                                       KGuiItem(i18n("&Delete"), "edit-delete"),
+		                                       i18ncp("@title:window", "Delete Alarm", "Delete Alarms", n),
+		                                       KGuiItem(i18nc("@action:button", "&Delete"), "edit-delete"),
 		                                       KStandardGuiItem::cancel(),
 		                                       Preferences::CONFIRM_ALARM_DELETION)
 		    != KMessageBox::Continue)
@@ -813,7 +789,7 @@ void MainWindow::slotShowArchived()
 {
 	mShowArchived = !mShowArchived;
 	mActionShowArchived->setChecked(mShowArchived);
-	mActionShowArchived->setToolTip(mShowArchived ? i18n_HideArchivedAlarms() : i18n_ShowArchivedAlarms());
+	mActionShowArchived->setToolTip(mShowArchived ? i18n_tip_HideArchivedAlarms() : i18n_tip_ShowArchivedAlarms());
 	mListFilterModel->setStatusFilter(mShowArchived ? static_cast<KCalEvent::Status>(KCalEvent::ACTIVE | KCalEvent::ARCHIVED) : KCalEvent::ACTIVE);
 	mListView->reset();
 }
@@ -824,11 +800,7 @@ void MainWindow::slotShowArchived()
 */
 void MainWindow::slotImportAlarms()
 {
-	if (AlarmCalendar::importAlarms(this))
-		EventListModel::alarms()->reload();
-#ifdef __GNUC__
-#warning Is reload necessary, or can signal tell EventListModel?
-#endif
+	AlarmCalendar::importAlarms(this);
 }
 
 /******************************************************************************
@@ -851,7 +823,7 @@ void MainWindow::slotBirthdays()
 			AlarmResources* resources = AlarmResources::instance();
 			for (int i = 0, end = events.count();  i < end;  ++i)
 				undos.append(events[i], resources->resourceForIncidence(events[i].id()));
-			Undo::saveAdds(undos, i18n("Import birthdays"));
+			Undo::saveAdds(undos, i18nc("@info", "Import birthdays"));
 
 			if (status != KAlarm::UPDATE_FAILED)
 				KAlarm::outputAlarmWarnings(&dlg);
@@ -861,7 +833,7 @@ void MainWindow::slotBirthdays()
 
 /******************************************************************************
 *  Called when the Templates menu item is selected, to display the alarm
-*  template editing dialogue.
+*  template editing dialog.
 */
 void MainWindow::slotTemplates()
 {
@@ -875,13 +847,13 @@ void MainWindow::slotTemplates()
 }
 
 /******************************************************************************
-*  Called when the alarm template editing dialogue has exited.
+*  Called when the alarm template editing dialog has exited.
 */
 void MainWindow::slotTemplatesEnd()
 {
 	if (mTemplateDlg)
 	{
-		mTemplateDlg->delayedDestruct();   // this deletes the dialogue once it is safe to do so
+		mTemplateDlg->delayedDestruct();   // this deletes the dialog once it is safe to do so
 		mTemplateDlg = 0;
 		enableTemplateMenuItem(true);      // re-enable menu item in all windows
 	}
@@ -1024,8 +996,12 @@ void MainWindow::initUndoMenu(QMenu* menu, Undo::Type type)
 	for (int i = 0, end = ids.count();  i < end;  ++i)
 	{
 		int id = ids[i];
-		QAction* act = menu->addAction(i18nc("Undo [action]: message", "%1 %2: %3",
-		                               action, Undo::actionText(type, id), Undo::description(type, id)));
+		QString actText = Undo::actionText(type, id);
+		QString descrip = Undo::description(type, id);
+		QString text = descrip.isEmpty()
+		             ? i18nc("@action Undo/Redo [action]", "%1 %2", action, actText)
+		             : i18nc("@action Undo [action]: message", "%1 %2: %3", action, actText, descrip);
+		QAction* act = menu->addAction(text);
 		mUndoMenuIds[act] = id;
 	}
 }
@@ -1186,7 +1162,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
 	KCal::CalendarLocal calendar(Preferences::timeZone(true));
 #ifndef NDEBUG
 	QString fmts = data->formats().join(", ");
-	kDebug(5950) << "MainWindow::executeDropEvent(): " << fmts << endl;
+	kDebug(5950) << "MainWindow::executeDropEvent():" << fmts;
 #endif
 
 	/* The order of the tests below matters, since some dropped objects
@@ -1196,7 +1172,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
 	if (!(bytes = data->data("message/rfc822")).isEmpty())
 	{
 		// Email message(s). Ignore all but the first.
-		kDebug(5950) << "MainWindow::executeDropEvent(email)" << endl;
+		kDebug(5950) << "MainWindow::executeDropEvent(email)";
 		KMime::Content content;
 		content.setContent(bytes);
 		content.parse();
@@ -1221,7 +1197,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
 	}
 	else if (!(files = KUrl::List::fromMimeData(data)).isEmpty())
 	{
-		kDebug(5950) << "MainWindow::executeDropEvent(URL)" << endl;
+		kDebug(5950) << "MainWindow::executeDropEvent(URL)";
 		action = KAEvent::FILE;
 		alarmText.setText(files[0].prettyUrl());
 	}
@@ -1229,7 +1205,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
 	{
 		mailList = KPIM::MailList::fromMimeData(data);
 		// KMail message(s). Ignore all but the first.
-		kDebug(5950) << "MainWindow::executeDropEvent(KMail_list)" << endl;
+		kDebug(5950) << "MainWindow::executeDropEvent(KMail_list)";
 		if (mailList.isEmpty())
 			return;
 		KPIM::MailSummary& summary = mailList[0];
@@ -1243,26 +1219,48 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
 	else if (KCal::ICalDrag::fromMimeData(data, &calendar))
 	{
 		// iCalendar - ignore all but the first event
-		kDebug(5950) << "MainWindow::executeDropEvent(iCalendar)" << endl;
+		kDebug(5950) << "MainWindow::executeDropEvent(iCalendar)";
 		KCal::Event::List events = calendar.rawEvents();
 		if (!events.isEmpty())
 		{
 			KAEvent ev(events[0]);
-			KAlarm::editNewAlarm(win, &ev);
+			KAlarm::editNewAlarm(ev, win);
 		}
 		return;
 	}
 	else if (data->hasText())
 	{
 		QString text = data->text();
-		kDebug(5950) << "MainWindow::executeDropEvent(text)" << endl;
+		kDebug(5950) << "MainWindow::executeDropEvent(text)";
 		alarmText.setText(text);
 	}
 	else
 		return;
 
 	if (!alarmText.isEmpty())
-		KAlarm::editNewAlarm(win, 0, action, &alarmText);
+	{
+		if (action == KAEvent::MESSAGE
+		&&  (alarmText.isEmail() || alarmText.isScript()))
+		{
+			// If the alarm text could be interpreted as an email or command script,
+			// prompt for which type of alarm to create.
+			QStringList types;
+			types += i18nc("@item:inlistbox", "Display Alarm");
+			if (alarmText.isEmail())
+				types += i18nc("@item:inlistbox", "Email Alarm");
+			else if (alarmText.isScript())
+				types += i18nc("@item:inlistbox", "Command Alarm");
+			bool ok = false;
+			QString type = KInputDialog::getItem(i18nc("@title:window", "Alarm Type"),
+			                                     i18nc("@info", "Choose alarm type to create:"), types, 0, false, &ok, mainMainWindow());
+			if (!ok)
+				return;   // user didn't press OK
+			int i = types.indexOf(type);
+			if (i == 1)
+				action = alarmText.isEmail() ? KAEvent::EMAIL : KAEvent::COMMAND;
+		}
+		KAlarm::editNewAlarm(action, win, &alarmText);
+	}
 }
 
 /******************************************************************************
@@ -1285,9 +1283,6 @@ void MainWindow::slotResourceStatusChanged(AlarmResource*, AlarmResources::Chang
 		w->mActionCreateTemplate->setEnabled(templat);
 		w->slotSelection();
 	}
-
-	if (change == AlarmResources::Location)
-		EventListModel::alarms()->reload();
 }
 
 /******************************************************************************
@@ -1344,7 +1339,7 @@ void MainWindow::slotSelection()
 		}
 	}
 
-	kDebug(5950) << "MainWindow::slotSelection(true)\n";
+	kDebug(5950) << "MainWindow::slotSelection(true)";
 	mActionCreateTemplate->setEnabled((count == 1) && (resources->activeCount(AlarmResource::TEMPLATE, true) > 0));
 	mActionCopy->setEnabled(active && count == 1);
 	mActionModify->setEnabled(active && !readOnly && selEvent && !KAEvent(selEvent).expired());
@@ -1362,7 +1357,7 @@ void MainWindow::slotSelection()
 */
 void MainWindow::slotRightButtonClicked(const QPoint& globalPos)
 {
-	kDebug(5950) << "MainWindow::slotRightButtonClicked()" << endl;
+	kDebug(5950) << "MainWindow::slotRightButtonClicked()";
 	if (mContextMenu)
 		mContextMenu->popup(globalPos);
 }
@@ -1383,11 +1378,11 @@ void MainWindow::selectionCleared()
 
 /******************************************************************************
 *  Called when the mouse is double clicked on the ListView.
-*  Displays the Edit Alarm dialog, for the clicked item if applicable.
+*  Displays the Edit Alarm dialog for the clicked item.
 */
 void MainWindow::slotDoubleClicked(const QModelIndex& index)
 {
-	kDebug(5950) << "MainWindow::slotDoubleClicked()\n";
+	kDebug(5950) << "MainWindow::slotDoubleClicked()";
 	if (index.isValid())
 	{
 		if (mActionModify->isEnabled())
@@ -1395,8 +1390,6 @@ void MainWindow::slotDoubleClicked(const QModelIndex& index)
 		else if (mActionView->isEnabled())
 			slotView();
 	}
-	else
-		slotNew();
 }
 
 /******************************************************************************
@@ -1405,7 +1398,7 @@ void MainWindow::slotDoubleClicked(const QModelIndex& index)
 void MainWindow::setEnableText(bool enable)
 {
 	mActionEnableEnable = enable;
-	mActionEnable->setText(enable ? i18n("Ena&ble") : i18n("Disa&ble"));
+	mActionEnable->setText(enable ? i18nc("@action", "Ena&ble") : i18nc("@action", "Disa&ble"));
 }
 
 /******************************************************************************
