@@ -28,6 +28,7 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QPushButton>
+#include <QCheckBox>
 #include <QLabel>
 #include <QTextEdit>
 #include <QPalette>
@@ -56,18 +57,13 @@
 #include <kmimetype.h>
 #include <kmessagebox.h>
 #include <kwindowsystem.h>
-#include <k3process.h>
 #include <kio/netaccess.h>
 #include <knotification.h>
 #include <kpushbutton.h>
-#if 0
-#include <phonon/simpleplayer.h>
-#else
 #include <phonon/mediaobject.h>
-#include <phonon/audiopath.h>
+#include <phonon/path.h>
 #include <phonon/audiooutput.h>
 #include <phonon/volumefadereffect.h>
-#endif
 #include <kdebug.h>
 #include <ktoolinvocation.h>
 
@@ -119,11 +115,6 @@ class MessageText : public QTextEdit
 static const Qt::WFlags          WFLAGS       = Qt::WindowStaysOnTopHint;
 static const Qt::WFlags          WFLAGS2      = Qt::WindowContextHelpButtonHint;
 static const Qt::WidgetAttribute WidgetFlags  = Qt::WA_DeleteOnClose;
-#ifdef __GNUC__
-#warning WA_GroupLeader deprecated and replaced with MainWindowBase::setWindowModality() - check
-#endif
-static const int WidgetFlags2 = 0;//Qt::WA_GroupLeader;
-//static const Qt::WidgetAttribute WidgetFlags2 = 0;//Qt::WA_GroupLeader;
 
 
 QList<MessageWin*> MessageWin::mWindowList;
@@ -162,6 +153,7 @@ MessageWin::MessageWin(const KAEvent& event, const KAAlarm& alarm, int flags)
 	  mEditButton(0),
 	  mDeferButton(0),
 	  mSilenceButton(0),
+	  mDontShowAgainCheck(0),
 	  mDeferDlg(0),
 	  mFlags(event.flags()),
 	  mLateCancel(event.lateCancel()),
@@ -176,8 +168,9 @@ MessageWin::MessageWin(const KAEvent& event, const KAAlarm& alarm, int flags)
 	  mNoCloseConfirm(false),
 	  mDisableDeferral(false)
 {
-	kDebug(5950) << "MessageWin::MessageWin(event)" << endl;
-	setAttribute(static_cast<Qt::WidgetAttribute>(WidgetFlags | WidgetFlags2));
+	kDebug(5950) << "MessageWin::MessageWin(event)";
+	setAttribute(static_cast<Qt::WidgetAttribute>(WidgetFlags));
+	setWindowModality(Qt::WindowModal);
 	setObjectName("MessageWin");    // used by LikeBack
 	if (!(flags & NO_INIT_VIEW))
 	{
@@ -195,9 +188,25 @@ MessageWin::MessageWin(const KAEvent& event, const KAAlarm& alarm, int flags)
 }
 
 /******************************************************************************
-*  Construct the message window for a specified error message.
+*  Display an error message window.
+*  If 'dontShowAgain' is non-null, a "Don't show again" option is displayed. Note
+*  that the option is specific to 'event'.
 */
-MessageWin::MessageWin(const KAEvent& event, const DateTime& alarmDateTime, const QStringList& errmsgs)
+void MessageWin::showError(const KAEvent& event, const DateTime& alarmDateTime,
+                           const QStringList& errmsgs, const QString& dontShowAgain)
+{
+	if (dontShowAgain.isEmpty()
+	||  !KAlarm::dontShowErrors(event.id(), dontShowAgain))
+		(new MessageWin(event, alarmDateTime, errmsgs, dontShowAgain))->show();
+}
+
+/******************************************************************************
+*  Construct the message window for a specified error message.
+*  If 'dontShowAgain' is non-null, a "Don't show again" option is displayed. Note
+*  that the option is specific to 'event'.
+*/
+MessageWin::MessageWin(const KAEvent& event, const DateTime& alarmDateTime,
+                       const QStringList& errmsgs, const QString& dontShowAgain)
 	: MainWindowBase(0, WFLAGS | WFLAGS2),
 	  mMessage(event.cleanText()),
 	  mDateTime(alarmDateTime),
@@ -206,6 +215,7 @@ MessageWin::MessageWin(const KAEvent& event, const DateTime& alarmDateTime, cons
 	  mAction(event.action()),
 	  mKMailSerialNumber(0),
 	  mErrorMsgs(errmsgs),
+	  mDontShowAgain(dontShowAgain),
 	  mRestoreHeight(0),
 	  mConfirmAck(false),
 	  mShowEdit(false),
@@ -217,6 +227,7 @@ MessageWin::MessageWin(const KAEvent& event, const DateTime& alarmDateTime, cons
 	  mEditButton(0),
 	  mDeferButton(0),
 	  mSilenceButton(0),
+	  mDontShowAgainCheck(0),
 	  mDeferDlg(0),
 	  mErrorWindow(true),
 	  mNoPostAction(true),
@@ -227,8 +238,9 @@ MessageWin::MessageWin(const KAEvent& event, const DateTime& alarmDateTime, cons
 	  mNoCloseConfirm(false),
 	  mDisableDeferral(false)
 {
-	kDebug(5950) << "MessageWin::MessageWin(errmsg)" << endl;
-	setAttribute(static_cast<Qt::WidgetAttribute>(WidgetFlags | WidgetFlags2));
+	kDebug(5950) << "MessageWin::MessageWin(errmsg)";
+	setAttribute(static_cast<Qt::WidgetAttribute>(WidgetFlags));
+	setWindowModality(Qt::WindowModal);
 	setObjectName("ErrorWin");    // used by LikeBack
 	initView();
 	mWindowList.append(this);
@@ -244,6 +256,7 @@ MessageWin::MessageWin()
 	  mEditButton(0),
 	  mDeferButton(0),
 	  mSilenceButton(0),
+	  mDontShowAgainCheck(0),
 	  mDeferDlg(0),
 	  mErrorWindow(false),
 	  mRecreating(false),
@@ -253,8 +266,9 @@ MessageWin::MessageWin()
 	  mNoCloseConfirm(false),
 	  mDisableDeferral(false)
 {
-	kDebug(5950) << "MessageWin::MessageWin(restore)\n";
+	kDebug(5950) << "MessageWin::MessageWin(restore)";
 	setAttribute(WidgetFlags);
+	setWindowModality(Qt::WindowModal);
 	setObjectName("RestoredMsgWin");    // used by LikeBack
 	mWindowList.append(this);
 }
@@ -264,7 +278,7 @@ MessageWin::MessageWin()
 */
 MessageWin::~MessageWin()
 {
-	kDebug(5950) << "MessageWin::~MessageWin(" << mEventID << ")" << endl;
+	kDebug(5950) << "MessageWin::~MessageWin(" << mEventID << ")";
 	stopPlay();
 	mWindowList.removeAll(this);
 	if (!mRecreating)
@@ -283,7 +297,7 @@ void MessageWin::initView()
 {
 	bool reminder = (!mErrorWindow  &&  (mAlarmType & KAAlarm::REMINDER_ALARM));
 	int leading = fontMetrics().leading();
-	setCaption((mAlarmType & KAAlarm::REMINDER_ALARM) ? i18n("Reminder") : i18n("Message"));
+	setCaption((mAlarmType & KAAlarm::REMINDER_ALARM) ? i18nc("@title:window", "Reminder") : i18nc("@title:window", "Message"));
 	QWidget* topWidget = new QWidget(this);
 	setCentralWidget(topWidget);
 	QVBoxLayout* topLayout = new QVBoxLayout(topWidget);
@@ -308,17 +322,37 @@ void MessageWin::initView()
 		// Alarm date/time.
 		// Display time zone if not local time zone.
 		QLabel* label = new QLabel(frame ? frame : topWidget);
-		label->setText(KGlobal::locale()->formatDateTime(KDateTime(mDateTime), KLocale::ShortDate, KLocale::DateTimeFormatOptions(mDateTime.isLocalZone() ? 0 : KLocale::TimeZone)));
+		QString tm;
+		if (mDateTime.isDateOnly())
+			tm = KGlobal::locale()->formatDate(mDateTime.date(), KLocale::ShortDate);
+		else
+		{
+			bool showZone = false;
+			if (mDateTime.timeType() == KDateTime::UTC
+			||  mDateTime.timeType() == KDateTime::TimeZone && !mDateTime.isLocalZone())
+			{
+				// Display time zone abbreviation if it's different from the local
+				// zone. Note that the iCalendar time zone might represent the local
+				// time zone in a slightly different way from the system time zone,
+				// so the zone comparison above might not produce the desired result.
+				QString tz = mDateTime.kDateTime().toString(QString::fromLatin1("%Z"));
+				KDateTime local = mDateTime.kDateTime();
+				local.setTimeSpec(KDateTime::Spec::LocalZone());
+				showZone = (local.toString(QString::fromLatin1("%Z")) != tz);
+			}
+			tm = KGlobal::locale()->formatDateTime(mDateTime.kDateTime(), KLocale::ShortDate, KLocale::DateTimeFormatOptions(showZone ? KLocale::TimeZone : 0));
+		}
+		label->setText(tm);
 		if (!frame)
 			label->setFrameStyle(QFrame::Box | QFrame::Raised);
 		label->setFixedSize(label->sizeHint());
 		layout->addWidget(label, 0, Qt::AlignHCenter);
-		label->setWhatsThis(i18n("The scheduled date/time for the message (as opposed to the actual time of display)."));
+		label->setWhatsThis(i18nc("@info:whatsthis", "The scheduled date/time for the message (as opposed to the actual time of display)."));
 
 		if (frame)
 		{
 			label = new QLabel(frame);
-			label->setText(i18n("Reminder"));
+			label->setText(i18nc("@info", "Reminder"));
 			label->setFixedSize(label->sizeHint());
 			layout->addWidget(label, 0, Qt::AlignHCenter);
 			frame->setFixedSize(frame->sizeHint());
@@ -336,7 +370,7 @@ void MessageWin::initView()
 				QLabel* label = new QLabel(mMessage, topWidget);
 				label->setFrameStyle(QFrame::Box | QFrame::Raised);
 				label->setFixedSize(label->sizeHint());
-				label->setWhatsThis(i18n("The file whose contents are displayed below"));
+				label->setWhatsThis(i18nc("@info:whatsthis", "The file whose contents are displayed below"));
 				topLayout->addWidget(label, 0, Qt::AlignHCenter);
 
 				// Display contents of file
@@ -352,7 +386,6 @@ void MessageWin::initView()
 					{
 						opened = true;
 						KTextBrowser* view = new KTextBrowser(topWidget);
-						view->setObjectName("fileContents");
 						bool imageType = (KAlarm::fileType(KMimeType::findByPath(tmpFile)->name()) == KAlarm::Image);
 #ifdef __GNUC__
 #warning Check that HTML links and link paths work
@@ -370,15 +403,15 @@ void MessageWin::initView()
 						// So there is no need to calculate an accurate size.
 						int h = 20*view->fontMetrics().lineSpacing() + 2*view->frameWidth();
 						view->resize(QSize(h, h).expandedTo(view->sizeHint()));
-						view->setWhatsThis(i18n("The contents of the file to be displayed"));
+						view->setWhatsThis(i18nc("@info:whatsthis", "The contents of the file to be displayed"));
 					}
 					KIO::NetAccess::removeTempFile(tmpFile);
 				}
 				if (!opened)
 				{
 					// File couldn't be opened
-					bool exists = KIO::NetAccess::exists(url, true, MainWindow::mainMainWindow());
-					mErrorMsgs += dir ? i18n("File is a folder") : exists ? i18n("Failed to open file") : i18n("File not found");
+					bool exists = KIO::NetAccess::exists(url, KIO::NetAccess::SourceSide, MainWindow::mainMainWindow());
+					mErrorMsgs += dir ? i18nc("@info", "File is a folder") : exists ? i18nc("@info", "Failed to open file") : i18nc("@info", "File not found");
 				}
 				break;
 			}
@@ -403,7 +436,7 @@ void MessageWin::initView()
 				text->setMaximumHeight(h + text->scrollBarHeight());
 				text->setMinimumHeight(qMin(h, lineSpacing*4));
 				text->setMaximumWidth(s.width() + text->scrollBarWidth());
-				text->setWhatsThis(i18n("The alarm message"));
+				text->setWhatsThis(i18nc("@info:whatsthis", "The alarm message"));
 				int vspace = lineSpacing/2;
 				int hspace = lineSpacing - KDialog::marginHint();
 				topLayout->addSpacing(vspace);
@@ -462,20 +495,20 @@ void MessageWin::initView()
 				// Display the email addresses and subject.
 				QFrame* frame = new QFrame(topWidget);
 				frame->setFrameStyle(QFrame::Box | QFrame::Raised);
-				frame->setWhatsThis(i18n("The email to send"));
+				frame->setWhatsThis(i18nc("@info:whatsthis", "The email to send"));
 				topLayout->addWidget(frame, 0, Qt::AlignHCenter);
 				QGridLayout* grid = new QGridLayout(frame);
 				grid->setMargin(KDialog::marginHint());
 				grid->setSpacing(KDialog::spacingHint());
 
-				QLabel* label = new QLabel(i18nc("Email addressee", "To:"), frame);
+				QLabel* label = new QLabel(i18nc("@info Email addressee", "To:"), frame);
 				label->setFixedSize(label->sizeHint());
 				grid->addWidget(label, 0, 0, Qt::AlignLeft);
 				label = new QLabel(mEvent.emailAddresses("\n"), frame);
 				label->setFixedSize(label->sizeHint());
 				grid->addWidget(label, 0, 1, Qt::AlignLeft);
 
-				label = new QLabel(i18nc("Email subject", "Subject:"), frame);
+				label = new QLabel(i18nc("@info Email subject", "Subject:"), frame);
 				label->setFixedSize(label->sizeHint());
 				grid->addWidget(label, 1, 0, Qt::AlignLeft);
 				label = new QLabel(mEvent.emailSubject(), frame);
@@ -501,7 +534,7 @@ void MessageWin::initView()
 	}
 	else
 	{
-		setCaption(i18n("Error"));
+		setCaption(i18nc("@title:window", "Error"));
 		QHBoxLayout* layout = new QHBoxLayout();
 		layout->setMargin(2*KDialog::marginHint());
 		layout->addStretch();
@@ -519,6 +552,12 @@ void MessageWin::initView()
 			vlayout->addWidget(label, 0, Qt::AlignLeft);
 		}
 		layout->addStretch();
+		if (!mDontShowAgain.isEmpty())
+		{
+			mDontShowAgainCheck = new QCheckBox(i18nc("@option:check", "Do not display this error message again for this alarm"), topWidget);
+			mDontShowAgainCheck->setFixedSize(mDontShowAgainCheck->sizeHint());
+			topLayout->addWidget(mDontShowAgainCheck, 0, Qt::AlignLeft);
+		}
 	}
 
 	QGridLayout* grid = new QGridLayout();
@@ -532,31 +571,31 @@ void MessageWin::initView()
 	mOkButton->clearFocus();
 	mOkButton->setFocusPolicy(Qt::ClickFocus);    // don't allow keyboard selection
 	mOkButton->setFixedSize(mOkButton->sizeHint());
-	connect(mOkButton, SIGNAL(clicked()), SLOT(close()));
+	connect(mOkButton, SIGNAL(clicked()), SLOT(slotOk()));
 	grid->addWidget(mOkButton, 0, gridIndex++, Qt::AlignHCenter);
-	mOkButton->setWhatsThis(i18n("Acknowledge the alarm"));
+	mOkButton->setWhatsThis(i18nc("@info:whatsthis", "Acknowledge the alarm"));
 
 	if (mShowEdit)
 	{
 		// Edit button
-		mEditButton = new QPushButton(i18n("&Edit..."), topWidget);
+		mEditButton = new QPushButton(i18nc("@action:button", "&Edit..."), topWidget);
 		mEditButton->setFocusPolicy(Qt::ClickFocus);    // don't allow keyboard selection
 		mEditButton->setFixedSize(mEditButton->sizeHint());
 		connect(mEditButton, SIGNAL(clicked()), SLOT(slotEdit()));
 		grid->addWidget(mEditButton, 0, gridIndex++, Qt::AlignHCenter);
-		mEditButton->setWhatsThis(i18n("Edit the alarm."));
+		mEditButton->setWhatsThis(i18nc("@info:whatsthis", "Edit the alarm."));
 	}
 
 	if (!mNoDefer)
 	{
 		// Defer button
-		mDeferButton = new QPushButton(i18n("&Defer..."), topWidget);
+		mDeferButton = new QPushButton(i18nc("@action:button", "&Defer..."), topWidget);
 		mDeferButton->setFocusPolicy(Qt::ClickFocus);    // don't allow keyboard selection
 		mDeferButton->setFixedSize(mDeferButton->sizeHint());
 		connect(mDeferButton, SIGNAL(clicked()), SLOT(slotDefer()));
 		grid->addWidget(mDeferButton, 0, gridIndex++, Qt::AlignHCenter);
-		mDeferButton->setWhatsThis(i18n("Defer the alarm until later.\n"
-		                                "You will be prompted to specify when the alarm should be redisplayed."));
+		mDeferButton->setWhatsThis(i18nc("@info:whatsthis", "<para>Defer the alarm until later.</para>"
+		                                "<para>You will be prompted to specify when the alarm should be redisplayed.</para>"));
 
 		setDeferralLimit(mEvent);    // ensure that button is disabled when alarm can't be deferred any more
 	}
@@ -570,8 +609,8 @@ void MessageWin::initView()
 		mSilenceButton->setFixedSize(mSilenceButton->sizeHint());
 		connect(mSilenceButton, SIGNAL(clicked()), SLOT(stopPlay()));
 		grid->addWidget(mSilenceButton, 0, gridIndex++, Qt::AlignHCenter);
-		mSilenceButton->setToolTip(i18n("Stop sound"));
-		mSilenceButton->setWhatsThis(i18n("Stop playing the sound"));
+		mSilenceButton->setToolTip(i18nc("@info:tooltip", "Stop sound"));
+		mSilenceButton->setWhatsThis(i18nc("@info:whatsthis", "Stop playing the sound"));
 		// To avoid getting in a mess, disable the button until sound playing has been set up
 		mSilenceButton->setEnabled(false);
 	}
@@ -580,28 +619,27 @@ void MessageWin::initView()
 	if (mKMailSerialNumber)
 	{
 		// KMail button
-		QPixmap pixmap = iconLoader.loadIcon(QLatin1String("kmail"), K3Icon::MainToolbar);
+		QPixmap pixmap = iconLoader.loadIcon(QLatin1String("kmail"), KIconLoader::MainToolbar);
 		mKMailButton = new QPushButton(topWidget);
 		mKMailButton->setIcon(pixmap);
 		mKMailButton->setFixedSize(mKMailButton->sizeHint());
 		connect(mKMailButton, SIGNAL(clicked()), SLOT(slotShowKMailMessage()));
 		grid->addWidget(mKMailButton, 0, gridIndex++, Qt::AlignHCenter);
-		mKMailButton->setToolTip(i18nc("Locate this email in KMail", "Locate in KMail"));
-		mKMailButton->setWhatsThis(i18n("Locate and highlight this email in KMail"));
+		mKMailButton->setToolTip(i18nc("@info:tooltip Locate this email in KMail", "Locate in <application>KMail</application>"));
+		mKMailButton->setWhatsThis(i18nc("@info:whatsthis", "Locate and highlight this email in <application>KMail</application>"));
 	}
 	else
 		mKMailButton = 0;
 
 	// KAlarm button
-	QPixmap pixmap = iconLoader.loadIcon(KGlobal::mainComponent().aboutData()->appName(), K3Icon::MainToolbar);
+	QPixmap pixmap = iconLoader.loadIcon(KGlobal::mainComponent().aboutData()->appName(), KIconLoader::MainToolbar);
 	mKAlarmButton = new QPushButton(topWidget);
 	mKAlarmButton->setIcon(pixmap);
 	mKAlarmButton->setFixedSize(mKAlarmButton->sizeHint());
 	connect(mKAlarmButton, SIGNAL(clicked()), SLOT(displayMainWindow()));
 	grid->addWidget(mKAlarmButton, 0, gridIndex++, Qt::AlignHCenter);
-	QString actKAlarm = i18n("Activate KAlarm");
-	mKAlarmButton->setToolTip(actKAlarm);
-	mKAlarmButton->setWhatsThis(actKAlarm);
+	mKAlarmButton->setToolTip(i18nc("@info:tooltip", "Activate <application>KAlarm</application>"));
+	mKAlarmButton->setWhatsThis(i18nc("@info:whatsthis", "Activate <application>KAlarm</application>"));
 
 	// Disable all buttons initially, to prevent accidental clicking on if they happen to be
 	// under the mouse just as the window appears.
@@ -640,11 +678,11 @@ void MessageWin::setRemainingTextDay()
 	else
 	{
 		if (days <= 0)
-			text = i18n("Today");
+			text = i18nc("@info", "Today");
 		else if (days % 7)
-			text = i18np("Tomorrow", "in %1 days' time", days);
+			text = i18ncp("@info", "Tomorrow", "in %1 days' time", days);
 		else
-			text = i18np("in 1 week's time", "in %1 weeks' time", days/7);
+			text = i18ncp("@info", "in 1 week's time", "in %1 weeks' time", days/7);
 	}
 	mRemainingText->setText(text);
 }
@@ -658,13 +696,13 @@ void MessageWin::setRemainingTextMinute()
 	QString text;
 	int mins = (KDateTime::currentUtcDateTime().secsTo(mDateTime.effectiveKDateTime()) + 59) / 60;
 	if (mins < 60)
-		text = i18np("in 1 minute's time", "in %1 minutes' time", (mins > 0 ? mins : 0));
+		text = i18ncp("@info", "in 1 minute's time", "in %1 minutes' time", (mins > 0 ? mins : 0));
 	else if (mins % 60 == 0)
-		text = i18np("in 1 hour's time", "in %1 hours' time", mins/60);
+		text = i18ncp("@info", "in 1 hour's time", "in %1 hours' time", mins/60);
 	else if (mins % 60 == 1)
-		text = i18np("in 1 hour 1 minute's time", "in %1 hours 1 minute's time", mins/60);
+		text = i18ncp("@info", "in 1 hour 1 minute's time", "in %1 hours 1 minute's time", mins/60);
 	else
-		text = i18np("in 1 hour %2 minutes' time", "in %1 hours %2 minutes' time", mins/60, mins%60);
+		text = i18ncp("@info", "in 1 hour %2 minutes' time", "in %1 hours %2 minutes' time", mins/60, mins%60);
 	mRemainingText->setText(text);
 }
 
@@ -714,6 +752,7 @@ void MessageWin::saveProperties(KConfigGroup& config)
 		config.writeEntry("NoDefer", mNoDefer);
 		config.writeEntry("NoPostAction", mNoPostAction);
 		config.writeEntry("KMailSerial", static_cast<qulonglong>(mKMailSerialNumber));
+		config.writeEntry("DontShowAgain", mDontShowAgain);
 	}
 	else
 		config.writeEntry("Invalid", true);
@@ -740,7 +779,7 @@ void MessageWin::readProperties(const KConfigGroup& config)
 	QString zone         = config.readEntry("TimeZone");
 	if (zone.isEmpty())
 		mDateTime = KDateTime(dt, KDateTime::ClockTime);
-	else if (zone == QString::fromLatin1("UTC"))
+	else if (zone == QLatin1String("UTC"))
 	{
 		dt.setTimeSpec(Qt::UTC);
 		mDateTime = KDateTime(dt, KDateTime::UTC);
@@ -766,9 +805,10 @@ void MessageWin::readProperties(const KConfigGroup& config)
 	mNoDefer             = config.readEntry("NoDefer", false);
 	mNoPostAction        = config.readEntry("NoPostAction", true);
 	mKMailSerialNumber   = static_cast<unsigned long>(config.readEntry("KMailSerial", QVariant(QVariant::ULongLong)).toULongLong());
+	mDontShowAgain       = config.readEntry("DontShowAgain", QString());
 	mShowEdit            = false;
 	mResource            = 0;
-	kDebug(5950) << "MessageWin::readProperties(" << mEventID << ")" << endl;
+	kDebug(5950) << "MessageWin::readProperties(" << mEventID << ")";
 	if (mAlarmType != KAAlarm::INVALID_ALARM)
 	{
 		// Recreate the event from the calendar file (if possible)
@@ -813,7 +853,7 @@ void MessageWin::redisplayAlarms()
 			if (!findEvent(event.id()))
 			{
 				// This event should be displayed, but currently isn't being
-				kDebug(5950) << "MessageWin::redisplayAlarms(): " << event.id() << endl;
+				kDebug(5950) << "MessageWin::redisplayAlarms():" << event.id();
 				KAAlarm alarm = event.convertDisplayingAlarm();
 				bool login = alarm.repeatAtLogin();
 				int flags = NO_RESCHEDULE | (login ? NO_DEFER : 0) | NO_INIT_VIEW;
@@ -847,7 +887,7 @@ bool MessageWin::retrieveEvent(KAEvent& event, AlarmResource*& resource, bool& s
 		event.setArchive();     // ensure that it gets re-archived if it's saved
 		event.setCategory(KCalEvent::ACTIVE);
 		if (mEventID != event.id())
-			kError(5950) << "MessageWin::retrieveEvent(): wrong event ID" << endl;
+			kError(5950) << "MessageWin::retrieveEvent(): wrong event ID";
 		event.setEventID(mEventID);
 		resource  = 0;
 		showEdit  = true;
@@ -880,16 +920,16 @@ bool MessageWin::reinstateFromDisplaying(const Event* kcalEvent, KAEvent& event,
 */
 void MessageWin::alarmShowing(KAEvent& event, const KCal::Event* kcalEvent)
 {
-	kDebug(5950) << "MessageWin::alarmShowing(" << event.id() << ", " << KAAlarm::debugType(mAlarmType) << ")\n";
+	kDebug(5950) << "MessageWin::alarmShowing(" << event.id() << "," << KAAlarm::debugType(mAlarmType) << ")";
 	if (!kcalEvent)
 		kcalEvent = AlarmCalendar::resources()->event(event.id());
 	if (!kcalEvent)
-		kError(5950) << "MessageWin::alarmShowing(): event ID not found: " << event.id() << endl;
+		kError(5950) << "MessageWin::alarmShowing(): event ID not found:" << event.id();
 	else
 	{
 		KAAlarm alarm = event.alarm(mAlarmType);
 		if (!alarm.valid())
-			kError(5950) << "MessageWin::alarmShowing(): alarm type not found: " << event.id() << ":" << mAlarmType << endl;
+			kError(5950) << "MessageWin::alarmShowing(): alarm type not found:" << event.id() << ":" << mAlarmType;
 		else
 		{
 			// Copy the alarm to the displaying calendar in case of a crash, etc.
@@ -942,33 +982,10 @@ void MessageWin::playAudio()
 	{
 		if (!mVolume  &&  mFadeVolume <= 0)
 			return;    // ensure zero volume doesn't play anything
-		QString play = mAudioFile;
-		QString file = QLatin1String("file:");
-		if (mAudioFile.startsWith(file))
-			play = mAudioFile.mid(file.length());
-#if 0
-		Phonon::SimplePlayer* player = new Phonon::SimplePlayer(this);
-		player->play(KUrl(QFile::encodeName(play)));
-#else
-		// An audio file is specified. Because loading it may take some time,
-		// call it on a timer to allow the window to display first.
-		Phonon::AudioOutput* output = new Phonon::AudioOutput(Phonon::NotificationCategory, this);
-		output->setVolume(mVolume);
-		Phonon::AudioPath* path = new Phonon::AudioPath(this);
-		path->addOutput(output);
-		mAudioObject = new Phonon::MediaObject(this);
-		mAudioObject->setCurrentSource(play);
-		mAudioObject->addAudioPath(path);
-		if (mFadeVolume >= 0  &&  mFadeSeconds > 0)
-		{
-			Phonon::VolumeFaderEffect* fader = new Phonon::VolumeFaderEffect(this);
-			fader->setVolume(mFadeVolume);
-			fader->fadeIn(mFadeSeconds);
-			path->insertEffect(fader);
-		}
-		connect(mAudioObject, SIGNAL(finished()), SLOT(checkAudioPlay()));
+		// An audio file is specified. Because initialising the sound system
+		// and loading the file may take some time, call it on a timer to
+		// allow the window to display first.
 		QTimer::singleShot(0, this, SLOT(slotPlayAudio()));
-#endif
 	}
 	else if (mSpeak)
 	{
@@ -992,8 +1009,8 @@ void MessageWin::slotSpeak()
 		QString error;
 		if (KToolInvocation::startServiceByDesktopName(QLatin1String("kttsd"), QStringList(), &error))
 		{
-			kDebug(5950) << "MessageWin::slotSpeak(): failed to start kttsd: " << error << endl;
-			KMessageBox::detailedError(0, i18n("Unable to speak message"), error);
+			kDebug(5950) << "MessageWin::slotSpeak(): failed to start kttsd:" << error;
+			KMessageBox::detailedError(0, i18nc("@info", "Unable to speak message"), error);
 			return;
 		}
 	}
@@ -1002,8 +1019,8 @@ void MessageWin::slotSpeak()
 	QDBusMessage reply = kttsdDBus.call(QLatin1String("sayMessage"), mMessage, QString());
 	if (reply.type() == QDBusMessage::ErrorMessage)
 	{
-		kDebug(5950) << "MessageWin::slotSpeak(): sayMessage() D-Bus error" << endl;
-		KMessageBox::detailedError(0, i18n("Unable to speak message"), i18n("DBus call sayMessage failed"));
+		kDebug(5950) << "MessageWin::slotSpeak(): sayMessage() D-Bus error";
+		KMessageBox::detailedError(0, i18nc("@info", "Unable to speak message"), i18nc("@info", "D-Bus call sayMessage failed"));
 	}
 }
 
@@ -1013,17 +1030,34 @@ void MessageWin::slotSpeak()
 */
 void MessageWin::slotPlayAudio()
 {
-	// First check that it exists, to avoid possible crashes if the filename is badly specified
-	MainWindow* mmw = MainWindow::mainMainWindow();
-#ifdef __GNUC__
-#warning Use mmw for error messages
-#endif
-	if (0)
+	if (mAudioObject)
+		return;
+	mAudioObject = new Phonon::MediaObject(this);
+	QString audioFile = mAudioFile;
+	audioFile.replace(QRegExp("^file:/*"), "/");
+	Phonon::MediaSource source(audioFile);
+	if (source.type() == Phonon::MediaSource::Invalid)
 	{
-		kError(5950) << "MessageWin::playAudio(): Open failure: " << mAudioFile << endl;
-		KMessageBox::error(this, i18n("Cannot open audio file:\n%1", mAudioFile));
+		delete mAudioObject;
+		mAudioObject = 0;
+		kError(5950) << "MessageWin::playAudio(): Open failure:" << audioFile;
+		KMessageBox::error(this, i18nc("@info", "Cannot open audio file: <filename>%1</filename>", audioFile));
 		return;
 	}
+	QCoreApplication::processEvents();
+	mAudioObject->setCurrentSource(source);
+	Phonon::AudioOutput* output = new Phonon::AudioOutput(Phonon::NotificationCategory, mAudioObject);
+	output->setVolume(mVolume);
+	Phonon::Path path = Phonon::createPath(mAudioObject, output);
+	if (mFadeVolume >= 0  &&  mFadeSeconds > 0)
+	{
+		Phonon::VolumeFaderEffect* fader = new Phonon::VolumeFaderEffect(mAudioObject);
+		fader->setVolume(mFadeVolume);
+		fader->fadeIn(mFadeSeconds);
+		path.insertEffect(fader);
+	}
+	connect(mAudioObject, SIGNAL(finished()), SLOT(checkAudioPlay()));
+	// First check that it exists, to avoid possible crashes if the filename is badly specified
 	mPlayedOnce = false;
 	mSilenceButton->setEnabled(true);
 	checkAudioPlay();
@@ -1049,7 +1083,7 @@ void MessageWin::checkAudioPlay()
 	mPlayedOnce = true;
 
 	// Start playing the file, either for the first time or again
-	kDebug(5950) << "MessageWin::checkAudioPlay(): start\n";
+	kDebug(5950) << "MessageWin::checkAudioPlay(): start";
 	mAudioObject->play();
 }
 
@@ -1063,6 +1097,7 @@ void MessageWin::stopPlay()
 	{
 		mAudioObject->stop();
 		delete mAudioObject;
+		mAudioObject = 0;
 	}
 	if (mSilenceButton)
 		mSilenceButton->setEnabled(false);
@@ -1076,7 +1111,7 @@ void MessageWin::repeat(const KAAlarm& alarm)
 {
 	if (mDeferDlg)
 	{
-		// Cancel any deferral dialogue so that the user notices something's going on,
+		// Cancel any deferral dialog so that the user notices something's going on,
 		// and also because the deferral time limit will have changed.
 		delete mDeferDlg;
 		mDeferDlg = 0;
@@ -1160,6 +1195,7 @@ void MessageWin::showEvent(QShowEvent* se)
 		 * method is called, so for large windows the size needs to be
 		 * set again later.
 		 */
+		bool execComplete = true;
 		QSize s = sizeHint();     // fit the window round the message
 		if (mAction == KAEvent::FILE  &&  !mErrorMsgs.count())
 			KAlarm::readConfigWindowSize("FileMessage", s);
@@ -1214,9 +1250,10 @@ void MessageWin::showEvent(QShowEvent* se)
 			{
 				mPositioning = true;
 				move(x, y);
+				execComplete = false;
 			}
 		}
-		if (!mPositioning)
+		if (execComplete)
 			displayComplete();    // play audio, etc.
 		if (mAction == KAEvent::MESSAGE)
 		{
@@ -1320,8 +1357,8 @@ void MessageWin::closeEvent(QCloseEvent* ce)
 		if (mConfirmAck  &&  !mNoCloseConfirm)
 		{
 			// Ask for confirmation of acknowledgement. Use warningYesNo() because its default is No.
-			if (KMessageBox::warningYesNo(this, i18n("Do you really want to acknowledge this alarm?"),
-			                                    i18n("Acknowledge Alarm"), KGuiItem(i18n("&Acknowledge")), KStandardGuiItem::cancel())
+			if (KMessageBox::warningYesNo(this, i18nc("@info", "Do you really want to acknowledge this alarm?"),
+			                                    i18nc("@action:button", "Acknowledge Alarm"), KGuiItem(i18nc("@action:button", "Acknowledge")), KStandardGuiItem::cancel())
 			    != KMessageBox::Yes)
 			{
 				ce->ignore();
@@ -1337,13 +1374,23 @@ void MessageWin::closeEvent(QCloseEvent* ce)
 	MainWindowBase::closeEvent(ce);
 }
 
+/******************************************************************************
+*  Called when the OK button is clicked.
+*/
+void MessageWin::slotOk()
+{
+	if (mDontShowAgainCheck  &&  mDontShowAgainCheck->isChecked())
+		KAlarm::setDontShowErrors(mEventID, mDontShowAgain);
+	close();
+}
+
 /******************************************************************************
 *  Called when the KMail button is clicked.
 *  Tells KMail to display the email message displayed in this message window.
 */
 void MessageWin::slotShowKMailMessage()
 {
-	kDebug(5950) << "MessageWin::slotShowKMailMessage()\n";
+	kDebug(5950) << "MessageWin::slotShowKMailMessage()";
 	if (!mKMailSerialNumber)
 		return;
 	QString err = KAlarm::runKMail(false);
@@ -1355,9 +1402,9 @@ void MessageWin::slotShowKMailMessage()
 	org::kde::kmail::kmail kmail(KMAIL_DBUS_SERVICE, KMAIL_DBUS_PATH, QDBusConnection::sessionBus());
 	QDBusReply<bool> reply = kmail.showMail((qulonglong)mKMailSerialNumber, QString());
 	if (!reply.isValid())
-		kError(5950) << "MessageWin::slotShowKMailMessage(): kmail D-Bus call failed: " << reply.error().message() << endl;
+		kError(5950) << "MessageWin::slotShowKMailMessage(): kmail D-Bus call failed:" << reply.error().message();
 	else if (!reply.value())
-		KMessageBox::sorry(this, i18n("Unable to locate this email in KMail"));
+		KMessageBox::sorry(this, i18nc("@info", "Unable to locate this email in <application>KMail</application>"));
 }
 
 /******************************************************************************
@@ -1366,12 +1413,12 @@ void MessageWin::slotShowKMailMessage()
 */
 void MessageWin::slotEdit()
 {
-	EditAlarmDlg editDlg(false, i18n("Edit Alarm"), this, &mEvent, EditAlarmDlg::RES_IGNORE);
-	if (editDlg.exec() == QDialog::Accepted)
+	EditAlarmDlg* editDlg = EditAlarmDlg::create(false, mEvent, false, this, EditAlarmDlg::RES_IGNORE);
+	if (editDlg->exec() == QDialog::Accepted)
 	{
 		KAEvent event;
 		AlarmResource* resource;
-		editDlg.getEvent(event, resource);
+		editDlg->getEvent(event, resource);
 		resource = mResource;
 
 		// Update the displayed lists and the calendar file
@@ -1379,24 +1426,26 @@ void MessageWin::slotEdit()
 		if (AlarmCalendar::resources()->event(mEventID))
 		{
 			// The old alarm hasn't expired yet, so replace it
-			status = KAlarm::modifyEvent(mEvent, event, &editDlg);
-			Undo::saveEdit(mEvent, event, resource);
+			Undo::Event undo(mEvent, resource);
+			status = KAlarm::modifyEvent(mEvent, event, editDlg);
+			Undo::saveEdit(undo, event);
 		}
 		else
 		{
 			// The old event has expired, so simply create a new one
-			status = KAlarm::addEvent(event, resource, &editDlg);
+			status = KAlarm::addEvent(event, resource, editDlg);
 			Undo::saveAdd(event, resource);
 		}
 
 		if (status == KAlarm::UPDATE_KORG_ERR)
-			KAlarm::displayKOrgUpdateError(&editDlg, KAlarm::ERR_MODIFY, 1);
-		KAlarm::outputAlarmWarnings(&editDlg, &event);
+			KAlarm::displayKOrgUpdateError(editDlg, KAlarm::ERR_MODIFY, 1);
+		KAlarm::outputAlarmWarnings(editDlg, &event);
 
 		// Close the alarm window
 		mNoCloseConfirm = true;   // allow window to close without confirmation prompt
 		close();
 	}
+	delete editDlg;
 }
 
 /******************************************************************************
@@ -1450,8 +1499,7 @@ void MessageWin::checkDeferralLimit()
 */
 void MessageWin::slotDefer()
 {
-	mDeferDlg = new DeferAlarmDlg(i18n("Defer Alarm"), KDateTime::currentDateTime(Preferences::timeZone()).addSecs(60),
-	                              false, this);
+	mDeferDlg = new DeferAlarmDlg(KDateTime::currentDateTime(Preferences::timeZone()).addSecs(60), false, this);
 	mDeferDlg->setObjectName("DeferDlg");    // used by LikeBack
 	if (mDefaultDeferMinutes > 0)
 		mDeferDlg->setDeferMinutes(mDefaultDeferMinutes);
@@ -1485,7 +1533,7 @@ void MessageWin::slotDefer()
 			{
 				// The event doesn't exist any more !?!, so recurrence data,
 				// flags, and more, have been lost.
-				KMessageBox::error(this, QString::fromLatin1("%1\n%2").arg(i18n("Cannot defer alarm:")).arg(i18n("Alarm not found")));
+				KMessageBox::error(this, i18nc("@info", "<para>Cannot defer alarm:</para><para>Alarm not found.</para>"));
 				raise();
 				delete mDeferDlg;
 				mDeferDlg = 0;
