@@ -41,7 +41,7 @@ class KALARM_EXPORT AlarmResources : public KCal::Calendar, public KRES::Manager
 {
 		Q_OBJECT
 	public:
-		enum Change { Added, Deleted, Enabled, ReadOnly, Location };
+		enum Change { Added, Deleted, Enabled, ReadOnly, Location, Colour };
 
 		class Ticket
 		{
@@ -310,6 +310,20 @@ class KALARM_EXPORT AlarmResources : public KCal::Calendar, public KRES::Manager
 		  KCal::EventSortField sortField = KCal::EventSortUnsorted,
 		  KCal::SortDirection sortDirection = KCal::SortDirectionAscending);
 
+		/**
+		   Return a sorted, unfiltered list of all Events for one resource.
+		   Call this in preference to AlarmResource::rawEvents(), to ensure
+		   that the overall events index is updated.
+
+		   @param resource the AlarmResource to retrieve events for
+		   @param sortField specifies the EventSortField.
+		   @param sortDirection specifies the SortDirection.
+		   @return the list of all unfiltered Events sorted as specified.
+		*/
+		virtual KCal::Event::List rawEvents(AlarmResource* resource,
+		  KCal::EventSortField sortField = KCal::EventSortUnsorted,
+		  KCal::SortDirection sortDirection = KCal::SortDirectionAscending);
+
 		/**
 		   Return an unfiltered list of all Events which occur on the given
 		   timestamp.
@@ -325,12 +339,14 @@ class KALARM_EXPORT AlarmResources : public KCal::Calendar, public KRES::Manager
 
 		   @param start is the starting date.
 		   @param end is the ending date.
+		   @param timespec the time spec to use to interpret @p start and @p end
 		   @param inclusive if true only Events which are completely included
 		   within the date range are returned.
 		   @return the list of unfiltered Events occurring within the specified
 		   date range.
 		*/
 		virtual KCal::Event::List rawEvents(const QDate& start, const QDate& end,
+		                       const KDateTime::Spec& timespec = KDateTime::Spec(),
 				       bool inclusive = false);
 
 		/**
@@ -339,12 +355,14 @@ class KALARM_EXPORT AlarmResources : public KCal::Calendar, public KRES::Manager
 		   @a sortDirection.
 
 		   @param date request unfiltered Event list for this QDate only.
+		   @param timespec the time spec to use to interpret @p date
 		   @param sortField specifies the EventSortField.
 		   @param sortDirection specifies the SortDirection.
 		   @return the list of sorted, unfiltered Events occurring on @a date.
 		*/
 		virtual KCal::Event::List rawEventsForDate(
 		  const QDate& date,
+		  const KDateTime::Spec& timespec = KDateTime::Spec(),
 		  KCal::EventSortField sortField = KCal::EventSortUnsorted,
 		  KCal::SortDirection sortDirection = KCal::SortDirectionAscending);
 
@@ -455,6 +473,7 @@ class KALARM_EXPORT AlarmResources : public KCal::Calendar, public KRES::Manager
 		void slotActiveChanged(AlarmResource* r)      { slotResourceStatusChanged(r, Enabled); }
 		void slotReadOnlyChanged(AlarmResource*);
 		void slotLocationChanged(AlarmResource* r)    { slotResourceStatusChanged(r, Location); }
+		void slotColourChanged(AlarmResource* r)      { slotResourceStatusChanged(r, Colour); }
 		void slotResLoaded(AlarmResource*);
 		void slotResourceLoaded(AlarmResource*);
 		void slotResourceSaved(AlarmResource*);
