@@ -102,6 +102,7 @@ template <class T> class UndoMulti : public UndoMultiBase
 class UndoAdd : public UndoItem
 {
 	public:
+		UndoAdd(Undo::Type, const Undo::Event&, const QString& name = QString());
 		UndoAdd(Undo::Type, const KAEvent&, AlarmResource*, const QString& name = QString());
 		UndoAdd(Undo::Type, const KAEvent&, AlarmResource*, const QString& name, KCalEvent::Status);
 		virtual Operation operation() const     { return ADD; }
@@ -124,7 +125,7 @@ class UndoEdit : public UndoItem
 {
 	public:
 		UndoEdit(Undo::Type, const KAEvent& oldEvent, const QString& newEventID,
-		         AlarmResource*, const QString& description);
+		         AlarmResource*, const QStringList& dontShowErrors, const QString& description);
 		~UndoEdit();
 		virtual Operation operation() const     { return EDIT; }
 		virtual QString   defaultActionText() const;
@@ -139,12 +140,14 @@ class UndoEdit : public UndoItem
 		KAEvent*       mOldEvent;
 		QString        mNewEventID;
 		QString        mDescription;
+		QStringList    mDontShowErrors;
 };
 
 class UndoDelete : public UndoItem
 {
 	public:
-		UndoDelete(Undo::Type, const KAEvent&, AlarmResource*, const QString& name = QString());
+		UndoDelete(Undo::Type, const Undo::Event&, const QString& name = QString());
+		UndoDelete(Undo::Type, const KAEvent&, AlarmResource*, const QStringList& dontShowErrors, const QString& name = QString());
 		~UndoDelete();
 		virtual Operation operation() const     { return DELETE; }
 		virtual QString   defaultActionText() const;
@@ -159,12 +162,14 @@ class UndoDelete : public UndoItem
 	private:
 		AlarmResource* mResource;  // resource calendar containing the event
 		KAEvent*       mEvent;
-		AlarmResource* mArchivedResource;   // resource in which event was archived, or null
+		QStringList    mDontShowErrors;
 };
 
 class UndoReactivate : public UndoAdd
 {
 	public:
+		UndoReactivate(Undo::Type t, const Undo::Event& e, const QString& name = QString())
+		         : UndoAdd(t, e.event, e.resource, name, KCalEvent::ACTIVE) { }
 		UndoReactivate(Undo::Type t, const KAEvent& e, AlarmResource* r, const QString& name = QString())
 		         : UndoAdd(t, e, r, name, KCalEvent::ACTIVE) { }
 		virtual Operation operation() const     { return REACTIVATE; }
@@ -177,7 +182,8 @@ class UndoReactivate : public UndoAdd
 class UndoDeactivate : public UndoDelete
 {
 	public:
-		UndoDeactivate(Undo::Type t, const KAEvent& e, AlarmResource* r, const QString& name = QString())  : UndoDelete(t, e, r, name) { }
+		UndoDeactivate(Undo::Type t, const KAEvent& e, AlarmResource* r, const QString& name = QString())
+		         : UndoDelete(t, e, r, QStringList(), name) { }
 		virtual Operation operation() const     { return DEACTIVATE; }
 		virtual QString   defaultActionText() const;
 		virtual UndoItem* restore();
@@ -272,17 +278,17 @@ void Undo::saveAdds(const Undo::EventList& events, const QString& name)
 	}
 }
 
-void Undo::saveEdit(const KAEvent& oldEvent, const KAEvent& newEvent, AlarmResource* resource)
+void Undo::saveEdit(const Undo::Event& oldEvent, const KAEvent& newEvent)
 {
-	new UndoEdit(UNDO, oldEvent, newEvent.id(), resource, AlarmText::summary(newEvent));
-	removeRedos(oldEvent.id());    // remove any redos which are made invalid by this edit
+	new UndoEdit(UNDO, oldEvent.event, newEvent.id(), oldEvent.resource, oldEvent.dontShowErrors, AlarmText::summary(newEvent));
+	removeRedos(oldEvent.event.id());    // remove any redos which are made invalid by this edit
 	emitChanged();
 }
 
-void Undo::saveDelete(const KAEvent& event, AlarmResource* resource, const QString& name)
+void Undo::saveDelete(const Undo::Event& event, const QString& name)
 {
-	new UndoDelete(UNDO, event, resource, name);
-	removeRedos(event.id());    // remove any redos which are made invalid by this deletion
+	new UndoDelete(UNDO, event.event, event.resource, event.dontShowErrors, name);
+	removeRedos(event.event.id());    // remove any redos which are made invalid by this deletion
 	emitChanged();
 }
 
@@ -290,7 +296,7 @@ void Undo::saveDeletes(const Undo::EventList& events, const QString& name)
 {
 	int count = events.count();
 	if (count == 1)
-		saveDelete(events[0].event, events[0].resource, name);
+		saveDelete(events[0], name);
 	else if (count > 1)
 	{
 		new UndoDeletes(UNDO, events, name);
@@ -327,7 +333,7 @@ void Undo::removeRedos(const QString& eventID)
 	for (int i = 0;  i < mRedoList.count();  )
 	{
 		UndoItem* item = mRedoList[i];
-//kDebug(5950)<<"removeRedos(): "<<item->eventID()<<" (looking for "<<id<<")"<<endl;
+//kDebug(5950)<<"removeRedos():"<<item->eventID()<<" (looking for"<<id<<")";
 		if (item->operation() == UndoItem::MULTI)
 		{
 			if (item->deleteID(id))
@@ -383,14 +389,14 @@ bool Undo::undo(int i, Undo::Type type, QWidget* parent, const QString& action)
 			KAlarm::displayKOrgUpdateError(parent, errcode, UndoItem::mRestoreWarningCount);
 			return true;
 		}
-		case UndoItem::ERR_NOT_FOUND:  err = i18n("Alarm not found");  break;
-		case UndoItem::ERR_CREATE:     err = i18n("Error recreating alarm");  break;
-		case UndoItem::ERR_TEMPLATE:   err = i18n("Error recreating alarm template");  break;
-		case UndoItem::ERR_ARCHIVED:   err = i18n("Cannot reactivate archived alarm");  break;
-		case UndoItem::ERR_PROG:       err = i18n("Program error");  break;
-		default:                       err = i18n("Unknown error");  break;
+		case UndoItem::ERR_NOT_FOUND:  err = i18nc("@info/plain", "Alarm not found");  break;
+		case UndoItem::ERR_CREATE:     err = i18nc("@info/plain", "Error recreating alarm");  break;
+		case UndoItem::ERR_TEMPLATE:   err = i18nc("@info/plain", "Error recreating alarm template");  break;
+		case UndoItem::ERR_ARCHIVED:   err = i18nc("@info/plain", "Cannot reactivate archived alarm");  break;
+		case UndoItem::ERR_PROG:       err = i18nc("@info/plain", "Program error");  break;
+		default:                       err = i18nc("@info/plain", "Unknown error");  break;
 	}
-	KMessageBox::sorry(parent, i18nc("Undo-action: message", "%1: %2", action, err));
+	KMessageBox::sorry(parent, i18nc("@info Undo-action: message", "%1: %2", action, err));
 	return false;
 }
 
@@ -524,9 +530,9 @@ QList<int> Undo::ids(Undo::Type type)
 		}
 		if (!omit)
 			ids.append(item->id());
-//else kDebug(5950)<<"Undo::ids(): omit "<<item->actionText()<<": "<<item->description()<<endl;
+//else kDebug(5950)<<"Undo::ids(): omit"<<item->actionText()<<":"<<item->description();
 	}
-//kDebug(5950)<<"Undo::ids(): "<<n<<" -> "<<ids.count()<<endl;
+//kDebug(5950)<<"Undo::ids():"<<n<<" ->"<<ids.count();
 	return ids;
 }
 
@@ -626,16 +632,16 @@ QString UndoItem::addDeleteActionText(KCalEvent::Status calendar, bool add)
 	{
 		case KCalEvent::ACTIVE:
 			if (add)
-				return i18nc("Action to create a new alarm", "New alarm");
+				return i18nc("@info/plain Action to create a new alarm", "New alarm");
 			else
-				return i18nc("Action to delete an alarm", "Delete alarm");
+				return i18nc("@info/plain Action to delete an alarm", "Delete alarm");
 		case KCalEvent::TEMPLATE:
 			if (add)
-				return i18nc("Action to create a new alarm template", "New template");
+				return i18nc("@info/plain Action to create a new alarm template", "New template");
 			else
-				return i18nc("Action to delete an alarm template", "Delete template");
+				return i18nc("@info/plain Action to delete an alarm template", "Delete template");
 		case KCalEvent::ARCHIVED:
-			return i18n("Delete archived alarm");
+			return i18nc("@info/plain", "Delete archived alarm");
 		default:
 			break;
 	}
@@ -653,7 +659,7 @@ UndoMulti<T>::UndoMulti(Undo::Type type, const Undo::EventList& events, const QS
 	: UndoMultiBase(type, name)    // UNDO only
 {
 	for (int i = 0, end = events.count();  i < end;  ++i)
-		mUndos.append(new T(Undo::NONE, events[i].event, events[i].resource));
+		mUndos.append(new T(Undo::NONE, events[i]));
 }
 
 UndoMultiBase::~UndoMultiBase()
@@ -725,6 +731,15 @@ bool UndoMulti<T>::deleteID(const QString& id)
 =  Undo item for alarm creation.
 =============================================================================*/
 
+UndoAdd::UndoAdd(Undo::Type type, const Undo::Event& undo, const QString& name)
+	: UndoItem(type, name),
+	  mResource(undo.resource),
+	  mEventID(undo.event.id())
+{
+	setCalendar(undo.event.category());
+	mDescription = UndoItem::description(undo.event);    // calendar must be set before calling this
+}
+
 UndoAdd::UndoAdd(Undo::Type type, const KAEvent& event, AlarmResource* resource, const QString& name)
 	: UndoItem(type, name),
 	  mResource(resource),
@@ -751,7 +766,7 @@ UndoAdd::UndoAdd(Undo::Type type, const KAEvent& event, AlarmResource* resource,
 UndoItem* UndoAdd::doRestore(bool setArchive)
 {
 	// Retrieve the current state of the alarm
-	kDebug(5950) << "UndoAdd::doRestore(" << mEventID << ")\n";
+	kDebug(5950) << "UndoAdd::doRestore(" << mEventID << ")";
 	const KCal::Event* kcalEvent = AlarmCalendar::getEvent(mEventID);
 	if (!kcalEvent)
 	{
@@ -806,7 +821,7 @@ UndoItem* UndoAdd::doRestore(bool setArchive)
 UndoItem* UndoAdd::createRedo(const KAEvent& event, AlarmResource* resource)
 {
 	Undo::Type t = (type() == Undo::UNDO) ? Undo::REDO : (type() == Undo::REDO) ? Undo::UNDO : Undo::NONE;
-	return new UndoDelete(t, event, resource, mName);
+	return new UndoDelete(t, event, resource, QStringList(), mName);
 }
 
 /******************************************************************************
@@ -837,7 +852,7 @@ UndoItem* UndoAdds::createRedo(Undo::List& undos)
 */
 QString UndoAdds::defaultActionText() const
 {
-	return i18n("Create multiple alarms");
+	return i18nc("@info/plain", "Create multiple alarms");
 }
 
 
@@ -847,12 +862,13 @@ QString UndoAdds::defaultActionText() const
 =============================================================================*/
 
 UndoEdit::UndoEdit(Undo::Type type, const KAEvent& oldEvent, const QString& newEventID,
-                   AlarmResource* resource, const QString& description)
+                   AlarmResource* resource, const QStringList& dontShowErrors, const QString& description)
 	: UndoItem(type),
 	  mResource(resource),
 	  mOldEvent(new KAEvent(oldEvent)),
 	  mNewEventID(newEventID),
-	  mDescription(description)
+	  mDescription(description),
+	  mDontShowErrors(dontShowErrors)
 {
 	setCalendar(oldEvent.category());
 }
@@ -869,7 +885,7 @@ UndoEdit::~UndoEdit()
 */
 UndoItem* UndoEdit::restore()
 {
-	kDebug(5950) << "UndoEdit::restore(" << mNewEventID << ")\n";
+	kDebug(5950) << "UndoEdit::restore(" << mNewEventID << ")";
 	// Retrieve the current state of the alarm
 	const KCal::Event* kcalEvent = AlarmCalendar::getEvent(mNewEventID);
 	if (!kcalEvent)
@@ -881,7 +897,7 @@ UndoItem* UndoEdit::restore()
 
 	// Create a redo item to restore the edit
 	Undo::Type t = (type() == Undo::UNDO) ? Undo::REDO : (type() == Undo::REDO) ? Undo::UNDO : Undo::NONE;
-	UndoItem* undo = new UndoEdit(t, newEvent, mOldEvent->id(), mResource, mDescription);
+	UndoItem* undo = new UndoEdit(t, newEvent, mOldEvent->id(), mResource, KAlarm::dontShowErrors(mNewEventID), mDescription);
 
 	switch (calendar())
 	{
@@ -896,8 +912,9 @@ UndoItem* UndoEdit::restore()
 				case KAlarm::UPDATE_KORG_ERR:
 					mRestoreWarning = WARN_KORG_MODIFY;
 					++mRestoreWarningCount;
-					break;
+					// fall through to default
 				default:
+					KAlarm::setDontShowErrors(mOldEvent->id(), mDontShowErrors);
 					break;
 			}
 			break;
@@ -922,9 +939,9 @@ QString UndoEdit::defaultActionText() const
 	switch (calendar())
 	{
 		case KCalEvent::ACTIVE:
-			return i18nc("Action to edit an alarm", "Edit alarm");
+			return i18nc("@info/plain Action to edit an alarm", "Edit alarm");
 		case KCalEvent::TEMPLATE:
-			return i18nc("Action to edit an alarm template", "Edit template");
+			return i18nc("@info/plain Action to edit an alarm template", "Edit template");
 		default:
 			break;
 	}
@@ -937,10 +954,20 @@ QString UndoEdit::defaultActionText() const
 =  Undo item for alarm deletion.
 =============================================================================*/
 
-UndoDelete::UndoDelete(Undo::Type type, const KAEvent& event, AlarmResource* resource, const QString& name)
+UndoDelete::UndoDelete(Undo::Type type, const Undo::Event& undo, const QString& name)
+	: UndoItem(type, name),
+	  mResource(undo.resource),
+	  mEvent(new KAEvent(undo.event)),
+	  mDontShowErrors(undo.dontShowErrors)
+{
+	setCalendar(mEvent->category());
+}
+
+UndoDelete::UndoDelete(Undo::Type type, const KAEvent& event, AlarmResource* resource, const QStringList& dontShowErrors, const QString& name)
 	: UndoItem(type, name),
 	  mResource(resource),
-	  mEvent(new KAEvent(event))
+	  mEvent(new KAEvent(event)),
+	  mDontShowErrors(dontShowErrors)
 {
 	setCalendar(mEvent->category());
 }
@@ -957,7 +984,7 @@ UndoDelete::~UndoDelete()
 */
 UndoItem* UndoDelete::restore()
 {
-	kDebug(5950) << "UndoDelete::restore(" << mEvent->id() << ")\n";
+	kDebug(5950) << "UndoDelete::restore(" << mEvent->id() << ")";
 	// Restore the original event
 	switch (calendar())
 	{
@@ -998,6 +1025,7 @@ UndoItem* UndoDelete::restore()
 						break;
 				}
 			}
+			KAlarm::setDontShowErrors(mEvent->id(), mDontShowErrors);
 			break;
 		case KCalEvent::TEMPLATE:
 			if (KAlarm::addTemplate(*mEvent, mResource) != KAlarm::UPDATE_OK)
@@ -1066,16 +1094,16 @@ QString UndoDeletes::defaultActionText() const
 		switch (mUndos[i]->calendar())
 		{
 			case KCalEvent::ACTIVE:
-				return i18n("Delete multiple alarms");
+				return i18nc("@info/plain", "Delete multiple alarms");
 			case KCalEvent::TEMPLATE:
-				return i18n("Delete multiple templates");
+				return i18nc("@info/plain", "Delete multiple templates");
 			case KCalEvent::ARCHIVED:
 				break;    // check if they are ALL archived
 			default:
 				return QString();
 		}
 	}
-	return i18n("Delete multiple archived alarms");
+	return i18nc("@info/plain", "Delete multiple archived alarms");
 }
 
 
@@ -1091,7 +1119,7 @@ QString UndoDeletes::defaultActionText() const
 */
 UndoItem* UndoReactivate::restore()
 {
-	kDebug(5950) << "UndoReactivate::restore()\n";
+	kDebug(5950) << "UndoReactivate::restore()";
 	// Validate the alarm's calendar
 	switch (calendar())
 	{
@@ -1118,7 +1146,7 @@ UndoItem* UndoReactivate::createRedo(const KAEvent& event, AlarmResource* resour
 */
 QString UndoReactivate::defaultActionText() const
 {
-	return i18n("Reactivate alarm");
+	return i18nc("@info/plain", "Reactivate alarm");
 }
 
 
@@ -1134,7 +1162,7 @@ QString UndoReactivate::defaultActionText() const
 */
 UndoItem* UndoDeactivate::restore()
 {
-	kDebug(5950) << "UndoDeactivate::restore()\n";
+	kDebug(5950) << "UndoDeactivate::restore()";
 	// Validate the alarm's calendar
 	switch (calendar())
 	{
@@ -1162,7 +1190,7 @@ UndoItem* UndoDeactivate::createRedo(const KAEvent& event, AlarmResource* resour
 */
 QString UndoDeactivate::defaultActionText() const
 {
-	return i18n("Reactivate alarm");
+	return i18nc("@info/plain", "Reactivate alarm");
 }
 
 
@@ -1185,5 +1213,18 @@ UndoItem* UndoReactivates::createRedo(Undo::List& undos)
 */
 QString UndoReactivates::defaultActionText() const
 {
-	return i18n("Reactivate multiple alarms");
+	return i18nc("@info/plain", "Reactivate multiple alarms");
+}
+
+
+/*=============================================================================
+=  Class: Event
+=  Event details for external calls.
+=============================================================================*/
+Undo::Event::Event(const KAEvent& e, AlarmResource* r)
+	: event(e),
+	  resource(r)
+{
+	if (e.category() == KCalEvent::ACTIVE)
+		dontShowErrors = KAlarm::dontShowErrors(e.id());
 }
