@@ -1,5 +1,5 @@
 /* -*- Mode: C++ -*-
-   $Id: KDGanttView.h 691748 2007-07-24 10:07:47Z tilladam $
+   $Id: KDGanttView.h 701212 2007-08-17 16:55:40Z amth $
    KDChart - a multi-platform charting engine
 */
 
@@ -379,13 +379,13 @@ public:
     virtual KDGanttViewItem* createNewItem( QString KDGanttViewItemTypeAsString,
                                     KDGanttViewItem* parent = 0,
                                     KDGanttViewItem* after = 0,
-                                    const QString& lvtext = QString::null,
-                                    const QString& name = QString::null  );
+                                    const QString& lvtext = QString(),
+                                    const QString& name = QString()  );
     virtual KDGanttViewItem* createUserDefinedItem( QString KDGanttViewItemTypeAsString,
                                                     KDGanttViewItem* parent = 0,
                                                     KDGanttViewItem* after = 0,
-                                                    const QString& lvtext = QString::null,
-                                                    const QString& name = QString::null  );
+                                                    const QString& lvtext = QString(),
+                                                    const QString& name = QString()  );
 
     void setConnectorEnabled( int connector, bool state );
     bool isConnectorEnabled( int connector ) const;
@@ -493,6 +493,7 @@ signals:
     void taskLinkDoubleClicked( KDGanttViewTaskLink* );
 
     void dropped ( QDropEvent * e, KDGanttViewItem* droppedItem, KDGanttViewItem* itemBelowMouse);
+    void dateTimeDoubleClicked ( const QDateTime& );
     void addOneTickRight();
     void addOneTickLeft();
 
@@ -549,6 +550,8 @@ private:
     bool loadXML( const QDomDocument& doc );
     QDomDocument saveXML( bool withPI = true ) const;
 
+    void emptySpaceDoubleClicked( QMouseEvent* e );
+
     static QString scaleToString( Scale scale );
     static QString yearFormatToString( YearFormat format );
     static QString hourFormatToString( HourFormat format );
