@@ -435,7 +435,7 @@ void AccountDialog::makeLocalAccountPage()
   topLayout->addWidget( mLocal.intervalLabel, 7, 0 );
   mLocal.intervalSpin = new KIntNumInput( page );
   mLocal.intervalLabel->setBuddy( mLocal.intervalSpin );
-  mLocal.intervalSpin->setRange( 1, 10000, 1, false );
+  mLocal.intervalSpin->setRange( GlobalSettings::self()->minimumCheckInterval(), 10000, 1, false );
   mLocal.intervalSpin->setSuffix( i18n(" min") );
   mLocal.intervalSpin->setValue( 1 );
   topLayout->addWidget( mLocal.intervalSpin, 7, 1 );
@@ -536,7 +536,7 @@ void AccountDialog::makeMaildirAccountPage()
   mMaildir.intervalLabel = new QLabel( i18n("Check inter&val:"), page );
   topLayout->addWidget( mMaildir.intervalLabel, 6, 0 );
   mMaildir.intervalSpin = new KIntNumInput( page );
-  mMaildir.intervalSpin->setRange( 1, 10000, 1, false );
+  mMaildir.intervalSpin->setRange( GlobalSettings::self()->minimumCheckInterval(), 10000, 1, false );
   mMaildir.intervalSpin->setSuffix( i18n(" min") );
   mMaildir.intervalSpin->setValue( 1 );
   mMaildir.intervalLabel->setBuddy( mMaildir.intervalSpin );
@@ -742,7 +742,7 @@ void AccountDialog::makePopAccountPage()
   mPop.intervalLabel = new QLabel( i18n("Chec&k interval:"), page1 );
   grid->addWidget( mPop.intervalLabel, 13, 0 );
   mPop.intervalSpin = new KIntNumInput( page1 );
-  mPop.intervalSpin->setRange( 1, 10000, 1, false );
+  mPop.intervalSpin->setRange( GlobalSettings::self()->minimumCheckInterval(), 10000, 1, false );
   mPop.intervalSpin->setSuffix( i18n(" min") );
   mPop.intervalSpin->setValue( 1 );
   mPop.intervalLabel->setBuddy( mPop.intervalSpin );
@@ -1108,8 +1108,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.intervalLabel = new QLabel( i18n("Check inter&val:"), page1 );
   grid->addWidget( mImap.intervalLabel, row, 0 );
   mImap.intervalSpin = new KIntNumInput( page1 );
-  const int kioskMinimumImapCheckInterval = GlobalSettings::minimumImapCheckInterval();
-  mImap.intervalSpin->setRange( kioskMinimumImapCheckInterval, 10000, 1, false );
+  mImap.intervalSpin->setRange( GlobalSettings::minimumCheckInterval(), 60, 1, false );
   mImap.intervalSpin->setValue( 1 );
   mImap.intervalSpin->setSuffix( i18n( " min" ) );
   mImap.intervalLabel->setBuddy( mImap.intervalSpin );
@@ -1572,7 +1571,7 @@ void AccountDialog::slotPipeliningClicked()
 
 void AccountDialog::slotPopEncryptionChanged(int id)
 {
-  kDebug(5006) << "slotPopEncryptionChanged( " << id << " )" << endl;
+  kDebug(5006) <<"slotPopEncryptionChanged(" << id <<" )";
   // adjust port
   if ( id == SSL || mPop.portEdit->text() == "995" )
     mPop.portEdit->setText( ( id == SSL ) ? "995" : "110" );
@@ -1597,7 +1596,7 @@ void AccountDialog::slotPopPasswordChanged(const QString& text)
 
 void AccountDialog::slotImapEncryptionChanged(int id)
 {
-  kDebug(5006) << "slotImapEncryptionChanged( " << id << " )" << endl;
+  kDebug(5006) <<"slotImapEncryptionChanged(" << id <<" )";
   // adjust port
   if ( id == SSL || mImap.portEdit->text() == "993" )
     mImap.portEdit->setText( ( id == SSL ) ? "993" : "143" );
@@ -1654,7 +1653,7 @@ void AccountDialog::slotCheckImapCapabilities()
 unsigned int AccountDialog::popCapabilitiesFromStringList( const QStringList & l )
 {
   unsigned int capa = 0;
-  kDebug( 5006 ) << k_funcinfo << l << endl;
+  kDebug( 5006 ) << l;
   for ( QStringList::const_iterator it = l.begin() ; it != l.end() ; ++it ) {
     QString cur = (*it).toUpper();
     if ( cur == "PLAIN" )
@@ -1694,9 +1693,9 @@ void AccountDialog::slotPopCapabilities( const QStringList & capaNormal,
   else
     mCapaTLS = 0;
   mCapaSSL = popCapabilitiesFromStringList( capaSSL );
-  kDebug(5006) << "mCapaNormal = " << mCapaNormal
-                << "; mCapaSSL = " << mCapaSSL
-                << "; mCapaTLS = " << mCapaTLS << endl;
+  kDebug(5006) <<"mCapaNormal =" << mCapaNormal
+                << "; mCapaSSL =" << mCapaSSL
+                << "; mCapaTLS =" << mCapaTLS;
   mPop.encryptionNone->setEnabled( !capaNormal.isEmpty() );
   mPop.encryptionSSL->setEnabled( !capaSSL.isEmpty() );
   mPop.encryptionTLS->setEnabled( mCapaTLS != 0 );
@@ -1708,7 +1707,7 @@ void AccountDialog::slotPopCapabilities( const QStringList & capaNormal,
 
 void AccountDialog::enablePopFeatures( unsigned int capa )
 {
-  kDebug(5006) << "enablePopFeatures( " << capa << " )" << endl;
+  kDebug(5006) <<"enablePopFeatures(" << capa <<" )";
   mPop.authPlain->setEnabled( capa & Plain );
   mPop.authLogin->setEnabled( capa & Login );
   mPop.authCRAM_MD5->setEnabled( capa & CRAM_MD5 );
@@ -1800,9 +1799,9 @@ void AccountDialog::slotImapCapabilities( const QStringList & capaNormal,
   else
     mCapaTLS = 0;
   mCapaSSL = imapCapabilitiesFromStringList( capaSSL );
-  kDebug(5006) << "mCapaNormal = " << mCapaNormal
-                << "; mCapaSSL = " << mCapaSSL
-                << "; mCapaTLS = " << mCapaTLS << endl;
+  kDebug(5006) <<"mCapaNormal =" << mCapaNormal
+                << "; mCapaSSL =" << mCapaSSL
+                << "; mCapaTLS =" << mCapaTLS;
   mImap.encryptionNone->setEnabled( !capaNormal.isEmpty() );
   mImap.encryptionSSL->setEnabled( !capaSSL.isEmpty() );
   mImap.encryptionTLS->setEnabled( mCapaTLS != 0 );
@@ -1831,7 +1830,7 @@ void AccountDialog::slotFilterOnServerSizeChanged ( int value )
 
 void AccountDialog::enableImapAuthMethods( unsigned int capa )
 {
-  kDebug(5006) << "enableImapAuthMethods( " << capa << " )" << endl;
+  kDebug(5006) <<"enableImapAuthMethods(" << capa <<" )";
   mImap.authPlain->setEnabled( capa & Plain );
   mImap.authLogin->setEnabled( capa & Login );
   mImap.authCramMd5->setEnabled( capa & CRAM_MD5 );
@@ -1844,7 +1843,7 @@ void AccountDialog::enableImapAuthMethods( unsigned int capa )
 
 void AccountDialog::checkHighest( QButtonGroup *btnGroup )
 {
-  kDebug(5006) << "checkHighest( " << btnGroup << " )" << endl;
+  kDebug(5006) <<"checkHighest(" << btnGroup <<" )";
   QAbstractButton *btn;
   foreach (btn, btnGroup->buttons()) {
     if (btn && btn->isEnabled()) {
@@ -1968,7 +1967,7 @@ void AccountDialog::saveSettings()
     mAccount->setCheckExclude( !mImap.includeInCheck->isChecked() );
     //mAccount->setFolder( NULL );
     mAccount->setFolder( kmkernel->dimapFolderMgr()->findById(mAccount->id()) );
-    //kDebug(5006) << "account for folder " << mAccount->folder()->name() << endl;
+    //kDebug(5006) <<"account for folder" << mAccount->folder()->name();
 
     initAccountForConnect();
     KMAcctCachedImap &epa = *(KMAcctCachedImap*)mAccount;
