@@ -82,28 +82,28 @@ AntiSpamWizard::AntiSpamWizard( WizardMode mode,
 
 #ifndef NDEBUG
   if ( mMode == AntiSpam )
-    kDebug(5006) << endl << "Considered anti-spam tools: " << endl;
+    kDebug(5006) << endl <<"Considered anti-spam tools:";
   else
-    kDebug(5006) << endl << "Considered anti-virus tools: " << endl;
+    kDebug(5006) << endl <<"Considered anti-virus tools:";
 #endif
   for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
         it != mToolList.end(); ++it ) {
 #ifndef NDEBUG
-    kDebug(5006) << "Predefined tool: " << (*it).getId() << endl;
-    kDebug(5006) << "Config version: " << (*it).getVersion() << endl;
-    kDebug(5006) << "Selection priority: " << (*it).getPrio() << endl;
-    kDebug(5006) << "Displayed name: " << (*it).getVisibleName() << endl;
-    kDebug(5006) << "Executable: " << (*it).getExecutable() << endl;
-    kDebug(5006) << "WhatsThis URL: " << (*it).getWhatsThisText() << endl;
-    kDebug(5006) << "Filter name: " << (*it).getFilterName() << endl;
-    kDebug(5006) << "Detection command: " << (*it).getDetectCmd() << endl;
-    kDebug(5006) << "Learn spam command: " << (*it).getSpamCmd() << endl;
-    kDebug(5006) << "Learn ham command: " << (*it).getHamCmd() << endl;
-    kDebug(5006) << "Detection header: " << (*it).getDetectionHeader() << endl;
-    kDebug(5006) << "Detection pattern: " << (*it).getDetectionPattern() << endl;
-    kDebug(5006) << "Use as RegExp: " << (*it).isUseRegExp() << endl;
-    kDebug(5006) << "Supports Bayes Filter: " << (*it).useBayesFilter() << endl;
-    kDebug(5006) << "Type: " << (*it).getType() << endl << endl;
+    kDebug(5006) <<"Predefined tool:" << (*it).getId();
+    kDebug(5006) <<"Config version:" << (*it).getVersion();
+    kDebug(5006) <<"Selection priority:" << (*it).getPrio();
+    kDebug(5006) <<"Displayed name:" << (*it).getVisibleName();
+    kDebug(5006) <<"Executable:" << (*it).getExecutable();
+    kDebug(5006) <<"WhatsThis URL:" << (*it).getWhatsThisText();
+    kDebug(5006) <<"Filter name:" << (*it).getFilterName();
+    kDebug(5006) <<"Detection command:" << (*it).getDetectCmd();
+    kDebug(5006) <<"Learn spam command:" << (*it).getSpamCmd();
+    kDebug(5006) <<"Learn ham command:" << (*it).getHamCmd();
+    kDebug(5006) <<"Detection header:" << (*it).getDetectionHeader();
+    kDebug(5006) <<"Detection pattern:" << (*it).getDetectionPattern();
+    kDebug(5006) <<"Use as RegExp:" << (*it).isUseRegExp();
+    kDebug(5006) <<"Supports Bayes Filter:" << (*it).useBayesFilter();
+    kDebug(5006) <<"Type:" << (*it).getType();
 #endif
   }
 
@@ -145,14 +145,14 @@ AntiSpamWizard::AntiSpamWizard( WizardMode mode,
 void AntiSpamWizard::accept()
 {
   if ( mSpamRulesPage ) {
-    kDebug( 5006 ) << "Folder name for messages classified as spam is "
-                    << mSpamRulesPage->selectedSpamFolderName() << endl;
-    kDebug( 5006 ) << "Folder name for messages classified as unsure is "
-                    << mSpamRulesPage->selectedUnsureFolderName() << endl;
+    kDebug( 5006 ) <<"Folder name for messages classified as spam is"
+                    << mSpamRulesPage->selectedSpamFolderName();
+    kDebug( 5006 ) <<"Folder name for messages classified as unsure is"
+                    << mSpamRulesPage->selectedUnsureFolderName();
   }
   if ( mVirusRulesPage )
-    kDebug( 5006 ) << "Folder name for viruses is "
-                    << mVirusRulesPage->selectedFolderName() << endl;
+    kDebug( 5006 ) <<"Folder name for viruses is"
+                    << mVirusRulesPage->selectedFolderName();
 
   KMFilterActionDict dict;
   QList<KMFilter*> filterList;
@@ -512,7 +512,7 @@ void AntiSpamWizard::checkToolAvailability()
     if ( (*it).isSpamTool() && (*it).isServerBased() ) {
       // check the configured account for pattern in <server>
       QString pattern = (*it).getServerPattern();
-      kDebug(5006) << "Testing for server pattern:" << pattern << endl;
+      kDebug(5006) <<"Testing for server pattern:" << pattern;
 
       AccountManager* mgr = kmkernel->acctMgr();
       KMAccount* account = mgr->first();
@@ -576,10 +576,10 @@ void AntiSpamWizard::slotBuildSummary()
       text = i18n( "<p>Messages classified as spam are not marked as read." );
 
     if ( mSpamRulesPage->moveSpamSelected() )
-      text += i18n( "<br>Spam messages are moved into the folder named <i>" )
+      text += i18n( "<br />Spam messages are moved into the folder named <i>" )
             + mSpamRulesPage->selectedSpamFolderName() + "</i>.</p>";
     else
-      text += i18n( "<br>Spam messages are not moved into a certain folder.</p>" );
+      text += i18n( "<br />Spam messages are not moved into a certain folder.</p>" );
 
     for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
           it != mToolList.end(); ++it ) {
@@ -629,7 +629,7 @@ void AntiSpamWizard::slotBuildSummary()
 
 int AntiSpamWizard::checkForProgram( const QString &executable )
 {
-  kDebug(5006) << "Testing for executable:" << executable << endl;
+  kDebug(5006) <<"Testing for executable:" << executable;
   KProcess process;
   process.setShellCommand( executable );
   return process.execute ();
@@ -663,7 +663,7 @@ void AntiSpamWizard::sortFilterOnExistance(
 //---------------------------------------------------------------------------
 AntiSpamWizard::SpamToolConfig::SpamToolConfig( const QString &toolId,
       int configVersion, int prio, const QString &name, const QString &exec,
-      const QString &url, const QString &filter, const QString &detection, 
+      const QString &url, const QString &filter, const QString &detection,
       const QString &spam, const QString &ham, const QString &noSpam,
       const QString &header, const QString &pattern, const QString &pattern2,
       const QString &serverPattern, bool detectionOnly, bool regExp,
@@ -748,8 +748,8 @@ AntiSpamWizard::SpamToolConfig
   QString id = configGroup.readEntry( "Ident" );
   int version = configGroup.readEntry( "Version", 0 );
 #ifndef NDEBUG
-  kDebug(5006) << "Found predefined tool: " << id << endl;
-  kDebug(5006) << "With config version  : " << version << endl;
+  kDebug(5006) <<"Found predefined tool:" << id;
+  kDebug(5006) <<"With config version  :" << version;
 #endif
   int prio = configGroup.readEntry( "Priority", 1 );
   QString name = configGroup.readEntry( "VisibleName" );
@@ -796,8 +796,8 @@ void AntiSpamWizard::ConfigReader::mergeToolConfig( AntiSpamWizard::SpamToolConf
   for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
         it != mToolList.end(); ++it ) {
 #ifndef NDEBUG
-    kDebug(5006) << "Check against tool: " << (*it).getId() << endl;
-    kDebug(5006) << "Against version   : " << (*it).getVersion() << endl;
+    kDebug(5006) <<"Check against tool:" << (*it).getId();
+    kDebug(5006) <<"Against version   :" << (*it).getVersion();
 #endif
     if ( (*it).getId() == config.getId() )
     {
@@ -805,7 +805,7 @@ void AntiSpamWizard::ConfigReader::mergeToolConfig( AntiSpamWizard::SpamToolConf
       if ( (*it).getVersion() < config.getVersion() )
       {
 #ifndef NDEBUG
-        kDebug(5006) << "Replacing config ..." << endl;
+        kDebug(5006) <<"Replacing config ...";
 #endif
         mToolList.erase( it );
         mToolList.append( config );
@@ -897,7 +897,7 @@ ASWizInfoPage::ASWizInfoPage( AntiSpamWizard::WizardMode mode,
       "the responsiveness of KMail because anti-virus tool "
       "operations are usually time consuming; please consider "
       "deleting the filter rules created by the wizard to get "
-      "back to the former behavior."
+      "back to the former behavior.</p>"
       ) );
   mIntroText->setWordWrap(true);
   layout->addWidget( mIntroText );
@@ -947,7 +947,7 @@ void ASWizInfoPage::addAvailableTool( const QString &visibleName )
 bool ASWizInfoPage::isProgramSelected( const QString &visibleName )
 {
   QString listName = visibleName;
-  
+
   QList<QListWidgetItem*> foundItems = mToolsList->findItems( listName, Qt::MatchFixedString );
   return (foundItems.size() > 0 && foundItems[0]->isSelected());
 }
@@ -993,8 +993,8 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( QWidget * parent, const char * name,
   mMoveUnsureRules->setWhatsThis(
       i18n( "The default folder is the inbox folder, but you may change that "
             "in the folder view below.<p>"
-            "Not all tools support a classification as unsure. If you haven't "
-            "selected a capable tool, you can't select a folder as well.") );
+            "Not all tools support a classification as unsure. If you have not "
+            "selected a capable tool, you cannot select a folder as well.</p>") );
   layout->addWidget( mMoveUnsureRules );
 
   mFolderReqForUnsureFolder = new FolderRequester( this, mainFolderTree );
