@@ -134,7 +134,7 @@ void CachedImapJob::execute()
   assert( mAccount != 0 );
   if( mAccount->makeConnection() != ImapAccountBase::Connected ) {
     // No connection to the IMAP server
-    kDebug(5006) << "mAccount->makeConnection() failed" << endl;
+    kDebug(5006) <<"mAccount->makeConnection() failed";
     mPassiveDestructor = true;
     delete this;
     return;
@@ -164,7 +164,7 @@ void CachedImapJob::listMessages()
   KUrl url = mAccount->getUrl();
   url.setPath( mFolder->imapPath() + ";UID=1:*;SECTION=FLAGS RFC822.SIZE");
 
-  KIO::SimpleJob *job = KIO::get(url, false, false);
+  KIO::SimpleJob *job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
   KIO::Scheduler::assignJobToSlave( mAccount->slave(), job );
   ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
   jd.cancellable = true;
@@ -205,7 +205,7 @@ void CachedImapJob::slotDeleteNextMessages( KJob* job )
   url.setPath( mFolder->imapPath() +
                QString::fromLatin1(";UID=%1").arg(uids) );
 
-  KIO::SimpleJob *simpleJob = KIO::file_delete( url, false );
+  KIO::SimpleJob *simpleJob = KIO::file_delete( url, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( mAccount->slave(), simpleJob );
   ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
   mAccount->insertJob( simpleJob, jd );
@@ -219,7 +219,7 @@ void CachedImapJob::expungeFolder()
   // Special URL that means EXPUNGE
   url.setPath( mFolder->imapPath() + QString::fromLatin1(";UID=*") );
 
-  KIO::SimpleJob *job = KIO::file_delete( url, false );
+  KIO::SimpleJob *job = KIO::file_delete( url, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( mAccount->slave(), job );
   ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
   mAccount->insertJob( job, jd );
@@ -308,14 +308,14 @@ void CachedImapJob::slotGetNextMessage(KJob * job)
   mMsg->setUID(mfd.uid);
   mMsg->setMsgSizeServer(mfd.size);
   if( mfd.flags > 0 )
-    KMFolderImap::flagsToStatus(mMsg, mfd.flags);
+    KMFolderImap::flagsToStatus(mMsg, mfd.flags, true, mFolder->permanentFlags());
   KUrl url = mAccount->getUrl();
   url.setPath(mFolder->imapPath() + QString(";UID=%1;SECTION=BODY.PEEK[]").arg(mfd.uid));
 
   ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
   jd.cancellable = true;
   mMsg->setTransferInProgress(true);
-  KIO::SimpleJob *simpleJob = KIO::get(url, false, false);
+  KIO::SimpleJob *simpleJob = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
   KIO::Scheduler::assignJobToSlave(mAccount->slave(), simpleJob);
   mAccount->insertJob(simpleJob, jd);
   connect(simpleJob, SIGNAL(processedSize(KJob *, qulonglong)),
@@ -363,7 +363,7 @@ void CachedImapJob::slotPutNextMessage()
   }
 
   KUrl url = mAccount->getUrl();
-  QString flags = KMFolderImap::statusToFlags( mMsg->status() );
+  QString flags = KMFolderImap::statusToFlags( mMsg->status(), mFolder->permanentFlags() );
   url.setPath( mFolder->imapPath() + ";SECTION=" + flags );
 
   ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
@@ -373,7 +373,8 @@ void CachedImapJob::slotPutNextMessage()
   int a = cstr.indexOf("\nX-UID: ");
   int b = cstr.indexOf('\n', a);
   if (a != -1 && b != -1 && cstr.indexOf("\n\n") > a) cstr.remove(a, b-a);
-  QByteArray mData(cstr.length() + cstr.count('\n'));
+  QByteArray mData;
+  mData.resize( cstr.length() + cstr.count('\n') );
   unsigned int i = 0;
   for( char *ch = cstr.data(); *ch; ch++ ) {
     if ( *ch == '\n' ) {
@@ -386,7 +387,7 @@ void CachedImapJob::slotPutNextMessage()
   jd.msgList.append( mMsg );
 
   mMsg->setTransferInProgress(true);
-  KIO::SimpleJob *simpleJob = KIO::put(url, 0, false, false, false);
+  KIO::SimpleJob *simpleJob = KIO::put(url, 0, KIO::HideProgressInfo);
   KIO::Scheduler::assignJobToSlave(mAccount->slave(), simpleJob);
   mAccount->insertJob(simpleJob, jd);
   connect( simpleJob, SIGNAL( result(KJob *) ),
@@ -431,7 +432,7 @@ void CachedImapJob::slotPutMessageInfoData(KJob *job, const QString &data, const
   if ( data.contains("UID") && mMsg )
   {
     int uid = (data.right(data.length()-4)).toInt();
-    kDebug( 5006 ) << k_funcinfo << "Server told us uid is: " << uid << endl;
+    kDebug( 5006 ) <<"Server told us uid is:" << uid;
     mMsg->setUID( uid );
   }
 }
@@ -578,7 +579,7 @@ void CachedImapJob::slotDeleteNextFolder( KJob *job )
   url.setPath(folderPath);
   ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
   jd.path = url.path();
-  KIO::SimpleJob *simpleJob = KIO::file_delete(url, false);
+  KIO::SimpleJob *simpleJob = KIO::file_delete(url, KIO::HideProgressInfo);
   KIO::Scheduler::assignJobToSlave(mAccount->slave(), simpleJob);
   mAccount->insertJob(simpleJob, jd);
   connect( simpleJob, SIGNAL( result(KJob *) ),
@@ -593,7 +594,7 @@ void CachedImapJob::checkUidValidity()
   ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
   jd.cancellable = true;
 
-  KIO::SimpleJob *job = KIO::get( url, false, false );
+  KIO::SimpleJob *job = KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( mAccount->slave(), job );
   mAccount->insertJob( job, jd );
   connect( job, SIGNAL(result(KJob *)),
@@ -623,25 +624,38 @@ void CachedImapJob::slotCheckUidValidityResult(KJob * job)
   if (a < 0) {
     // Something is seriously rotten here!
     // TODO: Tell the user that he has a problem
-    kDebug(5006) << "No uidvalidity available for folder "
-                  << mFolder->objectName() << endl;
+    kDebug(5006) <<"No uidvalidity available for folder"
+                  << mFolder->objectName();
   }
   else {
     int b = cstr.indexOf("\r\n", a);
     if ( (b - a - 15) >= 0 ) {
       QString uidv = cstr.mid(a + 15, b - a - 15);
-      // kDebug(5006) << "New uidv = " << uidv << ", old uidv = "
-      //               << mFolder->uidValidity() << endl;
+      // kDebug(5006) <<"New uidv =" << uidv <<", old uidv ="
+      //               << mFolder->uidValidity();
       if( !mFolder->uidValidity().isEmpty() && mFolder->uidValidity() != uidv ) {
-        // kDebug(5006) << "Expunging the mailbox " << mFolder->name()
-        //               << "!" << endl;
+        // kDebug(5006) <<"Expunging the mailbox" << mFolder->name()
+        //               << "!";
         mFolder->expunge();
         mFolder->setLastUid( 0 );
         mFolder->clearUidMap();
       }
     } else
-      kDebug(5006) << "No uidvalidity available for folder "
-                    << mFolder->objectName() << endl;
+      kDebug(5006) <<"No uidvalidity available for folder"
+                    << mFolder->objectName();
+  }
+
+  a = cstr.indexOf( "X-PermanentFlags: " );
+  if ( a < 0 ) {
+    kDebug(5006) << "no PERMANENTFLAGS response? assumming custom flags are not available";
+  } else {
+    int b = cstr.indexOf( "\r\n", a );
+    if ( (b - a - 18) >= 0 ) {
+      int flags = cstr.mid( a + 18, b - a - 18 ).toInt();
+      emit permanentFlags( flags );
+    } else {
+      kDebug(5006) << "PERMANENTFLAGS response broken, assumming custom flags are not available";
+    }
   }
 
   mAccount->removeJob(it);
@@ -666,7 +680,7 @@ void CachedImapJob::renameFolder( const QString &newName )
   ImapAccountBase::jobData jd( newName, mFolder->folder() );
   jd.path = imapPath;
 
-  KIO::SimpleJob *simpleJob = KIO::rename( urlSrc, urlDst, false );
+  KIO::SimpleJob *simpleJob = KIO::rename( urlSrc, urlDst, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( mAccount->slave(), simpleJob );
   mAccount->insertJob( simpleJob, jd );
   connect( simpleJob, SIGNAL(result(KJob *)),
@@ -724,9 +738,9 @@ void CachedImapJob::slotRenameFolderResult( KJob *job )
     mFolder->setImapPath( (*it).path );
     mFolder->FolderStorage::rename( (*it).url );
 
-    if( oldPath.endsWith( "/" ) ) oldPath.truncate( oldPath.length() -1 );
+    if( oldPath.endsWith( '/' ) ) oldPath.truncate( oldPath.length() -1 );
     QString newPath = mFolder->imapPath();
-    if( newPath.endsWith( "/" ) ) newPath.truncate( newPath.length() -1 );
+    if( newPath.endsWith( '/' ) ) newPath.truncate( newPath.length() -1 );
     renameChildFolders( mFolder->folder()->child(), oldPath, newPath );
     kmkernel->dimapFolderMgr()->contentsChanged();
 
