@@ -32,15 +32,14 @@
 class QPushButton;
 class QLabel;
 class QCheckBox;
-class ColorListBox;
 class QFont;
 class QTabWidget;
 class QRegExpValidator;
 class QPoint;
 class QGroupBox;
-class QVGroupBox;
 class QLineEdit;
 class QSpinBox;
+class QListWidget;
 
 class KButtonGroup;
 class KUrlRequester;
@@ -56,7 +55,6 @@ class SMimeConfiguration;
 class TemplatesConfiguration;
 class CustomTemplates;
 class KMMessageTagDescription;
-class K3ListBox;
 class KColorCombo;
 class KFontRequester;
 class KIconButton;
@@ -74,6 +72,10 @@ namespace Kleo {
   class CryptoConfig;
   }
 
+namespace KPIM {
+  class ColorListBox;
+}
+
 class WarningConfiguration : public QWidget, public Ui::WarningConfiguration
 {
 public:
@@ -200,9 +202,8 @@ private:
 class ConfigModule : public KCModule {
   Q_OBJECT
 public:
-  explicit ConfigModule( const KComponentData &instance, QWidget *parent=0,
-                         const QStringList &args=QStringList() )
-     : KCModule ( instance, parent, args )
+  explicit ConfigModule( const KComponentData &instance, QWidget *parent=0 )
+     : KCModule ( instance, parent )
      {}
   ~ConfigModule() {}
 
@@ -262,8 +263,7 @@ private:
 class ConfigModuleWithTabs : public ConfigModule {
   Q_OBJECT
 public:
-  explicit ConfigModuleWithTabs( const KComponentData &instance, QWidget *parent=0,
-                                 const QStringList &args=QStringList() );
+  explicit ConfigModuleWithTabs( const KComponentData &instance, QWidget *parent=0 );
    ~ConfigModuleWithTabs() {}
 
   // don't reimplement any of those methods
@@ -290,8 +290,7 @@ private:
 class KMAIL_EXPORT IdentityPage : public ConfigModule {
   Q_OBJECT
 public:
-  explicit IdentityPage( const KComponentData &instance, QWidget *parent = 0,
-                         const QStringList &args = QStringList() );
+  explicit IdentityPage( const KComponentData &instance, QWidget *parent = 0 );
   ~IdentityPage() {}
 
   QString helpAnchor() const;
@@ -299,9 +298,6 @@ public:
   void load();
   void save();
 
-public slots:
-  void slotUpdateTransportCombo( const QStringList & );
-
 private slots:
   void slotNewIdentity();
   void slotModifyIdentity();
@@ -406,8 +402,7 @@ private:
 class KMAIL_EXPORT AccountsPage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
-  explicit AccountsPage( const KComponentData &instance, QWidget *parent=0,
-                         const QStringList &args=QStringList() );
+  explicit AccountsPage( const KComponentData &instance, QWidget *parent=0 );
   QString helpAnchor() const;
 
 
@@ -473,7 +468,7 @@ private:
 
 private:
   QCheckBox    *mCustomColorCheck;
-  ColorListBox *mColorList;
+  KPIM::ColorListBox *mColorList;
   QCheckBox    *mRecycleColorCheck;
   QSpinBox     *mCloseToQuotaThreshold;
 };
@@ -501,6 +496,7 @@ private: // data
   QGroupBox     *mMIMETreeModeGroupBox;
   QButtonGroup  *mReaderWindowModeGroup;
   QGroupBox     *mReaderWindowModeGroupBox;
+  QCheckBox     *mFavoriteFolderViewCB;
 };
 
 class AppearancePageHeadersTab : public ConfigModuleTab {
@@ -613,7 +609,7 @@ private slots:
   Records the unselected tag's information, and applies visual changes
   necessary depending on the description of the new tag. Private since doesn't
   change the selection of the edit box itself*/
-  void slotSelectionChanged( int aIndex );
+  void slotSelectionChanged();
   /*This slot is necessary so that apply button is not activated when we are
   only applying visual changes after selecting a new tag in the list box*/
   void slotEmitChangeCheck();
@@ -626,9 +622,6 @@ private slots:
   /*Transfers changes in the tag name edit box to the list box for tags. Private
   since calling externally decouples the name in the list box from name edit box*/
   void slotNameLineTextChanged( const QString & );
-  /*Processes the shortcut button, OnurTodo is private needed? */
-  void slotShortcutCaptured( const QKeySequence & );
-
 
 private:
   virtual void doLoadFromGlobalSettings();
@@ -639,7 +632,7 @@ private: // data
   QPushButton *mTagAddButton, *mTagRemoveButton,
               *mTagUpButton, *mTagDownButton;
 
-  K3ListBox *mTagListBox;
+  QListWidget *mTagListBox;
 
   QCheckBox *mTextColorCheck, 
             *mTextFontCheck, *mInToolbarCheck;
@@ -665,8 +658,7 @@ private: // data
 class KMAIL_EXPORT AppearancePage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
-  explicit AppearancePage( const KComponentData &instance, QWidget *parent=0,
-                           const QStringList &args=QStringList() );
+  explicit AppearancePage( const KComponentData &instance, QWidget *parent=0 );
 
   QString helpAnchor() const;
 
@@ -882,8 +874,7 @@ private:
 class KMAIL_EXPORT ComposerPage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
-  explicit ComposerPage( const KComponentData &instance, QWidget *parent=0,
-                         const QStringList &args=QStringList() );
+  explicit ComposerPage( const KComponentData &instance, QWidget *parent=0 );
 
   QString helpAnchor() const;
 
@@ -1035,8 +1026,7 @@ private:
 class KMAIL_EXPORT SecurityPage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
-  explicit SecurityPage( const KComponentData &instance, QWidget *parent=0,
-                         const QStringList &args=QStringList() );
+  explicit SecurityPage( const KComponentData &instance, QWidget *parent=0 );
 
   QString helpAnchor() const;
 
@@ -1138,8 +1128,7 @@ private:
 class KMAIL_EXPORT MiscPage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
-  explicit MiscPage( const KComponentData &instance, QWidget *parent=0,
-                     const QStringList &args=QStringList() );
+  explicit MiscPage( const KComponentData &instance, QWidget *parent=0 );
   QString helpAnchor() const;
 
   typedef MiscPageFolderTab FolderTab;
@@ -1159,10 +1148,9 @@ private:
 class ListView : public QTreeWidget {
   Q_OBJECT
 public:
-  explicit ListView( QWidget *parent=0, int visibleItem=10 );
+  explicit ListView( QWidget *parent=0 );
   void resizeColums();
 
-  void setVisibleItem( int visibleItem, bool updateSize=true );
   virtual QSize sizeHint() const;
 
 protected:
