@@ -30,8 +30,6 @@
  *  your version.
  */
 
-#include <config.h>
-
 #include "folderdialogacltab.h"
 #include "acljobs.h"
 #include "kmfolderimap.h"
@@ -44,12 +42,11 @@
 #include <kabc/addresseelist.h>
 #include <kio/jobuidelegate.h>
 #ifdef KDEPIM_NEW_DISTRLISTS
-#include <libkdepim/distributionlist.h> // libkdepim
+#include <libkdepim/distributionlist.h>
 #else
 #include <kabc/distributionlist.h>
 #endif
 #include <kabc/stdaddressbook.h>
-#include <kaddrbook.h>
 #include <kpushbutton.h>
 #include <kdebug.h>
 #include <klocale.h>
@@ -57,10 +54,7 @@
 
 #include <QLayout>
 #include <QLabel>
-
 #include <QRadioButton>
-
-//Added by qt3to4:
 #include <QGridLayout>
 #include <QList>
 #include <QVBoxLayout>
@@ -78,8 +72,8 @@ static const struct {
   const char* userString;
 } standardPermissions[] = {
   { 0, I18N_NOOP2( "Permissions", "None" ) },
-  { ACLJobs::List | ACLJobs::Read, I18N_NOOP2( "Permissions", "Read" ) },
-  { ACLJobs::List | ACLJobs::Read | ACLJobs::Insert | ACLJobs::Post, I18N_NOOP2( "Permissions", "Append" ) },
+  { ACLJobs::List | ACLJobs::Read | ACLJobs::WriteSeenFlag, I18N_NOOP2( "Permissions", "Read" ) },
+  { ACLJobs::List | ACLJobs::Read | ACLJobs::WriteSeenFlag | ACLJobs::Insert | ACLJobs::Post, I18N_NOOP2( "Permissions", "Append" ) },
   { ACLJobs::AllWrite, I18N_NOOP2( "Permissions", "Write" ) },
   { ACLJobs::All, I18N_NOOP2( "Permissions", "All" ) }
 };
@@ -205,11 +199,7 @@ public:
 
   void load( const ACLListEntry& entry );
   void save( ACLList& list,
-#ifdef KDEPIM_NEW_DISTRLISTS
              KABC::AddressBook* abook,
-#else
-             KABC::DistributionListManager& manager,
-#endif
              IMAPUserIdFormat userIdFormat );
 
   QString userId() const { return text( 0 ); }
@@ -261,7 +251,7 @@ void KMail::FolderDialogACLTab::ListViewItem::load( const ACLListEntry& entry )
   // It's ok in distribution list names though, that's why this check is only done here
   // and also why there's no validator on the lineedit.
   if ( entry.userId.contains( ' ' ) )
-    kWarning(5006) << "Userid contains a space!!!  '" << entry.userId << "'" << endl;
+    kWarning(5006) <<"Userid contains a space!!!  '" << entry.userId <<"'";
 
   setUserId( entry.userId );
   mPermissions = entry.permissions;
@@ -271,11 +261,7 @@ void KMail::FolderDialogACLTab::ListViewItem::load( const ACLListEntry& entry )
 }
 
 void KMail::FolderDialogACLTab::ListViewItem::save( ACLList& aclList,
-#ifdef KDEPIM_NEW_DISTRLISTS
                                                  KABC::AddressBook* addressBook,
-#else
-                                                 KABC::DistributionListManager& manager,
-#endif
                                                  IMAPUserIdFormat userIdFormat )
 {
   // expand distribution lists
@@ -285,15 +271,20 @@ void KMail::FolderDialogACLTab::ListViewItem::save( ACLList& aclList,
     Q_ASSERT( mModified ); // it has to be new, it couldn't be stored as a distr list name....
     KPIM::DistributionList::Entry::List entryList = list.entries(addressBook);
     KPIM::DistributionList::Entry::List::ConstIterator it;
-    // (we share for loop with the old-distrlist-code)
+    for( it = entryList.begin(); it != entryList.end(); ++it ) {
+      QString email = (*it).email;
+      if ( email.isEmpty() )
+        email = addresseeToUserId( (*it).addressee, userIdFormat );
+      ACLListEntry entry( email, QString(), mPermissions );
+      entry.changed = true;
+      aclList.append( entry );
+    }
 #else
-  // kaddrbook.cpp has a strange two-pass case-insensitive lookup; is it ok to be case sensitive?
-  KABC::DistributionList* list = manager.list( userId() );
+  KABC::DistributionList* list = addressBook->findDistributionListByName( userId(),  Qt::CaseInsensitive );
   if ( list ) {
     Q_ASSERT( mModified ); // it has to be new, it couldn't be stored as a distr list name....
     KABC::DistributionList::Entry::List entryList = list->entries();
     KABC::DistributionList::Entry::List::ConstIterator it; // nice number of "::"!
-#endif
     for( it = entryList.begin(); it != entryList.end(); ++it ) {
       QString email = (*it).email();
       if ( email.isEmpty() )
@@ -302,6 +293,7 @@ void KMail::FolderDialogACLTab::ListViewItem::save( ACLList& aclList,
       entry.changed = true;
       aclList.append( entry );
     }
+#endif
   } else { // it wasn't a distribution list
     ACLListEntry entry( userId(), mInternalRightsList, mPermissions );
     if ( mModified ) {
@@ -670,19 +662,11 @@ bool KMail::FolderDialogACLTab::save()
   // listviewitems at the same time sounds dangerous, so let's just save into
   // ACLList and reload that.
   KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
-#ifndef KDEPIM_NEW_DISTRLISTS
-  KABC::DistributionListManager manager( addressBook );
-  manager.load();
-#endif
   ACLList aclList;
   for ( Q3ListViewItem* item = mListView->firstChild(); item; item = item->nextSibling() ) {
     ListViewItem* ACLitem = static_cast<ListViewItem *>( item );
     ACLitem->save( aclList,
-#ifdef KDEPIM_NEW_DISTRLISTS
                    addressBook,
-#else
-                   manager,
-#endif
                    mUserIdFormat );
   }
   loadListView( aclList );
@@ -797,7 +781,7 @@ void KMail::FolderDialogACLTab::slotACLChanged( const QString& userId, int permi
     ok = ( nr > 0 );
   }
   if ( !ok )
-    kWarning(5006) << k_funcinfo << " no item found for userId " << userId << endl;
+    kWarning(5006) <<" no item found for userId" << userId;
 }
 
 void KMail::FolderDialogACLTab::slotChanged( bool b )
