@@ -258,7 +258,7 @@ int FolderStorage::expungeOldMsg(int days)
     msgTime = mb->date();
 
     if (msgTime < maxTime) {
-      //kDebug(5006) << "deleting msg " << i << " : " << mb->subject() << " - " << mb->dateStr(); // << endl;
+      //kDebug(5006) <<"deleting msg" << i <<" :" << mb->subject() <<" -" << mb->dateStr(); //;
       removeMsg( i );
       msgnb++;
     }
@@ -376,7 +376,7 @@ void FolderStorage::removeMsg(int idx, bool)
   //assert(idx>=0);
   if(idx < 0)
   {
-    kDebug(5006) << "FolderStorage::removeMsg() : idx < 0\n" << endl;
+    kDebug(5006) <<"FolderStorage::removeMsg() : idx < 0";
     return;
   }
 
@@ -394,11 +394,11 @@ void FolderStorage::removeMsg(int idx, bool)
       (folder() == kmkernel->outboxFolder())) {
     --mUnreadMsgs;
     if ( !mQuiet ) {
-//      kDebug( 5006 ) << "FolderStorage::msgStatusChanged" << endl;
+//      kDebug( 5006 ) <<"FolderStorage::msgStatusChanged";
       emit numUnreadMsgsChanged( folder() );
     }else{
       if ( !mEmitChangedTimer->isActive() ) {
-//        kDebug( 5006 )<< "EmitChangedTimer started" << endl;
+//        kDebug( 5006 )<<"EmitChangedTimer started";
         mEmitChangedTimer->start( 3000 );
       }
       mChanged = true;
@@ -486,8 +486,8 @@ KMMessage* FolderStorage::getMsg(int idx)
       msg = readMsg(idx);
       // sanity check
       if (mCompactable && (msg->subject().isEmpty() != mbSubject.isEmpty())) {
-        kDebug(5006) << "Error: " << location() <<
-          " Index file is inconsistent with folder file. This should never happen." << endl;
+        kDebug(5006) <<"Error:" << location() <<
+          "Index file is inconsistent with folder file. This should never happen.";
         mCompactable = false; // Don't compact
         writeConfig();
       }
@@ -911,7 +911,7 @@ void FolderStorage::headerOfMsgChanged(const KMMsgBase* aMsg, int idx)
 //-----------------------------------------------------------------------------
 void FolderStorage::readConfig()
 {
-  //kDebug(5006)<<"#### READING CONFIG  = "<< name() <<endl;
+  //kDebug(5006)<<"#### READING CONFIG  ="<< name();
   KConfig* config = KMKernel::config();
   KConfigGroup group(config, "Folder-" + folder()->idString());
   if (mUnreadMsgs == -1)
@@ -939,7 +939,7 @@ void FolderStorage::writeConfig()
   group.writeEntry( "TotalMsgs", mTotalMsgs );
   group.writeEntry( "Compactable", mCompactable );
   group.writeEntry( "ContentsType", (int)mContentsType );
-  group.writeEntry("FolderSize", mSize);
+  group.writeEntry( "FolderSize", mSize );
 
   // Write the KMFolder parts
   if( folder() ) folder()->writeConfig( group );
@@ -1025,7 +1025,7 @@ void FolderStorage::replaceMsgSerNum( unsigned long sernum, KMMsgBase* msg, int
 void FolderStorage::setRDict( KMMsgDictREntry *rentry ) const
 {
   if ( ! mExportsSernums )
-    kDebug(5006) << "WTF, this FolderStorage should be invisible to the msgdict, who is calling us?" << kBacktrace() << endl;
+    kDebug(5006) <<"WTF, this FolderStorage should be invisible to the msgdict, who is calling us?" << kBacktrace();
   assert( mExportsSernums ); // otherwise things are very wrong
   if ( rentry == mRDict )
     return;
@@ -1136,7 +1136,7 @@ void FolderStorage::slotProcessNextSearchBatch()
       matchingSerNums.append( serNum );
   }
   mCurrentSearchedMsg = end;
-  bool complete = ( end == count() ) ? true : false;
+  bool complete = ( end >= count() );
   emit searchResult( folder(), matchingSerNums, mSearchPattern, complete );
   if ( !complete )
     QTimer::singleShot( 0, this, SLOT(slotProcessNextSearchBatch()) );
