@@ -55,7 +55,9 @@ using KMail::FolderRequester;
 #include "kleo/cryptobackendfactory.h"
 
 #include <kpimutils/email.h>
+#include <mailtransport/transport.h>
 #include <mailtransport/transportmanager.h>
+#include <mailtransport/transportcombobox.h>
 using MailTransport::TransportManager;
 
 // other KDE headers:
@@ -83,6 +85,7 @@ using MailTransport::TransportManager;
 #include <algorithm>
 
 using namespace KPIM;
+using namespace MailTransport;
 
 namespace KMail {
 
@@ -145,7 +148,7 @@ namespace KMail {
     glay->addWidget( label, row, 0 );
     msg = i18n("<qt><h3>Organization</h3>"
                "<p>This field should have the name of your organization "
-               "if you'd like it to be shown in the email header that "
+               "if you would like it to be shown in the email header that "
                "is sent out.</p>"
                "<p>It is safe (and normal) to leave this blank.</p></qt>");
     label->setWhatsThis( msg );
@@ -183,14 +186,14 @@ namespace KMail {
     mPGPSigningKeyRequester->dialogButton()->setText( i18n("Chang&e...") );
     mPGPSigningKeyRequester->setDialogCaption( i18n("Your OpenPGP Signature Key") );
     msg = i18n("Select the OpenPGP key which should be used to "
-	       "digitally sign your messages.");
+               "digitally sign your messages.");
     mPGPSigningKeyRequester->setDialogMessage( msg );
 
     msg = i18n("<qt><p>The OpenPGP key you choose here will be used "
                "to digitally sign messages. You can also use GnuPG keys.</p>"
                "<p>You can leave this blank, but KMail will not be able "
                "to digitally sign emails using OpenPGP; "
-	       "normal mail functions will not be affected.</p>"
+               "normal mail functions will not be affected.</p>"
                "<p>You can find out more about keys at <a>http://www.gnupg.org</a></p></qt>");
 
     label = new QLabel( i18n("OpenPGP signing key:"), tab );
@@ -208,17 +211,17 @@ namespace KMail {
     mPGPEncryptionKeyRequester->dialogButton()->setText( i18n("Chang&e...") );
     mPGPEncryptionKeyRequester->setDialogCaption( i18n("Your OpenPGP Encryption Key") );
     msg = i18n("Select the OpenPGP key which should be used when encrypting "
-	       "to yourself and for the \"Attach My Public Key\" "
-	       "feature in the composer.");
+               "to yourself and for the \"Attach My Public Key\" "
+               "feature in the composer.");
     mPGPEncryptionKeyRequester->setDialogMessage( msg );
 
     msg = i18n("<qt><p>The OpenPGP key you choose here will be used "
                "to encrypt messages to yourself and for the \"Attach My Public Key\" "
-	       "feature in the composer. You can also use GnuPG keys.</p>"
+               "feature in the composer. You can also use GnuPG keys.</p>"
                "<p>You can leave this blank, but KMail will not be able "
                "to encrypt copies of outgoing messages to you using OpenPGP; "
-	       "normal mail functions will not be affected.</p>"
-               "<p>You can find out more about keys at <a>http://www.gnupg.org</a></qt>");
+               "normal mail functions will not be affected.</p>"
+               "<p>You can find out more about keys at <a>http://www.gnupg.org</a></p></qt>");
     label = new QLabel( i18n("OpenPGP encryption key:"), tab );
     label->setBuddy( mPGPEncryptionKeyRequester );
     mPGPEncryptionKeyRequester->setWhatsThis( msg );
@@ -234,14 +237,14 @@ namespace KMail {
     mSMIMESigningKeyRequester->dialogButton()->setText( i18n("Chang&e...") );
     mSMIMESigningKeyRequester->setDialogCaption( i18n("Your S/MIME Signature Certificate") );
     msg = i18n("Select the S/MIME certificate which should be used to "
-	       "digitally sign your messages.");
+               "digitally sign your messages.");
     mSMIMESigningKeyRequester->setDialogMessage( msg );
 
     msg = i18n("<qt><p>The S/MIME (X.509) certificate you choose here will be used "
                "to digitally sign messages.</p>"
                "<p>You can leave this blank, but KMail will not be able "
                "to digitally sign emails using S/MIME; "
-	       "normal mail functions will not be affected.</p></qt>");
+               "normal mail functions will not be affected.</p></qt>");
     label = new QLabel( i18n("S/MIME signing certificate:"), tab );
     label->setBuddy( mSMIMESigningKeyRequester );
     mSMIMESigningKeyRequester->setWhatsThis( msg );
@@ -261,16 +264,16 @@ namespace KMail {
     mSMIMEEncryptionKeyRequester->dialogButton()->setText( i18n("Chang&e...") );
     mSMIMEEncryptionKeyRequester->setDialogCaption( i18n("Your S/MIME Encryption Certificate") );
     msg = i18n("Select the S/MIME certificate which should be used when encrypting "
-	       "to yourself and for the \"Attach My Certificate\" "
-	       "feature in the composer.");
+               "to yourself and for the \"Attach My Certificate\" "
+               "feature in the composer.");
     mSMIMEEncryptionKeyRequester->setDialogMessage( msg );
 
     msg = i18n("<qt><p>The S/MIME certificate you choose here will be used "
                "to encrypt messages to yourself and for the \"Attach My Certificate\" "
-	       "feature in the composer.</p>"
+               "feature in the composer.</p>"
                "<p>You can leave this blank, but KMail will not be able "
                "to encrypt copies of outgoing messages to you using S/MIME; "
-	       "normal mail functions will not be affected.</p></qt>");
+               "normal mail functions will not be affected.</p></qt>");
     label = new QLabel( i18n("S/MIME encryption certificate:"), tab );
     label->setBuddy( mSMIMEEncryptionKeyRequester );
     mSMIMEEncryptionKeyRequester->setWhatsThis( msg );
@@ -398,9 +401,8 @@ namespace KMail {
     ++row;
     mTransportCheck = new QCheckBox( i18n("Special &transport:"), tab );
     glay->addWidget( mTransportCheck, row, 0 );
-    mTransportCombo = new QComboBox( tab );
+    mTransportCombo = new TransportComboBox( tab );
     mTransportCombo->setEnabled( false ); // since !mTransportCheck->isChecked()
-    mTransportCombo->addItems( TransportManager::self()->transportNames() );
     glay->addWidget( mTransportCombo, row, 1 );
     connect( mTransportCheck, SIGNAL(toggled(bool)),
              mTransportCombo, SLOT(setEnabled(bool)) );
@@ -412,22 +414,26 @@ namespace KMail {
     //
     tab = new QWidget( tabWidget );
     tabWidget->addTab( tab, i18n("&Templates") );
-    vlay = new QVBoxLayout( tab, marginHint(), spacingHint() );
+    vlay = new QVBoxLayout( tab );
+    vlay->setMargin( marginHint() );
+    vlay->setSpacing( spacingHint() );
     mCustom = new QCheckBox( i18n("&Use custom message templates"), tab );
     vlay->addWidget( mCustom );
     mWidget = new TemplatesConfiguration( tab , "identity-templates" );
     mWidget->setEnabled( false );
     vlay->addWidget( mWidget );
-    QHBoxLayout *btns = new QHBoxLayout( vlay, spacingHint() );
+    QHBoxLayout *btns = new QHBoxLayout();
+    btns->setSpacing( spacingHint() );
     mCopyGlobal = new KPushButton( i18n("&Copy Global Templates"), tab );
     mCopyGlobal->setEnabled( false );
     btns->addWidget( mCopyGlobal );
+    vlay->addLayout( btns );
     connect( mCustom, SIGNAL( toggled( bool ) ),
-	     mWidget, SLOT( setEnabled( bool ) ) );
+             mWidget, SLOT( setEnabled( bool ) ) );
     connect( mCustom, SIGNAL( toggled( bool ) ),
-	     mCopyGlobal, SLOT( setEnabled( bool ) ) );
+             mCopyGlobal, SLOT( setEnabled( bool ) ) );
     connect( mCopyGlobal, SIGNAL(clicked()),
-	     this, SLOT(slotCopyGlobal()) );
+             this, SLOT(slotCopyGlobal()) );
 
     //
     // Tab Widget: Signature
@@ -446,7 +452,7 @@ namespace KMail {
     mNameEdit->setFocus();
 
     connect( tabWidget, SIGNAL(currentChanged(QWidget*)),
-	     SLOT(slotAboutToShow(QWidget*)) );
+             SLOT(slotAboutToShow(QWidget*)) );
     connect( this, SIGNAL(okClicked()),SLOT(slotOk()));
   }
 
@@ -474,7 +480,7 @@ namespace KMail {
   namespace {
     struct DoesntMatchEMailAddress {
       explicit DoesntMatchEMailAddress( const QString & s )
-	: email( s.trimmed().toLower() ) {}
+        : email( s.trimmed().toLower() ) {}
       bool operator()( const GpgME::Key & key ) const;
     private:
       bool checkForEmail( const char * email ) const;
@@ -485,8 +491,8 @@ namespace KMail {
     bool DoesntMatchEMailAddress::operator()( const GpgME::Key & key ) const {
       const std::vector<GpgME::UserID> uids = key.userIDs();
       for ( std::vector<GpgME::UserID>::const_iterator it = uids.begin() ; it != uids.end() ; ++it )
-	if ( checkForEmail( it->email() ? it->email() : it->id() ) )
-	  return false;
+        if ( checkForEmail( it->email() ? it->email() : it->id() ) )
+          return false;
       return true; // note the negation!
     }
 
@@ -497,12 +503,12 @@ namespace KMail {
 
     QString DoesntMatchEMailAddress::extractEmail( const char * e ) {
       if ( !e || !*e )
-	return QString();
+        return QString();
       const QString em = QString::fromUtf8( e );
       if ( e[0] == '<' )
-	return em.mid( 1, em.length() - 2 );
+        return em.mid( 1, em.length() - 2 );
       else
-	return em;
+        return em;
     }
   }
 
@@ -633,15 +639,19 @@ namespace KMail {
     mSMIMESigningKeyRequester->setFingerprint( ident.smimeSigningKey() );
     mSMIMEEncryptionKeyRequester->setFingerprint( ident.smimeEncryptionKey() );
 
-    mPreferredCryptoMessageFormat->setCurrentIndex( format2cb( 
+    mPreferredCryptoMessageFormat->setCurrentIndex( format2cb(
        Kleo::stringToCryptoMessageFormat( ident.preferredCryptoMessageFormat() ) ) );
 
     // "Advanced" tab:
     mReplyToEdit->setText( ident.replyToAddr() );
     mBccEdit->setText( ident.bcc() );
-    mTransportCheck->setChecked( !ident.transport().isEmpty() );
-    mTransportCombo->setEditText( ident.transport() );
-    mTransportCombo->setEnabled( !ident.transport().isEmpty() );
+    QString transportName = ident.transport();
+    Transport *transport =
+              TransportManager::self()->transportByName( transportName, false );
+    mTransportCheck->setChecked( transport != 0 );
+    mTransportCombo->setEnabled( transport != 0 );
+    if ( transport )
+      mTransportCombo->setCurrentTransport( transport->id() );
     mDictionaryCombo->setCurrentByDictionary( ident.dictionary() );
 
     if ( ident.fcc().isEmpty() ||
@@ -700,13 +710,13 @@ namespace KMail {
     ident.setPGPEncryptionKey( mPGPEncryptionKeyRequester->fingerprint().toLatin1() );
     ident.setSMIMESigningKey( mSMIMESigningKeyRequester->fingerprint().toLatin1() );
     ident.setSMIMEEncryptionKey( mSMIMEEncryptionKeyRequester->fingerprint().toLatin1() );
-    ident.setPreferredCryptoMessageFormat( 
+    ident.setPreferredCryptoMessageFormat(
        Kleo::cryptoMessageFormatToString(cb2format( mPreferredCryptoMessageFormat->currentIndex() ) ) );
     // "Advanced" tab:
     ident.setReplyToAddr( mReplyToEdit->text() );
     ident.setBcc( mBccEdit->text() );
     ident.setTransport( ( mTransportCheck->isChecked() ) ?
-                        mTransportCombo->currentText() : QString() );
+                          mTransportCombo->currentText() : QString() );
     ident.setDictionary( mDictionaryCombo->currentDictionary() );
     ident.setFcc( mFccCombo->folder() ?
                   mFccCombo->folder()->idString() : QString() );
@@ -719,7 +729,7 @@ namespace KMail {
     uint identity = ident.uoid();
     QString iid = QString("IDENTITY_%1").arg( identity );
     Templates t( iid );
-    kDebug(5006) << "use custom templates for identity " << identity << ": " << mCustom->isChecked() << endl;
+    kDebug(5006) <<"use custom templates for identity" << identity <<":" << mCustom->isChecked();
     t.setUseCustomTemplates(mCustom->isChecked());
     t.writeConfig();
     mWidget->saveToIdentity( identity );
@@ -729,17 +739,6 @@ namespace KMail {
     ident.setXFace( mXFaceConfigurator->xface() );
     ident.setXFaceEnabled( mXFaceConfigurator->isXFaceEnabled() );
   }
-
-  void IdentityDialog::slotUpdateTransportCombo( const QStringList & sl ) {
-    // save old setting:
-    QString content = mTransportCombo->currentText();
-    // update combo box:
-    mTransportCombo->clear();
-    mTransportCombo->addItems( sl );
-    // restore saved setting:
-    mTransportCombo->setEditText( content );
-  }
-
 }
 
 #include "identitydialog.moc"
