@@ -21,7 +21,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-
 #include "imapaccountbase.h"
 
 using KMail::SieveConfig;
@@ -33,7 +32,6 @@ using KPIM::BroadcastStatus;
 #include "kmmainwin.h"
 #include "kmfolderimap.h"
 #include "kmmainwidget.h"
-#include "kmmainwin.h"
 #include "kmmsgpart.h"
 #include "acljobs.h"
 #include "kmfoldercachedimap.h"
@@ -67,7 +65,6 @@ using KIO::PasswordDialog;
 #include <QRegExp>
 #include <QTextDocument>
 #include <QByteArray>
-#include <q3stylesheet.h>
 
 namespace KMail {
 
@@ -114,7 +111,7 @@ ImapAccountBase::~ImapAccountBase()
 {
   qDeleteAll (mBodyPartList );
   kWarning( mSlave, 5006 )
-    << "slave should have been destroyed by subclass!" << endl;
+    << "slave should have been destroyed by subclass!";
 }
 
 void ImapAccountBase::init()
@@ -399,7 +396,7 @@ void ImapAccountBase::changeSubscription( bool subscribe, const QString &imapPat
   if ( makeConnection() != Connected ) {
     return;// ## doesn't handle Connecting
   }
-  KIO::SimpleJob *job = KIO::special( url, packedArgs, false );
+  KIO::SimpleJob *job = KIO::special( url, packedArgs, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( mSlave, job );
   jobData jd( url.url(), NULL );
   // a bit of a hack to save one slot
@@ -486,11 +483,11 @@ void ImapAccountBase::slotGetUserRightsResult( KJob *_job )
       // when the imap server doesn't support ACLs
       mACLSupport = false;
     } else {
-      kWarning(5006) << "slotGetUserRightsResult: " << job->errorString() << endl;
+      kWarning(5006) <<"slotGetUserRightsResult:" << job->errorString();
     }
   } else {
 #ifndef NDEBUG
-    //kDebug(5006) << "User Rights: " << ACLJobs::permissionsToString( job->permissions() ) << endl;
+    //kDebug(5006) <<"User Rights:" << ACLJobs::permissionsToString( job->permissions() );
 #endif
     // Store the permissions
     if ( folder->folderType() == KMFolderTypeImap ) {
@@ -580,7 +577,7 @@ void ImapAccountBase::slotNoopTimeout()
 
     stream << ( int ) 'N';
 
-    KIO::SimpleJob *job = KIO::special( getUrl(), packedArgs, false );
+    KIO::SimpleJob *job = KIO::special( getUrl(), packedArgs, KIO::HideProgressInfo );
     KIO::Scheduler::assignJobToSlave( mSlave, job );
     connect( job, SIGNAL(result( KJob * ) ),
              this, SLOT( slotSimpleResult( KJob * ) ) );
@@ -657,7 +654,7 @@ void ImapAccountBase::slotSchedulerSlaveConnected( KIO::Slave *aSlave )
   QByteArray packedArgs;
   QDataStream stream( &packedArgs, QIODevice::WriteOnly );
   stream << (int) 'c';
-  KIO::SimpleJob *job = KIO::special( getUrl(), packedArgs, false );
+  KIO::SimpleJob *job = KIO::special( getUrl(), packedArgs, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( mSlave, job );
   connect( job, SIGNAL(infoMessage(KJob*, const QString&, const QString &)),
 	   SLOT(slotCapabilitiesResult(KJob*, const QString&, const QString&)) );
@@ -667,7 +664,7 @@ void ImapAccountBase::slotSchedulerSlaveConnected( KIO::Slave *aSlave )
 void ImapAccountBase::slotCapabilitiesResult( KJob*, const QString& result, const QString & )
 {
   mCapabilities = result.toLower().split( ' ', QString::SkipEmptyParts );
-  kDebug(5006) << "capabilities:" << mCapabilities << endl;
+  kDebug(5006) <<"capabilities:" << mCapabilities;
 }
 
 //-----------------------------------------------------------------------------
@@ -676,7 +673,7 @@ void ImapAccountBase::getNamespaces()
   disconnect( this, SIGNAL( connectionResult(int, const QString&) ),
               this, SLOT( getNamespaces() ) );
   if ( makeConnection() != Connected || !mSlave ) {
-    kDebug(5006) << "getNamespaces - wait for connection" << endl;
+    kDebug(5006) <<"getNamespaces - wait for connection";
     if ( mNamespaces.isEmpty() || mNamespaceToDelimiter.isEmpty() ) {
       // when the connection is established slotSchedulerSlaveConnected notifies us
     } else {
@@ -701,7 +698,7 @@ void ImapAccountBase::getNamespaces()
             SIGNAL( progressItemCanceled( KPIM::ProgressItem* ) ),
             this,
             SLOT( slotAbortRequested( KPIM::ProgressItem* ) ) );
-  KIO::SimpleJob *job = KIO::special( getUrl(), packedArgs, false );
+  KIO::SimpleJob *job = KIO::special( getUrl(), packedArgs, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( mSlave, job );
   insertJob( job, jd );
   connect( job, SIGNAL( infoMessage(KJob*, const QString&, const QString&) ),
@@ -718,10 +715,10 @@ void ImapAccountBase::slotNamespaceResult( KJob *job, const QString &str, const
 
   nsDelimMap map;
   namespaceDelim nsDelim;
-  QStringList ns = str.split( ",", QString::SkipEmptyParts );
+  QStringList ns = str.split( ',', QString::SkipEmptyParts );
   for ( QStringList::Iterator it2 = ns.begin(); it2 != ns.end(); ++it2 ) {
     // split, allow empty parts as we can get empty namespaces
-    QStringList parts = (*it2).split( "=" );
+    QStringList parts = (*it2).split( '=' );
     imapNamespace section = imapNamespace( parts[0].toInt() );
     if ( map.contains( section ) ) {
       nsDelim = map[section];
@@ -734,14 +731,14 @@ void ImapAccountBase::slotNamespaceResult( KJob *job, const QString &str, const
   }
   removeJob( it );
 
-  kDebug(5006) << "namespaces fetched" << endl;
+  kDebug(5006) <<"namespaces fetched";
   emit namespacesFetched( map );
 }
 
 //-----------------------------------------------------------------------------
 void ImapAccountBase::slotSaveNamespaces( const ImapAccountBase::nsDelimMap &map )
 {
-  kDebug(5006) << "slotSaveNamespaces " << name() << endl;
+  kDebug(5006) <<"slotSaveNamespaces" << name();
   // extract the needed information
   mNamespaces.clear();
   mNamespaceToDelimiter.clear();
@@ -770,10 +767,10 @@ void ImapAccountBase::migratePrefix()
 {
   if ( !mOldPrefix.isEmpty() && mOldPrefix != "/" ) {
     // strip /
-    if ( mOldPrefix.startsWith("/") ) {
+    if ( mOldPrefix.startsWith('/') ) {
       mOldPrefix = mOldPrefix.right( mOldPrefix.length() - 1 );
     }
-    if ( mOldPrefix.endsWith("/") ) {
+    if ( mOldPrefix.endsWith('/') ) {
       mOldPrefix = mOldPrefix.left( mOldPrefix.length() - 1 );
     }
     QStringList list = mNamespaces[PersonalNS];
@@ -782,7 +779,7 @@ void ImapAccountBase::migratePrefix()
       if ( (*it).startsWith( mOldPrefix ) ) {
         // should be ok
         done = true;
-        kDebug(5006) << "migratePrefix - no migration needed" << endl;
+        kDebug(5006) <<"migratePrefix - no migration needed";
         break;
       }
     }
@@ -800,7 +797,7 @@ void ImapAccountBase::migratePrefix()
           mNamespaceToDelimiter.remove( QString() );
           mNamespaceToDelimiter[mOldPrefix] = delim;
         }
-        kDebug(5006) << "migratePrefix - replaced empty with " << mOldPrefix << endl;
+        kDebug(5006) <<"migratePrefix - replaced empty with" << mOldPrefix;
         msg += i18n("The configuration was automatically migrated but you should check "
                     "your account configuration.");
       } else if ( list.count() == 1 ) {
@@ -814,18 +811,18 @@ void ImapAccountBase::migratePrefix()
           mNamespaceToDelimiter.remove( old );
           mNamespaceToDelimiter[mOldPrefix] = delim;
         }
-        kDebug(5006) << "migratePrefix - replaced single with " << mOldPrefix << endl;
+        kDebug(5006) <<"migratePrefix - replaced single with" << mOldPrefix;
         msg += i18n("The configuration was automatically migrated but you should check "
                     "your account configuration.");
       } else {
-        kDebug(5006) << "migratePrefix - migration failed" << endl;
+        kDebug(5006) <<"migratePrefix - migration failed";
         msg += i18n("It was not possible to migrate your configuration automatically "
                     "so please check your account configuration.");
       }
       KMessageBox::information( kmkernel->getKMMainWidget(), msg );
     }
   } else {
-    kDebug(5006) << "migratePrefix - no migration needed" << endl;
+    kDebug(5006) <<"migratePrefix - no migration needed";
   }
   mOldPrefix.clear();
 }
@@ -845,7 +842,7 @@ QString ImapAccountBase::namespaceForFolder( FolderStorage* storage )
     QStringList::Iterator strit;
     for ( strit = it.value().begin(); strit != it.value().end(); ++strit ) {
       QString ns = *strit;
-      if ( ns.endsWith("/") || ns.endsWith(".") ) {
+      if ( ns.endsWith('/') || ns.endsWith('.') ) {
         // strip delimiter for the comparison
         ns = ns.left( ns.length()-1 );
       }
@@ -861,7 +858,7 @@ QString ImapAccountBase::namespaceForFolder( FolderStorage* storage )
 //-----------------------------------------------------------------------------
 QString ImapAccountBase::delimiterForNamespace( const QString &prefix )
 {
-  kDebug(5006) << "delimiterForNamespace " << prefix << endl;
+  kDebug(5006) <<"delimiterForNamespace" << prefix;
   // try to match exactly
   if ( mNamespaceToDelimiter.contains( prefix ) ) {
     return mNamespaceToDelimiter[prefix];
@@ -884,7 +881,7 @@ QString ImapAccountBase::delimiterForNamespace( const QString &prefix )
     return mNamespaceToDelimiter[QString()];
   }
   // well, we tried
-  kDebug(5006) << "delimiterForNamespace - not found" << endl;
+  kDebug(5006) <<"delimiterForNamespace - not found";
   return QString();
 }
 
@@ -1025,7 +1022,7 @@ bool ImapAccountBase::handleError( int errorCode, const QString &errorMsg,
     mErrorDialogIsActive = false;
   } else {
     if ( mErrorDialogIsActive ) {
-      kDebug(5006) << "suppressing error:" << errorMsg << endl;
+      kDebug(5006) <<"suppressing error:" << errorMsg;
     }
   }
   if ( job && !jobsKilled ) {
@@ -1039,7 +1036,7 @@ void ImapAccountBase::cancelMailCheck()
 {
   QMap<KJob*, jobData>::Iterator it = mapJobData.begin();
   while ( it != mapJobData.end() ) {
-    kDebug(5006) << "cancelMailCheck: job is cancellable: " << (*it).cancellable << endl;
+    kDebug(5006) <<"cancelMailCheck: job is cancellable:" << (*it).cancellable;
     if ( (*it).cancellable ) {
       it.key()->kill();
       QMap<KJob*, jobData>::Iterator rmit = it;
@@ -1127,7 +1124,7 @@ void ImapAccountBase::handleBodyStructure( QDataStream &stream, KMMessage *msg,
   }
 
   if ( !as ) {
-    kWarning(5006) << k_funcinfo << " - found no attachment strategy!" << endl;
+    kWarning(5006) <<" - found no attachment strategy!";
     return;
   }
 
@@ -1154,7 +1151,7 @@ void ImapAccountBase::handleBodyStructure( QDataStream &stream, KMMessage *msg,
   if ( (mBodyPartList.count() * 0.5) < partsToLoad ) {
     // more than 50% of the parts have to be loaded anyway so it is faster
     // to load the message completely
-    kDebug(5006) << "Falling back to normal mode" << endl;
+    kDebug(5006) <<"Falling back to normal mode";
     FolderJob *job =
       msg->parent()->createJob( msg, FolderJob::tGetMessage, 0, "TEXT" );
     job->start();
@@ -1162,16 +1159,16 @@ void ImapAccountBase::handleBodyStructure( QDataStream &stream, KMMessage *msg,
   }
   for ( it = parts.begin(); it != parts.end(); ++it ) {
     KMMessagePart *part = (*it);
-    kDebug(5006) << "ImapAccountBase::handleBodyStructure - load " << part->partSpecifier()
-                 << " (" << part->originalContentTypeStr() << ")" << endl;
+    kDebug(5006) <<"ImapAccountBase::handleBodyStructure - load" << part->partSpecifier()
+                 << "(" << part->originalContentTypeStr() << ")";
     if ( part->loadHeaders() ) {
-      kDebug(5006) << "load HEADER" << endl;
+      kDebug(5006) <<"load HEADER";
       FolderJob *job =
         msg->parent()->createJob( msg, FolderJob::tGetMessage, 0, part->partSpecifier()+".MIME" );
       job->start();
     }
     if ( part->loadPart() ) {
-      kDebug(5006) << "load Part" << endl;
+      kDebug(5006) <<"load Part";
       FolderJob *job =
         msg->parent()->createJob( msg, FolderJob::tGetMessage, 0, part->partSpecifier() );
       job->start();
@@ -1189,8 +1186,8 @@ void ImapAccountBase::constructParts( QDataStream &stream, int count, KMMessageP
     KMMessagePart* part = new KMMessagePart( stream );
     part->setParent( parentKMPart );
     mBodyPartList.append( part );
-    kDebug(5006) << "ImapAccountBase::constructParts - created id " << part->partSpecifier()
-                 << " of type " << part->originalContentTypeStr() << endl;
+    kDebug(5006) <<"ImapAccountBase::constructParts - created id" << part->partSpecifier()
+                 << "of type" << part->originalContentTypeStr();
     DwBodyPart *dwpart = mCurrentMsg->createDWBodyPart( part );
 
     if ( parent ) {
@@ -1235,7 +1232,7 @@ void ImapAccountBase::setImapStatus( KMFolder *folder, const QString &path,
                                      const QByteArray &flags )
 {
   // set the status on the server, the uids are integrated in the path
-  kDebug(5006) << "setImapStatus path=" << path << " to: " << flags << endl;
+  kDebug(5006) <<"setImapStatus path=" << path <<" to:" << flags;
   KUrl url = getUrl();
   url.setPath( path );
 
@@ -1248,7 +1245,7 @@ void ImapAccountBase::setImapStatus( KMFolder *folder, const QString &path,
     return; // can't happen with dimap
   }
 
-  KIO::SimpleJob *job = KIO::special( url, packedArgs, false );
+  KIO::SimpleJob *job = KIO::special( url, packedArgs, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( slave(), job );
   ImapAccountBase::jobData jd( url.url(), folder );
   jd.path = path;
@@ -1256,6 +1253,29 @@ void ImapAccountBase::setImapStatus( KMFolder *folder, const QString &path,
   connect( job, SIGNAL(result(KJob *)),
            SLOT(slotSetStatusResult(KJob *)) );
 }
+
+void ImapAccountBase::setImapSeenStatus(KMFolder * folder, const QString & path, bool seen)
+{
+   KUrl url = getUrl();
+   url.setPath(path);
+
+   QByteArray packedArgs;
+   QDataStream stream( &packedArgs, QIODevice::WriteOnly );
+
+   stream << (int) 's' << url << seen;
+
+   if ( makeConnection() != Connected )
+     return; // can't happen with dimap
+
+   KIO::SimpleJob *job = KIO::special(url, packedArgs, KIO::HideProgressInfo);
+   KIO::Scheduler::assignJobToSlave(slave(), job);
+   ImapAccountBase::jobData jd( url.url(), folder );
+   jd.path = path;
+   insertJob(job, jd);
+   connect(job, SIGNAL(result(KIO::Job *)),
+           SLOT(slotSetStatusResult(KIO::Job *)));
+}
+
 //-----------------------------------------------------------------------------
 void ImapAccountBase::slotSetStatusResult( KJob *job )
 {
@@ -1338,10 +1358,10 @@ unsigned int ImapAccountBase::folderCount() const
 QString ImapAccountBase::addPathToNamespace( const QString &prefix )
 {
   QString myPrefix = prefix;
-  if ( !myPrefix.startsWith( "/" ) ) {
+  if ( !myPrefix.startsWith( '/' ) ) {
     myPrefix = '/' + myPrefix;
   }
-  if ( !myPrefix.endsWith( "/" ) ) {
+  if ( !myPrefix.endsWith( '/' ) ) {
     myPrefix += '/';
   }
 
@@ -1388,14 +1408,14 @@ QString ImapAccountBase::createImapPath( const QString &parent,
 {
   QString newName = parent;
   // strip / at the end
-  if ( newName.endsWith( "/" ) ) {
+  if ( newName.endsWith( '/' ) ) {
     newName = newName.left( newName.length() - 1 );
   }
   // add correct delimiter
   QString delim = delimiterForNamespace( newName );
   // should not happen...
   if ( delim.isEmpty() ) {
-    delim = "/";
+    delim = '/';
   }
   if ( !newName.isEmpty() &&
        !newName.endsWith( delim ) && !folderName.startsWith( delim ) ) {
@@ -1403,7 +1423,7 @@ QString ImapAccountBase::createImapPath( const QString &parent,
   }
   newName = newName + folderName;
   // add / at the end
-  if ( !newName.endsWith("/") ) {
+  if ( !newName.endsWith('/') ) {
     newName = newName + '/';
   }
 
