@@ -47,7 +47,6 @@ using KPIM::ProgressManager;
 #include <QList>
 #include <QTextDocument>
 #include <QByteArray>
-#include <q3stylesheet.h>
 
 namespace KMail {
 
@@ -87,9 +86,7 @@ void ImapJob::init( JobType jt, const QString &sets, KMFolderImap *folder,
   }
   KMFolder *msg_parent = msg->parent();
   if ( msg_parent ) {
-    if ( !folder || folder!= msg_parent->storage() ) {
-      msg_parent->open( "imapjobsrc" );
-    }
+    msg_parent->open( "imapjobsrc" );
   }
   mSrcFolder = msg_parent;
   // If there is a destination folder, this is a copy, move or put to an
@@ -123,7 +120,7 @@ void ImapJob::init( JobType jt, const QString &sets, KMFolderImap *folder,
         curMsg = mSrcFolder->getMsg( idx );
       }
       KUrl url = account->getUrl();
-      QString flags = KMFolderImap::statusToFlags( curMsg->status() );
+      QString flags = KMFolderImap::statusToFlags( curMsg->status(), folder->permanentFlags() );
       url.setPath( folder->imapPath() + ";SECTION=" + flags );
       ImapAccountBase::jobData jd;
       jd.parent = 0; jd.offset = 0; jd.done = 0;
@@ -158,7 +155,7 @@ void ImapJob::init( JobType jt, const QString &sets, KMFolderImap *folder,
       jd.progressItem->setTotalItems( jd.total );
       connect ( jd.progressItem, SIGNAL( progressItemCanceled( KPIM::ProgressItem*)),
           account, SLOT( slotAbortRequested( KPIM::ProgressItem* ) ) );
-      KIO::SimpleJob *job = KIO::put( url, 0, false, false, false );
+      KIO::SimpleJob *job = KIO::put( url, 0, KIO::HideProgressInfo );
       KIO::Scheduler::assignJobToSlave( account->slave(), job );
       account->insertJob( job, jd );
       connect( job, SIGNAL(result(KJob *)),
@@ -199,7 +196,7 @@ void ImapJob::init( JobType jt, const QString &sets, KMFolderImap *folder,
     jd.progressItem->setTotalItems( jd.total );
     connect ( jd.progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem*)),
               account, SLOT( slotAbortRequested(KPIM::ProgressItem* ) ) );
-    KIO::SimpleJob *simpleJob = KIO::special( url, packedArgs, false );
+    KIO::SimpleJob *simpleJob = KIO::special( url, packedArgs, KIO::HideProgressInfo );
     KIO::Scheduler::assignJobToSlave( account->slave(), simpleJob );
     mJob = simpleJob;
     account->insertJob( mJob, jd );
@@ -308,7 +305,7 @@ void ImapJob::slotGetNextMessage()
         jd.total = msg->msgSizeServer();
   }
   url.setPath( path );
-//  kDebug(5006) << "ImapJob::slotGetNextMessage - retrieve " << url.path() << endl;
+//  kDebug(5006) <<"ImapJob::slotGetNextMessage - retrieve" << url.path();
   // protect the message, otherwise we'll get crashes afterwards
   msg->setTransferInProgress( true );
   const QString escapedSubject = Qt::escape( msg->subject() );
@@ -323,7 +320,7 @@ void ImapJob::slotGetNextMessage()
             account, SLOT( slotAbortRequested( KPIM::ProgressItem* ) ) );
   jd.progressItem->setTotalItems( jd.total );
 
-  KIO::SimpleJob *simpleJob = KIO::get( url, false, false );
+  KIO::SimpleJob *simpleJob = KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( account->slave(), simpleJob );
   mJob = simpleJob;
   account->insertJob( mJob, jd );
@@ -377,7 +374,7 @@ void ImapJob::slotGetMessageResult( KJob * job )
   } else {
     if ((*it).data.size() > 0)
     {
-      kDebug(5006) << "ImapJob::slotGetMessageResult - retrieved part " << mPartSpecifier << endl;
+      kDebug(5006) <<"ImapJob::slotGetMessageResult - retrieved part" << mPartSpecifier;
       if ( mPartSpecifier.isEmpty() ||
            mPartSpecifier == "HEADER" )
       {
@@ -424,7 +421,7 @@ void ImapJob::slotGetMessageResult( KJob * job )
           msg->updateAttachmentState();
       }
     } else {
-      kDebug(5006) << "ImapJob::slotGetMessageResult - got no data for " << mPartSpecifier << endl;
+      kDebug(5006) <<"ImapJob::slotGetMessageResult - got no data for" << mPartSpecifier;
       gotData = false;
       msg->setReadyToShow( true );
       // nevertheless give visual feedback
