@@ -2,8 +2,6 @@
 #include "isubject.h"
 #include "interfaces/observer.h"
 
-#include <q3tl.h>
-
 #include <kdebug.h>
 
 namespace KMail {
@@ -27,7 +25,7 @@ namespace KMail {
 
   void ISubject::notify()
   {
-    kDebug(5006) << "ISubject::notify " << mObserverList.size() << endl;
+    kDebug(5006) <<"ISubject::notify" << mObserverList.size();
     for ( QVector<Interface::Observer*>::iterator it = mObserverList.begin() ; it != mObserverList.end() ; ++it )
       (*it)->update( this );
   }
