@@ -55,7 +55,6 @@
 #include <kmessagebox.h>
 
 #include <QStringList>
-#include <q3tl.h>
 #include <algorithm>
 #include <memory>
 #include <iterator>
@@ -97,18 +96,18 @@ static inline bool WithRespectToKeyID( const GpgME::Key & left, const GpgME::Key
 }
 
 static bool ValidTrustedOpenPGPEncryptionKey( const GpgME::Key & key ) {
-  if ( key.protocol() != GpgME::Context::OpenPGP ) {
+  if ( key.protocol() != GpgME::OpenPGP ) {
     return false;
   }
 #if 0
   if ( key.isRevoked() )
-    kWarning() << " is revoked" << endl;
+    kWarning(5006) <<" is revoked";
   if ( key.isExpired() )
-    kWarning() << " is expired" << endl;
+    kWarning(5006) <<" is expired";
   if ( key.isDisabled() )
-    kWarning() << " is disabled" << endl;
+    kWarning(5006) <<" is disabled";
   if ( !key.canEncrypt() )
-    kWarning() << " can't encrypt" << endl;
+    kWarning(5006) <<" can't encrypt";
 #endif
   if ( key.isRevoked() || key.isExpired() || key.isDisabled() || !key.canEncrypt() )
     return false;
@@ -119,16 +118,16 @@ static bool ValidTrustedOpenPGPEncryptionKey( const GpgME::Key & key ) {
 #if 0
     else
       if ( it->isRevoked() )
-        kWarning() << "a userid is revoked" << endl;
+        kWarning(5006) <<"a userid is revoked";
       else
-        kWarning() << "bad validity " << it->validity() << endl;
+        kWarning(5006) <<"bad validity" << it->validity();
 #endif
   }
   return false;
 }
 
 static bool ValidTrustedSMIMEEncryptionKey( const GpgME::Key & key ) {
-  if ( key.protocol() != GpgME::Context::CMS )
+  if ( key.protocol() != GpgME::CMS )
     return false;
   if ( key.isRevoked() || key.isExpired() || key.isDisabled() || !key.canEncrypt() )
     return false;
@@ -137,9 +136,9 @@ static bool ValidTrustedSMIMEEncryptionKey( const GpgME::Key & key ) {
 
 static inline bool ValidTrustedEncryptionKey( const GpgME::Key & key ) {
   switch ( key.protocol() ) {
-  case GpgME::Context::OpenPGP:
+  case GpgME::OpenPGP:
     return ValidTrustedOpenPGPEncryptionKey( key );
-  case GpgME::Context::CMS:
+  case GpgME::CMS:
     return ValidTrustedSMIMEEncryptionKey( key );
   default:
     return false;
@@ -153,11 +152,11 @@ static inline bool ValidSigningKey( const GpgME::Key & key ) {
 }
 
 static inline bool ValidOpenPGPSigningKey( const GpgME::Key & key ) {
-  return key.protocol() == GpgME::Context::OpenPGP && ValidSigningKey( key );
+  return key.protocol() == GpgME::OpenPGP && ValidSigningKey( key );
 }
 
 static inline bool ValidSMIMESigningKey( const GpgME::Key & key ) {
-  return key.protocol() == GpgME::Context::CMS && ValidSigningKey( key );
+  return key.protocol() == GpgME::CMS && ValidSigningKey( key );
 }
 
 static inline bool NotValidTrustedOpenPGPEncryptionKey( const GpgME::Key & key ) {
@@ -190,8 +189,8 @@ namespace {
 
     bool operator()( const GpgME::Key & key ) const {
       return
-	( isOpenPGP( format ) && key.protocol() != GpgME::Context::OpenPGP ) ||
-	( isSMIME( format )   && key.protocol() != GpgME::Context::CMS );
+	( isOpenPGP( format ) && key.protocol() != GpgME::OpenPGP ) ||
+	( isSMIME( format )   && key.protocol() != GpgME::CMS );
     }
 
     const Kleo::CryptoMessageFormat format;
@@ -445,7 +444,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
 						    bool mine, bool sign, bool ca,
 						    int recur_limit, const GpgME::Key & orig ) const {
   if ( recur_limit <= 0 ) {
-    kDebug(5006) << "Kleo::KeyResolver::checkKeyNearExpiry(): key chain too long (>100 certs)" << endl;
+    kDebug(5006) <<"Kleo::KeyResolver::checkKeyNearExpiry(): key chain too long (>100 certs)";
     return Kpgp::Ok;
   }
   const GpgME::Subkey subkey = key.subkey(0);
@@ -458,8 +457,8 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
   static const double secsPerDay = 24 * 60 * 60;
   const int daysTillExpiry =
     1 + int( ::difftime( subkey.expirationTime(), time(0) ) / secsPerDay );
-  kDebug(5006) << "Key 0x" << key.shortKeyID() << " expires in less than "
-	           << daysTillExpiry << " days" << endl;
+  kDebug(5006) <<"Key 0x" << key.shortKeyID() <<"expires in less than"
+	           << daysTillExpiry << "days";
   const int threshold =
     ca
     ? ( key.isRoot()
@@ -474,7 +473,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
 	: encryptKeyNearExpiryWarningThresholdInDays() );
   if ( threshold > -1 && daysTillExpiry <= threshold ) {
     const QString msg =
-      key.protocol() == GpgME::Context::OpenPGP
+      key.protocol() == GpgME::OpenPGP
       ? ( mine ? sign
 	  ? ki18np("<p>Your OpenPGP signing key</p><p align=center><b>%2</b> (KeyID 0x%3)</p>"
 		   "<p>expires in less than a day.</p>",
@@ -555,7 +554,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
 		       .subs( key.issuerSerial() )
 		       .toString() );
     if ( KMessageBox::warningContinueCancel( 0, msg,
-					     key.protocol() == GpgME::Context::OpenPGP
+					     key.protocol() == GpgME::OpenPGP
 					     ? i18n("OpenPGP Key Expires Soon" )
 					     : i18n("S/MIME Certificate Expires Soon" ),
 					     KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
@@ -1185,10 +1184,10 @@ Kpgp::Result Kleo::KeyResolver::showKeyApprovalDialog() {
       pref.smimeCertFingerprints.clear();
       const std::vector<GpgME::Key> & keys = items[i].keys;
       for ( std::vector<GpgME::Key>::const_iterator it = keys.begin(), end = keys.end() ; it != end ; ++it ) {
-        if ( it->protocol() == GpgME::Context::OpenPGP ) {
+        if ( it->protocol() == GpgME::OpenPGP ) {
           if ( const char * fpr = it->primaryFingerprint() )
             pref.pgpKeyFingerprints.push_back( fpr );
-        } else if ( it->protocol() == GpgME::Context::CMS ) {
+        } else if ( it->protocol() == GpgME::CMS ) {
           if ( const char * fpr = it->primaryFingerprint() )
             pref.smimeCertFingerprints.push_back( fpr );
         }
@@ -1314,9 +1313,9 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
   const QStringList fingerprints = keysForAddress( address );
 
   if ( !fingerprints.empty() ) {
-    kDebug(5006) << "Using encryption keys 0x"
+    kDebug(5006) <<"Using encryption keys 0x"
 	             << fingerprints.join( ", 0x" )
-	             << " for " << person << endl;
+	             << "for" << person;
     std::vector<GpgME::Key> keys = lookup( fingerprints );
     if ( !keys.empty() ) {
       // Check if all of the keys are trusted and valid encryption keys
@@ -1329,7 +1328,7 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
       // notified about it as early as possible:
       keys = selectKeys( person,
 			 i18nc("if in your language something like "
-			      "'key(s)' isn't possible please "
+			      "'key(s)' is not possible please "
 			      "use the plural in the translation",
 			      "There is a problem with the "
 			      "encryption key(s) for \"%1\".\n\n"
@@ -1365,14 +1364,14 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
   return selectKeys( person,
 		     matchingKeys.empty()
 		     ? i18nc("if in your language something like "
-			    "'key(s)' isn't possible please "
+			    "'key(s)' is not possible please "
 			    "use the plural in the translation",
 			    "No valid and trusted encryption key was "
 			    "found for \"%1\".\n\n"
 			    "Select the key(s) which should "
 			    "be used for this recipient.", person)
 		     : i18nc("if in your language something like "
-			    "'key(s)' isn't possible please "
+			    "'key(s)' is not possible please "
 			    "use the plural in the translation",
 			    "More than one key matches \"%1\".\n\n"
 			    "Select the key(s) which should "
@@ -1384,8 +1383,8 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
 std::vector<GpgME::Key> Kleo::KeyResolver::lookup( const QStringList & patterns, bool secret ) const {
   if ( patterns.empty() )
     return std::vector<GpgME::Key>();
-  kDebug(5006) << "Kleo::KeyResolver::lookup( \"" << patterns.join( "\", \"" )
-	           << "\", " << secret << " )" << endl;
+  kDebug(5006) <<"Kleo::KeyResolver::lookup( \"" << patterns.join("\", \"" )
+	           << "\"," << secret << ")";
   std::vector<GpgME::Key> result;
   if ( mCryptoMessageFormats & (InlineOpenPGPFormat|OpenPGPMIMEFormat) )
     if ( const Kleo::CryptoBackend::Protocol * p = Kleo::CryptoBackendFactory::instance()->openpgp() ) {
@@ -1405,7 +1404,7 @@ std::vector<GpgME::Key> Kleo::KeyResolver::lookup( const QStringList & patterns,
 	result.insert( result.end(), keys.begin(), keys.end() );
       }
     }
-  kDebug(5006) << "  returned " << result.size() << " keys" << endl;
+  kDebug(5006) <<"  returned" << result.size() <<" keys";
   return result;
 }
 
@@ -1417,9 +1416,9 @@ void Kleo::KeyResolver::addKeys( const std::vector<Item> & items, CryptoMessageF
 			 std::back_inserter( si.keys ), IsNotForFormat( f ) );
     dump();
     kWarning( si.keys.empty() )
-      << "Kleo::KeyResolver::addKeys(): Fix EncryptionFormatPreferenceCounter. "
+      << "Kleo::KeyResolver::addKeys(): Fix EncryptionFormatPreferenceCounter."
       << "It detected a common format, but the list of such keys for recipient \""
-      << it->address << "\" is empty!" << endl;
+      << it->address << "\" is empty!";
     d->mFormatInfoMap[ f ].splitInfos.push_back( si );
   }
   dump();
@@ -1437,8 +1436,8 @@ void Kleo::KeyResolver::addKeys( const std::vector<Item> & items ) {
       }
     }
     if ( f == AutoFormat )
-      kWarning() << "Kleo::KeyResolver::addKeys(): Something went wrong. Didn't find a format for \""
-                  << it->address << "\"" << endl;
+      kWarning(5006) <<"Kleo::KeyResolver::addKeys(): Something went wrong. Didn't find a format for \""
+                  << it->address << "\"";
     else
       std::remove_copy_if( it->keys.begin(), it->keys.end(),
                            std::back_inserter( si.keys ), IsNotForFormat( f ) );
