@@ -68,9 +68,10 @@ KMAcctImap::KMAcctImap(AccountManager* aOwner, const QString& aAccountName, uint
   connect(&mErrorTimer, SIGNAL(timeout()), SLOT(slotResetConnectionError()));
 
   QString serNumUri = KStandardDirs::locateLocal( "data", "kmail/unfiltered." +
-				   QString("%1").arg(KAccount::id()) );
+                                            QString("%1").arg(KAccount::id()) );
   KConfig config( serNumUri );
-  QStringList serNums = config.readEntry( "unfiltered" , QStringList() );
+  QStringList serNums =
+      config.group("<default>").readEntry( "unfiltered" , QStringList() );
 
   for ( QStringList::ConstIterator it = serNums.begin();
 	it != serNums.end(); ++it ) {
@@ -86,14 +87,14 @@ KMAcctImap::~KMAcctImap()
   killAllJobs( true );
 
   QString serNumUri = KStandardDirs::locateLocal( "data", "kmail/unfiltered." +
-				   QString("%1").arg(KAccount::id()) );
+                                            QString("%1").arg(KAccount::id()) );
   KConfig config( serNumUri );
   QStringList serNums;
   QHashIterator<QString, int> it( mFilterSerNumsToSave );
   while ( it.hasNext() ) {
     serNums.append( it.key() );
   }
-  config.writeEntry( "unfiltered", serNums );
+  config.group("<default>").writeEntry( "unfiltered", serNums );
   qDeleteAll( mOpenFolders );
 }
 
@@ -142,7 +143,7 @@ void KMAcctImap::killAllJobs( bool disconnectSlave )
     for ( ; it2 != msgList.end(); ++it2 ) {
        KMMessage *msg = *it2;
        if ( msg->transferInProgress() ) {
-          kDebug(5006) << "KMAcctImap::killAllJobs - resetting mail" << endl;
+          kDebug(5006) <<"KMAcctImap::killAllJobs - resetting mail";
           msg->setTransferInProgress( false );
        }
     }
@@ -261,7 +262,7 @@ void KMAcctImap::cancelMailCheck()
 //-----------------------------------------------------------------------------
 void KMAcctImap::processNewMail(bool interactive)
 {
-  kDebug(5006) << "processNewMail " << mCheckingSingleFolder << ",status="<<makeConnection()<<endl;
+  kDebug(5006) <<"processNewMail" << mCheckingSingleFolder <<",status="<<makeConnection();
   if ( !mFolder || !mFolder->folder() || !mFolder->folder()->child() ||
        makeConnection() == ImapAccountBase::Error ) {
     // checks for mCountRemainChecks
@@ -491,7 +492,7 @@ void KMAcctImap::slotUpdateFolderList()
 {
   if ( !mFolder || !mFolder->folder() || !mFolder->folder()->child() )
   {
-    kWarning(5006) << "KMAcctImap::slotUpdateFolderList return" << endl;
+    kWarning(5006) <<"KMAcctImap::slotUpdateFolderList return";
     return;
   }
   QStringList strList;
@@ -550,7 +551,7 @@ ImapAccountBase::ConnectionState KMAcctImap::makeConnection()
 void KMAcctImap::slotResetConnectionError()
 {
   mSlaveConnectionError = false;
-  kDebug(5006) << k_funcinfo << endl;
+  kDebug(5006) ;
 }
 
 void KMAcctImap::slotFolderSelected( KMFolderImap* folder, bool )
@@ -584,9 +585,9 @@ int KMAcctImap::slotFilterMsg( KMMessage *msg )
     mFilterSerNumsToSave.remove( QString( "%1" ).arg( serNum ) );
 
   int filterResult = kmkernel->filterMgr()->process(msg,
-						    KMFilterMgr::Inbound,
-						    true,
-						    id() );
+                                                    KMFilterMgr::Inbound,
+                                                    true,
+                                                    id() );
   if (filterResult == 2) {
     // something went horribly wrong (out of space?)
     kmkernel->emergencyExit( i18n("Unable to process messages: " ) + QString::fromLocal8Bit(strerror(errno)));
