@@ -18,7 +18,6 @@ using KPIM::MessageStatus;
 #include <QMenu>
 
 class KProgressDialog;
-class KProcess;
 class KMFilter;
 class KMFolder;
 class KMFolderImap;
@@ -157,7 +156,7 @@ class KMAIL_EXPORT KMMailtoComposeCommand : public KMCommand
   Q_OBJECT
 
 public:
-  KMMailtoComposeCommand( const KUrl &url, KMMessage *msg=0 );
+  explicit KMMailtoComposeCommand( const KUrl &url, KMMessage *msg=0 );
 
 private:
   virtual Result execute();
@@ -240,7 +239,7 @@ class KMAIL_EXPORT KMUrlCopyCommand : public KMCommand
   Q_OBJECT
 
 public:
-  KMUrlCopyCommand( const KUrl &url, KMMainWidget *mainWidget = 0 );
+  explicit KMUrlCopyCommand( const KUrl &url, KMMainWidget *mainWidget = 0 );
 
 private:
   virtual Result execute();
@@ -350,8 +349,8 @@ class KMAIL_EXPORT KMOpenMsgCommand : public KMCommand
   Q_OBJECT
 
 public:
-  KMOpenMsgCommand( QWidget *parent, const KUrl & url = KUrl(),
-                    const QString & encoding = QString() );
+  explicit KMOpenMsgCommand( QWidget *parent, const KUrl & url = KUrl(),
+            		     const QString & encoding = QString() );
 
 private:
   virtual Result execute();
@@ -823,7 +822,7 @@ class KMAIL_EXPORT KMResendMessageCommand : public KMCommand
   Q_OBJECT
 
 public:
-  KMResendMessageCommand( QWidget *parent, KMMessage *msg=0 );
+  explicit KMResendMessageCommand( QWidget *parent, KMMessage *msg=0 );
 
 private:
   virtual Result execute();
@@ -889,26 +888,6 @@ protected:
   virtual KUrl::List urls() const;
 };
 
-class KMAIL_EXPORT KMIMChatCommand : public KMCommand
-{
-  Q_OBJECT
-
-public:
-  KMIMChatCommand( const KUrl &url, KMMessage *msg=0 );
-
-private:
-  /**
-   * Try to start a chat with the addressee associated the mail address in <i>url</i>.
-   * If there is no addressee for the email address, or more than one, a KMessageBox is shown to inform the user.
-   * If the addressee does not have instant messaging address(es), this is currently handled by the instant messaging client
-   * which handles the request, since we don't have a convenient API for extracting them using KABC.
-   */
-  virtual Result execute();
-
-  KUrl mUrl;
-  KMMessage *mMessage;
-};
-
 class KMAIL_EXPORT KMHandleAttachmentCommand : public KMCommand
 {
   Q_OBJECT
