@@ -32,7 +32,7 @@ using KMail::RegExpLineEdit;
 #include <kdebug.h>
 #include <klocale.h>
 #include <kurlrequester.h>
-#include <phonon/audioplayer.h>
+#include <Phonon/MediaObject>
 #include <kshell.h>
 #include <kprocess.h>
 
@@ -122,7 +122,7 @@ void KMFilterAction::sendMDN( KMMessage * msg, KMime::MDN::DispositionType d,
 
   KMMessage * mdn = msg->createMDN( KMime::MDN::AutomaticAction, d, false, m );
   if ( mdn && !kmkernel->msgSender()->send( mdn, KMail::MessageSender::SendLater ) ) {
-    kDebug(5006) << "KMFilterAction::sendMDN(): sending failed." << endl;
+    kDebug(5006) <<"KMFilterAction::sendMDN(): sending failed.";
     //delete mdn;
   }
 
@@ -453,7 +453,7 @@ QString KMFilterActionWithCommand::substituteCommandLineArgsFor( KMMessage *aMsg
       KTemporaryFile *tf = new KTemporaryFile();
       if ( !tf->open() ) {
         delete tf;
-        kDebug(5006) << "KMFilterActionWithCommand: Could not create temp file!" << endl;
+        kDebug(5006) <<"KMFilterActionWithCommand: Could not create temp file!";
         return QString();
       }
       aTempFileList.append( tf );
@@ -609,6 +609,7 @@ KMFilterAction::ReturnCode KMFilterActionSendReceipt::process(KMMessage* msg) co
 //=============================================================================
 // KMFilterActionSetTransport - set transport to...
 // Specify mail transport (smtp server) to be used when replying to a message
+// TODO: use TransportComboBox so the user does not enter an invalid transport
 //=============================================================================
 class KMFilterActionTransport: public KMFilterActionWithString
 {
@@ -1475,7 +1476,7 @@ KMFilterAction::ReturnCode KMFilterActionForward::process( KMMessage *aMsg ) con
 
   // QString st = QString::fromUtf8( aMsg->createForwardBody() );
   TemplateParser parser( msg, TemplateParser::Forward,
-			 aMsg->body(), false, false, false, false);
+                         aMsg->body(), false, false, false);
   parser.process( aMsg );
 
   QByteArray
@@ -1536,7 +1537,7 @@ KMFilterAction::ReturnCode KMFilterActionForward::process( KMMessage *aMsg ) con
   sendMDN( aMsg, KMime::MDN::Dispatched );
 
   if ( !kmkernel->msgSender()->send( msg, KMail::MessageSender::SendLater ) ) {
-    kDebug(5006) << "KMFilterAction: could not forward message (sending failed)" << endl;
+    kDebug(5006) <<"KMFilterAction: could not forward message (sending failed)";
     return ErrorButGoOn; // error: couldn't send
   }
   return GoOn;
@@ -1576,7 +1577,7 @@ KMFilterAction::ReturnCode KMFilterActionRedirect::process(KMMessage* aMsg) cons
   sendMDN( aMsg, KMime::MDN::Dispatched );
 
   if ( !kmkernel->msgSender()->send( msg, KMail::MessageSender::SendLater ) ) {
-    kDebug(5006) << "KMFilterAction: could not redirect message (sending failed)" << endl;
+    kDebug(5006) <<"KMFilterAction: could not redirect message (sending failed)";
     return ErrorButGoOn; // error: couldn't send
   }
   return GoOn;
@@ -1673,7 +1674,7 @@ class PipeJob : public ThreadWeaver::Job
           filterFolder->addMsg( mMsg );
           handler->ignoreChanges( oldStatus );
         } else {
-          kDebug(5006) << "Warning: Cannot refresh the message from the external filter." << endl;
+          kDebug(5006) <<"Warning: Cannot refresh the message from the external filter.";
         }
       }
 
@@ -1760,7 +1761,7 @@ public:
   virtual bool requiresBody(KMMsgBase*) const;
   static KMFilterAction* newAction(void);
 private:
-  Phonon::AudioPlayer* mPlayer;
+  Phonon::MediaObject* mPlayer;
 };
 
 KMFilterActionWithTest::KMFilterActionWithTest( const char* aName, const QString &aLabel )
@@ -1816,7 +1817,7 @@ const QString KMFilterActionWithTest::displayString() const
 KMFilterActionExecSound::KMFilterActionExecSound()
   : KMFilterActionWithTest( "play sound", i18n("Play Sound") )
 {
-  mPlayer = new Phonon::AudioPlayer(Phonon::NotificationCategory);
+  mPlayer = Phonon::createPlayer(Phonon::NotificationCategory);
 }
 
 KMFilterActionExecSound::~KMFilterActionExecSound()
@@ -1833,7 +1834,8 @@ KMFilterAction::ReturnCode KMFilterActionExecSound::process(KMMessage*) const
 {
   if ( mParameter.isEmpty() )
     return ErrorButGoOn;
-  mPlayer->play( KUrl(mParameter) );
+  mPlayer->setCurrentSource( mParameter );
+  mPlayer->play();
   return GoOn;
 }
 
