@@ -131,7 +131,7 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, bool popFilter, bool createDummyFilter
   setButtons( Help|Ok|Apply|Cancel );
   setModal( false );
 #ifdef Q_OS_UNIX
-  KWindowSystem::setIcons( winId(), qApp->windowIcon().pixmap(IconSize(K3Icon::Desktop),IconSize(K3Icon::Desktop)), qApp->windowIcon().pixmap(IconSize(K3Icon::Small),IconSize(K3Icon::Small)) );
+  KWindowSystem::setIcons( winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)) );
 #endif
   setHelp( (bPopFilter)? KMPopFilterDlgHelpAnchor: KMFilterDlgHelpAnchor );
 
@@ -247,6 +247,7 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, bool popFilter, bool createDummyFilter
       mKeySeqWidget->setObjectName( "FilterShortcutSelector" );
       gl->addWidget( mKeySeqWidget, 7, 3, 1, 1);
       mKeySeqWidget->setEnabled( false );
+	  mKeySeqWidget->setCheckActionList(kmkernel->getKMMainWidget()->actionList());
       mConfigureToolbar = new QCheckBox( i18n("Additionally add this filter to the toolbar"), mAdvOptsGroup );
       gl->addWidget( mConfigureToolbar, 8, 0, 1, 4 );
       mConfigureToolbar->setEnabled( false );
@@ -258,7 +259,7 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, bool popFilter, bool createDummyFilter
 
       mFilterActionIconButton = new KIconButton( hbox );
       mFilterActionLabel->setBuddy( mFilterActionIconButton );
-      mFilterActionIconButton->setIconType( K3Icon::NoGroup, K3Icon::Action, false );
+      mFilterActionIconButton->setIconType( KIconLoader::NoGroup, KIconLoader::Action, false );
       mFilterActionIconButton->setIconSize( 16 );
       mFilterActionIconButton->setIcon( "gear" );
       mFilterActionIconButton->setEnabled( false );
@@ -288,35 +289,35 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, bool popFilter, bool createDummyFilter
     // transfer changes from the 'Apply this filter on...'
     // combo box to the filter
     connect( mApplyOnIn, SIGNAL(clicked()),
-  	     this, SLOT(slotApplicabilityChanged()) );
+             this, SLOT(slotApplicabilityChanged()) );
     connect( mApplyOnForAll, SIGNAL(clicked()),
-  	     this, SLOT(slotApplicabilityChanged()) );
+             this, SLOT(slotApplicabilityChanged()) );
     connect( mApplyOnForTraditional, SIGNAL(clicked()),
-  	     this, SLOT(slotApplicabilityChanged()) );
+             this, SLOT(slotApplicabilityChanged()) );
     connect( mApplyOnForChecked, SIGNAL(clicked()),
-  	     this, SLOT(slotApplicabilityChanged()) );
+             this, SLOT(slotApplicabilityChanged()) );
     connect( mApplyOnOut, SIGNAL(clicked()),
-  	     this, SLOT(slotApplicabilityChanged()) );
+             this, SLOT(slotApplicabilityChanged()) );
     connect( mApplyOnCtrlJ, SIGNAL(clicked()),
-  	     this, SLOT(slotApplicabilityChanged()) );
+             this, SLOT(slotApplicabilityChanged()) );
     connect( mAccountList, SIGNAL(clicked(Q3ListViewItem*)),
-  	     this, SLOT(slotApplicableAccountsChanged()) );
+             this, SLOT(slotApplicableAccountsChanged()) );
     connect( mAccountList, SIGNAL(spacePressed(Q3ListViewItem*)),
-  	     this, SLOT(slotApplicableAccountsChanged()) );
+             this, SLOT(slotApplicableAccountsChanged()) );
 
     // transfer changes from the 'stop processing here'
     // check box to the filter
     connect( mStopProcessingHere, SIGNAL(toggled(bool)),
-	     this, SLOT(slotStopProcessingButtonToggled(bool)) );
+             this, SLOT(slotStopProcessingButtonToggled(bool)) );
 
     connect( mConfigureShortcut, SIGNAL(toggled(bool)),
-	     this, SLOT(slotConfigureShortcutButtonToggled(bool)) );
+             this, SLOT(slotConfigureShortcutButtonToggled(bool)) );
 
     connect( mKeySeqWidget, SIGNAL( keySequenceChanged( const QKeySequence& ) ),
-             this, SLOT( slotCapturedShortcutChanged( const QKeySequence& ) ) );
+             this, SLOT( slotShortcutChanged( const QKeySequence& ) ) );
 
     connect( mConfigureToolbar, SIGNAL(toggled(bool)),
-	     this, SLOT(slotConfigureToolbarButtonToggled(bool)) );
+             this, SLOT(slotConfigureToolbarButtonToggled(bool)) );
 
     connect( mFilterActionIconButton, SIGNAL( iconChanged( const QString& ) ),
              this, SLOT( slotFilterActionIconChanged( const QString& ) ) );
@@ -394,12 +395,12 @@ void KMFilterDlg::slotFilterSelected( KMFilter* aFilter )
   mFilter = aFilter;
 
   if (!bPopFilter) {
-    kDebug(5006) << "apply on inbound == "
-		  << aFilter->applyOnInbound() << endl;
-    kDebug(5006) << "apply on outbound == "
-		  << aFilter->applyOnOutbound() << endl;
-    kDebug(5006) << "apply on explicit == "
-		  << aFilter->applyOnExplicit() << endl;
+    kDebug(5006) <<"apply on inbound =="
+		  << aFilter->applyOnInbound();
+    kDebug(5006) <<"apply on outbound =="
+		  << aFilter->applyOnOutbound();
+    kDebug(5006) <<"apply on explicit =="
+		  << aFilter->applyOnExplicit();
 
     // NOTE: setting these values activates the slot that sets them in
     // the filter! So make sure we have the correct values _before_ we
@@ -428,7 +429,8 @@ void KMFilterDlg::slotFilterSelected( KMFilter* aFilter )
     mApplyOnCtrlJ->setChecked( applyOnExplicit );
     mStopProcessingHere->setChecked( stopHere );
     mConfigureShortcut->setChecked( configureShortcut );
-    mKeySeqWidget->setKeySequence( shortcut.primary() );
+    mKeySeqWidget->setKeySequence( shortcut.primary(),
+                                   KKeySequenceWidget::NoValidate );
     mConfigureToolbar->setChecked( configureToolbar );
     mFilterActionIconButton->setIcon( icon );
   }
@@ -486,11 +488,10 @@ void KMFilterDlg::slotApplicabilityChanged()
       ++it;
     }
 
-    kDebug(5006) << "KMFilterDlg: setting filter to be applied at "
+    kDebug(5006) <<"KMFilterDlg: setting filter to be applied at"
                   << ( mFilter->applyOnInbound() ? "incoming " : "" )
                   << ( mFilter->applyOnOutbound() ? "outgoing " : "" )
-                  << ( mFilter->applyOnExplicit() ? "explicit CTRL-J" : "" )
-                  << endl;
+                  << ( mFilter->applyOnExplicit() ? "explicit CTRL-J" : "" );
   }
 }
 
@@ -527,17 +528,13 @@ void KMFilterDlg::slotConfigureShortcutButtonToggled( bool aChecked )
   }
 }
 
-void KMFilterDlg::slotCapturedShortcutChanged( const QKeySequence& ks )
+void KMFilterDlg::slotShortcutChanged( const QKeySequence &newSeq )
 {
-  if ( !ks.isEmpty() && !( kmkernel->getKMMainWidget()->shortcutIsValid( ks ) ) ) {
-    QString msg( i18n( "The selected shortcut is already used, "
-          "please select a different one." ) );
-    KMessageBox::sorry( this, msg );
-  } else {
-    mKeySeqWidget->setKeySequence( ks );
     if ( mFilter )
-      mFilter->setShortcut( KShortcut(ks, QKeySequence()) );
-  }
+    {
+      mKeySeqWidget->applyStealShortcut();
+      mFilter->setShortcut( KShortcut( newSeq ) );
+    }
 }
 
 void KMFilterDlg::slotConfigureToolbarButtonToggled( bool aChecked )
@@ -603,12 +600,12 @@ KMFilterListBox::KMFilterListBox( const QString & title, QWidget *parent,
   mBtnUp = new KPushButton( QString(), hb );
   mBtnUp->setAutoRepeat( true );
   mBtnUp->setIcon( KIcon( "go-up" ) );
-  mBtnUp->setIconSize( QSize( K3Icon::SizeSmall, K3Icon::SizeSmall ) );
+  mBtnUp->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
   mBtnUp->setMinimumSize( mBtnUp->sizeHint() * 1.2 );
   mBtnDown = new KPushButton( QString(), hb );
   mBtnDown->setAutoRepeat( true );
   mBtnDown->setIcon( KIcon( "go-down" ) );
-  mBtnDown->setIconSize( QSize( K3Icon::SizeSmall, K3Icon::SizeSmall ) );
+  mBtnDown->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
   mBtnDown->setMinimumSize( mBtnDown->sizeHint() * 1.2 );
   mBtnUp->setToolTip( i18n("Up") );
   mBtnDown->setToolTip( i18n("Down") );
@@ -622,15 +619,15 @@ KMFilterListBox::KMFilterListBox( const QString & title, QWidget *parent,
   hb->setSpacing(4);
   mBtnNew = new QPushButton( QString(), hb );
   mBtnNew->setIcon( KIcon( "document-new" ) );
-  mBtnNew->setIconSize( QSize( K3Icon::SizeSmall, K3Icon::SizeSmall ) );
+  mBtnNew->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
   mBtnNew->setMinimumSize( mBtnNew->sizeHint() * 1.2 );
   mBtnCopy = new QPushButton( QString(), hb );
   mBtnCopy->setIcon( KIcon( "edit-copy" ) );
-  mBtnCopy->setIconSize( QSize( K3Icon::SizeSmall, K3Icon::SizeSmall ) );
+  mBtnCopy->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
   mBtnCopy->setMinimumSize( mBtnCopy->sizeHint() * 1.2 );
   mBtnDelete = new QPushButton( QString(), hb );
   mBtnDelete->setIcon( KIcon( "edit-delete" ) );
-  mBtnDelete->setIconSize( QSize( K3Icon::SizeSmall, K3Icon::SizeSmall ) );
+  mBtnDelete->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
   mBtnDelete->setMinimumSize( mBtnDelete->sizeHint() * 1.2 );
   mBtnRename = new QPushButton( i18n("Rename..."), hb );
   mBtnNew->setToolTip( i18n("New") );
@@ -675,7 +672,7 @@ KMFilterListBox::~KMFilterListBox()
 
 
 void KMFilterListBox::createFilter( const QByteArray & field,
-				    const QString & value )
+                                    const QString & value )
 {
   KMSearchRule *newRule = KMSearchRule::createInstance( field, KMSearchRule::FuncContains, value );
 
@@ -699,7 +696,7 @@ bool KMFilterListBox::showLaterMsgs()
 void KMFilterListBox::slotUpdateFilterName()
 {
   if ( mIdxSelItem < 0 ) {
-    kDebug(5006) << "KMFilterListBox::slotUpdateFilterName called while no filter is selected, ignoring. idx=" << mIdxSelItem << endl;
+    kDebug(5006) <<"KMFilterListBox::slotUpdateFilterName called while no filter is selected, ignoring. idx=" << mIdxSelItem;
     return;
   }
 
@@ -793,7 +790,7 @@ void KMFilterListBox::slotApplyFilterChanges()
 
 void KMFilterListBox::slotSelected( int aIdx )
 {
-  kDebug(5006) << "KMFilterListBox::slotSelected called. idx=" << aIdx << endl;
+  kDebug(5006) <<"KMFilterListBox::slotSelected called. idx=" << aIdx;
   mIdxSelItem = aIdx;
 
   if ( mIdxSelItem >= 0 && mIdxSelItem < mFilterList.count() ) {
@@ -818,7 +815,7 @@ void KMFilterListBox::slotNew()
 void KMFilterListBox::slotCopy()
 {
   if ( mIdxSelItem < 0 ) {
-    kDebug(5006) << "KMFilterListBox::slotCopy called while no filter is selected, ignoring." << endl;
+    kDebug(5006) <<"KMFilterListBox::slotCopy called while no filter is selected, ignoring.";
     return;
   }
 
@@ -839,7 +836,7 @@ void KMFilterListBox::slotCopy()
 void KMFilterListBox::slotDelete()
 {
   if ( mIdxSelItem < 0 ) {
-    kDebug(5006) << "KMFilterListBox::slotDelete called while no filter is selected, ignoring." << endl;
+    kDebug(5006) <<"KMFilterListBox::slotDelete called while no filter is selected, ignoring.";
     return;
   }
 
@@ -881,11 +878,11 @@ void KMFilterListBox::slotDelete()
 void KMFilterListBox::slotUp()
 {
   if ( mIdxSelItem < 0 ) {
-    kDebug(5006) << "KMFilterListBox::slotUp called while no filter is selected, ignoring." << endl;
+    kDebug(5006) <<"KMFilterListBox::slotUp called while no filter is selected, ignoring.";
     return;
   }
   if ( mIdxSelItem == 0 ) {
-    kDebug(5006) << "KMFilterListBox::slotUp called while the _topmost_ filter is selected, ignoring." << endl;
+    kDebug(5006) <<"KMFilterListBox::slotUp called while the _topmost_ filter is selected, ignoring.";
     return;
   }
 
@@ -896,11 +893,11 @@ void KMFilterListBox::slotUp()
 void KMFilterListBox::slotDown()
 {
   if ( mIdxSelItem < 0 ) {
-    kDebug(5006) << "KMFilterListBox::slotDown called while no filter is selected, ignoring." << endl;
+    kDebug(5006) <<"KMFilterListBox::slotDown called while no filter is selected, ignoring.";
     return;
   }
   if ( mIdxSelItem == (int)mListWidget->count() - 1 ) {
-    kDebug(5006) << "KMFilterListBox::slotDown called while the _last_ filter is selected, ignoring." << endl;
+    kDebug(5006) <<"KMFilterListBox::slotDown called while the _last_ filter is selected, ignoring.";
     return;
   }
 
@@ -911,7 +908,7 @@ void KMFilterListBox::slotDown()
 void KMFilterListBox::slotRename()
 {
   if ( mIdxSelItem < 0 ) {
-    kDebug(5006) << "KMFilterListBox::slotRename called while no filter is selected, ignoring." << endl;
+    kDebug(5006) <<"KMFilterListBox::slotRename called while no filter is selected, ignoring.";
     return;
   }
 
@@ -1192,8 +1189,8 @@ void KMFilterActionWidgetLister::setActionList( QList<KMFilterAction*> *aList )
 
   int superfluousItems = (int)mActionList->count() - mMaxWidgets ;
   if ( superfluousItems > 0 ) {
-    kDebug(5006) << "KMFilterActionWidgetLister: Clipping action list to "
-	      << mMaxWidgets << " items!" << endl;
+    kDebug(5006) <<"KMFilterActionWidgetLister: Clipping action list to"
+	      << mMaxWidgets << "items!";
 
     for ( ; superfluousItems ; superfluousItems-- )
       mActionList->removeLast();
