@@ -80,7 +80,7 @@ KMFolder::KMFolder( KMFolderDir* aParent, const QString& aFolderName,
   dirinfo.setFile( mStorage->location() );
   if ( !dirinfo.exists() ) {
     int rc = mStorage->create();
-    QString msg = i18n("<qt>Error while creating file <b>%1</b>:<br>%2</qt>", aFolderName, strerror(rc));
+    QString msg = i18n("<qt>Error while creating file <b>%1</b>:<br />%2</qt>", aFolderName, strerror(rc));
     if ( rc ) {
       KMessageBox::information(0, msg);
     }
@@ -127,10 +127,13 @@ KMFolder::KMFolder( KMFolderDir* aParent, const QString& aFolderName,
 
   connect( mStorage, SIGNAL( contentsTypeChanged( KMail::FolderContentsType ) ),
                 this, SLOT( slotContentsTypeChanged( KMail::FolderContentsType ) ) );
-  
+
   connect( mStorage, SIGNAL( folderSizeChanged() ),
            this, SLOT( slotFolderSizeChanged() ) );
 
+  connect( kmkernel->identityManager(), SIGNAL( changed() ),
+           this, SLOT( slotIdentitiesChanged() ) );
+
   //FIXME: Centralize all the readConfig calls somehow - Zack
   // Meanwhile, readConfig must be done before registerWithMessageDict, since
   // that one can call writeConfig in some circumstances - David
@@ -174,8 +177,10 @@ void KMFolder::readConfig( KConfigGroup & configGroup )
   mMailingListEnabled = configGroup.readEntry( "MailingListEnabled", false );
   mMailingList.readConfig( configGroup );
 
-  mIdentity = configGroup.readEntry("Identity",
-                        kmkernel->identityManager()->defaultIdentity().uoid() );
+  mUseDefaultIdentity = configGroup.readEntry( "UseDefaultIdentity", true );
+  uint defaultIdentity = kmkernel->identityManager()->defaultIdentity().uoid();
+  mIdentity = configGroup.readEntry("Identity", defaultIdentity );
+  slotIdentitiesChanged();
 
   setUserWhoField( configGroup.readEntry( "WhoField" ), false );
   uint savedId = configGroup.readEntry( "Id" , 0 );
@@ -214,7 +219,8 @@ void KMFolder::writeConfig( KConfigGroup & configGroup ) const
   configGroup.writeEntry("MailingListEnabled", mMailingListEnabled);
   mMailingList.writeConfig( configGroup );
 
-  configGroup.writeEntry("Identity", mIdentity);
+  configGroup.writeEntry( "UseDefaultIdentity", mUseDefaultIdentity );
+  configGroup.writeEntry( "Identity", mIdentity );
 
   configGroup.writeEntry("WhoField", mUserWhoField);
   configGroup.writeEntry("Id", mId);
@@ -514,6 +520,12 @@ void KMFolder::markUnreadAsRead()
 
 void KMFolder::remove()
 {
+  /* The storage needs to be open before remove is called, otherwise
+     it will not unregister the corresponding serial numbers from
+     the message dict, since its message list is empty, and the .ids
+     file contents are not loaded. That can lead to lookups in the
+     dict returning stale pointers to the folder later. */
+  mStorage->open("folderremoval");
   mStorage->remove();
 }
 
@@ -608,6 +620,14 @@ void KMFolder::setMailingList( const MailingList& mlist )
   mStorage->writeConfig();
 }
 
+void KMFolder::setUseDefaultIdentity( bool useDefaultIdentity )
+{
+  mUseDefaultIdentity = useDefaultIdentity;
+  if ( mUseDefaultIdentity )
+    mIdentity = kmkernel->identityManager()->defaultIdentity().uoid();
+  kmkernel->slotRequestConfigSync();
+}
+
 void KMFolder::setIdentity( uint identity )
 {
   mIdentity = identity;
@@ -655,8 +675,7 @@ void KMFolder::setUserWhoField( const QString& whoField, bool writeConfig )
     mWhoField = whoField;
   else {
     // this should not happen...
-    kDebug(5006) << "Illegal setting " << whoField << " for userWhoField!"
-                  << endl;
+    kDebug(5006) <<"Illegal setting" << whoField << "for userWhoField!";
     return; // don't use the value
   }
   mUserWhoField = whoField;
@@ -865,5 +884,21 @@ void KMFolder::slotFolderSizeChanged()
   }
 }
 
+void KMFolder::slotIdentitiesChanged()
+{
+  uint defaultIdentity = kmkernel->identityManager()->defaultIdentity().uoid();
+
+  // The default identity may have changed, therefore set it again
+  // if necessary
+  if ( mUseDefaultIdentity )
+    mIdentity = defaultIdentity;
+
+  // Fall back to the default identity if the one used currently is invalid
+  if ( kmkernel->identityManager()->identityForUoid( mIdentity ).isNull() ) {
+    mIdentity = defaultIdentity;
+    mUseDefaultIdentity = true;
+  }
+}
+
 
 #include "kmfolder.moc"
