@@ -228,7 +228,7 @@ class KMFolderCachedImap : public KMFolderMaildir
 
     /** Reimplemented from KMFolderMaildir */
     virtual int addMsg( KMMessage *msg, int *index_return = 0 );
- 
+
 
     /**
       Adds a message without clearing it's X-UID field.
@@ -359,6 +359,9 @@ class KMFolderCachedImap : public KMFolderMaildir
     /**  \reimp */
     bool isCloseToQuota() const;
 
+    /** Flags that can be permanently stored on the server. */
+    int permanentFlags() const { return mPermanentFlags; }
+
     /**
       Specify an imap path that is used to create the folder on the server
       Otherwise the parent folder is used to construct the path.
@@ -381,6 +384,7 @@ class KMFolderCachedImap : public KMFolderMaildir
     */
     void slotConnectionResult( int errorCode, const QString &errorMsg );
 
+    void slotPermanentFlags( int flags );
     void slotCheckUidValidityResult( KMail::FolderJob *job );
     void slotTestAnnotationResult( KJob *job );
     void slotGetAnnotationResult( KJob *job );
@@ -413,6 +417,7 @@ class KMFolderCachedImap : public KMFolderMaildir
 
     void uploadNewMessages();
     void uploadFlags();
+    void uploadSeenFlags();
     void createNewFolders();
 
     /**
@@ -588,7 +593,7 @@ public slots:
       and not bumped up permaturely, as it is the watermark which is used
       to discern message which are not present locally, because they were
       deleted locally and now need to be deleted from the server,
-      from those which are new and need to be downloaded. Sucessfull
+      from those which are new and need to be downloaded. Successful
       downloading of all pending mail from the server sets this. Between
       invocations it is stored on disk in the uidcache file. It must not
       change during a sync.
@@ -640,6 +645,8 @@ public slots:
 
     QList<KMFolder*> mToBeDeletedAfterRescue;
     int mRescueCommandCount;
+
+  int mPermanentFlags;
 };
 
 #endif /*kmfoldercachedimap_h*/
