@@ -100,7 +100,7 @@ KMFolderDialog::KMFolderDialog(KMFolder *aFolder, KMFolderDir *aFolderDir,
   setObjectName( "KMFolderDialog" );
   setModal( true );
 
-  kDebug(5006)<<"KMFolderDialog::KMFolderDialog()" << endl;
+  kDebug(5006)<<"KMFolderDialog::KMFolderDialog()";
 
   QStringList folderNames;
   QList<QPointer<KMFolder> > folders;
@@ -339,7 +339,7 @@ KMail::FolderDialogGeneralTab::FolderDialogGeneralTab( KMFolderDialog* dlg,
 
     mNormalIconButton = new KIconButton( this );
     mNormalIconLabel->setBuddy( mNormalIconButton );
-    mNormalIconButton->setIconType( K3Icon::NoGroup , K3Icon::Place, false );
+    mNormalIconButton->setIconType( KIconLoader::NoGroup , KIconLoader::Place, false );
     mNormalIconButton->setIconSize( 16 );
     mNormalIconButton->setStrictIconSize( true );
     mNormalIconButton->setFixedSize( 28, 28 );
@@ -354,7 +354,7 @@ KMail::FolderDialogGeneralTab::FolderDialogGeneralTab( KMFolderDialog* dlg,
 
     mUnreadIconButton = new KIconButton( this );
     mUnreadIconLabel->setBuddy( mUnreadIconButton );
-    mUnreadIconButton->setIconType( K3Icon::NoGroup, K3Icon::Place, false );
+    mUnreadIconButton->setIconType( KIconLoader::NoGroup, KIconLoader::Place, false );
     mUnreadIconButton->setIconSize( 16 );
     mUnreadIconButton->setStrictIconSize( true );
     mUnreadIconButton->setFixedSize( 28, 28 );
@@ -434,6 +434,28 @@ KMail::FolderDialogGeneralTab::FolderDialogGeneralTab( KMFolderDialog* dlg,
   gl->setColumnStretch( 1, 100 ); // make the second column use all available space
   int row = -1;
 
+  // sender identity
+  ++row;
+  mUseDefaultIdentityCheckBox = new QCheckBox( i18n("Use &Default Identity"),
+                                               this );
+  gl->addWidget( mUseDefaultIdentityCheckBox );
+  connect( mUseDefaultIdentityCheckBox, SIGNAL( stateChanged(int) ),
+           this, SLOT( slotIdentityCheckboxChanged() ) );
+  ++row;
+  label = new QLabel( i18n("&Sender identity:"), this );
+  gl->addWidget( label, row, 0 );
+  mIdentityComboBox = new KPIMIdentities::IdentityCombo( kmkernel->identityManager(), this );
+  label->setBuddy( mIdentityComboBox );
+  gl->addWidget( mIdentityComboBox, row, 1 );
+  mIdentityComboBox->setWhatsThis(
+      i18n( "Select the sender identity to be used when writing new mail "
+        "or replying to mail in this folder. This means that if you are in "
+        "one of your work folders, you can make KMail use the corresponding "
+        "sender email address, signature and signing or encryption keys "
+        "automatically. Identities can be set up in the main configuration "
+        "dialog. (Settings -> Configure KMail)") );
+
+
   // sender or receiver column?
   ++row;
   QString tip = i18n("Show Sender/Receiver Column in List of Messages");
@@ -454,23 +476,6 @@ KMail::FolderDialogGeneralTab::FolderDialogGeneralTab( KMFolderDialog* dlg,
   else if (whoField == "From") mShowSenderReceiverComboBox->setCurrentIndex(1);
   else if (whoField == "To") mShowSenderReceiverComboBox->setCurrentIndex(2);
 
-
-  // sender identity
-  ++row;
-  label = new QLabel( i18n("&Sender identity:"), this );
-  gl->addWidget( label, row, 0 );
-  mIdentityComboBox = new KPIMIdentities::IdentityCombo( kmkernel->identityManager(), this );
-  label->setBuddy( mIdentityComboBox );
-  gl->addWidget( mIdentityComboBox, row, 1 );
-  mIdentityComboBox->setWhatsThis(
-      i18n( "Select the sender identity to be used when writing new mail "
-        "or replying to mail in this folder. This means that if you are in "
-        "one of your work folders, you can make KMail use the corresponding "
-        "sender email address, signature and signing or encryption keys "
-        "automatically. Identities can be set up in the main configuration "
-        "dialog. (Settings -> Configure KMail)") );
-
-
   // folder contents
   if ( !mIsLocalSystemFolder && kmkernel->iCalIface().isEnabled() ) {
     // Only do make this settable, if the IMAP resource is enabled
@@ -497,7 +502,7 @@ KMail::FolderDialogGeneralTab::FolderDialogGeneralTab( KMFolderDialog* dlg,
   } else {
     mContentsComboBox = 0;
   }
-  
+
   mIncidencesForComboBox = 0;
   mAlarmsBlockedCheckBox = 0;
 
@@ -585,6 +590,8 @@ void FolderDialogGeneralTab::initializeWithValuesFromFolder( KMFolder* folder )
 
   // folder identity
   mIdentityComboBox->setCurrentIdentity( folder->identity() );
+  mUseDefaultIdentityCheckBox->setChecked( folder->useDefaultIdentity() );
+
   // ignore new mail
   mNotifyOnNewMailCheckBox->setChecked( !folder->ignoreNewMail() );
 
@@ -637,11 +644,18 @@ void FolderDialogGeneralTab::slotFolderContentsSelectionChanged( int )
       mAlarmsBlockedCheckBox->setEnabled( enable );
 }
 
+//-----------------------------------------------------------------------------
+void FolderDialogGeneralTab::slotIdentityCheckboxChanged()
+{
+  mIdentityComboBox->setEnabled( !mUseDefaultIdentityCheckBox->isChecked() );
+}
+
 //-----------------------------------------------------------------------------
 bool FolderDialogGeneralTab::save()
 {
   KMFolder* folder = mDlg->folder();
   folder->setIdentity( mIdentityComboBox->currentIdentity() );
+  folder->setUseDefaultIdentity( mUseDefaultIdentityCheckBox->isChecked() );
   // set whoField
   if (mShowSenderReceiverComboBox->currentIndex() == 1)
     folder->setUserWhoField("From");
@@ -752,7 +766,9 @@ KMail::FolderDialogTemplatesTab::FolderDialogTemplatesTab( KMFolderDialog *dlg,
        mDlg->folder()->folderType() != KMFolderTypeImap &&
        mDlg->folder()->folderType() != KMFolderTypeCachedImap;
 
-  QVBoxLayout *topLayout = new QVBoxLayout( this, 0, KDialog::spacingHint() );
+  QVBoxLayout *topLayout = new QVBoxLayout( this );
+  topLayout->setMargin( 0 );
+  topLayout->setSpacing( KDialog::spacingHint() );
 
   mCustom = new QCheckBox( i18n("&Use custom message templates"), this );
   topLayout->addWidget( mCustom );
@@ -761,10 +777,12 @@ KMail::FolderDialogTemplatesTab::FolderDialogTemplatesTab( KMFolderDialog *dlg,
   mWidget->setEnabled( false );
   topLayout->addWidget( mWidget );
 
-  QHBoxLayout *btns = new QHBoxLayout( topLayout, KDialog::spacingHint() );
+  QHBoxLayout *btns = new QHBoxLayout();
+  btns->setSpacing( KDialog::spacingHint() );
   mCopyGlobal = new KPushButton( i18n("&Copy Global Templates"), this );
   mCopyGlobal->setEnabled( false );
   btns->addWidget( mCopyGlobal );
+  topLayout->addLayout( btns );
 
   connect( mCustom, SIGNAL(toggled(bool)),
         mWidget, SLOT(setEnabled(bool)) );
@@ -810,7 +828,7 @@ bool FolderDialogTemplatesTab::save()
   QString fid = folder->idString();
   Templates t(fid);
 
-  kDebug(5006) << "use custom templates for folder " << fid << ": " << mCustom->isChecked() << endl;
+  kDebug(5006) <<"use custom templates for folder" << fid <<":" << mCustom->isChecked();
   t.setUseCustomTemplates(mCustom->isChecked());
   t.writeConfig();
 
