@@ -22,8 +22,6 @@
  */
 
 #include "kmfolderimap.h"
-
-
 #include "kmfolder.h"
 #include "kmfoldermbox.h"
 #include "kmfoldertree.h"
@@ -31,7 +29,6 @@
 #include "undostack.h"
 #include "kmfoldermgr.h"
 #include "kmfiltermgr.h"
-#include "kmmsgdict.h"
 #include "imapaccountbase.h"
 using KMail::ImapAccountBase;
 #include "imapjob.h"
@@ -64,7 +61,8 @@ using KMail::RenameJob;
 #include <assert.h>
 
 KMFolderImap::KMFolderImap(KMFolder* folder, const char* aName)
-  : KMFolderMbox(folder, aName)
+  : KMFolderMbox(folder, aName),
+    mUploadAllFlags( false )
 {
   mContentState = imapNoInformation;
   mSubfolderState = imapNoInformation;
@@ -114,9 +112,9 @@ void KMFolderImap::close( const char *owner, bool aForced )
     mOpenCount--;
   }
   if ( mOpenCount == 0 && isSelected() && !aForced ) {
-    kWarning(5006) << "Trying to close the selected folder " << label()
-                   << " - ignoring! " << endl;
-//                   << " - ignoring! " << kBacktrace() << endl;
+    kWarning(5006) <<"Trying to close the selected folder" << label()
+                   << "- ignoring!";
+//                   << "- ignoring!" << kBacktrace();
     mOpenCount++;
     abort();
     return;
@@ -180,12 +178,12 @@ KMAcctImap* KMFolderImap::account() const
   if ( !mAccount ) {
     KMFolderDir *parentFolderDir = dynamic_cast<KMFolderDir*>( folder()->parent() );
     if ( !parentFolderDir ) {
-      kWarning() << k_funcinfo << "No parent folder dir found for " << folder()->prettyUrl() << endl;
+      kWarning(5006) <<"No parent folder dir found for" << folder()->prettyUrl();
       return 0;
     }
     KMFolder *parentFolder = parentFolderDir->owner();
     if ( !parentFolder ) {
-      kWarning() << k_funcinfo << "No parent folder found for " << folder()->prettyUrl() << endl;
+      kWarning(5006) <<"No parent folder found for" << folder()->prettyUrl();
       return 0;
     }
     KMFolderImap *parentStorage = dynamic_cast<KMFolderImap*>( parentFolder->storage() );
@@ -226,6 +224,8 @@ void KMFolderImap::readConfig()
   }
   mNoContent = group.readEntry( "NoContent", false );
   mReadOnly = group.readEntry( "ReadOnly", false );
+  mUploadAllFlags = group.readEntry( "UploadAllFlags", true );
+  mPermanentFlags = group.readEntry( "PermanentFlags", 31 /* default flags */ );
 
   KMFolderMbox::readConfig();
 }
@@ -240,6 +240,8 @@ void KMFolderImap::writeConfig()
   group.writeEntry("ImapPath", mImapPath);
   group.writeEntry("NoContent", mNoContent);
   group.writeEntry("ReadOnly", mReadOnly);
+  group.writeEntry( "UploadAllFlags", mUploadAllFlags );
+  group.writeEntry( "PermanentFlags", mPermanentFlags );
   KMFolderMbox::writeConfig();
 }
 
@@ -260,7 +262,7 @@ void KMFolderImap::remove()
     emit removed(folder(), false);
     return;
   }
-  KIO::SimpleJob *job = KIO::file_delete(url, false);
+  KIO::SimpleJob *job = KIO::file_delete(url, KIO::HideProgressInfo);
   KIO::Scheduler::assignJobToSlave(account()->slave(), job);
   ImapAccountBase::jobData jd(url.url());
   jd.progressItem = ProgressManager::createProgressItem(
@@ -350,7 +352,7 @@ void KMFolderImap::addMsgQuiet(KMMessage* aMsg)
     assert( idx != -1 );
     aFolder->take( idx );
   } else {
-    kDebug(5006) << k_funcinfo << "no parent" << endl;
+    kDebug(5006) <<"no parent";
   }
   if ( !account()->hasCapability("uidplus") ) {
     // Remember the status with the MD5 as key
@@ -394,7 +396,7 @@ void KMFolderImap::addMsgQuiet(QList<KMMessage*> msgList)
   if ( aFolder ) {
     aFolder->take( msgList );
   } else {
-    kDebug(5006) << k_funcinfo << "no parent" << endl;
+    kDebug(5006) <<"no parent";
   }
   while ( !msgList.empty() )
     msgList.takeFirst();
@@ -463,7 +465,7 @@ int KMFolderImap::addMsg(QList<KMMessage*>& msgList, QList<int>& aIndex_ret)
           {
             // we need the messages that belong to the current set to pass them to the ImapJob
             QList<KMMessage*> temp_msgs = splitMessageList(*it, msgList);
-            if ( temp_msgs.isEmpty() ) kDebug(5006) << "Wow! KMFolderImap::splitMessageList() returned an empty list!" << endl;
+            if ( temp_msgs.isEmpty() ) kDebug(5006) <<"Wow! KMFolderImap::splitMessageList() returned an empty list!";
             imapJob = new ImapJob(temp_msgs, *it, ImapJob::tMoveMessage, this);
             connect(imapJob, SIGNAL(messageCopied(QList<KMMessage*>)),
                 SLOT(addMsgQuiet(QList<KMMessage*>)));
@@ -531,7 +533,7 @@ int KMFolderImap::addMsg(QList<KMMessage*>& msgList, QList<int>& aIndex_ret)
 //-----------------------------------------------------------------------------
 void KMFolderImap::slotCopyMsgResult( KMail::FolderJob* job )
 {
-  kDebug(5006) << k_funcinfo << job->error() << endl;
+  kDebug(5006) << job->error();
   if ( job->error() ) // getFolder() will not be called in this case
     emit folderComplete( this, false );
 }
@@ -628,17 +630,17 @@ void KMFolderImap::slotListNamespaces()
       this, SLOT( slotListNamespaces() ) );
   if ( account()->makeConnection() == ImapAccountBase::Error )
   {
-    kWarning(5006) << "slotListNamespaces - got no connection" << endl;
+    kWarning(5006) <<"slotListNamespaces - got no connection";
     return;
   } else if ( account()->makeConnection() == ImapAccountBase::Connecting )
   {
     // wait for the connectionResult
-    kDebug(5006) << "slotListNamespaces - waiting for connection" << endl;
+    kDebug(5006) <<"slotListNamespaces - waiting for connection";
     connect( account(), SIGNAL( connectionResult(int, const QString&) ),
         this, SLOT( slotListNamespaces() ) );
     return;
   }
-  kDebug(5006) << "slotListNamespaces" << endl;
+  kDebug(5006) <<"slotListNamespaces";
   // reset subfolder states recursively
   setSubfolderState( imapNoInformation );
   mSubfolderState = imapListingInProgress;
@@ -684,8 +686,8 @@ void KMFolderImap::slotCheckNamespace( const QStringList& subfolderNames,
                                        const QStringList& subfolderAttributes,
                                        const ImapAccountBase::jobData& jobData )
 {
-  kDebug(5006) << "slotCheckNamespace - " << subfolderNames.join(",") << endl;
-  kDebug(5006) << "slotCheckNamespace - " << jobData.path << endl;
+  kDebug(5006) <<"slotCheckNamespace -" << subfolderNames.join(",");
+  kDebug(5006) <<"slotCheckNamespace -" << jobData.path;
 
   // get a correct foldername:
   // strip / and make sure it does not contain the delimiter
@@ -714,7 +716,7 @@ void KMFolderImap::slotCheckNamespace( const QStringList& subfolderNames,
   }
   if ( subfolderNames.isEmpty() ) {
     if ( node ) {
-      kDebug(5006) << "delete namespace folder " << name << endl;
+      kDebug(5006) <<"delete namespace folder" << name;
       KMFolder *fld = static_cast<KMFolder*>(node);
       KMFolderImap* nsFolder = static_cast<KMFolderImap*>(fld->storage());
       nsFolder->setAlreadyRemoved( true );
@@ -723,7 +725,7 @@ void KMFolderImap::slotCheckNamespace( const QStringList& subfolderNames,
   } else {
     if ( node ) {
       // folder exists so pass on the attributes
-      kDebug(5006) << "found namespace folder " << name << endl;
+      kDebug(5006) <<"found namespace folder" << name;
       if ( !account()->listOnlyOpenFolders() ) {
         KMFolderImap* nsFolder =
           static_cast<KMFolderImap*>(static_cast<KMFolder*>(node)->storage());
@@ -732,7 +734,7 @@ void KMFolderImap::slotCheckNamespace( const QStringList& subfolderNames,
       }
     } else {
       // create folder
-      kDebug(5006) << "create namespace folder " << name << endl;
+      kDebug(5006) <<"create namespace folder" << name;
       KMFolder *fld = folder()->child()->createFolder( name );
       if ( fld ) {
         KMFolderImap* f = static_cast<KMFolderImap*> ( fld->storage() );
@@ -754,7 +756,7 @@ bool KMFolderImap::listDirectory()
   if ( !account() ||
        ( account() && account()->makeConnection() == ImapAccountBase::Error ) )
   {
-    kDebug(5006) << "KMFolderImap::listDirectory - got no connection" << endl;
+    kDebug(5006) <<"KMFolderImap::listDirectory - got no connection";
     return false;
   }
 
@@ -791,11 +793,11 @@ void KMFolderImap::slotListResult( const QStringList& subfolderNames,
                                    const ImapAccountBase::jobData& jobData )
 {
   mSubfolderState = imapFinished;
-  //kDebug(5006) << label() << ": folderNames=" << subfolderNames << " folderPaths="
-  //<< subfolderPaths << " mimeTypes=" << subfolderMimeTypes << endl;
+  //kDebug(5006) << label() <<": folderNames=" << subfolderNames <<" folderPaths="
+  //<< subfolderPaths << "mimeTypes=" << subfolderMimeTypes;
   if ( account() == 0 ) {
       // if we don't have an account here, something is very wrong
-      kWarning(5006) << "No account set on folder: " << folder()->prettyUrl();
+      kWarning(5006) <<"No account set on folder:" << folder()->prettyUrl();
       return;
   }
   // don't react on changes
@@ -817,8 +819,8 @@ void KMFolderImap::slotListResult( const QStringList& subfolderNames,
     KMFolderImap* parent = findParent( subfolderPaths.first(), subfolderNames.first() );
     if ( parent )
     {
-      kDebug(5006) << "KMFolderImap::slotListResult - pass listing to "
-        << parent->label() << endl;
+      kDebug(5006) <<"KMFolderImap::slotListResult - pass listing to"
+        << parent->label();
       parent->slotListResult( subfolderNames, subfolderPaths,
           subfolderMimeTypes, subfolderAttributes, jobData );
       // cleanup
@@ -862,13 +864,13 @@ void KMFolderImap::slotListResult( const QStringList& subfolderNames,
     }
     else if ( subfolderPaths[i].toUpper() != "/INBOX/" )
     {
-      kDebug(5006) << "create folder " << subfolderNames[i] << endl;
+      kDebug(5006) <<"create folder" << subfolderNames[i];
       KMFolder *fld = folder()->child()->createFolder(subfolderNames[i]);
       if ( fld ) {
         f = static_cast<KMFolderImap*> ( fld->storage() );
         settingsChanged = true;
       } else {
-        kWarning(5006) << "can't create folder " << subfolderNames[i] << endl;
+        kWarning(5006) <<"can't create folder" << subfolderNames[i];
       }
     }
     if ( f ) {
@@ -901,7 +903,7 @@ void KMFolderImap::slotListResult( const QStringList& subfolderNames,
         f->listDirectory();
       }
     } else {
-      kWarning(5006) << "can't find folder " << subfolderNames[i] << endl;
+      kWarning(5006) <<"can't find folder" << subfolderNames[i];
     }
   } // for subfolders
 
@@ -994,8 +996,8 @@ void KMFolderImap::checkFolders( const QStringList& subfolderNames,
       // that the folder is within the current namespace
       bool isInNamespace = ( myNamespace.isEmpty() ||
           myNamespace == account()->namespaceForFolder( imapFld ) );
-      kDebug(5006) << node->name() << " in namespace " << myNamespace << ":" <<
-        isInNamespace << endl;
+      kDebug(5006) << node->name() <<"in namespace" << myNamespace <<":" <<
+        isInNamespace;
       // ignore some cases
       QString name = node->name();
       bool ignore = ( ( this == account()->rootFolder() ) &&
@@ -1009,11 +1011,11 @@ void KMFolderImap::checkFolders( const QStringList& subfolderNames,
       if ( !ignore )
       {
         // remove the folder without server round trip
-        kDebug(5006) << "checkFolders - " << node->name() << " disappeared" << endl;
+        kDebug(5006) <<"checkFolders -" << node->name() <<" disappeared";
         imapFld->setAlreadyRemoved( true );
         toRemove.append( fld );
       } else {
-        kDebug(5006) << "checkFolders - " << node->name() << " ignored" << endl;
+        kDebug(5006) <<"checkFolders -" << node->name() <<" ignored";
       }
     }
   }
@@ -1064,7 +1066,7 @@ void KMFolderImap::checkValidity()
   }
   KUrl url = account()->getUrl();
   url.setPath( imapPath() + ";UID=0:0" );
-  kDebug(5006) << "KMFolderImap::checkValidity of: " << imapPath() << endl;
+  kDebug(5006) <<"KMFolderImap::checkValidity of:" << imapPath();
 
   // Start with a clean slate
   disconnect( account(), SIGNAL( connectionResult(int, const QString&) ),
@@ -1072,21 +1074,21 @@ void KMFolderImap::checkValidity()
 
   KMAcctImap::ConnectionState connectionState = account()->makeConnection();
   if ( connectionState == ImapAccountBase::Error ) {
-    kDebug(5006) << "KMFolderImap::checkValidity - got no connection" << endl;
+    kDebug(5006) <<"KMFolderImap::checkValidity - got no connection";
     emit folderComplete(this, false);
     mContentState = imapNoInformation;
     return;
   } else if ( connectionState == ImapAccountBase::Connecting ) {
     // We'll wait for the connectionResult signal from the account. If it
     // errors, the above will catch it.
-    kDebug(5006) << "CheckValidity - waiting for connection" << endl;
+    kDebug(5006) <<"CheckValidity - waiting for connection";
     connect( account(), SIGNAL( connectionResult(int, const QString&) ),
         this, SLOT( checkValidity() ) );
     return;
   }
   // Only check once at a time.
   if ( mCheckingValidity ) {
-    kDebug(5006) << "KMFolderImap::checkValidity - already checking" << endl;
+    kDebug(5006) <<"KMFolderImap::checkValidity - already checking";
     return;
   }
   // otherwise we already are inside a mailcheck
@@ -1108,7 +1110,7 @@ void KMFolderImap::checkValidity()
   }
   open( "checkvalidity" );
   ImapAccountBase::jobData jd( url.url() );
-  KIO::SimpleJob *job = KIO::get( url, false, false );
+  KIO::SimpleJob *job = KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
   KIO::Scheduler::assignJobToSlave( account()->slave(), job );
   account()->insertJob( job, jd );
   connect( job, SIGNAL( result( KJob * ) ),
@@ -1142,8 +1144,7 @@ void KMFolderImap::slotCheckValidityResult( KJob *job )
     return;
   }
 
-  kDebug(5006) << "KMFolderImap::slotCheckValidityResult of: " << fileName()
-               << endl;
+  kDebug(5006) <<"KMFolderImap::slotCheckValidityResult of:" << fileName();
 
   mCheckingValidity = false;
   ImapAccountBase::JobIterator it
@@ -1161,7 +1162,7 @@ void KMFolderImap::slotCheckValidityResult( KJob *job )
         static_cast<KIO::Job*>(job),
         i18n("Error while querying the server status.") );
     }
-    kDebug(5006) << "error in slotCheckValidityResult\n";
+    kDebug(5006) <<"error in slotCheckValidityResult";
     mContentState = imapNoInformation;
     emit folderComplete( this, false );
     close( "checkvalidity" );
@@ -1186,12 +1187,17 @@ void KMFolderImap::slotCheckValidityResult( KJob *job )
     if ( (b - a - 9) >= 0 )
       exists = cstr.mid(a + 9, b - a - 9).toInt(&ok);
     if ( !ok ) exists = -1;
+    a = cstr.indexOf( "X-PermanentFlags: " );
+    b = cstr.indexOf( "\r\n", a );
+    if ( a >= 0 && (b - a - 18) >= 0 )
+      mPermanentFlags = cstr.mid( a + 18, b - a - 18 ).toInt(&ok);
+    if ( !ok ) mPermanentFlags = 0;
     QString startUid;
     if (uidValidity() != uidv)
     {
       // uidValidity changed
-      kDebug(5006) << k_funcinfo << "uidValidty changed from "
-       << uidValidity() << " to " << uidv << endl;
+      kDebug(5006) <<"uidValidty changed from"
+       << uidValidity() << "to" << uidv;
       if ( !uidValidity().isEmpty() )
       {
         account()->ignoreJobsForFolder( folder() );
@@ -1245,13 +1251,13 @@ void KMFolderImap::getFolder( bool force )
 {
   mGuessedUnreadMsgs = -1;
   if ( mNoContent ) {
-    kDebug(5006) << "getFolder " << force << " " << mContentState << endl;
+    kDebug(5006) <<"getFolder" << force << mContentState;
     mContentState = imapFinished;
     emit folderComplete(this, true);
     return;
   }
   open( "getfolder" );
-  kDebug(5006) << "getFolder2 " << force << " " << mContentState << endl;
+  kDebug(5006) <<"getFolder2" << force  << mContentState;
   mContentState = imapListingInProgress;
   if ( force ) {
     // force an update
@@ -1264,7 +1270,7 @@ void KMFolderImap::getFolder( bool force )
 //-----------------------------------------------------------------------------
 void KMFolderImap::reallyGetFolder( const QString &startUid )
 {
-  kDebug(5006) << "reallyGetFolder " << startUid << endl;
+  kDebug(5006) <<"reallyGetFolder" << startUid;
   KUrl url = account()->getUrl();
   if ( account()->makeConnection() != ImapAccountBase::Connected ) {
     mContentState = imapNoInformation;
@@ -1277,13 +1283,13 @@ void KMFolderImap::reallyGetFolder( const QString &startUid )
       mMailCheckProgressItem->setStatus( i18n("Retrieving message status") );
     }
     url.setPath( imapPath() + ";SECTION=UID FLAGS" );
-    KIO::SimpleJob *job = KIO::listDir( url, false );
+    KIO::SimpleJob *job = KIO::listDir( url, KIO::HideProgressInfo );
     open( "listfolder" );
     KIO::Scheduler::assignJobToSlave( account()->slave(), job );
     ImapAccountBase::jobData jd( url.url(), folder() );
     jd.cancellable = true;
     account()->insertJob( job, jd );
-    kDebug(5006) << "listDir " << url << " " << job << endl;
+    kDebug(5006) <<"listDir" << url  << job;
     connect( job, SIGNAL( result( KJob * ) ),
              this, SLOT( slotListFolderResult( KJob * ) ) );
     connect( job, SIGNAL( entries( KIO::Job *, const KIO::UDSEntryList & ) ),
@@ -1295,8 +1301,8 @@ void KMFolderImap::reallyGetFolder( const QString &startUid )
       mMailCheckProgressItem->setStatus( i18n("Retrieving messages") );
     }
     url.setPath( imapPath() + ";UID=" + startUid + ":*;SECTION=ENVELOPE" );
-    kDebug(5006) << folder()->name() << " download " << url << endl;
-    KIO::SimpleJob *newJob = KIO::get( url, false, false );
+    kDebug(5006) << folder()->name() <<" download" << url;
+    KIO::SimpleJob *newJob = KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
     KIO::Scheduler::assignJobToSlave( account()->slave(), newJob );
     ImapAccountBase::jobData jd( url.url(), folder() );
     jd.cancellable = true;
@@ -1312,7 +1318,7 @@ void KMFolderImap::reallyGetFolder( const QString &startUid )
 //-----------------------------------------------------------------------------
 void KMFolderImap::slotListFolderResult( KJob *job )
 {
-  kDebug(5006) << "slotListFolderResult " << job << " " << job->error() << endl;
+  kDebug(5006) <<"slotListFolderResult" << job  << job->error();
   ImapAccountBase::JobIterator it =
     account()->findJob( static_cast<KIO::Job*>( job ) );
   if ( it == account()->jobsEnd() ) {
@@ -1356,7 +1362,9 @@ void KMFolderImap::slotListFolderResult( KJob *job )
         // server since we can't write our status back our local version
         // is what has to be considered correct.
         if ( !mReadOnly ) {
-          flagsToStatus( msgBase, serverFlags, false );
+          flagsToStatus( msgBase, serverFlags, false, mUploadAllFlags ? 31 : mPermanentFlags );
+        } else {
+          seenFlagToStatus( msgBase, serverFlags, false );
         }
         idx++;
         uid = (*it).items.erase( uid );
@@ -1413,8 +1421,8 @@ void KMFolderImap::slotListFolderResult( KJob *job )
     mContentState = imapDownloadInProgress;
     KUrl url = account()->getUrl();
     url.setPath( imapPath() + ";UID=" + *i + ";SECTION=ENVELOPE" );
-    KIO::SimpleJob *newJob = KIO::get( url, false, false );
-    kDebug(5006) << folder()->name() << " download " << url << endl;
+    KIO::SimpleJob *newJob = KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
+    kDebug(5006) << folder()->name() <<" download" << url;
     jd.url = url.url();
     KIO::Scheduler::assignJobToSlave( account()->slave(), newJob );
     account()->insertJob( newJob, jd );
@@ -1454,34 +1462,61 @@ void KMFolderImap::slotListFolderEntries( KIO::Job *job,
 
 
 //-----------------------------------------------------------------------------
-void KMFolderImap::flagsToStatus(KMMsgBase *msg, int flags, bool newMsg)
+void KMFolderImap::flagsToStatus(KMMsgBase *msg, int flags, bool newMsg, int supportedFlags )
 {
-  MessageStatus status;
-
   if ( !msg ) return;
 
-  if (flags & 4)
-    status.setImportant();
-  if (flags & 2)
-    status.setReplied();
-  if (flags & 1)
-    status.setOld();
+  // see imap4/imapinfo.h for the magic numbers
+  static const struct {
+    const int imapFlag;
+    const KPIM::MessageStatus kmFlag;
+    const bool standardFlag;
+  } imapFlagMap[] = {
+    { 2, KPIM::MessageStatus::statusReplied(), true },
+    { 4, KPIM::MessageStatus::statusImportant(), true },
+    { 128, KPIM::MessageStatus::statusForwarded(), false },
+    { 256, KPIM::MessageStatus::statusTodo(), false },
+    { 512, KPIM::MessageStatus::statusWatched(), false },
+    { 1024, KPIM::MessageStatus::statusIgnored(), false }
+  };
+  static const int numFlags = sizeof imapFlagMap / sizeof *imapFlagMap;
+
+  const KPIM::MessageStatus oldStatus = msg->status();
+  for ( int i = 0; i < numFlags; ++i ) {
+    if ( ( (supportedFlags & imapFlagMap[i].imapFlag) == 0 && (supportedFlags & 64) == 0 )
+         && !imapFlagMap[i].standardFlag ) {
+      continue;
+    }
+    if ( ((flags & imapFlagMap[i].imapFlag) > 0) != (oldStatus & imapFlagMap[i].kmFlag) ) {
+      msg->toggleStatus( imapFlagMap[i].kmFlag );
+    }
+  }
+
+  seenFlagToStatus( msg, flags, newMsg );
+}
+
+void KMFolderImap::seenFlagToStatus(KMMsgBase * msg, int flags, bool newMsg)
+{
+  if ( !msg ) return;
+
+  const KPIM::MessageStatus oldStatus = msg->status();
+  if ( (flags & 1) && oldStatus.isOld() )
+    msg->status().setOld();
 
   // In case the message does not have the seen flag set, override our local
   // notion that it is read. Otherwise the count of unread messages and the
   // number of messages which actually show up as read can go out of sync.
-  if ( ( msg->status().isOfUnknownStatus() ) || !(flags&1) ) {
+  if ( ( msg->status().isOfUnknownStatus() ) || (!(flags&1) && !msg->status().isNew() && !msg->status().isUnread() ) ) {
     if (newMsg)
-      status.setNew();
+      msg->status().setNew();
     else
-      status.setUnread();
+      msg->status().setUnread();
   }
-  msg->setStatus( status );
 }
 
 
 //-----------------------------------------------------------------------------
-QString KMFolderImap::statusToFlags( const MessageStatus& status )
+QString KMFolderImap::statusToFlags( const MessageStatus& status, int supportedFlags )
 {
   QString flags;
   if ( status.isDeleted() )
@@ -1492,7 +1527,16 @@ QString KMFolderImap::statusToFlags( const MessageStatus& status )
     if ( status.isReplied() )
       flags += "\\ANSWERED ";
     if ( status.isImportant() )
-      flags += "\\FLAGGED";
+      flags += "\\FLAGGED ";
+    // non standard flags
+    if ( status.isForwarded() && ((supportedFlags & 64) || (supportedFlags & 128)) )
+      flags += "$FORWARDED ";
+    if ( status.isTodo() && ((supportedFlags & 64) || (supportedFlags & 256)) )
+      flags += "$TODO ";
+    if ( status.isWatched() && ((supportedFlags & 64) || (supportedFlags & 512)) )
+      flags += "$WATCHED ";
+    if ( status.isIgnored() && ((supportedFlags & 64) || (supportedFlags & 1024)) )
+      flags += "$IGNORED ";
   }
 
   return flags.simplified();
@@ -1542,8 +1586,8 @@ void KMFolderImap::slotGetMessagesData( KIO::Job *job, const QByteArray &data )
         (*it).cdata.mid(
           c+10, (*it).cdata.indexOf( "\r\n", c+1 ) - c - 10 ).toInt( &ok );
       if ( ok && exists < count() ) {
-        kDebug(5006) << "KMFolderImap::slotGetMessagesData - server has less messages (" <<
-          exists << ") then folder (" << count() << "), so reload" << endl;
+        kDebug(5006) <<"KMFolderImap::slotGetMessagesData - server has less messages (" <<
+          exists << ") then folder (" << count() << "), so reload";
         open( "getMessage" );
         reallyGetFolder( QString() );
         (*it).cdata.remove( 0, pos );
@@ -1611,7 +1655,7 @@ void KMFolderImap::slotGetMessagesData( KIO::Job *job, const QByteArray &data )
         }
         KMFolderMbox::addMsg(msg, 0);
         // Merge with the flags from the server.
-        flagsToStatus((KMMsgBase*)msg, flags);
+        flagsToStatus((KMMsgBase*)msg, flags, true, mUploadAllFlags ? 31 : mPermanentFlags);
         // set the correct size
         msg->setMsgSizeServer( msg->headerField("X-Length").toUInt() );
         msg->setUID(uid);
@@ -1688,8 +1732,8 @@ KMFolderImap::doCreateJob( QList<KMMessage*>& msgList, const QString& sets,
 //-----------------------------------------------------------------------------
 void KMFolderImap::getMessagesResult( KIO::Job *job, bool lastSet )
 {
-  kDebug(5006) << "getMessagesResult " << job << " " << job->error()
-               << " " << lastSet << endl;
+  kDebug(5006) <<"getMessagesResult" << job << job->error()
+               << lastSet;
   ImapAccountBase::JobIterator it = account()->findJob( job );
   if ( it == account()->jobsEnd() ) {
     return;
@@ -1723,10 +1767,10 @@ void KMFolderImap::slotGetMessagesResult(KJob * job)
 void KMFolderImap::createFolder(const QString &name, const QString& parentPath,
                                 bool askUser)
 {
-  kDebug(5006) << "KMFolderImap::createFolder - name=" << name << ",parent=" <<
-    parentPath << ",askUser=" << askUser << endl;
+  kDebug(5006) <<"KMFolderImap::createFolder - name=" << name <<",parent=" <<
+    parentPath << ",askUser=" << askUser;
   if ( account()->makeConnection() != ImapAccountBase::Connected ) {
-    kWarning(5006) << "KMFolderImap::createFolder - got no connection" << endl;
+    kWarning(5006) <<"KMFolderImap::createFolder - got no connection";
     return;
   }
   KUrl url = account()->getUrl();
@@ -1784,7 +1828,7 @@ QString KMFolderImap::encodeFileName(const QString &name)
 //-----------------------------------------------------------------------------
 QString KMFolderImap::decodeFileName(const QString &name)
 {
-  return KIMAP::decodeImapFolderName(name); 
+  return KIMAP::decodeImapFolderName(name);
 }
 
 //-----------------------------------------------------------------------------
@@ -1821,14 +1865,14 @@ void KMFolderImap::deleteMessage(KMMessage * msg)
      folder, so we better safeguard against that. See ::expungeFolder, as
      to why. :( */
   if ( uid == 0 ) {
-     kDebug( 5006 ) << "KMFolderImap::deleteMessage: Attempt to delete "
-                        "an empty UID. Aborting."  << endl;
+     kDebug( 5006 ) <<"KMFolderImap::deleteMessage: Attempt to delete"
+                        "an empty UID. Aborting.";
      return;
   }
   url.setPath(msg_parent->imapPath() + ";UID=" + QString::number(uid) );
   if ( account()->makeConnection() != ImapAccountBase::Connected )
     return;
-  KIO::SimpleJob *job = KIO::file_delete(url, false);
+  KIO::SimpleJob *job = KIO::file_delete(url, KIO::HideProgressInfo);
   KIO::Scheduler::assignJobToSlave(account()->slave(), job);
   ImapAccountBase::jobData jd( url.url(), 0 );
   account()->insertJob(job, jd);
@@ -1861,7 +1905,7 @@ void KMFolderImap::deleteMessage(const QList<KMMessage*>& msgList)
     url.setPath(msg_parent->imapPath() + ";UID=" + uid);
     if ( account()->makeConnection() != ImapAccountBase::Connected )
       return;
-    KIO::SimpleJob *job = KIO::file_delete(url, false);
+    KIO::SimpleJob *job = KIO::file_delete(url, KIO::HideProgressInfo);
     KIO::Scheduler::assignJobToSlave(account()->slave(), job);
     ImapAccountBase::jobData jd( url.url(), 0 );
     account()->insertJob(job, jd);
@@ -1878,13 +1922,20 @@ void KMFolderImap::setStatus( int idx,
   setStatus( ids, status, toggle );
 }
 
-void KMFolderImap::setStatus( QList<int> &ids,
+void KMFolderImap::setStatus( QList<int> &_ids,
                               const MessageStatus &status, bool toggle )
 {
   open( "setstatus" );
-  FolderStorage::setStatus( ids, status, toggle );
-  if ( mReadOnly ) {
-    return;
+  FolderStorage::setStatus(_ids, status, toggle);
+  QList<int> ids;
+  if ( mUploadAllFlags ) {
+    kDebug(5006) << "Migrating all flags to the server";
+    ids.clear();
+    for ( int i = 0; i < count(); ++i )
+      ids << i;
+    mUploadAllFlags = false;
+  } else {
+    ids = _ids;
   }
 
   /* The status has been already set in the local index. Update the flags on
@@ -1901,6 +1952,39 @@ void KMFolderImap::setStatus( QList<int> &ids,
    *   Build sets for each of those and sort them, so the server can handle
    *   them efficiently.
    */
+
+  if ( mReadOnly ) { // mUserRights is not available here
+    // FIXME duplicated code in KMFolderCachedImap
+    QList<ulong> seenUids, unseenUids;
+    for ( QList<int>::ConstIterator it = ids.constBegin(); it != ids.constEnd(); ++it ) {
+      KMMessage *msg = 0;
+      bool unget = !isMessage(*it);
+      msg = getMsg(*it);
+      if (!msg) continue;
+      if ( msg->status().isOld() || msg->status().isRead() )
+        seenUids.append( msg->UID() );
+      else
+        unseenUids.append( msg->UID() );
+      if (unget) unGetMsg(*it);
+    }
+    if ( !seenUids.isEmpty() ) {
+      QStringList sets = KMFolderImap::makeSets( seenUids, true );
+      for( QStringList::Iterator it = sets.begin(); it != sets.end(); ++it ) {
+        QString imappath = imapPath() + ";UID=" + ( *it );
+        account()->setImapSeenStatus( folder(), imappath, true );
+      }
+    }
+    if ( !unseenUids.isEmpty() ) {
+      QStringList sets = KMFolderImap::makeSets( unseenUids, true );
+      for( QStringList::Iterator it = sets.begin(); it != sets.end(); ++it ) {
+        QString imappath = imapPath() + ";UID=" + ( *it );
+        account()->setImapSeenStatus( folder(), imappath, false );
+      }
+    }
+    close( "setstatus" );
+    return;
+  }
+
   QMap< QString, QStringList > groups;
   for ( QList<int>::Iterator it = ids.begin(); it != ids.end(); ++it ) {
     KMMessage *msg = 0;
@@ -1909,7 +1993,7 @@ void KMFolderImap::setStatus( QList<int> &ids,
     if ( !msg ) {
       continue;
     }
-    QString flags = statusToFlags( msg->status() );
+    QString flags = statusToFlags( msg->status(), mPermanentFlags );
     // Collect uids for each type of flags.
     groups[flags].append( QString::number( msg->UID() ) );
     if ( unget ) {
@@ -1927,13 +2011,13 @@ void KMFolderImap::setStatus( QList<int> &ids,
        account()->setImapStatus(folder(), imappath, flags);
      }
   }
-  kDebug(5006) << folder()->name() << " setStatus " << mContentState << endl;
+  kDebug(5006) << folder()->name() <<" setStatus" << mContentState;
   if ( mContentState == imapListingInProgress ) {
     // we're currently get'ing this folder
     // to make sure that we get the latest flags abort the current listing and
     // create a new one
-    kDebug(5006) << "Set status during folder listing, restarting listing." << endl;
-    kDebug(5006) << "disconnect slotListFolderResult\n";
+    kDebug(5006) <<"Set status during folder listing, restarting listing.";
+    kDebug(5006) <<"disconnect slotListFolderResult";
     disconnect( this, SLOT( slotListFolderResult( KJob * ) ) );
     quiet( false );
     reallyGetFolder( QString() );
@@ -2034,7 +2118,7 @@ void KMFolderImap::expungeFolder(KMFolderImap * aFolder, bool quiet)
   url.setPath(aFolder->imapPath() + ";UID=*");
   if ( account()->makeConnection() != ImapAccountBase::Connected )
     return;
-  KIO::SimpleJob *job = KIO::file_delete(url, false);
+  KIO::SimpleJob *job = KIO::file_delete(url, KIO::HideProgressInfo);
   KIO::Scheduler::assignJobToSlave(account()->slave(), job);
   ImapAccountBase::jobData jd( url.url(), 0 );
   jd.quiet = quiet;
@@ -2060,11 +2144,11 @@ bool KMFolderImap::processNewMail(bool)
 {
    // a little safety
   if ( !account() ) {
-    kDebug(5006) << "KMFolderImap::processNewMail - account is null!" << endl;
+    kDebug(5006) <<"KMFolderImap::processNewMail - account is null!";
     return false;
   }
   if ( imapPath().isEmpty() ) {
-    kDebug(5006) << "KMFolderImap::processNewMail - imapPath of " << objectName() << " is empty!" << endl;
+    kDebug(5006) <<"KMFolderImap::processNewMail - imapPath of" << objectName() <<" is empty!";
     // remove it locally
     setAlreadyRemoved( true );
     kmkernel->imapFolderMgr()->remove( folder() );
@@ -2072,12 +2156,12 @@ bool KMFolderImap::processNewMail(bool)
   }
   // check the connection
   if ( account()->makeConnection() == ImapAccountBase::Error ) {
-    kDebug(5006) << "KMFolderImap::processNewMail - got no connection!" << endl;
+    kDebug(5006) <<"KMFolderImap::processNewMail - got no connection!";
     return false;
   } else if ( account()->makeConnection() == ImapAccountBase::Connecting )
   {
     // wait
-    kDebug(5006) << "KMFolderImap::processNewMail - waiting for connection: " << label() << endl;
+    kDebug(5006) <<"KMFolderImap::processNewMail - waiting for connection:" << label();
     connect( account(), SIGNAL( connectionResult(int, const QString&) ),
         this, SLOT( slotProcessNewMail(int, const QString&) ) );
     return true;
@@ -2096,7 +2180,7 @@ bool KMFolderImap::processNewMail(bool)
               false,
               account()->useSSL() || account()->useTLS() );
 
-  KIO::SimpleJob *job = KIO::stat(url, false);
+  KIO::SimpleJob *job = KIO::stat(url, KIO::HideProgressInfo);
   KIO::Scheduler::assignJobToSlave(account()->slave(), job);
   ImapAccountBase::jobData jd(url.url(), folder() );
   jd.cancellable = true;
@@ -2200,7 +2284,7 @@ int KMFolderImap::expungeContents()
   url.setPath( imapPath() + ";UID=1:*");
   if ( account()->makeConnection() == ImapAccountBase::Connected )
   {
-    KIO::SimpleJob *job = KIO::file_delete(url, false);
+    KIO::SimpleJob *job = KIO::file_delete(url, KIO::HideProgressInfo);
     KIO::Scheduler::assignJobToSlave(account()->slave(), job);
     ImapAccountBase::jobData jd( url.url(), 0 );
     jd.quiet = true;
@@ -2223,7 +2307,7 @@ void
 KMFolderImap::setUserRights( unsigned int userRights )
 {
   mUserRights = userRights;
-  kDebug(5006) << imapPath() << " setUserRights: " << userRights << endl;
+  kDebug(5006) << imapPath() <<" setUserRights:" << userRights;
 }
 
 //-----------------------------------------------------------------------------
@@ -2354,7 +2438,7 @@ const ulong KMFolderImap::serNumForUID( ulong uid )
     KMMsgMetaData *md = mUidMetaDataMap[uid];
     return md->serNum();
   } else {
-    kDebug(5006) << "serNumForUID: unknown uid " << uid << endl;
+    kDebug(5006) <<"serNumForUID: unknown uid" << uid;
     return 0;
   }
 }
@@ -2373,7 +2457,7 @@ void KMFolderImap::saveMsgMetaData( KMMessage* msg, ulong uid )
 void KMFolderImap::setImapPath( const QString& path )
 {
   if ( path.isEmpty() ) {
-    kWarning(5006) << k_funcinfo << "ignoring empty path" << endl;
+    kWarning(5006) <<"ignoring empty path";
   } else {
     mImapPath = path;
   }
@@ -2381,8 +2465,8 @@ void KMFolderImap::setImapPath( const QString& path )
 
 void KMFolderImap::finishMailCheck( const char *dbg, imapState state )
 {
-  kDebug(5006) << folder()->name() << " finishMailCheck " << dbg
-               << " " << state << endl;
+  kDebug(5006) << folder()->name() <<" finishMailCheck" << dbg
+               << state;
   quiet( false );
   mContentState = state;
   emit folderComplete( this, mContentState == imapFinished );
