@@ -23,8 +23,9 @@ using KMail::MaildirJob;
 
 #include <kdebug.h>
 #include <klocale.h>
-#include <kstaticdeleter.h>
+#include <k3staticdeleter.h>
 #include <kmessagebox.h>
+#include <krandom.h>
 
 #include <QDateTime>
 
@@ -36,7 +37,6 @@ using KMail::MaildirJob;
 #include <unistd.h>
 #include <assert.h>
 #include <limits.h>
-#include <unistd.h>
 #include <fcntl.h>
 
 #ifndef MAX_LINE
@@ -46,6 +46,8 @@ using KMail::MaildirJob;
 #define INIT_MSGS 8
 #endif
 
+using KPIMUtils::removeDirAndContentsRecursively;
+
 
 //-----------------------------------------------------------------------------
 KMFolderMaildir::KMFolderMaildir(KMFolder* folder, const char* name)
@@ -166,36 +168,36 @@ int KMFolderMaildir::createMaildirFolders( const QString & folderPath )
   // create the maildir directory structure
 #ifdef Q_OS_WIN
   if ( ::mkdir( QFile::encodeName( folderPath ) ) > 0 ) {
-    kDebug(5006) << "Could not create folder " << folderPath << endl;
+    kDebug(5006) <<"Could not create folder" << folderPath;
     return errno;
   }
   if ( ::mkdir( QFile::encodeName( folderPath + "/new" ) ) > 0 ) {
-    kDebug(5006) << "Could not create folder " << folderPath << "/new" << endl;
+    kDebug(5006) <<"Could not create folder" << folderPath <<"/new";
     return errno;
   }
   if ( ::mkdir( QFile::encodeName( folderPath + "/cur" ) ) > 0 ) {
-    kDebug(5006) << "Could not create folder " << folderPath << "/cur" << endl;
+    kDebug(5006) <<"Could not create folder" << folderPath <<"/cur";
     return errno;
   }
   if ( ::mkdir( QFile::encodeName( folderPath + "/tmp" ) ) > 0 ) {
-    kDebug(5006) << "Could not create folder " << folderPath << "/tmp" << endl;
+    kDebug(5006) <<"Could not create folder" << folderPath <<"/tmp";
     return errno;
   }
 #else
   if ( ::mkdir( QFile::encodeName( folderPath ), S_IRWXU ) > 0 ) {
-    kDebug(5006) << "Could not create folder " << folderPath << endl;
+    kDebug(5006) <<"Could not create folder" << folderPath;
     return errno;
   }
   if ( ::mkdir( QFile::encodeName( folderPath + "/new" ), S_IRWXU ) > 0 ) {
-    kDebug(5006) << "Could not create folder " << folderPath << "/new" << endl;
+    kDebug(5006) <<"Could not create folder" << folderPath <<"/new";
     return errno;
   }
   if ( ::mkdir( QFile::encodeName( folderPath + "/cur" ), S_IRWXU ) > 0 ) {
-    kDebug(5006) << "Could not create folder " << folderPath << "/cur" << endl;
+    kDebug(5006) <<"Could not create folder" << folderPath <<"/cur";
     return errno;
   }
   if ( ::mkdir( QFile::encodeName( folderPath + "/tmp" ), S_IRWXU ) > 0 ) {
-    kDebug(5006) << "Could not create folder " << folderPath << "/tmp" << endl;
+    kDebug(5006) <<"Could not create folder" << folderPath <<"/tmp";
     return errno;
   }
 #endif  // Q_OS_WIN
@@ -312,7 +314,7 @@ int KMFolderMaildir::compact( unsigned int startIndex, int nbMessages, const QSt
 
   unsigned int stopIndex = nbMessages == -1 ? mMsgList.count() :
                            qMin( mMsgList.count(), startIndex + nbMessages );
-  //kDebug(5006) << "KMFolderMaildir: compacting from " << startIndex << " to " << stopIndex << endl;
+  //kDebug(5006) <<"KMFolderMaildir: compacting from" << startIndex <<" to" << stopIndex;
   for(unsigned int idx = startIndex; idx < stopIndex; ++idx) {
     KMMsgInfo* mi = (KMMsgInfo*)mMsgList.at(idx);
     if (!mi)
@@ -399,10 +401,8 @@ if( fileD0.open( QIODevice::WriteOnly ) ) {
     fileD0.close();  // If data is 0 we just create a zero length file.
 }
 */
-  bool opened = false;
   KMFolder* msgParent;
   int idx(-1);
-  int rc;
 
   // take message out of the folder it is currently in, if any
   msgParent = aMsg->parent();
@@ -432,7 +432,7 @@ if( fileD0.open( QIODevice::WriteOnly ) ) {
     aMsg->setHeaderField( "X-UID", uidHeader );
 
   if ( msgText.length() <= 0 ) {
-    kDebug(5006) << "Message added to folder `" << objectName() << "' contains no data. Ignoring it." << endl;
+    kDebug(5006) <<"Message added to folder `" << objectName() <<"' contains no data. Ignoring it.";
     return 0;
   }
 
@@ -447,12 +447,11 @@ if( fileD0.open( QIODevice::WriteOnly ) ) {
 
   QFile file(tmp_file);
 
-  if (!isOpened())
+  KMFolderOpener openThis(folder(), "maildir");
+  if (openThis.openResult())
   {
-    opened = true;
-    rc = open( "maildir" );
-    kDebug(5006) << "KMFolderMaildir::addMsg-open: " << rc << " of folder: " << label() << endl;
-    if (rc) return rc;
+    kDebug(5006) <<"KMFolderMaildir::addMsg-open:" << openThis.openResult() <<" of folder:" << label();
+    return openThis.openResult();
   }
 
   // now move the file to the correct location
@@ -461,14 +460,11 @@ if( fileD0.open( QIODevice::WriteOnly ) ) {
   if (moveInternal(tmp_file, new_loc, filename, aMsg->messageStatus()).isNull())
   {
     file.remove();
-    if ( opened ) {
-      close( "maildir" );
-    }
     return -1;
   }
 
-  if (msgParent)
-    if (idx >= 0) msgParent->take(idx);
+  if (msgParent && idx >= 0)
+    msgParent->take(idx);
 
   // just to be sure it does not end up in the index
   if ( stripUid ) aMsg->setUID( 0 );
@@ -484,11 +480,11 @@ if( fileD0.open( QIODevice::WriteOnly ) ) {
     else
       ++mUnreadMsgs;
     if ( !mQuiet ) {
-      kDebug( 5006 ) << "FolderStorage::msgStatusChanged" << endl;
+      kDebug( 5006 ) <<"FolderStorage::msgStatusChanged";
       emit numUnreadMsgsChanged( folder() );
     }else{
       if ( !mEmitChangedTimer->isActive() ) {
-//        kDebug( 5006 )<< "QuietTimer started" << endl;
+//        kDebug( 5006 )<<"QuietTimer started";
         mEmitChangedTimer->start( 3000 );
       }
       mChanged = true;
@@ -525,7 +521,7 @@ if( fileD0.open( QIODevice::WriteOnly ) ) {
     mb->setIndexOffset( ftell(mIndexStream) );
     mb->setIndexLength( len );
     if(fwrite(buffer, len, 1, mIndexStream) != 1)
-    kDebug(5006) << "Whoa! " << __FILE__ << ":" << __LINE__ << endl;
+      kDebug(5006) <<"Whoa!";
 
     fflush(mIndexStream);
     int error = ferror(mIndexStream);
@@ -534,9 +530,9 @@ if( fileD0.open( QIODevice::WriteOnly ) ) {
       error |= appendToFolderIdsFile( idx );
 
     if (error) {
-      kDebug(5006) << "Error: Could not add message to folder (No space left on device?)" << endl;
+      kDebug(5006) <<"Error: Could not add message to folder (No space left on device?)";
       if (ftell(mIndexStream) > revert) {
-	kDebug(5006) << "Undoing changes" << endl;
+	kDebug(5006) <<"Undoing changes";
 	truncate( QFile::encodeName(indexLocation()), revert );
       }
       kmkernel->emergencyExit(i18n("KMFolderMaildir::addMsg: abnormally terminating to prevent data loss."));
@@ -550,22 +546,17 @@ if( fileD0.open( QIODevice::WriteOnly ) ) {
 	     "(No space left on device or insufficient quota?)\n"
 	     "Free space and sufficient quota are required to continue safely."));
       if (busy) kmkernel->kbp()->busy();
-      if (opened) close();
       */
       return error;
     }
   }
 
-  // some "paper work"
   if (index_return)
     *index_return = idx;
 
   emitMsgAddedSignals(idx);
   needsCompact = true;
 
-  if ( opened ) {
-    close( "maildir" );
-  }
 /*
 QFile fileD1( "testdat_xx-kmfoldermaildir-1" );
 if( fileD1.open( QIODevice::WriteOnly ) ) {
@@ -610,7 +601,7 @@ DwString KMFolderMaildir::getDwString(int idx)
       return str;
     }
   }
-  kDebug(5006) << "Could not open file r+ " << abs_file << endl;
+  kDebug(5006) <<"Could not open file r+" << abs_file;
   return DwString();
 }
 
@@ -640,10 +631,9 @@ void KMFolderMaildir::readFileHeaderIntern( const QString& dir,
   // open the file and get a pointer to it
   QFile f( file );
   if ( f.open( QIODevice::ReadOnly ) == false ) {
-    kWarning(5006) << "The file '" << QFile::encodeName(dir) << "/" << file
-                   << "' could not be opened for reading the message. "
-                   << "Please check ownership and permissions."
-                   << endl;
+    kWarning(5006) <<"The file '" << QFile::encodeName(dir) <<"/" << file
+                   << "' could not be opened for reading the message."
+                   << "Please check ownership and permissions.";
     return;
   }
 
@@ -861,7 +851,7 @@ int KMFolderMaildir::createIndexFromContents()
   dirinfo.setFile(location() + "/new");
   if (!dirinfo.exists() || !dirinfo.isDir())
   {
-    kDebug(5006) << "Directory " << location() << "/new doesn't exist or is a file"<< endl;
+    kDebug(5006) <<"Directory" << location() <<"/new doesn't exist or is a file";
     return 1;
   }
   QDir newDir(location() + "/new");
@@ -870,7 +860,7 @@ int KMFolderMaildir::createIndexFromContents()
   dirinfo.setFile(location() + "/cur");
   if (!dirinfo.exists() || !dirinfo.isDir())
   {
-    kDebug(5006) << "Directory " << location() << "/cur doesn't exist or is a file"<< endl;
+    kDebug(5006) <<"Directory" << location() <<"/cur doesn't exist or is a file";
     return 1;
   }
   QDir curDir(location() + "/cur");
@@ -978,7 +968,7 @@ bool KMFolderMaildir::removeFile( const QString & folderPath,
       return true;
   }
 
-  kDebug(5006) << "Can't delete " << abs_file << " " << perror << endl;
+  kDebug(5006) <<"Can't delete" << abs_file << perror;
   return false;
 }
 
@@ -987,35 +977,6 @@ bool KMFolderMaildir::removeFile( const QString & filename )
   return removeFile( location(), filename );
 }
 
-#include <sys/types.h>
-#include <dirent.h>
-#include <krandom.h>
-static bool removeDirAndContentsRecursively( const QString & path )
-{
-  bool success = true;
-
-  QDir d;
-  d.setPath( path );
-  d.setFilter( QDir::Files | QDir::Dirs | QDir::Hidden | QDir::NoSymLinks );
-
-  QFileInfoList list = d.entryInfoList();
-  QFileInfo fi;
-
-  Q_FOREACH( fi, list ) {
-    if( fi.isDir() ) {
-      if ( fi.fileName() != "." && fi.fileName() != ".." )
-        success = success && removeDirAndContentsRecursively( fi.absoluteFilePath() );
-    } else {
-      success = success && d.remove( fi.absoluteFilePath() );
-    }
-  }
-
-  if ( success ) {
-    success = success && d.rmdir( path ); // nuke ourselves, we should be empty now
-  }
-  return success;
-}
-
 //-----------------------------------------------------------------------------
 int KMFolderMaildir::removeContents()
 {
@@ -1035,7 +996,7 @@ int KMFolderMaildir::removeContents()
 }
 
 static QRegExp *suffix_regex = 0;
-static KStaticDeleter<QRegExp> suffix_regex_sd;
+static K3StaticDeleter<QRegExp> suffix_regex_sd;
 
 //-----------------------------------------------------------------------------
 // static
@@ -1119,7 +1080,7 @@ void KMFolderMaildir::msgStatusChanged( const MessageStatus& oldStatus,
 size_t KMFolderMaildir::doFolderSize() const
 {
   if (mCurrentlyCheckingFolderSize) return -1;
-  QList<KFileItem> list;
+  KFileItemList list;
   list.append( KFileItem( S_IFDIR, -1, location() + "/cur" ) );
   list.append( KFileItem( S_IFDIR, -1, location() + "/new" ) );
   list.append( KFileItem( S_IFDIR, -1, location() + "/tmp" ) );
