@@ -101,9 +101,9 @@ int KMFolderMbox::open( const char *owner )
 {
   mOwners.append( owner );
 
-  kDebug(5006) << "\nopen " << mOpenCount << " " << folder()->name()
-               << " " << mOwners << ", adding: " << owner << " \n" << endl;
-//           << " " << mOwners << ", adding: " << owner << " \n" << kBacktrace() << endl;
+  kDebug(5006) << endl << "open" << mOpenCount << folder()->name()
+               << mOwners << ", adding:" << owner;
+//           << mOwners << ", adding:" << owner << kBacktrace();
   int rc = 0;
 
   mOpenCount++;
@@ -121,7 +121,7 @@ int KMFolderMbox::open( const char *owner )
     KNotification::event( "warning",
                           i18n("Cannot open file \"%1\":\n%2",
                                location(), strerror( errno ) ) );
-    kDebug(5006) << "Cannot open folder `" << location() << "': " << strerror(errno) << endl;
+    kDebug(5006) <<"Cannot open folder `" << location() <<"':" << strerror(errno);
     mOpenCount = 0;
     return errno;
   }
@@ -210,7 +210,7 @@ int KMFolderMbox::canAccess()
   assert(!folder()->name().isEmpty());
 
   if (access(QFile::encodeName(location()), R_OK | W_OK) != 0) {
-    kDebug(5006) << "KMFolderMbox::access call to access function failed" << endl;
+    kDebug(5006) <<"KMFolderMbox::access call to access function failed";
       return 1;
   }
   return 0;
@@ -225,11 +225,11 @@ int KMFolderMbox::create()
   assert(!folder()->name().isEmpty());
   assert(mOpenCount == 0);
 
-  kDebug(5006) << "Creating folder " << objectName() << endl;
+  kDebug(5006) <<"Creating folder" << objectName();
   if (access(QFile::encodeName(location()), F_OK) == 0) {
-    kDebug(5006) << "KMFolderMbox::create call to access function failed." << endl;
-    kDebug(5006) << "File:: " << endl;
-    kDebug(5006) << "Error " << endl;
+    kDebug(5006) <<"KMFolderMbox::create call to access function failed.";
+    kDebug(5006) <<"File::";
+    kDebug(5006) <<"Error";
     return EEXIST;
   }
 
@@ -268,9 +268,9 @@ int KMFolderMbox::create()
 //-----------------------------------------------------------------------------
 void KMFolderMbox::close( const char *owner, bool aForced )
 {
-  kDebug(5006) << "\nclose " << folder()->name() << " " << mOwners
-               << " " << owner << " " << mOpenCount << " \n" << endl;
-//               << " " << owner << " " << mOpenCount << " \n" << kBacktrace() << endl;
+  kDebug(5006) <<"\nclose" << folder()->name() << mOwners
+               << owner << mOpenCount;
+//             << owner << mOpenCount << kBacktrace();
   QStringList::iterator it = mOwners.find( owner );
   if ( !aForced && !mOwners.isEmpty() ) {
     assert( it != mOwners.end() );
@@ -299,8 +299,8 @@ void KMFolderMbox::close( const char *owner, bool aForced )
 
   if ( mAutoCreateIndex ) {
       if ( KMFolderIndex::IndexOk != indexStatus() ) {
-        kDebug(5006) << "Critical error: " << location()
-                     << " has been modified by an external application while KMail was running." << endl;
+        kDebug(5006) <<"Critical error:" << location()
+                     << "has been modified by an external application while KMail was running.";
         //      exit(1); backed out due to broken nfs
       }
 
@@ -363,8 +363,8 @@ int KMFolderMbox::lock()
 
       if (rc < 0)
       {
-        kDebug(5006) << "Cannot lock folder `" << location() << "': "
-                  << strerror(errno) << " (" << errno << ")" << endl;
+        kDebug(5006) <<"Cannot lock folder `" << location() <<"':"
+                  << strerror(errno) << "(" << errno << ")";
         mReadOnly = true;
         return errno;
       }
@@ -375,8 +375,8 @@ int KMFolderMbox::lock()
 
         if (rc < 0)
         {
-          kDebug(5006) << "Cannot lock index of folder `" << location() << "': "
-                    << strerror(errno) << " (" << errno << ")" << endl;
+          kDebug(5006) <<"Cannot lock index of folder `" << location() <<"':"
+                    << strerror(errno) << "(" << errno << ")";
           rc = errno;
           fl.l_type = F_UNLCK;
           /*rc =*/ fcntl(fileno(mIndexStream), F_SETLK, &fl);
@@ -396,8 +396,8 @@ int KMFolderMbox::lock()
       rc = system( cmd_str.data() );
       if( rc != 0 )
       {
-        kDebug(5006) << "Cannot lock folder `" << location() << "': "
-                  << strerror(rc) << " (" << rc << ")" << endl;
+        kDebug(5006) <<"Cannot lock folder `" << location() <<"':"
+                  << strerror(rc) << "(" << rc << ")";
         mReadOnly = true;
         return rc;
       }
@@ -407,8 +407,8 @@ int KMFolderMbox::lock()
         rc = system( cmd_str.data() );
         if( rc != 0 )
         {
-          kDebug(5006) << "Cannot lock index of folder `" << location() << "': "
-                    << strerror(rc) << " (" << rc << ")" << endl;
+          kDebug(5006) <<"Cannot lock index of folder `" << location() <<"':"
+                    << strerror(rc) << "(" << rc << ")";
           mReadOnly = true;
           return rc;
         }
@@ -420,8 +420,8 @@ int KMFolderMbox::lock()
       rc = system( cmd_str.data() );
       if( rc != 0 )
       {
-        kDebug(5006) << "Cannot lock folder `" << location() << "': "
-                  << strerror(rc) << " (" << rc << ")" << endl;
+        kDebug(5006) <<"Cannot lock folder `" << location() <<"':"
+                  << strerror(rc) << "(" << rc << ")";
         mReadOnly = true;
         return rc;
       }
@@ -431,8 +431,8 @@ int KMFolderMbox::lock()
         rc = system( cmd_str.data() );
         if( rc != 0 )
         {
-          kDebug(5006) << "Cannot lock index of folder `" << location() << "': "
-                    << strerror(rc) << " (" << rc << ")" << endl;
+          kDebug(5006) <<"Cannot lock index of folder `" << location() <<"':"
+                    << strerror(rc) << "(" << rc << ")";
           mReadOnly = true;
           return rc;
         }
@@ -444,8 +444,8 @@ int KMFolderMbox::lock()
       rc = system( cmd_str.data() );
       if( rc != 0 )
       {
-        kDebug(5006) << "Cannot lock folder `" << location() << "': "
-                  << strerror(rc) << " (" << rc << ")" << endl;
+        kDebug(5006) <<"Cannot lock folder `" << location() <<"':"
+                  << strerror(rc) << "(" << rc << ")";
         mReadOnly = true;
         return rc;
       }
@@ -455,8 +455,8 @@ int KMFolderMbox::lock()
         rc = system( cmd_str.data() );
         if( rc != 0 )
         {
-          kDebug(5006) << "Cannot lock index of folder `" << location() << "': "
-                    << strerror(rc) << " (" << rc << ")" << endl;
+          kDebug(5006) <<"Cannot lock index of folder `" << location() <<"':"
+                    << strerror(rc) << "(" << rc << ")";
           mReadOnly = true;
           return rc;
         }
@@ -957,7 +957,6 @@ int KMFolderMbox::addMsg( KMMessage *aMsg, int *aIndex_ret )
   if ( !canAddMsgNow( aMsg, aIndex_ret ) ) {
     return 0;
   }
-  bool opened = false;
   QByteArray msgText;
   char endStr[3];
   int idx = -1, rc;
@@ -965,14 +964,11 @@ int KMFolderMbox::addMsg( KMMessage *aMsg, int *aIndex_ret )
   bool editing = false;
   int growth = 0;
 
-  if ( !mStream ) {
-    opened = true;
-    rc = open( "mboxaddMsg" );
-    kDebug(5006) << "KMFolderMBox::addMsg-open: " << rc
-                 << " of folder: " << label() << endl;
-    if ( rc ) {
-      return rc;
-    }
+  KMFolderOpener openThis( folder(), "mboxaddMsg" );
+  if ( openThis.openResult() )
+  {
+    kdDebug(5006) << "KMFolderMbox::addMsg-open: " << openThis.openResult() << " of folder: " << label() << endl;
+    return openThis.openResult();
   }
 
   // take message out of the folder it is currently in, if any
@@ -981,7 +977,7 @@ int KMFolderMbox::addMsg( KMMessage *aMsg, int *aIndex_ret )
     if ( msgParent== folder() ) {
       if ( kmkernel->folderIsDraftOrOutbox( folder() ) ) {
         //special case for Edit message.
-        kDebug(5006) << "Editing message in outbox or drafts" << endl;
+        kDebug(5006) <<"Editing message in outbox or drafts";
         editing = true;
       } else {
         return 0;
@@ -1019,11 +1015,8 @@ if( fileD1.open( QIODevice::WriteOnly ) ) {
   assert( mStream != 0 );
   clearerr( mStream );
   if ( len <= 0 ) {
-    kDebug(5006) << "Message added to folder `" << objectName()
-                 << "' contains no data. Ignoring it." << endl;
-    if ( opened ) {
-      close( "mboxaddMsg" );
-    }
+    kDebug(5006) <<"Message added to folder `" << objectName()
+                 << "' contains no data. Ignoring it.";
     return 0;
   }
 
@@ -1046,14 +1039,10 @@ if( fileD1.open( QIODevice::WriteOnly ) ) {
       }
     }
   }
-  fseek( mStream,0,SEEK_END ); // this is needed on solaris and others
+  fseek( mStream, 0, SEEK_END ); // this is needed on solaris and others
   int error = ferror( mStream );
-  if ( error ) {
-    if ( opened ) {
-      close( "mboxaddMsg" );
-    }
+  if ( error )
     return error;
-  }
 
   QByteArray messageSeparator( aMsg->mboxMessageSeparator() );
   fwrite( messageSeparator.data(), messageSeparator.length(), 1, mStream );
@@ -1067,10 +1056,10 @@ if( fileD1.open( QIODevice::WriteOnly ) ) {
 
   error = ferror( mStream );
   if ( error ) {
-    kDebug(5006) << "Error: Could not add message to folder: "
-                 << strerror(errno) << endl;
+    kDebug(5006) <<"Error: Could not add message to folder:"
+                 << strerror(errno);
     if ( ftell( mStream ) > revert ) {
-      kDebug(5006) << "Undoing changes" << endl;
+      kDebug(5006) <<"Undoing changes";
       truncate( QFile::encodeName(location()), revert );
     }
     kmkernel->emergencyExit( i18n("Could not add message to folder: ") +
@@ -1084,7 +1073,6 @@ if( fileD1.open( QIODevice::WriteOnly ) ) {
                "(No space left on device or insufficient quota?)\n"
                "Free space and sufficient quota are required to continue safely."));
     if (busy) kmkernel->kbp()->busy();
-    if (opened) close();
     kmkernel->kbp()->idle();
     */
     return error;
@@ -1149,7 +1137,7 @@ if( fileD1.open( QIODevice::WriteOnly ) ) {
     mb->setIndexOffset( ftell( mIndexStream ) );
     mb->setIndexLength( len );
     if ( fwrite( buffer, len, 1, mIndexStream ) != 1 ) {
-      kDebug(5006) << "Whoa! " << __FILE__ << ":" << __LINE__ << endl;
+      kDebug(5006) <<"Whoa!";
     }
 
     fflush( mIndexStream );
@@ -1160,13 +1148,13 @@ if( fileD1.open( QIODevice::WriteOnly ) ) {
     }
 
     if (error) {
-      kWarning(5006) << "Error: Could not add message to folder (No space left on device?)" << endl;
+      kWarning(5006) <<"Error: Could not add message to folder (No space left on device?)";
       if ( ftell( mIndexStream ) > revert ) {
-        kWarning(5006) << "Undoing changes" << endl;
+        kWarning(5006) <<"Undoing changes";
         truncate( QFile::encodeName( indexLocation() ), revert );
       }
       if ( errno ) {
-        kmkernel->emergencyExit( i18n("Could not add message to folder:") +
+        kmkernel->emergencyExit( i18n("Could not add message to folder: ") +
                                  QString::fromLocal8Bit( strerror( errno ) ) );
       } else {
         kmkernel->emergencyExit( i18n("Could not add message to folder (No space left on device?)") );
@@ -1180,20 +1168,15 @@ if( fileD1.open( QIODevice::WriteOnly ) ) {
              "(No space left on device or insufficient quota?)\n"
              "Free space and sufficient quota are required to continue safely."));
       if (busy) kmkernel->kbp()->busy();
-      if (opened) close();
       */
       return error;
     }
   }
 
-  // some "paper work"
   if ( aIndex_ret ) {
     *aIndex_ret = idx;
   }
   emitMsgAddedSignals(idx);
-  if ( opened ) {
-    close( "mboxaddMsg" );
-  }
 
   // All streams have been flushed without errors if we arrive here
   // Return success!
@@ -1209,7 +1192,7 @@ int KMFolderMbox::compact( int startIndex, int nbMessages, FILE *tmpfile,
   int stopIndex = nbMessages == -1
                   ? mMsgList.count()
                   : qMin( (int)mMsgList.count(), startIndex + nbMessages );
-  //kDebug(5006) << "KMFolderMbox: compacting from " << startIndex << " to " << stopIndex << endl;
+  //kDebug(5006) <<"KMFolderMbox: compacting from" << startIndex <<" to" << stopIndex;
   for ( int idx = startIndex; idx < stopIndex; ++idx ) {
     KMMsgInfo* mi = (KMMsgInfo*)mMsgList.at( idx );
     size_t msize = mi->msgSize();
