@@ -20,6 +20,7 @@ using KMail::AccountManager;
 #include "acljobs.h"
 #include "messagecopyhelper.h"
 using KMail::MessageCopyHelper;
+#include "favoritefolderview.h"
 
 #include <maillistdrag.h>
 using namespace KPIM;
@@ -58,7 +59,7 @@ KMFolderTreeItem::KMFolderTreeItem( KFolderTree *parent, const QString & name,
 {
   setObjectName( name );
   init();
-  setPixmap( 0, normalIcon() );
+  setPixmap( 0, normalIcon( iconSize() ) );
 }
 
 //-----------------------------------------------------------------------------
@@ -70,7 +71,7 @@ KMFolderTreeItem::KMFolderTreeItem( KFolderTree *parent, const QString & name,
 {
   setObjectName( name );
   init();
-  setPixmap( 0, normalIcon() );
+  setPixmap( 0, normalIcon( iconSize() ) );
 }
 
 //-----------------------------------------------------------------------------
@@ -82,7 +83,7 @@ KMFolderTreeItem::KMFolderTreeItem( KFolderTreeItem *parent, const QString & nam
 {
   setObjectName( name );
   init();
-  setPixmap( 0, normalIcon() );
+  setPixmap( 0, normalIcon( iconSize() ) );
 }
 
 KMFolderTreeItem::~KMFolderTreeItem()
@@ -108,7 +109,7 @@ static KFolderTreeItem::Protocol protocolFor( KMFolderType t ) {
 QPixmap KMFolderTreeItem::normalIcon(int size) const
 {
   QString icon;
-  if ( (!mFolder && type() == Root) || depth() == 0 ) {
+  if ( (!mFolder && type() == Root) || useTopLevelIcon() ) {
     switch ( protocol() ) {
       case KFolderTreeItem::Imap:
       case KFolderTreeItem::CachedImap:
@@ -124,7 +125,7 @@ QPixmap KMFolderTreeItem::normalIcon(int size) const
     switch ( type() ) {
       case Inbox: icon = "folder-inbox"; break;
       case Outbox: icon = "folder-outbox"; break;
-      case SentMail: icon = "folder-sent_mail"; break;
+      case SentMail: icon = "folder-sent-mail"; break;
       case Trash: icon = "user-trash"; break;
       case Drafts: icon = "edit"; break;
       case Templates: icon = "document-new"; break;
@@ -146,11 +147,11 @@ QPixmap KMFolderTreeItem::normalIcon(int size) const
     icon = mFolder->normalIconPath();
   }
   KIconLoader * il = KIconLoader::global();
-  QPixmap pm = il->loadIcon( icon, K3Icon::Small, size,
-                             K3Icon::DefaultState, QStringList(), 0, true );
+  QPixmap pm = il->loadIcon( icon, KIconLoader::Small, size,
+                             KIconLoader::DefaultState, QStringList(), 0, true );
   if ( mFolder && pm.isNull() ) {
-      pm = il->loadIcon( mFolder->normalIconPath(), K3Icon::Small, size,
-                         K3Icon::DefaultState, QStringList(), 0, true );
+      pm = il->loadIcon( mFolder->normalIconPath(), KIconLoader::Small, size,
+                         KIconLoader::DefaultState, QStringList(), 0, true );
   }
 
   return pm;
@@ -160,7 +161,7 @@ QPixmap KMFolderTreeItem::unreadIcon(int size) const
 {
   QPixmap pm;
 
-  if ( !mFolder || depth() == 0 || mFolder->isSystemFolder()
+  if ( !mFolder || useTopLevelIcon() || mFolder->isSystemFolder()
     || kmkernel->folderIsTrash( mFolder )
     || kmkernel->folderIsTemplates( mFolder )
     || kmkernel->folderIsDraftOrOutbox( mFolder ) )
@@ -168,22 +169,22 @@ QPixmap KMFolderTreeItem::unreadIcon(int size) const
 
   KIconLoader * il = KIconLoader::global();
   if ( mFolder && mFolder->useCustomIcons() ) {
-    pm = il->loadIcon( mFolder->unreadIconPath(), K3Icon::Small, size,
-                       K3Icon::DefaultState, QStringList(), 0, true );
+    pm = il->loadIcon( mFolder->unreadIconPath(), KIconLoader::Small, size,
+                       KIconLoader::DefaultState, QStringList(), 0, true );
     if ( pm.isNull() )
-      pm = il->loadIcon( mFolder->normalIconPath(), K3Icon::Small, size,
-                         K3Icon::DefaultState, QStringList(), 0, true );
+      pm = il->loadIcon( mFolder->normalIconPath(), KIconLoader::Small, size,
+                         KIconLoader::DefaultState, QStringList(), 0, true );
   }
   if ( pm.isNull() ) {
     if ( mFolder && mFolder->noContent() ) {
-      pm = il->loadIcon( "folder_grey_open", K3Icon::Small, size,
-                         K3Icon::DefaultState, QStringList(), 0, true );
+      pm = il->loadIcon( "folder_grey_open", KIconLoader::Small, size,
+                         KIconLoader::DefaultState, QStringList(), 0, true );
     } else {
       pm = il->loadIcon( kmkernel->iCalIface().folderPixmap( type() ),
-                         K3Icon::Small, size, K3Icon::DefaultState, QStringList(), 0, true );
+                         KIconLoader::Small, size, KIconLoader::DefaultState, QStringList(), 0, true );
       if ( pm.isNull() )
-        pm = il->loadIcon( "folder-open", K3Icon::Small, size,
-                           K3Icon::DefaultState, QStringList(), 0, true );
+        pm = il->loadIcon( "folder-open", KIconLoader::Small, size,
+                           KIconLoader::DefaultState, QStringList(), 0, true );
     }
   }
 
@@ -197,7 +198,7 @@ void KMFolderTreeItem::init()
 
   setProtocol( protocolFor( mFolder->folderType() ) );
 
-  if ( depth() == 0 )
+  if ( useTopLevelIcon() )
     setType(Root);
   else {
     if ( mFolder == kmkernel->inboxFolder() )
@@ -227,32 +228,33 @@ void KMFolderTreeItem::init()
   if ( !mFolder->isSystemFolder() )
     setRenameEnabled( 0, false );
 
-  KMFolderTree* tree = static_cast<KMFolderTree*>( listView() );
-  tree->insertIntoFolderToItemMap( mFolder, this );
+  KMFolderTree* tree = dynamic_cast<KMFolderTree*>( listView() );
+  if ( tree )
+    tree->insertIntoFolderToItemMap( mFolder, this );
 }
 
 void KMFolderTreeItem::adjustUnreadCount( int newUnreadCount ) {
   // adjust the icons if the folder is now newly unread or
   // now newly not-unread
   if ( newUnreadCount != 0 && unreadCount() == 0 )
-    setPixmap( 0, unreadIcon() );
+    setPixmap( 0, unreadIcon( iconSize() ) );
   if ( unreadCount() != 0 && newUnreadCount == 0 )
-    setPixmap( 0, normalIcon() );
+    setPixmap( 0, normalIcon( iconSize() ) );
 
   setUnreadCount( newUnreadCount );
 }
 
 void KMFolderTreeItem::slotIconsChanged()
 {
-  kDebug(5006) << k_funcinfo << endl;
+  kDebug(5006) ;
   // this is prone to change, so better check
   if( kmkernel->iCalIface().isResourceFolder( mFolder ) )
       setType( kmkernel->iCalIface().folderType(mFolder) );
 
   if ( unreadCount() > 0 )
-    setPixmap( 0, unreadIcon() );
+    setPixmap( 0, unreadIcon( iconSize() ) );
   else
-    setPixmap( 0, normalIcon() );
+    setPixmap( 0, normalIcon( iconSize() ) );
   emit iconChanged( this );
   repaint();
 }
@@ -315,7 +317,7 @@ void KMFolderTreeItem::properties()
   if ( !mFolder )
     return;
 
-  KMFolderTree* tree = static_cast<KMFolderTree*>( listView() );
+  KMail::FolderTreeBase* tree = static_cast<KMail::FolderTreeBase*>( listView() );
   tree->mainWidget()->modifyFolder( this );
   //Nothing here the above may actually delete this KMFolderTreeItem
 }
@@ -328,7 +330,7 @@ void KMFolderTreeItem::assignShortcut()
 
   KMail::FolderShortcutDialog *shorty =
     new KMail::FolderShortcutDialog( mFolder,
-              static_cast<KMFolderTree *>( listView() )->mainWidget(),
+              kmkernel->getKMMainWidget(),
               listView() );
   shorty->exec();
   return;
@@ -340,7 +342,7 @@ void KMFolderTreeItem::assignShortcut()
 
 KMFolderTree::KMFolderTree( KMMainWidget *mainWidget, QWidget *parent,
                             const char *name )
-  : KFolderTree( parent, name )
+  : KMail::FolderTreeBase( mainWidget, parent, name )
 {
   oldSelected = 0;
   oldCurrent = 0;
@@ -437,48 +439,6 @@ void KMFolderTree::connectSignals()
   connect( this, SIGNAL(folderSelected(KMFolder*)), SLOT(updateCopyActions()) );
 }
 
-//-----------------------------------------------------------------------------
-bool KMFolderTree::event(QEvent *e)
-{
-  if (e->type() == QEvent::ApplicationPaletteChange)
-  {
-     readColorConfig();
-     return true;
-  }
-  return K3ListView::event(e);
-}
-
-//-----------------------------------------------------------------------------
-void KMFolderTree::readColorConfig (void)
-{
-  // Custom/System color support
-  KConfigGroup conf( KMKernel::config(), "Reader" );
-  QColor c1=QColor(qApp->palette().color( QPalette::Text ));
-  QColor c2=QColor("blue");
-  QColor c4=QColor(qApp->palette().color( QPalette::Base ));
-  QColor c5=QColor("red");
-
-  if (!conf.readEntry( "defaultColors", true ) ) {
-    mPaintInfo.colFore = conf.readEntry( "ForegroundColor",
-                                        c1);
-    mPaintInfo.colUnread = conf.readEntry( "UnreadMessage",
-                                        c2);
-    mPaintInfo.colBack = conf.readEntry( "BackgroundColor",
-                                        c4 );
-    mPaintInfo.colCloseToQuota = conf.readEntry("CloseToQuotaColor", QColor( Qt::red ));
-  }
-  else {
-    mPaintInfo.colFore = c1;
-    mPaintInfo.colUnread = c2;
-    mPaintInfo.colBack = c4;
-    mPaintInfo.colCloseToQuota = c5;
-  }
-  QPalette newPal = qApp->palette();
-  newPal.setColor( QPalette::Base, mPaintInfo.colBack );
-  newPal.setColor( QPalette::Text, mPaintInfo.colFore );
-  setPalette( newPal );
-}
-
 //-----------------------------------------------------------------------------
 void KMFolderTree::readConfig (void)
 {
@@ -547,7 +507,7 @@ void KMFolderTree::reload(bool openFolders)
 {
   if ( mReloading ) {
     // no parallel reloads are allowed
-    kDebug(5006) << "KMFolderTree::reload - already reloading" << endl;
+    kDebug(5006) <<"KMFolderTree::reload - already reloading";
     return;
   }
   mReloading = true;
@@ -748,6 +708,12 @@ void KMFolderTree::addDirectory( KMFolderDir *fdir, KMFolderTreeItem* parent )
         // It is
         continue;
 
+      // hide local inbox if unused
+      if ( kmkernel->inboxFolder() == folder && hideLocalInbox() ) {
+        connect( kmkernel->inboxFolder(), SIGNAL(msgAdded(KMFolder*,Q_UINT32)), SLOT(slotUnhideLocalInbox()) );
+        continue;
+      }
+
       // create new child
       fti = new KMFolderTreeItem( parent, folder->label(), folder );
       // set folders explicitly to exandable when they have children
@@ -1121,10 +1087,16 @@ void KMFolderTree::slotContextMenuRequested( Q3ListViewItem *lvi,
 
       folderMenu->addAction( mMainWidget->action("compact") );
 
+      if ( GlobalSettings::self()->enableFavoriteFolderView() ) {
+        folderMenu->addAction( KIcon("bookmark-new"), i18n("Add to Favorite Folders"),
+                               this, SLOT(slotAddToFavorites()) );
+      }
+
       folderMenu->addSeparator();
-      folderMenu->addAction( mMainWidget->action("empty") );
-      if ( !fti->folder()->isSystemFolder() )
-        folderMenu->addAction( mMainWidget->action("delete_folder") );
+      folderMenu->addAction(mMainWidget->action("empty"));
+      if ( !fti->folder()->isSystemFolder() ) {
+        folderMenu->addAction(mMainWidget->action("delete_folder"));
+      }
       folderMenu->addSeparator();
     }
   }
@@ -1137,7 +1109,7 @@ void KMFolderTree::slotContextMenuRequested( Q3ListViewItem *lvi,
     folderMenu->addAction(KIcon("bookmark_folder"),
         i18n("Subscription..."), mMainWidget,
         SLOT(slotSubscriptionDialog()));
-    folderMenu->insertItem(SmallIcon("bookmark_folder"),
+    folderMenu->addAction(SmallIcon("bookmark_folder"),
         i18n("Local Subscription..."), mMainWidget,
         SLOT(slotLocalSubscriptionDialog()));
 
@@ -1377,21 +1349,12 @@ void KMFolderTree::cleanupConfigFile()
 
       //KMessageBox::error( 0, "cleanupConfigFile: Deleting group " + *grpIt );
       config->deleteGroup(*grpIt, KConfig::NLS);
-      kDebug(5006) << "Deleting information about folder " << name << endl;
+      kDebug(5006) <<"Deleting information about folder" << name;
     }
   }
 }
 
 
-//-----------------------------------------------------------------------------
-// Drag and Drop handling -- based on the Troll Tech dirview example
-
-enum {
-  DRAG_COPY = 0,
-  DRAG_MOVE = 1,
-  DRAG_CANCEL = 2
-};
-
 //-----------------------------------------------------------------------------
 void KMFolderTree::openFolder()
 {
@@ -1452,10 +1415,10 @@ void KMFolderTree::contentsDragMoveEvent( QDragMoveEvent *e )
                 case Qt::CopyAction:
                 break;
                 case Qt::MoveAction:
-                e->acceptAction();
+                e->acceptProposedAction();
                 break;
                 case Qt::LinkAction:
-                e->acceptAction();
+                e->acceptProposedAction();
                 break;
                 default:
                 ;
@@ -1490,46 +1453,25 @@ void KMFolderTree::contentsDropEvent( QDropEvent *e )
 
     Q3ListViewItem *item = itemAt( contentsToViewport(e->pos()) );
     KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>(item);
-    int action = -1;
+
     // Check that each pointer is not null
     for ( QList<QPointer<KMFolder> >::ConstIterator it = mCopySourceFolders.constBegin();
-	  it != mCopySourceFolders.constEnd(); ++it ) {
+          it != mCopySourceFolders.constEnd(); ++it ) {
       if ( ! (*it) ) {
-	fti = 0;
-	break;
+        fti = 0;
+        break;
       }
     }
-    if (fti && mCopySourceFolders.count() == 1)
-    {
+
+    if (fti && mCopySourceFolders.count() == 1) {
       KMFolder *source = mCopySourceFolders.first();
       // if we are dragging to ourselves or to our parent, set fti to 0 so nothing is done
-      if (source == fti->folder() || source->parent()->owner() == fti->folder()) fti = 0;
+      if (source == fti->folder() || source->parent()->owner() == fti->folder())
+        fti = 0;
     }
-    if ( fti && acceptDrag(e) && ( fti != oldSelected || e->source() == mMainWidget->headers()->viewport() ) )
-    {
-      //First, determine if we want to copy or to move the dropped contents
-      int keybstate = qApp->keyboardModifiers();
-      if ( keybstate & Qt::ControlModifier ) {
-        action = DRAG_COPY;
-      } else if ( keybstate & Qt::ShiftModifier ) {
-        action = DRAG_MOVE;
-      } else {
-        if ( GlobalSettings::self()->showPopupAfterDnD() || e->provides("application/x-qlistviewitem") ) {
-          KMenu *menu = new KMenu( this );
-          const QAction *dragMove = menu->addAction( i18n("&Move Here") );
-          const QAction *dragCopy = menu->addAction( SmallIcon("edit-copy"), i18n("&Copy Here") );
-          menu->addSeparator();
-          menu->addAction( SmallIcon("cancel"), i18n("C&ancel") );
-          const QAction *selectedAction = menu->exec( QCursor::pos() );
-          if ( selectedAction == dragMove )
-            action = DRAG_MOVE;
-          else if ( selectedAction == dragCopy )
-            action = DRAG_COPY;
-        }
-        else
-          action = DRAG_MOVE;
-      }
 
+    if ( fti && acceptDrag(e) && ( fti != oldSelected || e->source() == mMainWidget->headers()->viewport() ) ) {
+      int action = dndMode( e->provides("application/x-qlistviewitem") /* always ask */ );
       //If the dropped content is a folder, move/copy the folder
       if ( e->provides("application/x-qlistviewitem") ) {
         if ( (action == DRAG_COPY || action == DRAG_MOVE) && !mCopySourceFolders.isEmpty() ) {
@@ -1540,10 +1482,9 @@ void KMFolderTree::contentsDropEvent( QDropEvent *e )
           }
           moveOrCopyFolder( mCopySourceFolders, fti->folder(), (action == DRAG_MOVE) );
         }
-      }
+      } else {
 
-      //If the dropped content are messages, move/copy the messages
-      else {
+        //If the dropped content are messages, move/copy the messages
         if ( e->source() == mMainWidget->headers()->viewport() ) {
           // KMHeaders does copy/move itself
           if ( action == DRAG_MOVE && fti->folder() )
@@ -1552,7 +1493,7 @@ void KMFolderTree::contentsDropEvent( QDropEvent *e )
             emit folderDropCopy( fti->folder() );
         } else if ( action == DRAG_COPY || action == DRAG_MOVE ) {
           if ( !MailList::canDecode( e->mimeData() ) ) {
-            kWarning() << k_funcinfo << "Could not decode drag data!" << endl;
+            kWarning(5006) <<"Could not decode drag data!";
           } else {
             MailList list = MailList::fromMimeData( e->mimeData() );
             QList<quint32> serNums = MessageCopyHelper::serNumListFromMailList( list );
@@ -1660,10 +1601,10 @@ void KMFolderTree::slotUpdateCounts(KMFolderImap * folder, bool success)
 //-----------------------------------------------------------------------------
 void KMFolderTree::slotUpdateCountsDelayed(KMFolder * folder)
 {
-//  kDebug(5006) << "KMFolderTree::slotUpdateCountsDelayed()" << endl;
+//  kDebug(5006) <<"KMFolderTree::slotUpdateCountsDelayed()";
   if ( !mFolderToUpdateCount.contains( folder->idString() ) )
   {
-//    kDebug( 5006 )<< "adding " << folder->idString() << " to updateCountList " << endl;
+//    kDebug( 5006 )<<"adding" << folder->idString() <<" to updateCountList";
     mFolderToUpdateCount.insert( folder->idString(),folder );
   }
   if ( !mUpdateCountTimer->isActive() )
@@ -1673,7 +1614,7 @@ void KMFolderTree::slotUpdateCountsDelayed(KMFolder * folder)
 
 void KMFolderTree::slotUpdateCountTimeout()
 {
-//  kDebug(5006) << "KMFolderTree::slotUpdateCountTimeout()" << endl;
+//  kDebug(5006) <<"KMFolderTree::slotUpdateCountTimeout()";
 
   QMap<QString,KMFolder*>::iterator it;
   for ( it= mFolderToUpdateCount.begin();
@@ -1689,7 +1630,7 @@ void KMFolderTree::slotUpdateCountTimeout()
 
 void KMFolderTree::slotUpdateCounts(KMFolder * folder)
 {
- // kDebug(5006) << "KMFolderTree::slotUpdateCounts()" << endl;
+ // kDebug(5006) <<"KMFolderTree::slotUpdateCounts()";
   Q3ListViewItem * current;
   if (folder)
     current = indexOfFolder(folder);
@@ -1803,7 +1744,7 @@ void KMFolderTree::toggleColumn(int column, bool openFolders)
     // toggle KMenu
     mSizeAction->setChecked( isSizeActive() );
 
-  } else kDebug(5006) << "unknown column:" << column << endl;
+  } else kDebug(5006) <<"unknown column:" << column;
 
   // toggles the switches of the mainwin
   emit columnsChanged();
@@ -2045,7 +1986,7 @@ void KMFolderTree::copySelectedToFolder( QAction* act )
 //-----------------------------------------------------------------------------
 void KMFolderTree::moveOrCopyFolder( QList<QPointer<KMFolder> > sources, KMFolder* destination, bool move )
 {
-  kDebug(5006) << k_funcinfo << "source: " << sources << " destination: " << destination << " move: " << move << endl;
+  kDebug(5006) <<"source:" << sources <<" destination:" << destination <<" move:" << move;
 
   // Disable drag during copy operation since it prevents from many crashes
   setDragEnabled( false );
@@ -2142,8 +2083,8 @@ void KMFolderTree::moveOrCopyFolder( QList<QPointer<KMFolder> > sources, KMFolde
   for ( QList<QPointer<KMFolder> >::ConstIterator it = sources.constBegin(); it != sources.constEnd(); ++it ) {
     KMFolder* source = *it;
     if ( move ) {
-      kDebug(5006) << "move folder " << (source ? source->label(): "Unknown") << " to "
-        << ( destination ? destination->label() : "Local Folders" ) << endl;
+      kDebug(5006) <<"move folder" << (source ? source->label():"Unknown") <<"to"
+        << ( destination ? destination->label() : "Local Folders" );
       kmkernel->folderMgr()->moveFolder( source, parent );
     } else {
       kmkernel->folderMgr()->copyFolder( source, parent );
@@ -2217,4 +2158,19 @@ void KMFolderTree::updateCopyActions()
     paste->setEnabled( true );
 }
 
+void KMFolderTree::slotAddToFavorites()
+{
+  KMail::FavoriteFolderView *favView = mMainWidget->favoriteFolderView();
+  assert( favView );
+  foreach ( const QPointer<KMFolder> &f, selectedFolders() )
+    favView->addFolder( f );
+}
+
+void KMFolderTree::slotUnhideLocalInbox()
+{
+  disconnect( kmkernel->inboxFolder(), SIGNAL(msgAdded(KMFolder*,Q_UINT32)),
+              this, SLOT(slotUnhideLocalInbox()) );
+  reload();
+}
+
 #include "kmfoldertree.moc"
