@@ -28,7 +28,7 @@ using KMail::AccountManager;
 #include "kmmainwidget.h"
 #include "kmfoldertree.h"
 #include "recentaddresses.h"
-using KRecentAddress::RecentAddresses;
+using KPIM::RecentAddresses;
 #include "kmmsgdict.h"
 #include <kpimidentities/identity.h>
 #include <kpimidentities/identitymanager.h>
@@ -49,7 +49,6 @@ using KMail::TemplateParser;
 
 #include <kmessagebox.h>
 #include <knotification.h>
-#include <kstaticdeleter.h>
 #include <kstandarddirs.h>
 #include <kconfig.h>
 #include <kpassivepopup.h>
@@ -90,12 +89,10 @@ KMKernel *KMKernel::mySelf = 0;
 /********************************************************************/
 KMKernel::KMKernel (QObject *parent, const char *name) :
   QObject(parent),
-  mIdentityManager(0), mConfigureDialog(0),
+  mIdentityManager(0), mConfigureDialog(0), mICalIface(0), mMailService(0),
   mContextMenuShown( false ), mWallet( 0 )
 {
-  (void) new KmailAdaptor( this );
-  QDBusConnection::sessionBus().registerObject("/KMail", this);
-  kDebug(5006) << "KMKernel::KMKernel" << endl;
+  kDebug(5006);
   setObjectName( name );
   mySelf = this;
   the_startingUp = true;
@@ -130,9 +127,6 @@ KMKernel::KMKernel (QObject *parent, const char *name) :
   // would be unexpected
   GlobalSettings::self();
 
-  // Set up DCOP interface
-  mICalIface = new KMailICalIfaceImpl();
-
   mJobScheduler = new JobScheduler( this );
 
   mXmlGuiInstance = KComponentData();
@@ -151,8 +145,6 @@ KMKernel::KMKernel (QObject *parent, const char *name) :
   } else {
     netCodec = QTextCodec::codecForLocale();
   }
-  mMailService =  new MailServiceImpl();
-  QDBusConnection::sessionBus().connect(QString(), "/KMail", DBUS_KMAIL, "kmailSelectFolder(QString)", this, SLOT(selectFolder(QString)) );
 
   connect( MailTransport::TransportManager::self(),
            SIGNAL(transportRemoved(int,QString)),
@@ -175,17 +167,23 @@ KMKernel::~KMKernel ()
 
   delete mICalIface;
   mICalIface = 0;
-#ifdef __GNUC__
-#warning: mMailservice delete crashes for me...
-#endif
-  //delete mMailService;
+  delete mMailService;
   mMailService = 0;
 
   GlobalSettings::self()->writeConfig();
   delete mWallet;
   mWallet = 0;
   mySelf = 0;
-  kDebug(5006) << "KMKernel::~KMKernel" << endl;
+  kDebug(5006);
+}
+
+void KMKernel::setupDBus()
+{
+  (void) new KmailAdaptor( this );
+  QDBusConnection::sessionBus().registerObject("/KMail", this);
+  mICalIface = new KMailICalIfaceImpl();
+  mICalIface->readConfig();
+  mMailService =  new MailServiceImpl();
 }
 
 bool KMKernel::handleCommandLine( bool noArgsOpensReader )
@@ -323,7 +321,7 @@ QStringList KMKernel::accounts()
 
 void KMKernel::checkAccount (const QString &account) //might create a new reader but won't show!!
 {
-  kDebug(5006) << "KMKernel::checkMail called" << endl;
+  kDebug(5006) <<"KMKernel::checkMail called";
 
   KMAccount* acct = kmkernel->acctMgr()->findByName(account);
   if (acct)
@@ -334,12 +332,13 @@ void KMKernel::openReader( bool onlyCheck )
 {
   mWin = 0;
   KMainWindow *ktmw = 0;
-  kDebug(5006) << "KMKernel::openReader called" << endl;
+  kDebug(5006) <<"KMKernel::openReader called";
 
-  for ( QList<KMainWindow*>::const_iterator it = KMainWindow::memberList().begin();
-       it != KMainWindow::memberList().end(); ++it ) {
-    if ( ::qobject_cast<KMMainWin *>(*it) ) {
-      ktmw = (*it);
+  foreach ( KMainWindow *window, KMainWindow::memberList() )
+  {
+    if ( ::qobject_cast<KMMainWin *>( window ) )
+    {
+      ktmw = window;
       break;
     }
   }
@@ -373,7 +372,7 @@ int KMKernel::openComposer( const QString &to, const QString &cc,
                             const KUrl::List &attachURLs,
                             const QStringList &customHeaders )
 {
-  kDebug(5006) << "KMKernel::openComposer called" << endl;
+  kDebug(5006) <<"KMKernel::openComposer called";
   KMMessage *msg = new KMMessage;
   msg->initHeader();
   msg->setCharset("utf-8");
@@ -393,7 +392,7 @@ int KMKernel::openComposer( const QString &to, const QString &cc,
     }
     else {
       TemplateParser parser( msg, TemplateParser::NewMessage,
-			     "", false, false, false, false );
+                             QString(), false, false, false );
       parser.process( NULL, NULL );
     }
   }
@@ -402,7 +401,7 @@ int KMKernel::openComposer( const QString &to, const QString &cc,
   }
   else {
     TemplateParser parser( msg, TemplateParser::NewMessage,
-			   "", false, false, false, false );
+                           QString(), false, false, false );
     parser.process( NULL, NULL );
   }
 
@@ -450,7 +449,7 @@ int KMKernel::openComposer (const QString &to, const QString &cc,
                             const QByteArray &attachContDisp,
                             const QByteArray &attachCharset )
 {
-  kDebug(5006) << "KMKernel::openComposer()" << endl;
+  kDebug(5006) <<"KMKernel::openComposer()";
 
   KMMessage *msg = new KMMessage;
   KMMessagePart *msgPart = 0;
@@ -464,7 +463,7 @@ int KMKernel::openComposer (const QString &to, const QString &cc,
     msg->setBody(body.toUtf8());
   } else {
     TemplateParser parser( msg, TemplateParser::NewMessage,
-      "", false, false, false, false );
+                           QString(), false, false, false );
     parser.process( NULL, NULL );
   }
 
@@ -504,8 +503,8 @@ int KMKernel::openComposer (const QString &to, const QString &cc,
         msgPart->setContentDisposition( attachContDisp );
       }
       if( !attachCharset.isEmpty() ) {
-        // kDebug(5006) << "KMKernel::openComposer set attachCharset to "
-        // << attachCharset << endl;
+        // kDebug(5006) <<"KMKernel::openComposer set attachCharset to"
+        // << attachCharset;
         msgPart->setCharset( attachCharset );
       }
       // Don't show the composer window, if the automatic sending is checked
@@ -544,7 +543,7 @@ void KMKernel::setDefaultTransport( const QString & transport )
 {
   MailTransport::Transport *t = MailTransport::TransportManager::self()->transportByName( transport, false );
   if ( !t ) {
-    kWarning() << "The transport you entered is not available" << endl;
+    kWarning(5006) <<"The transport you entered is not available";
     return;
   }
   MailTransport::TransportManager::self()->setDefaultTransport( t->id() );
@@ -565,7 +564,7 @@ QDBusObjectPath KMKernel::openComposer(const QString &to, const QString &cc,
     msg->setBody(body.toUtf8());
   } else {
     TemplateParser parser( msg, TemplateParser::NewMessage,
-			   "", false, false, false, false );
+                           QString(), false, false, false );
     parser.process( NULL, NULL );
   }
 
@@ -615,12 +614,12 @@ QDBusObjectPath KMKernel::newMessage(const QString &to,
 
   if ( useFolderId ) {
     TemplateParser parser( msg, TemplateParser::NewMessage,
-      "", false, false, false, false );
+                           QString(), false, false, false );
     parser.process( NULL, folder );
     win = makeComposer( msg, id );
   } else {
     TemplateParser parser( msg, TemplateParser::NewMessage,
-      "", false, false, false, false );
+                           QString(), false, false, false );
     parser.process( NULL, NULL );
     win = makeComposer( msg );
   }
@@ -683,9 +682,9 @@ int KMKernel::dbusAddMessage( const QString & foldername, const QString & msgUrl
 int KMKernel::dbusAddMessage( const QString & foldername,const KUrl & msgUrl,
                               const QString & MsgStatusFlags)
 {
-  kDebug(5006) << "KMKernel::dbusAddMessage called" << endl;
+  kDebug(5006) <<"KMKernel::dbusAddMessage called";
 
-  if ( foldername.isEmpty() || foldername.startsWith("."))
+  if ( foldername.isEmpty() || foldername.startsWith('.'))
     return -1;
 
   int retval;
@@ -720,7 +719,7 @@ int KMKernel::dbusAddMessage( const QString & foldername,const KUrl & msgUrl,
 
         for ( QStringList::Iterator it = subFList.begin(); it != subFList.end(); ++it ) {
           QString _newFolder = *it;
-          if(_newFolder.startsWith(".")) return -1;
+          if(_newFolder.startsWith('.')) return -1;
 
           if(root) {
             folder = the_folderMgr->findOrCreate(*it, false);
@@ -862,9 +861,9 @@ int KMKernel::dbusAddMessage_fastImport( const QString & foldername,
 {
   // Use this function to import messages without
   // search for already existing emails.
-  kDebug(5006) << "KMKernel::dbusAddMessage_fastImport called" << endl;
+  kDebug(5006) <<"KMKernel::dbusAddMessage_fastImport called";
 
-  if ( foldername.isEmpty() || foldername.startsWith("."))
+  if ( foldername.isEmpty() || foldername.startsWith('.'))
     return -1;
 
   int retval;
@@ -899,7 +898,7 @@ int KMKernel::dbusAddMessage_fastImport( const QString & foldername,
 
         for ( QStringList::Iterator it = subFList.begin(); it != subFList.end(); ++it ) {
           QString _newFolder = *it;
-          if(_newFolder.startsWith(".")) return -1;
+          if(_newFolder.startsWith('.')) return -1;
 
           if(root) {
             folder = the_folderMgr->findOrCreate(*it, false);
@@ -964,7 +963,7 @@ QStringList KMKernel::folderList() const
   return folders;
 }
 
-QDBusObjectPath KMKernel::getFolder( const QString& vpath )
+QString KMKernel::getFolder( const QString& vpath )
 {
   QString adaptorName;
   const QString localPrefix = "/Local";
@@ -984,9 +983,10 @@ QDBusObjectPath KMKernel::getFolder( const QString& vpath )
         delete folderAdaptor;
       }
     folderAdaptor = new KMail::FolderAdaptor(adaptorName);
-    return QDBusObjectPath(vpath);
+    return vpath;
   }
-  return QDBusObjectPath();
+  kWarning(5006) << "Folder not found:" << vpath;
+  return QString();
 }
 
 void KMKernel::raise()
@@ -996,8 +996,8 @@ void KMKernel::raise()
   if (!iface.isValid() || !(reply = iface.call("newInstance")).isValid())
   {
        QDBusError err = iface.lastError();
-       kError() << "Communication problem with kmail"
-                 << "Error message was: " << err.name() << ": \"" << err.message() << "\"" << endl;
+       kError() <<"Communication problem with kmail"
+                 << "Error message was:" << err.name() << ": \"" << err.message() << "\"";
   }
 
 }
@@ -1025,7 +1025,7 @@ bool KMKernel::showMail( quint32 serialNumber, const QString& /* messageId */ )
     KMMsgDict::instance()->getLocation(serialNumber, &folder, &idx);
     if (!folder || (idx == -1))
       return false;
-    folder->open( "showmail" );
+    KMFolderOpener openFolder(folder, "showmail");
     KMMsgBase *msgBase = folder->getMsgBase(idx);
     if (!msgBase)
       return false;
@@ -1042,7 +1042,6 @@ bool KMKernel::showMail( quint32 serialNumber, const QString& /* messageId */ )
 
     if (unGet)
       folder->unGetMsg(idx);
-    folder->close( "showmail" );
     return true;
   }
 
@@ -1056,7 +1055,7 @@ QString KMKernel::getFrom( quint32 serialNumber )
   KMMsgDict::instance()->getLocation(serialNumber, &folder, &idx);
   if (!folder || (idx == -1))
     return QString();
-  folder->open( "getFrom" );
+  KMFolderOpener openFolder(folder, "getFrom");
   KMMsgBase *msgBase = folder->getMsgBase(idx);
   if (!msgBase)
     return QString();
@@ -1065,7 +1064,6 @@ QString KMKernel::getFrom( quint32 serialNumber )
   QString result = msg->from();
   if (unGet)
     folder->unGetMsg(idx);
-  folder->close( "getFrom" );
   return result;
 }
 
@@ -1087,17 +1085,16 @@ QString KMKernel::debugSernum( quint32 serialNumber )
     // different folder
     if (folder && (idx != -1)) {
       // everything is ok
-      folder->open( "debugser" );
+      KMFolderOpener openFolder( folder, "debugser" );
       msg = folder->getMsgBase( idx );
       if (msg) {
-	res.append( QString( " subject %s,\n sender %s,\n date %s.\n" )
-		    .arg( msg->subject() )
-		    .arg( msg->fromStrip() )
-		    .arg( msg->dateStr() ) );
+        res.append( QString( " subject %s,\n sender %s,\n date %s.\n" )
+                             .arg( msg->subject() )
+                             .arg( msg->fromStrip() )
+                             .arg( msg->dateStr() ) );
       } else {
-	res.append( QString( "Invalid serial number." ) );
+        res.append( QString( "Invalid serial number." ) );
       }
-      folder->close( "debugser" );
     } else {
       res.append( QString( "Invalid serial number." ) );
     }
@@ -1264,8 +1261,8 @@ void KMKernel::recoverDeadLetters()
     return;
 
   KMFolder folder( 0, pathName + "autosave", KMFolderTypeMaildir, false /* no index */ );
-  const int rc = folder.open( "recover" );
-  if ( rc ) {
+  KMFolderOpener openFolder( &folder, "recover" );
+  if ( !folder.isOpened() ) {
     perror( "cannot open autosave folder" );
     return;
   }
@@ -1280,7 +1277,6 @@ void KMKernel::recoverDeadLetters()
       win->show();
     }
   }
-  folder.close( "recover" );
 }
 
 //-----------------------------------------------------------------------------
@@ -1380,18 +1376,18 @@ void KMKernel::init()
   the_previousVersion = group.readEntry("previous-version");
   group.writeEntry("previous-version", KMAIL_VERSION);
   QString foldersPath = group.readPathEntry( "folders" );
-  kDebug(5006) << k_funcinfo << "foldersPath (from config): '" << foldersPath << "'" << endl;
+  kDebug(5006) <<"foldersPath (from config): '" << foldersPath <<"'";
 
   if ( foldersPath.isEmpty() ) {
     foldersPath = localDataPath() + "mail";
     if ( transferMail( foldersPath ) ) {
       group.writePathEntry( "folders", foldersPath );
     }
-    kDebug(5006) << k_funcinfo << "foldersPath (after transferMail): '" << foldersPath << "'" << endl;
+    kDebug(5006) <<"foldersPath (after transferMail): '" << foldersPath <<"'";
   }
   //Here because folderMgr's need it when they read the index and sort tags
-  the_msgTagMgr = new KMMessageTagMgr(); 
-  the_msgTagMgr->readConfig(); 
+  the_msgTagMgr = new KMMessageTagMgr();
+  the_msgTagMgr->readConfig();
 
   // moved up here because KMMessage::stripOffPrefixes is used below
   KMMessage::readConfig();
@@ -1419,7 +1415,6 @@ void KMKernel::init()
 
   the_msgSender = new KMSender;
   the_server_is_ready = true;
-  imProxy()->initialize();
   { // area for config group "Composer"
     KConfigGroup group(cfg, "Composer");
     if (group.readEntry("pref-charsets", QStringList() ).isEmpty())
@@ -1428,7 +1423,6 @@ void KMKernel::init()
     }
   }
   readConfig();
-  mICalIface->readConfig();
   // filterMgr->dump();
 
   the_weaver =  new ThreadWeaver::Weaver( this );
@@ -1613,7 +1607,8 @@ void KMKernel::cleanup(void)
     }
   }
 
-  mICalIface->cleanup();
+  if ( mICalIface )
+    mICalIface->cleanup();
 
   QList<QPointer<KMFolder> > folders;
   QStringList strList;
@@ -1693,18 +1688,18 @@ bool KMKernel::transferMail( QString & destinationDir )
   // disabled for now since moving fails in certain cases (e.g. if symbolic links are involved)
   const QString kmailName = KGlobal::mainComponent().aboutData()()->programName();
   QString msg;
-  if ( KIO::NetAccess::exists( destinationDir, true, 0 ) ) {
+  if ( KIO::NetAccess::exists( destinationDir, KIO::NetAccess::SourceSide, 0 ) ) {
     // if destinationDir exists, we need to warn about possible
     // overwriting of files. otherwise, we don't have to
     msg = ki18nc( "%1-%3 is the application name, %4-%7 are folder path",
                   "<qt>The <i>%4</i> folder exists. "
                   "%1 now uses the <i>%5</i> folder for "
                   "its messages.<p>"
-                  "%2 can move the contents of <i>%6<i> into this folder for "
+                  "%2 can move the contents of <i>%6</i> into this folder for "
                   "you, though this may replace any existing files with "
-                  "the same name in <i>%7</i>.<p>"
+                  "the same name in <i>%7</i>.</p><p>"
                   "<strong>Would you like %3 to move the mail "
-                  "files now?</strong></qt>" )
+                  "files now?</strong></p></qt>" )
           .subs( kmailName ).subs( kmailName ).subs( kmailName )
           .subs( dir ).subs( destinationDir ).subs( dir ).subs( destinationDir )
           .toString();
@@ -1716,7 +1711,7 @@ bool KMKernel::transferMail( QString & destinationDir )
                   "its messages. %2 can move the contents of <i>%6</i> into "
                   "this folder for you.<p>"
                   "<strong>Would you like %3 to move the mail "
-                  "files now?</strong></qt>" )
+                  "files now?</strong></p></qt>" )
           .subs( kmailName ).subs( kmailName ).subs( kmailName )
           .subs( dir ).subs( destinationDir ).subs( dir )
           .toString();
@@ -1731,8 +1726,8 @@ bool KMKernel::transferMail( QString & destinationDir )
   }
 
   if ( !KIO::NetAccess::move( dir, destinationDir ) ) {
-    kDebug(5006) << k_funcinfo << "Moving " << dir << " to " << destinationDir << " failed: " << KIO::NetAccess::lastErrorString() << endl;
-    kDebug(5006) << k_funcinfo << "Deleting " << destinationDir << endl;
+    kDebug(5006) <<"Moving" << dir <<" to" << destinationDir <<" failed:" << KIO::NetAccess::lastErrorString();
+    kDebug(5006) <<"Deleting" << destinationDir;
     KIO::NetAccess::del( destinationDir, 0 );
     destinationDir = dir;
     return false;
@@ -1779,7 +1774,7 @@ void KMKernel::byteArrayToRemoteFile(const QByteArray &aData, const KUrl &aURL,
   bool overwrite)
 {
   // ## when KDE 3.3 is out: use KIO::storedPut to remove slotDataReq altogether
-  KIO::Job *job = KIO::put(aURL, -1, overwrite, false);
+  KIO::Job *job = KIO::put(aURL, -1, overwrite ? KIO::Overwrite : KIO::DefaultFlags);
   putData pd; pd.url = aURL; pd.data = aData; pd.offset = 0;
   mPutJobs.insert(job, pd);
   connect(job, SIGNAL(dataReq(KIO::Job*,QByteArray&)),
@@ -1800,7 +1795,7 @@ void KMKernel::slotDataReq(KIO::Job *job, QByteArray &data)
     // send MAX_CHUNK_SIZE bytes to the receiver (deep copy)
     data = QByteArray( (*it).data.data() + (*it).offset, MAX_CHUNK_SIZE );
     (*it).offset += MAX_CHUNK_SIZE;
-    //kDebug( 5006 ) << "Sending " << MAX_CHUNK_SIZE << " bytes ("
+    //kDebug( 5006 ) <<"Sending" << MAX_CHUNK_SIZE <<" bytes ("
     //                << remainingBytes - MAX_CHUNK_SIZE << " bytes remain)\n";
   }
   else
@@ -1809,7 +1804,7 @@ void KMKernel::slotDataReq(KIO::Job *job, QByteArray &data)
     data = QByteArray( (*it).data.data() + (*it).offset, remainingBytes );
     (*it).data = QByteArray();
     (*it).offset = 0;
-    //kDebug( 5006 ) << "Sending " << remainingBytes << " bytes\n";
+    //kDebug( 5006 ) <<"Sending" << remainingBytes <<" bytes";
   }
 }
 
@@ -1908,7 +1903,7 @@ void KMKernel::emergencyExit( const QString& reason )
                       "terminate now.\nThe error was:\n%1", reason );
   }
 
-  kWarning() << mesg << endl;
+  kWarning(5006) << mesg;
   KNotification::event(KNotification::Catastrophe, mesg);
 
   ::exit(1);
@@ -1989,7 +1984,7 @@ bool KMKernel::folderIsSentMailFolder( const KMFolder * folder )
 
 KPIMIdentities::IdentityManager * KMKernel::identityManager() {
   if ( !mIdentityManager ) {
-    kDebug(5006) << "instantating KPIMIdentities::IdentityManager" << endl;
+    kDebug(5006) <<"instantating KPIMIdentities::IdentityManager";
     mIdentityManager = new KPIMIdentities::IdentityManager( false, this, "mIdentityManager" );
   }
   return mIdentityManager;
@@ -2066,7 +2061,7 @@ KMailICalIfaceImpl& KMKernel::iCalIface()
 
 void KMKernel::selectFolder( const QString &folderPath )
 {
-  kDebug(5006)<<"Selecting a folder "<<folderPath<<endl;
+  kDebug(5006)<<"Selecting a folder"<<folderPath;
   const QString localPrefix = "/Local";
   KMFolder *folder = kmkernel->folderMgr()->getFolderByURL( folderPath );
   if ( !folder && folderPath.startsWith( localPrefix ) )
@@ -2158,11 +2153,6 @@ KMFolder* KMKernel::findFolderById( const QString& idString )
   return folder;
 }
 
-::KIMProxy* KMKernel::imProxy()
-{
-  return KIMProxy::instance();
-}
-
 void KMKernel::enableMailCheck()
 {
   mMailCheckAborted = false;
@@ -2278,9 +2268,8 @@ void KMKernel::transportRemoved(int id, const QString & name)
 
   // if the deleted transport is the currently used transport reset it to default
   const QString& currentTransport = GlobalSettings::self()->currentTransport();
-  if ( name == currentTransport ) {
+  if ( name == currentTransport )
     GlobalSettings::self()->setCurrentTransport( QString() );
-  }
 
   if ( !changedIdents.isEmpty() ) {
     QString information = i18np( "This identity has been changed to use the default transport:",
