@@ -168,8 +168,8 @@ void KMReaderWin::objectTreeToDecryptedMsg( partNode* node,
                                             bool weAreReplacingTheRootNode,
                                             int recCount )
 {
-  kDebug(5006) << QString("-------------------------------------------------" ) << endl;
-  kDebug(5006) << QString("KMReaderWin::objectTreeToDecryptedMsg( %1 )  START").arg( recCount ) << endl;
+  kDebug(5006) << QString("-------------------------------------------------" );
+  kDebug(5006) << QString("KMReaderWin::objectTreeToDecryptedMsg( %1 )  START").arg( recCount );
   if( node ) {
     partNode* curNode = node;
     partNode* dataNode = curNode;
@@ -178,50 +178,50 @@ void KMReaderWin::objectTreeToDecryptedMsg( partNode* node,
 
     switch( curNode->type() ){
       case DwMime::kTypeText: {
-kDebug(5006) << "* text *" << endl;
+          kDebug(5006) <<"* text *";
           switch( curNode->subType() ){
           case DwMime::kSubtypeHtml:
-kDebug(5006) << "html" << endl;
+            kDebug(5006) <<"html";
             break;
           case DwMime::kSubtypeXVCard:
-kDebug(5006) << "v-card" << endl;
+            kDebug(5006) <<"v-card";
             break;
           case DwMime::kSubtypeRichtext:
-kDebug(5006) << "rich text" << endl;
+            kDebug(5006) <<"rich text";
             break;
           case DwMime::kSubtypeEnriched:
-kDebug(5006) << "enriched " << endl;
+            kDebug(5006) <<"enriched";
             break;
           case DwMime::kSubtypePlain:
-kDebug(5006) << "plain " << endl;
+            kDebug(5006) <<"plain";
             break;
           default:
-kDebug(5006) << "default " << endl;
+            kDebug(5006) <<"default";
             break;
           }
         }
         break;
       case DwMime::kTypeMultipart: {
-kDebug(5006) << "* multipart *" << endl;
+          kDebug(5006) <<"* multipart *";
           bIsMultipart = true;
           switch( curNode->subType() ){
           case DwMime::kSubtypeMixed:
-kDebug(5006) << "mixed" << endl;
+            kDebug(5006) <<"mixed";
             break;
           case DwMime::kSubtypeAlternative:
-kDebug(5006) << "alternative" << endl;
+            kDebug(5006) <<"alternative";
             break;
           case DwMime::kSubtypeDigest:
-kDebug(5006) << "digest" << endl;
+            kDebug(5006) <<"digest";
             break;
           case DwMime::kSubtypeParallel:
-kDebug(5006) << "parallel" << endl;
+            kDebug(5006) <<"parallel";
             break;
           case DwMime::kSubtypeSigned:
-kDebug(5006) << "signed" << endl;
+            kDebug(5006) <<"signed";
             break;
           case DwMime::kSubtypeEncrypted: {
-kDebug(5006) << "encrypted" << endl;
+              kDebug(5006) <<"encrypted";
               if ( child ) {
                 /*
                     ATTENTION: This code is to be replaced by the new 'auto-detect' feature. --------------------------------------
@@ -236,16 +236,16 @@ kDebug(5006) << "encrypted" << endl;
             }
             break;
           default :
-kDebug(5006) << "(  unknown subtype  )" << endl;
+            kDebug(5006) <<"(  unknown subtype  )";
             break;
           }
         }
         break;
       case DwMime::kTypeMessage: {
-kDebug(5006) << "* message *" << endl;
+          kDebug(5006) <<"* message *";
           switch( curNode->subType() ){
           case DwMime::kSubtypeRfc822: {
-kDebug(5006) << "RfC 822" << endl;
+              kDebug(5006) <<"RfC 822";
               if ( child )
                 dataNode = child;
             }
@@ -254,25 +254,25 @@ kDebug(5006) << "RfC 822" << endl;
         }
         break;
       case DwMime::kTypeApplication: {
-kDebug(5006) << "* application *" << endl;
+          kDebug(5006) <<"* application *";
           switch( curNode->subType() ){
           case DwMime::kSubtypePostscript:
-kDebug(5006) << "postscript" << endl;
+            kDebug(5006) <<"postscript";
             break;
           case DwMime::kSubtypeOctetStream: {
-kDebug(5006) << "octet stream" << endl;
+              kDebug(5006) <<"octet stream";
               if ( child )
                 dataNode = child;
             }
             break;
           case DwMime::kSubtypePgpEncrypted:
-kDebug(5006) << "pgp encrypted" << endl;
+            kDebug(5006) <<"pgp encrypted";
             break;
           case DwMime::kSubtypePgpSignature:
-kDebug(5006) << "pgp signed" << endl;
+            kDebug(5006) <<"pgp signed";
             break;
           case DwMime::kSubtypePkcs7Mime: {
-kDebug(5006) << "pkcs7 mime" << endl;
+              kDebug(5006) <<"pkcs7 mime";
               // note: subtype Pkcs7Mime can also be signed
               //       and we do NOT want to remove the signature!
               if ( child && curNode->encryptionState() != KMMsgNotEncrypted )
@@ -283,37 +283,37 @@ kDebug(5006) << "pkcs7 mime" << endl;
         }
         break;
       case DwMime::kTypeImage: {
-kDebug(5006) << "* image *" << endl;
+          kDebug(5006) <<"* image *";
           switch( curNode->subType() ){
           case DwMime::kSubtypeJpeg:
-kDebug(5006) << "JPEG" << endl;
+            kDebug(5006) <<"JPEG";
             break;
           case DwMime::kSubtypeGif:
-kDebug(5006) << "GIF" << endl;
+            kDebug(5006) <<"GIF";
             break;
           }
         }
         break;
       case DwMime::kTypeAudio: {
-kDebug(5006) << "* audio *" << endl;
+          kDebug(5006) <<"* audio *";
           switch( curNode->subType() ){
           case DwMime::kSubtypeBasic:
-kDebug(5006) << "basic" << endl;
+            kDebug(5006) <<"basic";
             break;
           }
         }
         break;
       case DwMime::kTypeVideo: {
-kDebug(5006) << "* video *" << endl;
+          kDebug(5006) <<"* video *";
           switch( curNode->subType() ){
           case DwMime::kSubtypeMpeg:
-kDebug(5006) << "mpeg" << endl;
+            kDebug(5006) <<"mpeg";
             break;
           }
         }
         break;
       case DwMime::kTypeModel:
-kDebug(5006) << "* model *" << endl;
+          kDebug(5006) <<"* model *";
         break;
     }
 
@@ -327,20 +327,20 @@ kDebug(5006) << "* model *" << endl;
             ? &rootHeaders
             : 0 ) );
     if( dataNode == curNode ) {
-kDebug(5006) << "dataNode == curNode:  Save curNode without replacing it." << endl;
+      kDebug(5006) <<"dataNode == curNode:  Save curNode without replacing it.";
 
       // A) Store the headers of this part IF curNode is not the root node
       //    AND we are not replacing a node that already *has* replaced
       //    the root node in previous recursion steps of this function...
       if( headers ) {
         if( dataNode->parentNode() && !weAreReplacingTheRootNode ) {
-kDebug(5006) << "dataNode is NOT replacing the root node:  Store the headers." << endl;
+          kDebug(5006) <<"dataNode is NOT replacing the root node:  Store the headers.";
           resultingData += headers->AsString().c_str();
         } else if( weAreReplacingTheRootNode && part && part->hasHeaders() ){
-kDebug(5006) << "dataNode replace the root node:  Do NOT store the headers but change" << endl;
-kDebug(5006) << "                                 the Message's headers accordingly." << endl;
-kDebug(5006) << "              old Content-Type = " << rootHeaders.ContentType().AsString().c_str() << endl;
-kDebug(5006) << "              new Content-Type = " << headers->ContentType(   ).AsString().c_str() << endl;
+          kDebug(5006) <<"dataNode replace the root node:  Do NOT store the headers but change";
+          kDebug(5006) <<"                                 the Message's headers accordingly.";
+          kDebug(5006) <<"              old Content-Type =" << rootHeaders.ContentType().AsString().c_str();
+          kDebug(5006) <<"              new Content-Type =" << headers->ContentType(   ).AsString().c_str();
           rootHeaders.ContentType()             = headers->ContentType();
           theMessage.setContentTransferEncodingStr(
               headers->HasContentTransferEncoding()
@@ -354,12 +354,12 @@ kDebug(5006) << "              new Content-Type = " << headers->ContentType(   )
 
       // B) Store the body of this part.
       if( headers && bIsMultipart && dataNode->firstChild() )  {
-kDebug(5006) << "is valid Multipart, processing children:" << endl;
+        kDebug(5006) <<"is valid Multipart, processing children:";
         QByteArray boundary = headers->ContentType().Boundary().c_str();
         curNode = dataNode->firstChild();
         // store children of multipart
         while( curNode ) {
-kDebug(5006) << "--boundary" << endl;
+          kDebug(5006) <<"--boundary";
           if( resultingData.size() &&
               ( '\n' != resultingData.at( resultingData.size()-1 ) ) )
             resultingData += '\n';
@@ -377,23 +377,23 @@ kDebug(5006) << "--boundary" << endl;
                                     recCount + 1 );
           curNode = curNode->nextSibling();
         }
-kDebug(5006) << "--boundary--" << endl;
+        kDebug(5006) <<"--boundary--";
         resultingData += "\n--";
         resultingData += boundary;
         resultingData += "--\n\n";
-kDebug(5006) << "Multipart processing children - DONE" << endl;
+        kDebug(5006) <<"Multipart processing children - DONE";
       } else if( part ){
         // store simple part
-kDebug(5006) << "is Simple part or invalid Multipart, storing body data .. DONE" << endl;
+        kDebug(5006) <<"is Simple part or invalid Multipart, storing body data .. DONE";
         resultingData += part->Body().AsString().c_str();
       }
     } else {
-kDebug(5006) << "dataNode != curNode:  Replace curNode by dataNode." << endl;
+      kDebug(5006) <<"dataNode != curNode:  Replace curNode by dataNode.";
       bool rootNodeReplaceFlag = weAreReplacingTheRootNode || !curNode->parentNode();
       if( rootNodeReplaceFlag ) {
-kDebug(5006) << "                      Root node will be replaced." << endl;
+        kDebug(5006) <<"                      Root node will be replaced.";
       } else {
-kDebug(5006) << "                      Root node will NOT be replaced." << endl;
+        kDebug(5006) <<"                      Root node will NOT be replaced.";
       }
       // store special data to replace the current part
       // (e.g. decrypted data or embedded RfC 822 data)
@@ -404,7 +404,7 @@ kDebug(5006) << "                      Root node will NOT be replaced." << endl;
                                 recCount + 1 );
     }
   }
-  kDebug(5006) << QString("\nKMReaderWin::objectTreeToDecryptedMsg( %1 )  END").arg( recCount ) << endl;
+  kDebug(5006) << QString("\nKMReaderWin::objectTreeToDecryptedMsg( %1 )  END").arg( recCount );
 }
 
 
@@ -451,8 +451,8 @@ const int KMReaderWin::delay = 150;
 
 //-----------------------------------------------------------------------------
 KMReaderWin::KMReaderWin(QWidget *aParent,
-			 QWidget *mainWindow,
-			 KActionCollection* actionCollection,
+                         QWidget *mainWindow,
+                         KActionCollection* actionCollection,
                          Qt::WindowFlags aFlags )
   : QWidget(aParent, aFlags | Qt::WDestructiveClose),
     mAttachmentStrategy( 0 ),
@@ -473,7 +473,6 @@ KMReaderWin::KMReaderWin(QWidget *aParent,
     mUrlOpenAction( 0 ),
     mUrlSaveAsAction( 0 ),
     mAddBookmarksAction( 0 ),
-    mStartIMChatAction( 0 ),
     mSelectAllAction( 0 ),
     mSelectEncodingAction( 0 ),
     mToggleFixFontAction( 0 ),
@@ -506,9 +505,9 @@ KMReaderWin::KMReaderWin(QWidget *aParent,
   mResizeTimer.setSingleShot( true );
   mDelayedMarkTimer.setSingleShot( true );
   connect( &updateReaderWinTimer, SIGNAL(timeout()),
-  	   this, SLOT(updateReaderWin()) );
+           this, SLOT(updateReaderWin()) );
   connect( &mResizeTimer, SIGNAL(timeout()),
-  	   this, SLOT(slotDelayedResize()) );
+           this, SLOT(slotDelayedResize()) );
   connect( &mDelayedMarkTimer, SIGNAL(timeout()),
            this, SLOT(slotTouchMessage()) );
 
@@ -647,10 +646,6 @@ void KMReaderWin::createActions( KActionCollection * ac ) {
   ac->addAction("toggle_fixedfont", mToggleFixFontAction );
   connect(mToggleFixFontAction, SIGNAL(triggered(bool) ), SLOT(slotToggleFixedFont()));
   mToggleFixFontAction->setShortcut(QKeySequence(Qt::Key_X));
-
-  mStartIMChatAction  = new KAction(i18n("Chat &With..."), this);
-  ac->addAction("start_im_chat", mStartIMChatAction );
-  connect(mStartIMChatAction, SIGNAL(triggered(bool) ), SLOT(slotIMChat()));
 }
 
 // little helper function
@@ -722,7 +717,7 @@ void KMReaderWin::slotAllHeaders() {
 
 void KMReaderWin::slotLevelQuote( int l )
 {
-  kDebug(5006) << "Old Level: " << mLevelQuote << " New Level: " << l << endl;
+  kDebug(5006) <<"Old Level:" << mLevelQuote <<" New Level:" << l;
   mLevelQuote = l;
   QScrollArea *scrollview = mViewer->view();
   mSavedRelativePosition = (float)scrollview->widget()->pos().y() /
@@ -802,7 +797,7 @@ void KMReaderWin::slotMessageArrived( KMMessage *msg )
     if ( msg->getMsgSerNum() == mWaitingForSerNum ) {
       setMsg( msg, true );
     } else {
-      kDebug( 5006 ) <<  "KMReaderWin::slotMessageArrived - ignoring update" << endl;
+      kDebug( 5006 ) <<"KMReaderWin::slotMessageArrived - ignoring update";
     }
   }
 }
@@ -812,7 +807,7 @@ void KMReaderWin::update( KMail::Interface::Observable * observable )
 {
   if ( !mAtmUpdate ) {
     // reparse the msg
-    kDebug(5006) << "KMReaderWin::update - message" << endl;
+    kDebug(5006) <<"KMReaderWin::update - message";
     updateReaderWin();
     return;
   }
@@ -825,12 +820,12 @@ void KMReaderWin::update( KMail::Interface::Observable * observable )
 
   // find our partNode and update it
   if ( !msg->lastUpdatedPart() ) {
-    kDebug(5006) << "KMReaderWin::update - no updated part" << endl;
+    kDebug(5006) <<"KMReaderWin::update - no updated part";
     return;
   }
   partNode* node = mRootNode->findNodeForDwPart( msg->lastUpdatedPart() );
   if ( !node ) {
-    kDebug(5006) << "KMReaderWin::update - can't find node for part" << endl;
+    kDebug(5006) <<"KMReaderWin::update - can't find node for part";
     return;
   }
   node->setDwPart( msg->lastUpdatedPart() );
@@ -903,7 +898,7 @@ void KMReaderWin::readConfig(void)
   mHtmlLoadExternal = reader.readEntry( "htmlLoadExternal", false );
 
   setHeaderStyleAndStrategy( HeaderStyle::create( reader.readEntry( "header-style", "fancy" ) ),
-			     HeaderStrategy::create( reader.readEntry( "header-set-displayed", "rich" ) ) );
+                             HeaderStrategy::create( reader.readEntry( "header-set-displayed", "rich" ) ) );
   KToggleAction *raction = actionForHeaderStyle( headerStyle(), headerStrategy() );
   if ( raction )
     raction->setChecked( true );
@@ -1014,47 +1009,21 @@ void KMReaderWin::initHtmlWidget(void)
   if ( !htmlWriter() )
 #ifdef KMAIL_READER_HTML_DEBUG
     mHtmlWriter = new TeeHtmlWriter( new FileHtmlWriter( QString() ),
-				     new KHtmlPartHtmlWriter( mViewer, 0 ) );
+                                     new KHtmlPartHtmlWriter( mViewer, 0 ) );
 #else
     mHtmlWriter = new KHtmlPartHtmlWriter( mViewer, 0 );
 #endif
 
   connect(mViewer->browserExtension(),
-          SIGNAL(openUrlRequest(const KUrl &, const KParts::URLArgs &)),this,
-          SLOT(slotUrlOpen(const KUrl &)));
+          SIGNAL(openUrlRequest(const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &)),this,
+          SLOT(slotUrlOpen(const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &)));
   connect(mViewer->browserExtension(),
-          SIGNAL(createNewWindow(const KUrl &, const KParts::URLArgs &)),this,
-          SLOT(slotUrlOpen(const KUrl &)));
+          SIGNAL(createNewWindow(const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &)),this,
+          SLOT(slotUrlOpen(const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &)));
   connect(mViewer,SIGNAL(onURL(const QString &)),this,
           SLOT(slotUrlOn(const QString &)));
   connect(mViewer,SIGNAL(popupMenu(const QString &, const QPoint &)),
           SLOT(slotUrlPopup(const QString &, const QPoint &)));
-  connect( kmkernel->imProxy(), SIGNAL( sigContactPresenceChanged( const QString & ) ),
-          this, SLOT( contactStatusChanged( const QString & ) ) );
-  connect( kmkernel->imProxy(), SIGNAL( sigPresenceInfoExpired() ),
-          this, SLOT( updateReaderWin() ) );
-}
-
-void KMReaderWin::contactStatusChanged( const QString &uid)
-{
-//  kDebug( 5006 ) << k_funcinfo << " got a presence change for " << uid << endl;
-  // get the list of nodes for this contact from the htmlView
-  DOM::NodeList presenceNodes = mViewer->htmlDocument()
-    .getElementsByName( DOM::DOMString( QString::fromLatin1("presence-") + uid ) );
-  for ( unsigned int i = 0; i < presenceNodes.length(); ++i ) {
-    DOM::Node n =  presenceNodes.item( i );
-    kDebug( 5006 ) << "name is " << n.nodeName().string() << endl;
-    kDebug( 5006 ) << "value of content was " << n.firstChild().nodeValue().string() << endl;
-#ifdef __GNUC__
-#warning Port KIMProxy usage!
-#endif
-/*    QString newPresence = kmkernel->imProxy()->presenceString( uid );
-    if ( newPresence.isNull() ) // KHTML crashes if you setNodeValue( QString() )
-      newPresence = QString::fromLatin1( "ENOIMRUNNING" );
-    n.firstChild().setNodeValue( newPresence );*/
-//    kDebug( 5006 ) << "value of content is now " << n.firstChild().nodeValue().string() << endl;
-  }
-//  kDebug( 5006 ) << "and we updated the above presence nodes" << uid << endl;
 }
 
 void KMReaderWin::setAttachmentStrategy( const AttachmentStrategy * strategy ) {
@@ -1063,7 +1032,7 @@ void KMReaderWin::setAttachmentStrategy( const AttachmentStrategy * strategy ) {
 }
 
 void KMReaderWin::setHeaderStyleAndStrategy( const HeaderStyle * style,
-					     const HeaderStrategy * strategy ) {
+                                             const HeaderStrategy * strategy ) {
   mHeaderStyle = style ? style : HeaderStyle::fancy();
   mHeaderStrategy = strategy ? strategy : HeaderStrategy::rich();
   update( true );
@@ -1091,8 +1060,8 @@ void KMReaderWin::setOverrideEncoding( const QString & encoding )
       }
       if ( i == encodings.size() ) {
         // the value of encoding is unknown => use Auto
-        kWarning(5006) << "Unknown override character encoding \"" << encoding
-                       << "\". Using Auto instead." << endl;
+        kWarning(5006) <<"Unknown override character encoding \"" << encoding
+                       << "\". Using Auto instead.";
         mSelectEncodingAction->setCurrentItem( 0 );
         mOverrideEncoding.clear();
       }
@@ -1111,7 +1080,7 @@ void KMReaderWin::setPrintFont( const QFont& font )
 //-----------------------------------------------------------------------------
 const QTextCodec * KMReaderWin::overrideCodec() const
 {
-  kDebug(5006) << k_funcinfo << " mOverrideEncoding == '" << mOverrideEncoding << "'" << endl;
+  kDebug(5006) <<" mOverrideEncoding == '" << mOverrideEncoding <<"'";
   if ( mOverrideEncoding.isEmpty() || mOverrideEncoding == "Auto" ) // Auto
     return 0;
   else
@@ -1143,10 +1112,10 @@ void KMReaderWin::readGlobalOverrideCodec()
 void KMReaderWin::setMsg(KMMessage* aMsg, bool force)
 {
   if (aMsg)
-      kDebug(5006) << "(" << aMsg->getMsgSerNum() << ", last " << mLastSerNum << ") " << aMsg->subject() << " "
-        << aMsg->fromStrip() << ", readyToShow " << (aMsg->readyToShow()) << endl;
+      kDebug(5006) <<"(" << aMsg->getMsgSerNum() <<", last" << mLastSerNum <<")" << aMsg->subject()
+        << aMsg->fromStrip() << ", readyToShow" << (aMsg->readyToShow());
 
-	//Reset the level quote if the msg has changed.
+  //Reset the level quote if the msg has changed.
   if (aMsg && aMsg->getMsgSerNum() != mLastSerNum ){
     mLevelQuote = GlobalSettings::self()->collapseQuoteLevelSpin()-1;
   }
@@ -1323,24 +1292,24 @@ void KMReaderWin::displayAboutPage()
 {
   KLocalizedString info =
     ki18nc("%1: KMail version; %2: help:// URL; %3: homepage URL; "
-	 "%4: generated list of new features; "
-	 "%5: First-time user text (only shown on first start); "
+         "%4: generated list of new features; "
+         "%5: First-time user text (only shown on first start); "
          "%6: generated list of important changes; "
-	 "--- end of comment ---",
-	 "<h2 style='margin-top: 0px;'>Welcome to KMail %1</h2><p>KMail is the email client for the K "
-	 "Desktop Environment. It is designed to be fully compatible with "
-	 "Internet mailing standards including MIME, SMTP, POP3 and IMAP."
-	 "</p>\n"
-	 "<ul><li>KMail has many powerful features which are described in the "
-	 "<a href=\"%2\">documentation</a></li>\n"
-	 "<li>The <a href=\"%3\">KMail homepage</A> offers information about "
-	 "new versions of KMail</li></ul>\n"
+         "--- end of comment ---",
+         "<h2 style='margin-top: 0px;'>Welcome to KMail %1</h2><p>KMail is the email client for the K "
+         "Desktop Environment. It is designed to be fully compatible with "
+         "Internet mailing standards including MIME, SMTP, POP3 and IMAP."
+         "</p>\n"
+         "<ul><li>KMail has many powerful features which are described in the "
+         "<a href=\"%2\">documentation</a></li>\n"
+         "<li>The <a href=\"%3\">KMail homepage</A> offers information about "
+         "new versions of KMail</li></ul>\n"
          "%6\n" // important changes
          "%4\n" // new features
-	 "%5\n" // first start info
-	 "<p>We hope that you will enjoy KMail.</p>\n"
-	 "<p>Thank you,</p>\n"
-	     "<p style='margin-bottom: 0px'>&nbsp; &nbsp; The KMail Team</p>")
+         "%5\n" // first start info
+         "<p>We hope that you will enjoy KMail.</p>\n"
+         "<p>Thank you,</p>\n"
+         "<p style='margin-bottom: 0px'>&nbsp; &nbsp; The KMail Team</p>")
            .subs( KMAIL_VERSION ) // KMail version
            .subs( "help:/kmail/index.html" ) // KMail help:// URL
            .subs( "http://kontact.kde.org/kmail/" ); // KMail homepage URL
@@ -1361,11 +1330,11 @@ void KMReaderWin::displayAboutPage()
 
   if( kmkernel->firstStart() ) {
     info = info.subs( i18n("<p>Please take a moment to fill in the KMail "
-			  "configuration panel at Settings-&gt;Configure "
-			  "KMail.\n"
-			  "You need to create at least a default identity and "
-			  "an incoming as well as outgoing mail account."
-			  "</p>\n") );
+                           "configuration panel at Settings-&gt;Configure "
+                           "KMail.\n"
+                           "You need to create at least a default identity and "
+                           "an incoming as well as outgoing mail account."
+                           "</p>\n") );
   } else {
     info = info.subs( QString() ); // remove the place holder
   }
@@ -1405,8 +1374,9 @@ void KMReaderWin::updateReaderWin()
 
   htmlWriter()->reset();
 
-  KMFolder *folder;
-  if ( message( &folder ) ) {
+  KMFolder* folder = 0;
+  if (message(&folder))
+  {
     if ( mShowColorbar ) {
       mColorBar->show();
     } else {
@@ -1455,8 +1425,8 @@ void KMReaderWin::displayMessage() {
 
   mMimePartTree->clear();
   showHideMimeTree( !msg || // treat no message as "text/plain"
-		    ( msg->type() == DwMime::kTypeText
-		      && msg->subtype() == DwMime::kSubtypePlain ) );
+                    ( msg->type() == DwMime::kTypeText
+                   && msg->subtype() == DwMime::kSubtypePlain ) );
 
   if ( !msg )
     return;
@@ -1488,9 +1458,9 @@ void KMReaderWin::parseMsg(KMMessage* aMsg)
 {
 #ifndef NDEBUG
   kDebug( 5006 )
-    << "parseMsg(KMMessage* aMsg "
+    << "parseMsg(KMMessage* aMsg"
     << ( aMsg == message() ? "==" : "!=" )
-    << " aMsg )" << endl;
+    << "aMsg )";
 #endif
 
   KMMessagePart msgPart;
@@ -1500,7 +1470,7 @@ void KMReaderWin::parseMsg(KMMessage* aMsg)
   aMsg->setIsBeingParsed( true );
 
   if ( mRootNode && !mRootNode->processed() ) {
-    kWarning() << "The root node is not yet processed! Danger!\n";
+    kWarning(5006) <<"The root node is not yet processed! Danger!";
     return;
   } else {
     delete mRootNode;
@@ -1519,14 +1489,16 @@ void KMReaderWin::parseMsg(KMMessage* aMsg)
     cntEnc = aMsg->contentTransferEncodingStr();
 
   // fill the MIME part tree viewer
-  mRootNode->fillMimePartTree( 0,
-			       mMimePartTree,
-			       cntDesc,
-			       mainCntTypeStr,
-			       cntEnc,
-			       cntSize );
+  mRootNode->fillMimePartTree( 0, mMimePartTree, cntDesc, mainCntTypeStr,
+                               cntEnc, cntSize );
 
+  // Check if any part of this message is a v-card
+  // v-cards can be either text/x-vcard or text/directory, so we need to check
+  // both.
   partNode* vCardNode = mRootNode->findType( DwMime::kTypeText, DwMime::kSubtypeXVCard );
+  if ( !vCardNode )
+    vCardNode = mRootNode->findType( DwMime::kTypeText, DwMime::kSubtypeDirectory );
+  
   bool hasVCard = false;
   if( vCardNode ) {
     // ### FIXME: We should only do this if the vCard belongs to the sender,
@@ -1535,7 +1507,7 @@ void KMReaderWin::parseMsg(KMMessage* aMsg)
     KABC::VCardConverter t;
     if ( !t.parseVCards( vCard ).isEmpty() ) {
       hasVCard = true;
-      kDebug(5006) << "FOUND A VALID VCARD" << endl;
+      kDebug(5006) <<"FOUND A VALID VCARD";
       writeMessagePartToTempFile( &vCardNode->msgPart(), vCardNode->nodeId() );
     }
   }
@@ -1574,14 +1546,14 @@ void KMReaderWin::parseMsg(KMMessage* aMsg)
   //       something different than 'curNode'.
 
 
-kDebug(5006) << "\n\n\nKMReaderWin::parseMsg()  -  special post-encryption handling:\n1." << endl;
-kDebug(5006) << "(aMsg == msg) = "                      << (aMsg == message()) << endl;
-kDebug(5006) << "   mLastStatus.isOfUnknownStatus() = " << mLastStatus.isOfUnknownStatus() << endl;
-kDebug(5006) << "|| mLastStatus.isNew() = "             << mLastStatus.isNew() << endl;
-kDebug(5006) << "|| mLastStatus.isUnread) = "           << mLastStatus.isUnread() << endl;
-kDebug(5006) << "(mIdOfLastViewedMessage != aMsg->msgId()) = "       << (mIdOfLastViewedMessage != aMsg->msgId()) << endl;
-kDebug(5006) << "   (KMMsgFullyEncrypted == encryptionState) = "     << (KMMsgFullyEncrypted == encryptionState) << endl;
-kDebug(5006) << "|| (KMMsgPartiallyEncrypted == encryptionState) = " << (KMMsgPartiallyEncrypted == encryptionState) << endl;
+kDebug(5006) <<"\n\n\nKMReaderWin::parseMsg()  -  special post-encryption handling:\n1.";
+kDebug(5006) <<"(aMsg == msg) ="                      << (aMsg == message());
+kDebug(5006) <<"   mLastStatus.isOfUnknownStatus() =" << mLastStatus.isOfUnknownStatus();
+kDebug(5006) <<"|| mLastStatus.isNew() ="             << mLastStatus.isNew();
+kDebug(5006) <<"|| mLastStatus.isUnread) ="           << mLastStatus.isUnread();
+kDebug(5006) <<"(mIdOfLastViewedMessage != aMsg->msgId()) ="       << (mIdOfLastViewedMessage != aMsg->msgId());
+kDebug(5006) <<"   (KMMsgFullyEncrypted == encryptionState) ="     << (KMMsgFullyEncrypted == encryptionState);
+kDebug(5006) <<"|| (KMMsgPartiallyEncrypted == encryptionState) =" << (KMMsgPartiallyEncrypted == encryptionState);
          // only proceed if we were called the normal way - not by
          // double click on the message (==not running in a separate window)
   if(    (aMsg == message())
@@ -1596,15 +1568,15 @@ kDebug(5006) << "|| (KMMsgPartiallyEncrypted == encryptionState) = " << (KMMsgPa
       && (    (KMMsgFullyEncrypted == encryptionState)
            || (KMMsgPartiallyEncrypted == encryptionState) ) ) {
 
-kDebug(5006) << "KMReaderWin  -  calling objectTreeToDecryptedMsg()" << endl;
+kDebug(5006) <<"KMReaderWin  -  calling objectTreeToDecryptedMsg()";
 
     QByteArray decryptedData;
     // note: The following call may change the message's headers.
     objectTreeToDecryptedMsg( mRootNode, decryptedData, *aMsg );
-kDebug(5006) << "KMReaderWin  -  resulting data:" << decryptedData << endl;
+kDebug(5006) <<"KMReaderWin  -  resulting data:" << decryptedData;
 
     if( !decryptedData.isEmpty() ) {
-kDebug(5006) << "KMReaderWin  -  composing unencrypted message" << endl;
+kDebug(5006) <<"KMReaderWin  -  composing unencrypted message";
       // try this:
       aMsg->setBody( decryptedData );
       KMMessage* unencryptedMessage = new KMMessage( *aMsg );
@@ -1616,8 +1588,8 @@ kDebug(5006) << "KMReaderWin  -  composing unencrypted message" << endl;
       dwMsg.Body().Parse();
       KMMessage* unencryptedMessage = new KMMessage( &dwMsg );
       */
-kDebug(5006) << "KMReaderWin  -  resulting message:" << unencryptedMessage->asString() << endl;
-kDebug(5006) << "KMReaderWin  -  attach unencrypted message to aMsg" << endl;
+kDebug(5006) <<"KMReaderWin  -  resulting message:" << unencryptedMessage->asString();
+kDebug(5006) <<"KMReaderWin  -  attach unencrypted message to aMsg";
       aMsg->setUnencryptedMsg( unencryptedMessage );
       emitReplaceMsgByUnencryptedVersion = true;
     }
@@ -1632,12 +1604,12 @@ kDebug(5006) << "KMReaderWin  -  attach unencrypted message to aMsg" << endl;
   setIdOfLastViewedMessage( aMsg->msgId() );
 
   if( emitReplaceMsgByUnencryptedVersion ) {
-    kDebug(5006) << "KMReaderWin  -  invoce saving in decrypted form:" << endl;
+    kDebug(5006) <<"KMReaderWin  -  invoce saving in decrypted form:";
     emit replaceMsgByUnencryptedVersion();
   } else {
-    kDebug(5006) << "KMReaderWin  -  finished parsing and displaying of message." << endl;
+    kDebug(5006) <<"KMReaderWin  -  finished parsing and displaying of message.";
     showHideMimeTree( rootNodeCntType == DwMime::kTypeText &&
-		      rootNodeCntSubtype == DwMime::kSubtypePlain );
+                      rootNodeCntSubtype == DwMime::kSubtypePlain );
   }
 
   aMsg->setIsBeingParsed( false );
@@ -1648,9 +1620,9 @@ kDebug(5006) << "KMReaderWin  -  attach unencrypted message to aMsg" << endl;
 QString KMReaderWin::writeMsgHeader(KMMessage* aMsg, bool hasVCard)
 {
   kFatal( !headerStyle(), 5006 )
-    << "trying to writeMsgHeader() without a header style set!" << endl;
+    << "trying to writeMsgHeader() without a header style set!";
   kFatal( !headerStrategy(), 5006 )
-    << "trying to writeMsgHeader() without a header strategy set!" << endl;
+    << "trying to writeMsgHeader() without a header strategy set!";
   QString href;
   if (hasVCard)
     href = QString("file:") + KUrl::toPercentEncoding( mTempFiles.last() );
@@ -1795,8 +1767,8 @@ void KMReaderWin::slotTouchMessage()
        message()->encryptionState() != KMMsgEncryptionStateUnknown )
     return;
   if ( KMMessage * receipt = message()->createMDN( MDN::ManualAction,
-						   MDN::Displayed,
-						   true /* allow GUI */ ) )
+                                                   MDN::Displayed,
+                                                   true /* allow GUI */ ) )
     if ( !kmkernel->msgSender()->send( receipt ) ) // send or queue
       KMessageBox::error( this, i18n("Could not send MDN.") );
 }
@@ -1866,20 +1838,20 @@ void KMReaderWin::slotUrlOn(const QString &aUrl)
 
   const QString msg = URLHandlerManager::instance()->statusBarMessage( url, this );
 
-  kWarning( msg.isEmpty(), 5006 ) << "KMReaderWin::slotUrlOn(): Unhandled URL hover!" << endl;
+  kWarning( msg.isEmpty(), 5006 ) <<"KMReaderWin::slotUrlOn(): Unhandled URL hover!";
   KPIM::BroadcastStatus::instance()->setTransientStatusMsg( msg );
 }
 
 
 //-----------------------------------------------------------------------------
-void KMReaderWin::slotUrlOpen(const KUrl &aUrl, const KParts::URLArgs &)
+void KMReaderWin::slotUrlOpen(const KUrl &aUrl, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &)
 {
   mUrlClicked = aUrl;
 
   if ( URLHandlerManager::instance()->handleClick( aUrl, this ) )
     return;
 
-  kWarning( 5006 ) << "KMReaderWin::slotOpenUrl(): Unhandled URL click!" << endl;
+  kWarning( 5006 ) <<"KMReaderWin::slotOpenUrl(): Unhandled URL click!";
   emit urlClicked( aUrl, Qt::LeftButton );
 }
 
@@ -1893,13 +1865,13 @@ void KMReaderWin::slotUrlPopup(const QString &aUrl, const QPoint& aPos)
     return;
 
   if ( message() ) {
-    kWarning( 5006 ) << "KMReaderWin::slotUrlPopup(): Unhandled URL right-click!" << endl;
+    kWarning( 5006 ) <<"KMReaderWin::slotUrlPopup(): Unhandled URL right-click!";
     emit popupMenu( *message(), url, aPos );
   }
 }
 
 //-----------------------------------------------------------------------------
-void KMReaderWin::showAttachmentPopup( int id, const QString & name, const QPoint & p )
+void KMReaderWin::showAttachmentPopup( int id, const QString & name, const QPoint &p )
 {
   mAtmCurrent = id;
   mAtmCurrentName = name;
@@ -1941,6 +1913,8 @@ void KMReaderWin::showAttachmentPopup( int id, const QString & name, const QPoin
   action = menu->addAction(i18n("Properties") );
   connect( action, SIGNAL( triggered(bool) ), attachmentMapper, SLOT( map() ) );
   attachmentMapper->setMapping( action, KMHandleAttachmentCommand::Properties );
+  menu->exec( p );
+  delete menu;
 }
 
 //-----------------------------------------------------------------------------
@@ -2047,7 +2021,7 @@ void KMReaderWin::setMsgPart( partNode * node ) {
 
 //-----------------------------------------------------------------------------
 void KMReaderWin::setMsgPart( KMMessagePart* aMsgPart, bool aHTML,
-			      const QString& aFileName, const QString& pname )
+                              const QString& aFileName, const QString& pname )
 {
   KCursorSaver busy(KBusyPtr::busy());
   if (kasciistricmp(aMsgPart->typeStr(), "message")==0) {
@@ -2179,7 +2153,7 @@ void KMReaderWin::openAttachment( int id, const QString & name )
 
   partNode* node = mRootNode ? mRootNode->findId( id ) : 0;
   if( !node ) {
-    kWarning(5006) << "KMReaderWin::openAttachment - could not find node " << id << endl;
+    kWarning(5006) <<"KMReaderWin::openAttachment - could not find node" << id;
     return;
   }
 
@@ -2235,7 +2209,7 @@ void KMReaderWin::openAttachment( int id, const QString & name )
       KGuiItem(open_text), KStandardGuiItem::cancel(),
       QString::fromLatin1("askSave") + mimetype->name() );
 
-  if( choice == KMessageBox::Yes ) {		// Save
+  if( choice == KMessageBox::Yes ) { // Save
     mAtmUpdate = true;
     KMHandleAttachmentCommand* command = new KMHandleAttachmentCommand( node,
         message(), mAtmCurrent, mAtmCurrentName, KMHandleAttachmentCommand::Save,
@@ -2244,7 +2218,7 @@ void KMReaderWin::openAttachment( int id, const QString & name )
         this, SLOT( slotAtmView( int, const QString& ) ) );
     command->start();
   }
-  else if( choice == KMessageBox::No ) {	// Open
+  else if( choice == KMessageBox::No ) { // Open
     KMHandleAttachmentCommand::AttachmentAction action = ( offer ?
         KMHandleAttachmentCommand::Open : KMHandleAttachmentCommand::OpenWith );
     mAtmUpdate = true;
@@ -2253,8 +2227,8 @@ void KMReaderWin::openAttachment( int id, const QString & name )
     connect( command, SIGNAL( showAttachment( int, const QString& ) ),
         this, SLOT( slotAtmView( int, const QString& ) ) );
     command->start();
-  } else {					// Cancel
-    kDebug(5006) << "Canceled opening attachment" << endl;
+  } else { // Cancel
+    kDebug(5006) <<"Canceled opening attachment";
   }
 }
 
@@ -2378,7 +2352,7 @@ KMMessage *KMReaderWin::message( KMFolder **aFolder ) const
     if (folder )
       message = folder->getMsg( index );
     if (!message)
-      kWarning(5006) << "Attempt to reference invalid serial number " << mLastSerNum << "\n" << endl;
+      kWarning(5006) <<"Attempt to reference invalid serial number" << mLastSerNum;
     return message;
   }
   return 0;
@@ -2394,7 +2368,7 @@ void KMReaderWin::slotUrlClicked()
   }
 
   KMCommand *command = new KMUrlClickedCommand( mUrlClicked, identity, this,
-						false, mainWidget );
+                                                false, mainWidget );
   command->start();
 }
 
@@ -2409,7 +2383,7 @@ void KMReaderWin::slotMailtoCompose()
 void KMReaderWin::slotMailtoForward()
 {
   KMCommand *command = new KMMailtoForwardCommand( mMainWindow, mUrlClicked,
-						   message() );
+                                                   message() );
   command->start();
 }
 
@@ -2417,7 +2391,7 @@ void KMReaderWin::slotMailtoForward()
 void KMReaderWin::slotMailtoAddAddrBook()
 {
   KMCommand *command = new KMMailtoAddAddrBookCommand( mUrlClicked,
-						       mMainWindow);
+                                                       mMainWindow);
   command->start();
 }
 
@@ -2425,7 +2399,7 @@ void KMReaderWin::slotMailtoAddAddrBook()
 void KMReaderWin::slotMailtoOpenAddrBook()
 {
   KMCommand *command = new KMMailtoOpenAddrBookCommand( mUrlClicked,
-							mMainWindow );
+                                                        mMainWindow );
   command->start();
 }
 
@@ -2499,12 +2473,6 @@ void KMReaderWin::slotSaveMsg()
   else
     saveCommand->start();
 }
-//-----------------------------------------------------------------------------
-void KMReaderWin::slotIMChat()
-{
-  KMCommand *command = new KMIMChatCommand( mUrlClicked, message() );
-  command->start();
-}
 
 //-----------------------------------------------------------------------------
 QString KMReaderWin::createAtmFileLink() const
@@ -2521,7 +2489,7 @@ QString KMReaderWin::createAtmFileLink() const
   if ( link(QFile::encodeName(mAtmCurrentName), QFile::encodeName(linkName)) == 0 ) {
     return linkName; // success
   }
-  kWarning(5006) << "Couldn't link to " << mAtmCurrentName << endl;
+  kWarning(5006) <<"Couldn't link to" << mAtmCurrentName;
   return QString();
 }
 
