@@ -24,7 +24,6 @@
 #include "filterlog.h"
 using KMail::FilterLog;
 #include "kmkernel.h"
-#include "kmmsgdict.h"
 #include "kmfolder.h"
 
 #include <kpimutils/email.h>
@@ -778,23 +777,20 @@ bool KMSearchPattern::matches( quint32 serNum, bool ignoreBody ) const
     return false;
   }
 
-  bool opened = folder->isOpened();
-  if ( !opened ) {
-    folder->open( "searchptr" );
-  }
+  KMFolderOpener openFolder( folder, "searptr" );
   KMMsgBase *msgBase = folder->getMsgBase( idx );
   if (requiresBody() && !ignoreBody) {
     bool unGet = !msgBase->isMessage();
     KMMessage *msg = folder->getMsg(idx);
-    res = matches( msg, ignoreBody );
-    if (unGet)
-      folder->unGetMsg(idx);
+    res = false;
+    if ( msg ) {
+      res = matches( msg, ignoreBody );
+      if (unGet)
+        folder->unGetMsg(idx);
+    }
   } else {
     res = matches( folder->getDwString(idx), ignoreBody );
   }
-  if ( !opened ) {
-    folder->close( "searchptr" );
-  }
   return res;
 }
 
@@ -812,7 +808,7 @@ void KMSearchPattern::purify() {
     --it;
     if ( (*it)->isEmpty() ) {
 #ifndef NDEBUG
-      kDebug(5006) << "KMSearchPattern::purify(): removing " << (*it)->asString() << endl;
+      kDebug(5006) <<"KMSearchPattern::purify(): removing" << (*it)->asString();
 #endif
       erase( it );
       it = end();
@@ -825,7 +821,7 @@ void KMSearchPattern::readConfig( const KConfigGroup & config ) {
 
   mName = config.readEntry("name");
   if ( !config.hasKey("rules") ) {
-    kDebug(5006) << "KMSearchPattern::readConfig: found legacy config! Converting." << endl;
+    kDebug(5006) <<"KMSearchPattern::readConfig: found legacy config! Converting.";
     importLegacyConfig( config );
     return;
   }
