@@ -180,8 +180,8 @@ bool KMSender::doSend(KMMessage *aMsg, short sendNow )
     sendNow = mSendImmediate;
   }
 
-  kmkernel->outboxFolder()->open( "outbox" );
-  const KMFolderCloser openOutbox( "outbox", kmkernel->outboxFolder() );
+  KMFolder * const outbox = kmkernel->outboxFolder();
+  const KMFolderOpener openOutbox( outbox, "KMSender" );
 
   aMsg->setStatus( MessageStatus::statusQueued() );
 
@@ -253,9 +253,9 @@ bool KMSender::doSendQueued( const QString &customTransport )
 }
 
 //-----------------------------------------------------------------------------
-void KMSender::emitProgressInfo( int currentFileProgress )
+void KMSender::slotProcessedSize( KJob *, qulonglong size )
 {
-  int percent = (mTotalBytes) ? ( 100 * (mSentBytes+currentFileProgress) / mTotalBytes ) : 0;
+  int percent = (mTotalBytes) ? ( 100 * (mSentBytes+size) / mTotalBytes ) : 0;
   if (percent > 100) percent = 100;
   mProgressItem->setProgress(percent);
 }
@@ -326,7 +326,7 @@ void KMSender::doSendMsg()
   if ( mCurrentMsg  && kmkernel->filterMgr() ) {
     mCurrentMsg->setTransferInProgress( false );
     if ( mCurrentMsg->hasUnencryptedMsg() ) {
-      kDebug(5006) << "KMSender::doSendMsg() post-processing: replace mCurrentMsg body by unencryptedMsg data" << endl;
+      kDebug(5006) <<"KMSender::doSendMsg() post-processing: replace mCurrentMsg body by unencryptedMsg data";
       // delete all current body parts
       mCurrentMsg->deleteBodyParts();
       // copy Content-[..] headers from unencrypted message to current one
@@ -524,18 +524,17 @@ void KMSender::doSendMsg()
   }
 
   QString msgTransport = mCustomTransport;
-  if ( msgTransport.isEmpty() ) {
+  if ( msgTransport.isEmpty() )
     msgTransport = mCurrentMsg->headerField( "X-KMail-Transport" );
-  }
-  if ( msgTransport.isEmpty() ) {
+
+  if ( msgTransport.isEmpty() )
     msgTransport = TransportManager::self()->defaultTransportName();
-  }
 
   if ( !mTransportJob ) {
-    mTransportJob = TransportManager::self()->createTransportJob( msgTransport );
     mMethodStr = msgTransport;
+    mTransportJob = TransportManager::self()->createTransportJob( msgTransport );
     if ( !mTransportJob ) {
-      KMessageBox::error( 0, i18n( "Transport '%1' is invalid.", msgTransport ),
+      KMessageBox::error( 0, i18n( "Transport '%1' is invalid.", mMethodStr ),
                           i18n( "Sending failed" ) );
       mProgressItem->cancel();
       mProgressItem->setComplete();
@@ -594,6 +593,8 @@ void KMSender::doSendMsg()
     mTransportJob->setData( message );
 
     connect( mTransportJob, SIGNAL(result(KJob*)), SLOT(slotResult(KJob*)) );
+    connect( mTransportJob, SIGNAL(processedSize(KJob *, qulonglong)),
+             SLOT( slotProcessedSize(KJob *, qulonglong)) );
     mSendProcStarted = true;
     mTransportJob->start();
   }
@@ -603,7 +604,7 @@ void KMSender::doSendMsg()
 //-----------------------------------------------------------------------------
 void KMSender::cleanup( void )
 {
-  kDebug(5006) << k_funcinfo << endl;
+  kDebug(5006) ;
   if ( mTransportJob && mSendProcStarted ) {
     mTransportJob->kill();
   }
@@ -691,11 +692,7 @@ void KMSender::slotResult( KJob *job )
       }
       mCurrentMsg = 0;
       mFailedMessages++;
-      // reset cached password
-      QMap<QString, QString>::iterator pc;
-      if ( ( pc = mPasswdCache.find( mMethodStr ) ) != mPasswdCache.end() ) {
-        mPasswdCache.erase( pc );
-      }
+
       // Sending of message failed.
       if ( !errString.isEmpty() ) {
         int res = KMessageBox::Yes;
@@ -770,7 +767,7 @@ void KMSender::setStatusByLink( const KMMessage *aMsg )
     int index = -1;
     KMMsgDict::instance()->getLocation( msn, &folder, &index );
     if ( folder && index != -1 ) {
-      folder->open( "setstatus" );
+      KMFolderOpener openFolder( folder, "setstatus" );
       if ( status.isDeleted() ) {
         // Move the message to the trash folder
         KMDeleteMsgCommand *cmd =
@@ -779,9 +776,8 @@ void KMSender::setStatusByLink( const KMMessage *aMsg )
       } else {
         folder->setStatus( index, status );
       }
-      folder->close( "setstatus" );
     } else {
-      kWarning(5006) << k_funcinfo << "Cannot update linked message, it could not be found!" << endl;
+      kWarning(5006) <<"Cannot update linked message, it could not be found!";
     }
   }
 }
