@@ -34,7 +34,6 @@
 #define REALLY_WANT_KMCOMPOSEWIN_H
 #include "kmcomposewin.h"
 #undef REALLY_WANT_KMCOMPOSEWIN_H
-#include "klistboxdialog.h"
 #include "kcursorsaver.h"
 #include "messagesender.h"
 #include "kmfolder.h"
@@ -43,8 +42,8 @@
 #include "kleo_util.h"
 #include "globalsettings.h"
 #include "custommimeheader.h"
-#include "kmedit.h"
 #include "util.h"
+#include "kmcomposereditor.h"
 
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
@@ -315,7 +314,24 @@ class ComposeMessageJob : public MessageComposerJob {
 
 MessageComposer::MessageComposer( KMComposeWin *win )
   : QObject( win ), mComposeWin( win ), mCurrentJob( 0 ),
-    mKeyResolver( 0 ), mIdentityUid( 0 ), mPerformingSignOperation( false )
+    mReferenceMessage( 0 ), mKeyResolver( 0 ), 
+    mUseOpportunisticEncryption( false ),
+    mSignBody( false ), mEncryptBody( false ),
+    mSigningRequested(  false ), mEncryptionRequested( false ),
+    mDoSign( false ), mDoEncrypt( false ),
+    mAllowedCryptoMessageFormats( 0 ),
+    mDisableCrypto( false ),
+    mDisableBreaking( false ),
+    mDebugComposerCrypto( false ),
+    mAutoCharset( true ),
+    mIsRichText( false ),
+    mIdentityUid( 0 ), mRc( true ),
+    mHoldJobs( false ),
+    mNewBodyPart( 0 ),
+    mEarlyAddAttachments( false ), mAllAttachmentsAreInBody( false ),
+    mPreviousBoundaryLevel( 0 ),
+    mEncryptWithChiasmus( false ),
+    mPerformingSignOperation( false )
 {
 }
 
@@ -331,10 +347,10 @@ void MessageComposer::applyChanges( bool disableCrypto )
   if ( getenv( "KMAIL_DEBUG_COMPOSER_CRYPTO" ) != 0 ) {
     QByteArray cE = getenv( "KMAIL_DEBUG_COMPOSER_CRYPTO" );
     mDebugComposerCrypto = cE == "1" || cE.toUpper() == "ON" || cE.toUpper() == "TRUE";
-    kDebug(5006) << "KMAIL_DEBUG_COMPOSER_CRYPTO = TRUE" << endl;
+    kDebug(5006) <<"KMAIL_DEBUG_COMPOSER_CRYPTO = TRUE";
   } else {
     mDebugComposerCrypto = false;
-    kDebug(5006) << "KMAIL_DEBUG_COMPOSER_CRYPTO = FALSE" << endl;
+    kDebug(5006) <<"KMAIL_DEBUG_COMPOSER_CRYPTO = FALSE";
   }
 
   mHoldJobs = false;
@@ -545,7 +561,8 @@ void MessageComposer::readFromComposeWin()
   // Hopefully we can get rid of this eventually, it's needed to be able
   // to break the plain/text version of a multipart/alternative (html) mail
   // according to the line breaks of the richtext version.
-  mLineBreakColumn = mComposeWin->mEditor->lineBreakColumn();
+//Laurent fixme
+  //mLineBreakColumn = mComposeWin->mEditor->lineBreakColumn();
 }
 static QByteArray escape_quoted_string( const QByteArray &str ) {
   QByteArray result;
@@ -1161,17 +1178,17 @@ static inline bool textMode( Kleo::CryptoMessageFormat f )
   return f == Kleo::InlineOpenPGPFormat;
 }
 
-static inline GpgME::Context::SignatureMode signingMode( Kleo::CryptoMessageFormat f )
+static inline GpgME::SignatureMode signingMode( Kleo::CryptoMessageFormat f )
 {
   switch ( f ) {
   case Kleo::SMIMEOpaqueFormat:
-    return GpgME::Context::Normal;
+    return GpgME::NormalSignatureMode;
   case Kleo::InlineOpenPGPFormat:
-    return GpgME::Context::Clearsigned;
+    return GpgME::Clearsigned;
   default:
   case Kleo::SMIMEFormat:
   case Kleo::OpenPGPMIMEFormat:
-    return GpgME::Context::Detached;
+    return GpgME::Detached;
   }
 }
 
@@ -1252,8 +1269,7 @@ void MessageComposer::composeInlineOpenPGPMessage( KMMessage &theMessage,
   const std::vector<Kleo::KeyResolver::SplitInfo> splitInfos =
     mKeyResolver->encryptionItems( Kleo::InlineOpenPGPFormat );
   kWarning( splitInfos.empty() )
-    << "MessageComposer::continueComposeMessage(): splitInfos.empty() for InlineOpenPGPFormat"
-    << endl;
+    << "MessageComposer::continueComposeMessage(): splitInfos.empty() for InlineOpenPGPFormat";
   std::vector<Kleo::KeyResolver::SplitInfo>::const_iterator it;
   for ( it = splitInfos.begin(); it != splitInfos.end(); ++it ) {
     const Kleo::KeyResolver::SplitInfo &splitInfo = *it;
@@ -1386,7 +1402,7 @@ void MessageComposer::composeMessage( KMMessage &theMessage,
                                       bool doSign, bool doEncrypt,
                                       Kleo::CryptoMessageFormat format )
 {
-  kDebug(5006) << "entering KMComposeWin::composeMessage" << endl;
+  kDebug(5006) <<"entering KMComposeWin::composeMessage";
   if ( format == Kleo::InlineOpenPGPFormat ) {
     composeInlineOpenPGPMessage( theMessage, doSign, doEncrypt );
     return;
@@ -1396,7 +1412,6 @@ void MessageComposer::composeMessage( KMMessage &theMessage,
     composeChiasmusMessage( theMessage, format );
     return;
   }
-
   // create informative header for those that have no mime-capable
   // email client
   theMessage.setBody( "This message is in MIME format." );
@@ -1447,8 +1462,8 @@ void MessageComposer::composeMessage( KMMessage &theMessage,
     }
   }
 
-  kDebug(5006) << "mEarlyAddAttachments=" << mEarlyAddAttachments
-               << " mAllAttachmentsAreInBody=" << mAllAttachmentsAreInBody << endl;
+  kDebug(5006) <<"mEarlyAddAttachments=" << mEarlyAddAttachments
+               << "mAllAttachmentsAreInBody=" << mAllAttachmentsAreInBody;
 
   // if an html message is to be generated, make a text/plain and text/html part
   if ( mIsRichText ) {
@@ -1538,8 +1553,8 @@ void MessageComposer::composeMessage( KMMessage &theMessage,
         const QByteArray body = it->part->bodyDecodedBinary();
         QList<int> dummy;
         it->part->setBodyAndGuessCte( body, dummy, false, it->sign );
-        kDebug(5006) << "Changed encoding of message part from "
-                     << cte << " to " << it->part->cteStr() << endl;
+        kDebug(5006) <<"Changed encoding of message part from"
+                     << cte << "to" << it->part->cteStr();
       }
     }
   }
@@ -1647,7 +1662,7 @@ void MessageComposer::composeMessage( KMMessage &theMessage,
 
     // replace simple LFs by CRLFs for all MIME supporting CryptPlugs
     // according to RfC 2633, 3.1.1 Canonicalization
-    //kDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
+    //kDebug(5006) <<"Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)";
     mEncodedBody = KMail::Util::lf2crlf( mEncodedBody );
   }
 
@@ -1659,7 +1674,7 @@ void MessageComposer::composeMessage( KMMessage &theMessage,
     mPerformingSignOperation = false;
 
     if ( mSignature.isEmpty() ) {
-      kDebug(5006) << "signature was empty" << endl;
+      kDebug(5006) <<"signature was empty";
       mRc = false;
       return;
     }
@@ -1698,8 +1713,8 @@ void MessageComposer::continueComposeMessage( KMMessage &theMessage,
   const std::vector<Kleo::KeyResolver::SplitInfo> splitInfos =
     mKeyResolver->encryptionItems( format );
   kWarning( splitInfos.empty() )
-    << "MessageComposer::continueComposeMessage(): splitInfos.empty() for "
-    << Kleo::cryptoMessageFormatToString( format ) << endl;
+    << "MessageComposer::continueComposeMessage(): splitInfos.empty() for"
+    << Kleo::cryptoMessageFormatToString( format );
 
   if ( !splitInfos.empty() && doEncrypt && !saveMessagesEncrypted() ) {
     mJobs.push_front( new SetLastMessageAsUnencryptedVersionOfLastButOne( this ) );
@@ -1755,9 +1770,9 @@ void MessageComposer::encryptMessage( KMMessage *msg,
     // now do the encrypting:
     // replace simple LFs by CRLFs for all MIME supporting CryptPlugs
     // according to RfC 2633, 3.1.1 Canonicalization
-    //kDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
+    //kDebug(5006) <<"Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)";
     innerContent = KMail::Util::lf2crlf( innerContent );
-    //kDebug(5006) << "                                                       done." << endl;
+    //kDebug(5006) <<"                                                       done.";
 
     QByteArray encryptedBody;
     Kpgp::Result result = pgpEncryptedMsg( encryptedBody, innerContent,
@@ -1804,8 +1819,8 @@ void MessageComposer::addBodyAndAttachments( KMMessage *msg,
     msg->headers().ContentType().SetType( DwMime::kTypeMultipart );
     msg->headers().ContentType().SetSubtype( DwMime::kSubtypeMixed );
     msg->headers().ContentType().CreateBoundary( 0 );
-    kDebug(5006) << "MessageComposer::addBodyAndAttachments() : "
-                 << "set top level Content-Type to Multipart/Mixed" << endl;
+    kDebug(5006) <<"MessageComposer::addBodyAndAttachments() :"
+                 << "set top level Content-Type to Multipart/Mixed";
 
     // add our Body Part
     DwBodyPart *tmpDwPart = msg->createDWBodyPart( &ourFineBodyPart );
@@ -1852,7 +1867,7 @@ void MessageComposer::addBodyAndAttachments( KMMessage *msg,
 
       // replace simple LFs by CRLFs for all MIME supporting CryptPlugs
       // according to RfC 2633, 3.1.1 Canonicalization
-      //kDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
+      //kDebug(5006) <<"Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)";
       encodedAttachment = KMail::Util::lf2crlf( encodedAttachment );
 
       // sign this attachment
@@ -1923,15 +1938,15 @@ void MessageComposer::addBodyAndAttachments( KMMessage *msg,
     if ( !ourFineBodyPart.originalContentTypeStr().isEmpty() ) {
       msg->headers().ContentType().FromString( ourFineBodyPart.originalContentTypeStr() );
       msg->headers().ContentType().Parse();
-      kDebug(5006) << "MessageComposer::addBodyAndAttachments() : "
+      kDebug(5006) <<"MessageComposer::addBodyAndAttachments() :"
                    << "set top level Content-Type from originalContentTypeStr()="
-                   << ourFineBodyPart.originalContentTypeStr() << endl;
+                   << ourFineBodyPart.originalContentTypeStr();
     } else {
       msg->headers().ContentType().FromString(
         ourFineBodyPart.typeStr() + '/' + ourFineBodyPart.subtypeStr() );
-      kDebug(5006) << "MessageComposer::addBodyAndAttachments() : "
-                   << "set top level Content-Type to "
-                   << ourFineBodyPart.typeStr() << "/" << ourFineBodyPart.subtypeStr() << endl;
+      kDebug(5006) <<"MessageComposer::addBodyAndAttachments() :"
+                   << "set top level Content-Type to"
+                   << ourFineBodyPart.typeStr() << "/" << ourFineBodyPart.subtypeStr();
     }
     if ( !ourFineBodyPart.charset().isEmpty() ) {
       msg->setCharset( ourFineBodyPart.charset() );
@@ -1944,8 +1959,8 @@ void MessageComposer::addBodyAndAttachments( KMMessage *msg,
                          ourFineBodyPart.contentDisposition() );
 
     if ( mDebugComposerCrypto ) {
-      kDebug(5006) << "MessageComposer::addBodyAndAttachments() : "
-                   << "top level headers and body adjusted" << endl;
+      kDebug(5006) <<"MessageComposer::addBodyAndAttachments() :"
+                   << "top level headers and body adjusted";
     }
 
     // set body content
@@ -1961,11 +1976,11 @@ void MessageComposer::addBodyAndAttachments( KMMessage *msg,
                        splitInfo.recipients.join( ", " ), KMMessage::Address );
 
   if ( mDebugComposerCrypto ) {
-    kDebug(5006) << "MessageComposer::addBodyAndAttachments():\n      "
-                 << "Final message:\n|||" << msg->asString() << "|||\n\n" << endl;
+    kDebug(5006) <<"MessageComposer::addBodyAndAttachments():"
+                 << "Final message:\n|||" << msg->asString() << "|||\n\n";
     msg->headers().Assemble();
-    kDebug(5006) << "\n\n\nMessageComposer::addBodyAndAttachments():\n      "
-                 << "Final headers:\n\n" << msg->headerAsString() << "|||\n\n\n\n\n" << endl;
+    kDebug(5006) <<"\n\n\nMessageComposer::addBodyAndAttachments():"
+                 << "Final headers:\n\n" << msg->headerAsString() << "|||\n\n\n\n\n";
   }
 }
 
@@ -2024,7 +2039,7 @@ bool MessageComposer::processStructuringInfo( const QString bugURL,
       }
     }
 
-    //kDebug(5006) << "processStructuringInfo: mainHeader=" << mainHeader << endl;
+    //kDebug(5006) <<"processStructuringInfo: mainHeader=" << mainHeader;
 
     DwString mainDwStr = KMail::Util::dwString( mainHeader );
     mainDwStr += "\n\n";
@@ -2086,7 +2101,7 @@ bool MessageComposer::processStructuringInfo( const QString bugURL,
       }
       mainStr += "--\n";
 
-      //kDebug(5006) << "processStructuringInfo: mainStr=" << mainStr << endl;
+      //kDebug(5006) <<"processStructuringInfo: mainStr=" << mainStr;
       resultingPart.setBodyEncoded( mainStr );
     }
 
@@ -2111,7 +2126,7 @@ bool MessageComposer::processStructuringInfo( const QString bugURL,
       KMessageBox::sorry( mComposeWin,
                           i18n( "<qt><p>Error: The backend did not return "
                                 "any encoded data.</p>"
-                                "<p>Please report this bug:<br>%1</p></qt>" ,
+                                "<p>Please report this bug:<br />%1</p></qt>" ,
                                 bugURL ) );
       bOk = false;
     }
@@ -2138,7 +2153,7 @@ QByteArray MessageComposer::plainTextFromMarkup( const QString &markupText ) con
   if ( mCharset == "us-ascii" ) {
     textbody = KMMsgBase::toUsAscii( text );
   } else if ( codec == 0 ) {
-    kDebug(5006) << "Something is wrong and I can not get a codec." << endl;
+    kDebug(5006) <<"Something is wrong and I can not get a codec.";
     textbody = text.toLocal8Bit();
   } else {
     text = codec->toUnicode( text.toLatin1() );
@@ -2155,9 +2170,8 @@ QByteArray MessageComposer::plainTextFromMarkup( const QString &markupText ) con
 //-----------------------------------------------------------------------------
 QByteArray MessageComposer::breakLinesAndApplyCodec() const
 {
-  QString text;
   QByteArray cText;
-
+  QString text;
   if ( mDisableBreaking || mIsRichText ) {
     text = mComposeWin->mEditor->text();
   } else {
@@ -2172,7 +2186,7 @@ QByteArray MessageComposer::breakLinesAndApplyCodec() const
     cText = KMMsgBase::toUsAscii( text );
     newText = QString::fromLatin1( cText );
   } else if ( codec == 0 ) {
-    kDebug(5006) << "Something is wrong and I can not get a codec." << endl;
+    kDebug(5006) <<"Something is wrong and I can not get a codec.";
     cText = text.toLocal8Bit();
     newText = QString::fromLocal8Bit( cText );
   } else {
@@ -2190,7 +2204,7 @@ QByteArray MessageComposer::breakLinesAndApplyCodec() const
     bool anyway = ( KMessageBox::warningYesNo(
                       mComposeWin,
                       i18n("<qt>Not all characters fit into the chosen"
-                           " encoding.<br><br>Send the message anyway?</qt>"),
+                           " encoding.<br /><br />Send the message anyway?</qt>"),
                       i18n("Some Characters Will Be Lost"),
                       KGuiItem ( i18n("Lose Characters") ),
                       KGuiItem( i18n("Change Encoding") ) ) == KMessageBox::Yes );
@@ -2212,7 +2226,7 @@ QByteArray MessageComposer::breakLinesAndApplyCodec() const
   //  MUST be identical).
   // So make sure that the body ends with a <LF>.
   if ( cText.isEmpty() || !cText.endsWith('\n') ) {
-    kDebug(5006) << "Added an <LF> on the last line" << endl;
+    kDebug(5006) <<"Added an <LF> on the last line";
     cText += '\n';
   }
   return cText;
@@ -2251,11 +2265,11 @@ void MessageComposer::pgpSignedMsg( const QByteArray &cText, Kleo::CryptoMessage
   const GpgME::SigningResult res =
     job->exec( signingKeys, plainText, signingMode( format ), signature );
   if ( res.error().isCanceled() ) {
-    kDebug(5006) << "signing was canceled by user" << endl;
+    kDebug(5006) <<"signing was canceled by user";
     return;
   }
   if ( res.error() ) {
-    kDebug(5006) << "signing failed: " << res.error().asString() << endl;
+    kDebug(5006) <<"signing failed:" << res.error().asString();
     job->showErrorDialog( mComposeWin );
     return;
   }
@@ -2298,11 +2312,11 @@ Kpgp::Result MessageComposer::pgpEncryptedMsg( QByteArray &encryptedBody,
   const GpgME::EncryptionResult res =
     job->exec( encryptionKeys, plainText, false, encryptedBody );
   if ( res.error().isCanceled() ) {
-    kDebug(5006) << "encryption was canceled by user" << endl;
+    kDebug(5006) <<"encryption was canceled by user";
     return Kpgp::Canceled;
   }
   if ( res.error() ) {
-    kDebug(5006) << "encryption failed: " << res.error().asString() << endl;
+    kDebug(5006) <<"encryption failed:" << res.error().asString();
     job->showErrorDialog( mComposeWin );
     return Kpgp::Failure;
   }
@@ -2336,14 +2350,14 @@ Kpgp::Result MessageComposer::pgpSignedAndEncryptedMsg( QByteArray &encryptedBod
   const std::pair<GpgME::SigningResult,GpgME::EncryptionResult> res =
     job->exec( signingKeys, encryptionKeys, cText, false, encryptedBody );
   if ( res.first.error().isCanceled() || res.second.error().isCanceled() ) {
-    kDebug(5006) << "encrypt/sign was canceled by user" << endl;
+    kDebug(5006) <<"encrypt/sign was canceled by user";
     return Kpgp::Canceled;
   }
   if ( res.first.error() || res.second.error() ) {
     if ( res.first.error() ) {
-      kDebug(5006) << "signing failed: " << res.first.error().asString() << endl;
+      kDebug(5006) <<"signing failed:" << res.first.error().asString();
     } else {
-      kDebug(5006) << "encryption failed: " << res.second.error().asString() << endl;
+      kDebug(5006) <<"encryption failed:" << res.second.error().asString();
     }
     job->showErrorDialog( mComposeWin );
     return Kpgp::Failure;
