@@ -85,7 +85,7 @@ partNode::partNode( DwBodyPart* dwPart, int explicitType, int explicitSubType,
     mType    = explicitType;     // this happens e.g. for the Root Node
     mSubType = explicitSubType;  // representing the _whole_ message
   } else {
-//    kDebug(5006) << "\n        partNode::partNode()      explicitType == DwMime::kTypeUnknown\n" << endl;
+//    kDebug(5006) <<"\n        partNode::partNode()      explicitType == DwMime::kTypeUnknown";
     if(dwPart && dwPart->hasHeaders() && dwPart->Headers().HasContentType()) {
       mType    = (!dwPart->Headers().ContentType().Type())?DwMime::kTypeUnknown:dwPart->Headers().ContentType().Type();
       mSubType = dwPart->Headers().ContentType().Subtype();
@@ -99,7 +99,7 @@ partNode::partNode( DwBodyPart* dwPart, int explicitType, int explicitSubType,
     DwString type, subType;
     DwTypeEnumToStr( mType, type );
     DwSubtypeEnumToStr( mSubType, subType );
-    kDebug(5006) << "\npartNode::partNode()   " << type.c_str() << "/" << subType.c_str() << "\n" << endl;
+    kDebug(5006) <<"\npartNode::partNode()" << type.c_str() <<"/" << subType.c_str();
   }
 #endif
 }
@@ -163,8 +163,8 @@ partNode::~partNode() {
 
 #ifndef NDEBUG
 void partNode::dump( int chars ) const {
-  kDebug(5006) << QString().fill( ' ', chars ) << "+ "
-		<< typeString() << '/' << subTypeString() << endl;
+  kDebug(5006) << QString().fill( ' ', chars ) <<"+"
+		<< typeString() << '/' << subTypeString();
   if ( mChild )
     mChild->dump( chars + 1 );
   if ( mNext )
@@ -291,7 +291,7 @@ KMMsgEncryptionState partNode::overallEncryptionState() const
         }
     }
 
-//kDebug(5006) << "\n\n  KMMsgEncryptionState: " << myState << endl;
+//kDebug(5006) <<"\n\n  KMMsgEncryptionState:" << myState;
 
     return myState;
 }
@@ -334,7 +334,7 @@ KMMsgSignatureState  partNode::overallSignatureState() const
         }
     }
 
-//kDebug(5006) << "\n\n  KMMsgSignatureState: " << myState << endl;
+//kDebug(5006) <<"\n\n  KMMsgSignatureState:" << myState;
 
     return myState;
 }
@@ -395,8 +395,8 @@ partNode* partNode::findType( int type, int subType, bool deep, bool wide )
   DwString typeStr, subTypeStr;
   DwTypeEnumToStr( mType, typeStr );
   DwSubtypeEnumToStr( mSubType, subTypeStr );
-  kDebug(5006) << "partNode::findType() is looking at " << typeStr.c_str()
-                << "/" << subTypeStr.c_str() << endl;
+  kDebug(5006) <<"partNode::findType() is looking at" << typeStr.c_str()
+                << "/" << subTypeStr.c_str();
 #endif
     if(    (mType != DwMime::kTypeUnknown)
            && (    (type == DwMime::kTypeUnknown)
@@ -493,8 +493,8 @@ void partNode::fillMimePartTree( KMMimePartTreeItem* parentItem,
     // remove linebreak+whitespace from folded Content-Description
     cntDesc.replace( QRegExp("\\n\\s*"), " " );
 
-kDebug(5006) << "      Inserting one item into MimePartTree" << endl;
-kDebug(5006) << "                Content-Type: " << cntType << endl;
+kDebug(5006) <<"      Inserting one item into MimePartTree";
+kDebug(5006) <<"                Content-Type:" << cntType;
     if( parentItem )
       mMimePartTreeItem = new KMMimePartTreeItem( parentItem,
                                                   this,
@@ -586,7 +586,7 @@ bool partNode::isFirstTextPart() const {
   for ( const partNode * n = root ; n ; n = n->next() )
     if ( n->type() == DwMime::kTypeText )
       return n == this;
-  kFatal() << "partNode::isFirstTextPart(): Didn't expect to end up here..." << endl;
+  kFatal(5006) <<"partNode::isFirstTextPart(): Didn't expect to end up here...";
   return false; // make comiler happy
 }
 
