@@ -21,18 +21,20 @@
 
 
 #include "recipientspicker.h"
-
 #include "globalsettings.h"
 
 #include <libkdepim/recentaddresses.h>
+#ifdef KDEPIM_NEW_DISTRLISTS
+#include <libkdepim/distributionlist.h>
+#else
+#include <kabc/distributionlist.h>
+#endif
 
-#include <k3listview.h>
 #include <klocale.h>
 #include <kabc/resource.h>
 #include <kiconloader.h>
 #include <kdialog.h>
 #include <kwindowsystem.h>
-#include <kabc/distributionlist.h>
 #include <kmessagebox.h>
 #include <kconfiggroup.h>
 
@@ -45,21 +47,40 @@
 #include <QPixmap>
 #include <QPushButton>
 #include <QToolButton>
+#include <QTreeWidget>
 #include <QVBoxLayout>
 
+#ifdef KDEPIM_NEW_DISTRLISTS
+RecipientItem::RecipientItem( KABC::AddressBook *ab )
+  : mAddressBook( ab )
+{
+}
+#else
 RecipientItem::RecipientItem()
   : mDistributionList( 0 )
 {
 }
+#endif
 
+#ifdef KDEPIM_NEW_DISTRLISTS
+void RecipientItem::setDistributionList( const KPIM::DistributionList &list )
+{
+  mDistributionList = list;
+
+  mIcon = KIconLoader::global()->loadIcon( "kdmconfig", KIconLoader::Small );
+
+  mKey = 'D' + list.name();
+}
+#else
 void RecipientItem::setDistributionList( KABC::DistributionList *list )
 {
   mDistributionList = list;
 
-  mIcon = KIconLoader::global()->loadIcon( "kdmconfig", K3Icon::Small );
+  mIcon = KIconLoader::global()->loadIcon( "kdmconfig", KIconLoader::Small );
 
   mKey = 'D' + list->name();
 }
+#endif
 
 void RecipientItem::setAddressee( const KABC::Addressee &a,
   const QString &email )
@@ -71,7 +92,7 @@ void RecipientItem::setAddressee( const KABC::Addressee &a,
   if ( !img.isNull() )
     mIcon = QPixmap::fromImage( img.scaled( 20, 20, Qt::KeepAspectRatio, Qt::SmoothTransformation ) );
   else
-    mIcon = KIconLoader::global()->loadIcon( "personal", K3Icon::Small );
+    mIcon = KIconLoader::global()->loadIcon( "personal", KIconLoader::Small );
 
   mKey = 'A' + a.preferredEmail();
 }
@@ -83,22 +104,46 @@ QPixmap RecipientItem::icon() const
 
 QString RecipientItem::name() const
 {
+#ifdef KDEPIM_NEW_DISTRLISTS
+  if ( !mAddressee.isEmpty() ) return mAddressee.realName();
+  else if ( !mDistributionList.isEmpty() ) return mDistributionList.name();
+  else return QString();
+#else
   if ( !mAddressee.isEmpty() ) return mAddressee.realName();
   else if ( mDistributionList ) return mDistributionList->name();
   else return QString();
+#endif
 }
 
 QString RecipientItem::email() const
 {
+#ifdef KDEPIM_NEW_DISTRLISTS
+  if ( mAddressee.isEmpty() && !mDistributionList.isEmpty() ) {
+    int count = mDistributionList.entries( mAddressBook ).count();
+    return i18np( "1 email address", "%1 email addresses", count );
+  } else {
+    return mEmail;
+  }
+#else
   if ( mAddressee.isEmpty() &&  mDistributionList ) {
     int count = mDistributionList->entries().count();
     return i18np( "1 email address", "%1 email addresses", count );
   } else {
     return mEmail;
   }
+#endif
   return QString();
 }
 
+#ifdef KDEPIM_NEW_DISTRLISTS
+QString RecipientItem::recipient() const
+{
+  QString r;
+  if ( !mAddressee.isEmpty() ) r = mAddressee.fullEmail( mEmail );
+  else if ( !mDistributionList.isEmpty() ) r = mDistributionList.name();
+  return r;
+}
+#else
 QString RecipientItem::recipient() const
 {
   QString r;
@@ -106,6 +151,7 @@ QString RecipientItem::recipient() const
   else if ( mDistributionList ) r = mDistributionList->name();
   return r;
 }
+#endif
 
 QString RecipientItem::toolTip() const
 {
@@ -116,6 +162,24 @@ QString RecipientItem::toolTip() const
       txt += mAddressee.realName() + "<br/>";
     }
     txt += "<b>" + mEmail + "</b>";
+#ifdef KDEPIM_NEW_DISTRLISTS
+  } else if ( !mDistributionList.isEmpty() ) {
+    txt += "<b>" + i18n( "Distribution List %1", mDistributionList.name() ) + "</b>";
+    txt += "<ul>";
+    KPIM::DistributionList::Entry::List entries = mDistributionList.entries( mAddressBook );
+    KPIM::DistributionList::Entry::List::ConstIterator it;
+    for( it = entries.begin(); it != entries.end(); ++it ) {
+      txt += "<li>";
+      txt += (*it).addressee.realName() + ' ';
+      txt += "<em>";
+      if ( (*it).email.isEmpty() ) txt += (*it).addressee.preferredEmail();
+      else txt += (*it).email;
+      txt += "</em>";
+      txt += "<li/>";
+    }
+    txt += "</ul>";
+  }
+#else
   } else if ( mDistributionList ) {
     txt += "<b>" + i18n("Distribution List %1",
         mDistributionList->name() ) + "</b>";
@@ -129,10 +193,11 @@ QString RecipientItem::toolTip() const
       if ( (*it).email().isEmpty() ) txt += (*it).addressee().preferredEmail();
       else txt += (*it).email();
       txt += "</em>";
-      txt += "<li/>";
+      txt += "</li>";
     }
     txt += "</ul>";
   }
+#endif
 
   return txt;
 }
@@ -148,14 +213,14 @@ QString RecipientItem::recipientType() const
 }
 
 
-RecipientViewItem::RecipientViewItem( RecipientItem *item, K3ListView *listView )
-  : K3ListViewItem( listView ), mRecipientItem( item )
+RecipientViewItem::RecipientViewItem( RecipientItem *item, QTreeWidget *listView )
+  : QTreeWidgetItem( listView ), mRecipientItem( item )
 {
   setText( 0, item->recipientType() );
   setText( 1, item->name() );
   setText( 2, item->email() );
 
-  setPixmap( 1, item->icon() );
+  setIcon( 1, item->icon() );
 }
 
 RecipientItem *RecipientViewItem::recipientItem() const
@@ -163,35 +228,6 @@ RecipientItem *RecipientViewItem::recipientItem() const
   return mRecipientItem;
 }
 
-
-#ifdef __GNUC__
-#warning Port me!
-#endif
-#if 0
-RecipientsListToolTip::RecipientsListToolTip( QWidget *parent,
-  K3ListView *listView )
-  : QToolTip( parent )
-{
-  mListView = listView;
-}
-
-void RecipientsListToolTip::maybeTip( const QPoint & pos )
-{
-  QRect r;
-  Q3ListViewItem *item = mListView->itemAt( pos );
-  RecipientViewItem *i = static_cast<RecipientViewItem *>( item );
-
-  if( item ) {
-    r = mListView->itemRect( item );
-    QString tipText( i->recipientItem()->toolTip() );
-    if ( !tipText.isEmpty() ) {
-      tip( r, tipText );
-    }
-  }
-}
-#endif
-
-
 RecipientsCollection::RecipientsCollection()
 {
 }
@@ -243,8 +279,8 @@ void RecipientsCollection::deleteAll()
 }
 
 
-SearchLine::SearchLine( QWidget *parent, K3ListView *listView )
-  : K3ListViewSearchLine( parent, listView )
+SearchLine::SearchLine( QWidget *parent, QTreeWidget *listView )
+  : KTreeWidgetSearchLine( parent, listView )
 {
 }
 
@@ -252,17 +288,23 @@ void SearchLine::keyPressEvent( QKeyEvent *ev )
 {
   if ( ev->key() == Qt::Key_Down ) emit downPressed();
 
-  K3ListViewSearchLine::keyPressEvent( ev );
+  KTreeWidgetSearchLine::keyPressEvent( ev );
 }
 
+RecipientsTreeWidget::RecipientsTreeWidget( QWidget *parent )
+  : QTreeWidget( parent )
+{}
+
+void RecipientsTreeWidget::keyPressEvent ( QKeyEvent *event ) {
+  if ( event->key() == Qt::Key_Return )
+    emit returnPressed();
+  QTreeWidget::keyPressEvent( event );
+}
 
 RecipientsPicker::RecipientsPicker( QWidget *parent )
-  : QDialog( parent ),
-  mDistributionListManager( 0 )
+  : QDialog( parent )
 {
   setObjectName("RecipientsPicker");
-//  KWindowSystem::setType( winId(), NET::Dock );
-
   setWindowTitle( i18n("Select Recipient") );
 
   QBoxLayout *topLayout = new QVBoxLayout( this );
@@ -290,25 +332,26 @@ RecipientsPicker::RecipientsPicker( QWidget *parent )
   label = new QLabel( i18n("&Search:"), this );
   searchLayout->addWidget( label );
 
-  mRecipientList = new K3ListView( this );
-  mRecipientList->setSelectionMode( Q3ListView::Extended );
+  mRecipientList = new RecipientsTreeWidget( this );
+  mRecipientList->setSelectionMode( QAbstractItemView::ExtendedSelection );
   mRecipientList->setAllColumnsShowFocus( true );
-  mRecipientList->setFullWidth( true );
+  mRecipientList->setIndentation( 0 );
+  mRecipientList->setAlternatingRowColors( true );
+  mRecipientList->setSortingEnabled( true );
+  mRecipientList->sortItems( 1, Qt::AscendingOrder );
+  mRecipientList->setHeaderLabels( QStringList() << i18n("->")
+                                                 << i18n("Name")
+                                                 << i18n("Email") );
+  mRecipientList->setColumnWidth( 0, 80);
+  mRecipientList->setColumnWidth( 1, 200 );
+  mRecipientList->setColumnWidth( 2, 200 );
   topLayout->addWidget( mRecipientList );
-  mRecipientList->addColumn( i18n("->") );
-  mRecipientList->addColumn( i18n("Name") );
-  mRecipientList->addColumn( i18n("Email") );
-  connect( mRecipientList, SIGNAL( doubleClicked( Q3ListViewItem *,
-    const QPoint &, int ) ), SLOT( slotPicked() ) );
-  connect( mRecipientList, SIGNAL( returnPressed( Q3ListViewItem * ) ),
-    SLOT( slotPicked() ) );
 
-#ifdef __GNUC__
-#warning Port me!
-#endif
-#if 0
-  new RecipientsListToolTip( mRecipientList->viewport(), mRecipientList );
-#endif
+  connect( mRecipientList, SIGNAL( itemDoubleClicked(QTreeWidgetItem*,int) ),
+           SLOT( slotPicked() ) );
+  connect( mRecipientList, SIGNAL( returnPressed() ),
+           SLOT( slotPicked() ) );
+
   mSearchLine = new SearchLine( this, mRecipientList );
   searchLayout->addWidget( mSearchLine );
   label->setBuddy( label );
@@ -330,8 +373,6 @@ RecipientsPicker::RecipientsPicker( QWidget *parent )
   mBccButton = new QPushButton( i18n("Add as BCC"), this );
   buttonLayout->addWidget( mBccButton );
   connect( mBccButton, SIGNAL( clicked() ), SLOT( slotBccClicked() ) );
-  // BCC isn't commonly used, so hide it for now
-  //mBccButton->hide();
 
   QPushButton *closeButton = new QPushButton( i18n("&Cancel"), this );
   buttonLayout->addWidget( closeButton );
@@ -363,8 +404,6 @@ RecipientsPicker::~RecipientsPicker()
 {
   writeConfig();
 
-  delete mDistributionListManager;
-
   mAllRecipients->deleteAll();
 
   QMap<int,RecipientsCollection *>::ConstIterator it;
@@ -409,7 +448,11 @@ void RecipientsPicker::insertAddressBook( KABC::AddressBook *addressbook )
     QStringList emails = (*it).emails();
     QStringList::ConstIterator it3;
     for( it3 = emails.begin(); it3 != emails.end(); ++it3 ) {
+#ifdef KDEPIM_NEW_DISTRLISTS
+      RecipientItem *item = new RecipientItem( mAddressBook );
+#else
       RecipientItem *item = new RecipientItem;
+#endif
       item->setAddressee( *it, *it3 );
       mAllRecipients->addItem( item );
 
@@ -455,22 +498,23 @@ void RecipientsPicker::insertDistributionLists()
   RecipientsCollection *collection = new RecipientsCollection;
   collection->setTitle( i18n("Distribution Lists") );
 
-  delete mDistributionListManager;
-  mDistributionListManager =
-    new KABC::DistributionListManager( KABC::StdAddressBook::self( true ) );
-
-  mDistributionListManager->load();
-
-  QStringList lists = mDistributionListManager->listNames();
-
-  QStringList::Iterator listIt;
-  for ( listIt = lists.begin(); listIt != lists.end(); ++listIt ) {
-    KABC::DistributionList *list = mDistributionListManager->list( *listIt );
+#ifdef KDEPIM_NEW_DISTRLISTS
+  QList<KPIM::DistributionList> lists = KPIM::DistributionList::allDistributionLists( mAddressBook );
+  for ( int i = 0; i < lists.count(); ++i ) {
+    RecipientItem *item = new RecipientItem( mAddressBook );
+    item->setDistributionList( lists[ i ] );
+    mAllRecipients->addItem( item );
+    collection->addItem( item );
+  }
+#else
+  QList<KABC::DistributionList*> lists = mAddressBook->allDistributionLists();
+  foreach ( KABC::DistributionList *list, lists ) {
     RecipientItem *item = new RecipientItem;
     item->setDistributionList( list );
     mAllRecipients->addItem( item );
     collection->addItem( item );
   }
+#endif
 
   insertCollection( collection );
 }
@@ -482,11 +526,15 @@ void RecipientsPicker::insertRecentAddresses()
 
   KConfig config( "kmailrc" );
   KABC::Addressee::List recents =
-    KRecentAddress::RecentAddresses::self( &config )->kabcAddresses();
+    KPIM::RecentAddresses::self( &config )->kabcAddresses();
 
   KABC::Addressee::List::ConstIterator it;
   for( it = recents.begin(); it != recents.end(); ++it ) {
+#ifdef KDEPIM_NEW_DISTRLISTS
+    RecipientItem *item = new RecipientItem( mAddressBook );
+#else
     RecipientItem *item = new RecipientItem;
+#endif
     item->setAddressee( *it, (*it).preferredEmail() );
     if ( !mAllRecipients->hasEquivalentItem( item ) ) {
       mAllRecipients->addItem( item );
@@ -501,8 +549,8 @@ void RecipientsPicker::insertCollection( RecipientsCollection *coll )
 {
   int index = mCollectionMap.count();
 
-  kDebug(5006) << "RecipientsPicker::insertCollection() " << coll->title()
-    << "  index: " << index << endl;
+  kDebug(5006) <<"RecipientsPicker::insertCollection()" << coll->title()
+    << "index:" << index;
 
   mCollectionCombo->insertItem( index, coll->title() );
   mCollectionMap.insert( index, coll );
@@ -547,7 +595,11 @@ void RecipientsPicker::setRecipients( const Recipient::List &recipients )
       a.setNameFromString( name );
       a.insertEmail( email );
 
+#ifdef KDEPIM_NEW_DISTRLISTS
+      item = new RecipientItem( mAddressBook );
+#else
       item = new RecipientItem;
+#endif
       item->setAddressee( a, a.preferredEmail() );
       item->setRecipientType( (*it).typeLabel() );
       mAllRecipients->addItem( item );
@@ -567,14 +619,9 @@ void RecipientsPicker::setDefaultButton( QPushButton *button )
 void RecipientsPicker::setDefaultType( Recipient::Type type )
 {
   mDefaultType = type;
-
-  if ( type == Recipient::To ) {
-    setDefaultButton( mToButton );
-  } else if ( type == Recipient::Cc ) {
-    setDefaultButton( mCcButton );
-  } else if ( type == Recipient::Bcc ) {
-    setDefaultButton( mBccButton );
-  }
+  mToButton->setDefault( type == Recipient::To );
+  mCcButton->setDefault( type == Recipient::Cc );
+  mBccButton->setDefault( type == Recipient::Bcc );
 }
 
 void RecipientsPicker::updateList()
@@ -586,7 +633,10 @@ void RecipientsPicker::updateList()
   RecipientItem::List items = coll->items();
   RecipientItem::List::ConstIterator it;
   for( it = items.begin(); it != items.end(); ++it ) {
-    new RecipientViewItem( *it, mRecipientList );
+    RecipientViewItem *newItem = new RecipientViewItem( *it, mRecipientList );
+    for ( int i = 0; i < mRecipientList->columnCount(); i++ )
+      newItem->setToolTip( i, newItem->recipientItem()->toolTip() );
+    mRecipientList->addTopLevelItem( newItem );
   }
 
   mSearchLine->updateSearch();
@@ -607,7 +657,7 @@ void RecipientsPicker::slotBccClicked()
   pick( Recipient::Bcc );
 }
 
-void RecipientsPicker::slotPicked( Q3ListViewItem *viewItem )
+void RecipientsPicker::slotPicked( QTreeWidgetItem *viewItem )
 {
   RecipientViewItem *item = static_cast<RecipientViewItem *>( viewItem );
   if ( item ) {
@@ -624,13 +674,9 @@ void RecipientsPicker::slotPicked()
 
 void RecipientsPicker::pick( Recipient::Type type )
 {
-  kDebug(5006) << "RecipientsPicker::pick " << int( type ) << endl;
+  kDebug(5006) <<"RecipientsPicker::pick" << int( type );
 
-  int count = 0;
-  Q3ListViewItemIterator it( mRecipientList ,
-            Q3ListViewItemIterator::Visible | Q3ListViewItemIterator::Selected );
-  for ( ; it.current(); ++it )
-      ++count;
+  int count = mRecipientList->selectedItems().count();
 
   if ( count > GlobalSettings::self()->maximumRecipients() ) {
     KMessageBox::sorry( this,
@@ -642,10 +688,10 @@ void RecipientsPicker::pick( Recipient::Type type )
     return;
   }
 
-  it = Q3ListViewItemIterator( mRecipientList ,
-            Q3ListViewItemIterator::Visible | Q3ListViewItemIterator::Selected );
-  for ( ; it.current(); ++it ) {
-    RecipientViewItem *item = static_cast<RecipientViewItem *>( it.current() );
+  QList<QTreeWidgetItem*> selectedItems = mRecipientList->selectedItems();
+  QList<QTreeWidgetItem*>::iterator it = selectedItems.begin();
+  for ( ; it != selectedItems.end(); ++it ) {
+    RecipientViewItem *item = static_cast<RecipientViewItem *>( *it );
     if ( item ) {
       RecipientItem *i = item->recipientItem();
       Recipient r = i->recipient();
@@ -658,9 +704,10 @@ void RecipientsPicker::pick( Recipient::Type type )
 
 void RecipientsPicker::keyPressEvent( QKeyEvent *ev )
 {
-  if ( ev->key() == Qt::Key_Escape ) close();
+  if ( ev->key() == Qt::Key_Escape )
+    close();
 
-  QWidget::keyPressEvent( ev );
+  QDialog::keyPressEvent( ev );
 }
 
 void RecipientsPicker::readConfig()
