@@ -42,7 +42,6 @@
 #include <QStackedWidget>
 #include <QString>
 #include <QObject>
-#include <QObject>
 
 #include <assert.h>
 
@@ -229,10 +228,13 @@ namespace {
   */
   int childCount( const QObject *parent, const QString &objName )
   {
-    QObjectList list = parent->queryList( 0, objName.toLatin1().data(), false, false );
-    if ( list.isEmpty() )
-      return 0;
-    const int count = list.count();
+    QObjectList list = parent->children();
+    QObject *item;
+    int count = 0;
+    foreach( item, list ) {
+      if ( item->objectName() == objName )
+        count++;
+    }
     return count;
   }
 }
@@ -252,9 +254,8 @@ void KMail::RuleWidgetHandlerManager::createWidgets( QStackedWidget *functionSta
       }
       else {
         // there was already a widget with this name, so discard this widget
-        kDebug(5006) << "RuleWidgetHandlerManager::createWidgets: "
-                      << w->objectName() << " already exists in functionStack"
-                      << endl;
+        kDebug(5006) <<"RuleWidgetHandlerManager::createWidgets:"
+                      << w->objectName() << "already exists in functionStack";
         delete w; w = 0;
       }
     }
@@ -267,9 +268,8 @@ void KMail::RuleWidgetHandlerManager::createWidgets( QStackedWidget *functionSta
       }
       else {
         // there was already a widget with this name, so discard this widget
-        kDebug(5006) << "RuleWidgetHandlerManager::createWidgets: "
-                      << w->objectName() << " already exists in valueStack"
-                      << endl;
+        kDebug(5006) <<"RuleWidgetHandlerManager::createWidgets:"
+                      << w->objectName() << "already exists in valueStack";
         delete w; w = 0;
       }
     }
@@ -337,8 +337,8 @@ void KMail::RuleWidgetHandlerManager::update( const QByteArray &field,
                                               QStackedWidget *functionStack,
                                               QStackedWidget *valueStack ) const
 {
-  //kDebug(5006) << "RuleWidgetHandlerManager::update( \"" << field
-  //              << "\", ... )" << endl;
+  //kDebug(5006) <<"RuleWidgetHandlerManager::update( \"" << field
+  //              << "\", ... )";
   for ( const_iterator it = mHandlers.begin(); it != mHandlers.end(); ++it ) {
     if ( (*it)->update( field, functionStack, valueStack ) )
       return;
@@ -447,7 +447,8 @@ namespace {
 
     // blank QLabel to hide value widget for in-address-book rule
     if ( number == 1 ) {
-      QLabel *label = new QLabel( "textRuleValueHider" );
+      QLabel *label = new QLabel( valueStack );
+      label->setObjectName( "textRuleValueHider" );
       label->setBuddy( valueStack );
       return label;
     }
@@ -479,8 +480,8 @@ namespace {
       return TextFunctions[funcCombo->currentIndex()].id;
     }
     else
-      kDebug(5006) << "TextRuleWidgetHandler::currentFunction: "
-                       "textRuleFuncCombo not found." << endl;
+      kDebug(5006) <<"TextRuleWidgetHandler::currentFunction:"
+                       "textRuleFuncCombo not found.";
     return KMSearchRule::FuncNone;
   }
 
@@ -510,8 +511,8 @@ namespace {
         return combo->currentText();
       }
       else {
-        kDebug(5006) << "TextRuleWidgetHandler::currentValue: "
-                         "categoryCombo not found." << endl;
+        kDebug(5006) <<"TextRuleWidgetHandler::currentValue:"
+                         "categoryCombo not found.";
         return QString();
       }
     }
@@ -527,8 +528,8 @@ namespace {
       return lineEdit->text();
       }
     else
-      kDebug(5006) << "TextRuleWidgetHandler::currentValue: "
-                       "regExpLineEdit not found." << endl;
+      kDebug(5006) <<"TextRuleWidgetHandler::currentValue:"
+                       "regExpLineEdit not found.";
 
     // or anything else, like addressbook
     return QString();
@@ -633,9 +634,9 @@ namespace {
       if ( i < TextFunctionCount )
         funcCombo->setCurrentIndex( i );
       else {
-        kDebug(5006) << "TextRuleWidgetHandler::setRule( "
+        kDebug(5006) <<"TextRuleWidgetHandler::setRule("
                       << rule->asString()
-                      << " ): unhandled function" << endl;
+                      << "): unhandled function";
         funcCombo->setCurrentIndex( 0 );
       }
       funcCombo->blockSignals( false );
@@ -780,7 +781,8 @@ namespace {
 
     // blank QLabel to hide value widget for has-attachment rule
     if ( number == 1 ) {
-      QLabel *label = new QLabel( "textRuleValueHider" );
+      QLabel *label = new QLabel( valueStack );
+      label->setObjectName( "textRuleValueHider" );
       label->setBuddy( valueStack );
       return label;
     }
@@ -802,8 +804,8 @@ namespace {
       return MessageFunctions[funcCombo->currentIndex()].id;
     }
     else
-      kDebug(5006) << "MessageRuleWidgetHandler::currentFunction: "
-                       "messageRuleFuncCombo not found." << endl;
+      kDebug(5006) <<"MessageRuleWidgetHandler::currentFunction:"
+                       "messageRuleFuncCombo not found.";
     return KMSearchRule::FuncNone;
   }
 
@@ -833,8 +835,8 @@ namespace {
       return lineEdit->text();
     }
     else
-      kDebug(5006) << "MessageRuleWidgetHandler::currentValue: "
-                       "regExpLineEdit not found." << endl;
+      kDebug(5006) <<"MessageRuleWidgetHandler::currentValue:"
+                       "regExpLineEdit not found.";
 
     return QString();
   }
@@ -934,9 +936,9 @@ namespace {
       if ( i < MessageFunctionCount )
         funcCombo->setCurrentIndex( i );
       else {
-        kDebug(5006) << "MessageRuleWidgetHandler::setRule( "
+        kDebug(5006) <<"MessageRuleWidgetHandler::setRule("
                       << rule->asString()
-                      << " ): unhandled function" << endl;
+                      << "): unhandled function";
         funcCombo->setCurrentIndex( 0 );
       }
       funcCombo->blockSignals( false );
@@ -1074,8 +1076,8 @@ namespace {
       return StatusFunctions[funcCombo->currentIndex()].id;
     }
     else
-      kDebug(5006) << "StatusRuleWidgetHandler::currentFunction: "
-                       "statusRuleFuncCombo not found." << endl;
+      kDebug(5006) <<"StatusRuleWidgetHandler::currentFunction:"
+                       "statusRuleFuncCombo not found.";
     return KMSearchRule::FuncNone;
   }
 
@@ -1104,8 +1106,8 @@ namespace {
       return statusCombo->currentIndex();
     }
     else
-      kDebug(5006) << "StatusRuleWidgetHandler::currentStatusValue: "
-                       "statusRuleValueCombo not found." << endl;
+      kDebug(5006) <<"StatusRuleWidgetHandler::currentStatusValue:"
+                       "statusRuleValueCombo not found.";
     return -1;
   }
 
@@ -1199,9 +1201,9 @@ namespace {
       if ( funcIndex < StatusFunctionCount )
         funcCombo->setCurrentIndex( funcIndex );
       else {
-        kDebug(5006) << "StatusRuleWidgetHandler::setRule( "
+        kDebug(5006) <<"StatusRuleWidgetHandler::setRule("
                       << rule->asString()
-                      << " ): unhandled function" << endl;
+                      << "): unhandled function";
         funcCombo->setCurrentIndex( 0 );
       }
       funcCombo->blockSignals( false );
@@ -1223,9 +1225,9 @@ namespace {
       if ( valueIndex < KMail::StatusValueCountWithoutHidden )
         statusCombo->setCurrentIndex( valueIndex );
       else {
-        kDebug(5006) << "StatusRuleWidgetHandler::setRule( "
+        kDebug(5006) <<"StatusRuleWidgetHandler::setRule("
                       << rule->asString()
-                      << " ): unhandled value" << endl;
+                      << "): unhandled value";
         statusCombo->setCurrentIndex( 0 );
       }
       statusCombo->blockSignals( false );
@@ -1329,8 +1331,8 @@ namespace {
       return NumericFunctions[funcCombo->currentIndex()].id;
     }
     else
-      kDebug(5006) << "NumericRuleWidgetHandler::currentFunction: "
-                       "numericRuleFuncCombo not found." << endl;
+      kDebug(5006) <<"NumericRuleWidgetHandler::currentFunction:"
+                       "numericRuleFuncCombo not found.";
     return KMSearchRule::FuncNone;
   }
 
@@ -1359,8 +1361,8 @@ namespace {
       return QString::number( numInput->value() );
     }
     else
-      kDebug(5006) << "NumericRuleWidgetHandler::currentValue: "
-                       "KIntNumInput not found." << endl;
+      kDebug(5006) <<"NumericRuleWidgetHandler::currentValue:"
+                       "KIntNumInput not found.";
     return QString();
   }
 
@@ -1460,9 +1462,9 @@ namespace {
       if ( funcIndex < NumericFunctionCount )
         funcCombo->setCurrentIndex( funcIndex );
       else {
-        kDebug(5006) << "NumericRuleWidgetHandler::setRule( "
+        kDebug(5006) <<"NumericRuleWidgetHandler::setRule("
                       << rule->asString()
-                      << " ): unhandled function" << endl;
+                      << "): unhandled function";
         funcCombo->setCurrentIndex( 0 );
       }
       funcCombo->blockSignals( false );
