@@ -19,8 +19,8 @@
 */
 
 
-#ifndef __AKONADI_SERIALIZER_MAIL_H__
-#define __AKONADI_SERIALIZER_MAIL_H__
+#ifndef __AKONADI_SERIALIZER_SMS_H__
+#define __AKONADI_SERIALIZER_SMS_H__
 
 #include <libakonadi/itemserializerplugin.h>
 
@@ -29,7 +29,7 @@ namespace Akonadi {
 class SerializerPluginSMS : public ItemSerializerPlugin
 {
 public:
-    void deserialize( Item& item, const QString& label, QIODevice& data );
+    bool deserialize( Item& item, const QString& label, QIODevice& data );
     void serialize( const Item& item, const QString& label, QIODevice& data );
 };
 
