@@ -1,6 +1,7 @@
 /***************************************************************************
    Copyright (C) 2007
    by Marco Gulino <marco@kmobiletools.org>
+   by Matthias Lechner <matthias@lmme.de>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -94,9 +95,13 @@
 #include "calldialogimpl.h"
 //#include "mainIFace_stub.h"
 
+#include <QtGui/QTreeWidgetItem>
 
 #include <libkmobiletools/errorhandler.h>
 #include <libkmobiletools/errortypes/baseerror.h>
+#include <libkmobiletools/sms.h>
+#include <libkmobiletools/homepage.h>
+#include <libkmobiletools/enginedata.h>
 
 #define INDEX_WIDGET_ID 0
 #define PHONEBOOK_WIDGET_ID 2
@@ -135,12 +140,15 @@ ContactListViewItem::ContactListViewItem(Q3ListView *parent, const KABC::Address
     setText(0, p_contact.formattedName());
 }
 
+KABC::Addressee ContactListViewItem::contact() {
+    return p_contact;
+}
 
 
-DeviceHome::DeviceHome( QWidget *parentWidget, const QString &devicename, kmobiletoolsMainPart *parent ) : QObject( parent ), p_mainPart(parent), statusBarExtension(0), memslotSelected(0), signalProgress(0),
-    smsTypeSelected(0), networkLabel(0), batteryProgress(0), devNameLabel(0), voidLabel(0),
-    batteryLabel(0), signalLabel(0), statusBarBox(0), suspends_count(0), engine(0), p_calendar(0),
-    b_dialing(false), b_dialing_called(false)
+DeviceHome::DeviceHome( QWidget *parentWidget, const QString &devicename, kmobiletoolsMainPart *parent ) : QObject( parent ), engine(0), suspends_count(0), statusBarExtension(0), memslotSelected(0),
+    smsTypeSelected(0), p_mainPart(parent), p_calendar(0), statusBarBox(0), signalProgress(0),
+    batteryProgress(0), networkLabel(0), devNameLabel(0), voidLabel(0), batteryLabel(0),
+    signalLabel(0), b_dialing(false), b_dialing_called(false)
 {
     m_widget = new QWidget(parentWidget);
     ui.setupUi(m_widget);
@@ -210,30 +218,44 @@ void DeviceHome::setupWidgets()
     ui.widgetStack->raiseWidget(INDEX_WIDGET_ID);
     m_widget->setFocusPolicy(Qt::ClickFocus);
 
-    p_listViewItem=new DeviceListViewItem(p_mainPart->listview() , DEVCFG(objectName() )->devicename());
+    /*
+    p_listViewItem=new DeviceListViewItem(DEVCFG(objectName() )->devicename(), p_mainPart->listview() );
     p_listViewItem->setDeviceName( objectName() );
-    p_listViewItem->setOpen(true);
-    p_listViewItem->setPixmap(0,DEVCFG(objectName() )->deviceTypeIcon(DEVCFG(objectName() )->currentGroup(), K3Icon::NoGroup, K3Icon::SizeSmall ));
+    p_listViewItem->setIcon( 0, DEVCFG(objectName() )->deviceTypeIcon(DEVCFG(objectName() )->currentGroup(), KIconLoader::NoGroup, KIconLoader::SizeSmall ) );
+
+    (new QTreeWidgetItem( p_listViewItem, QStringList("Calls") ) )
+    ->setIcon( 0, KIcon( "kaddressbook" ) );
+
+    (new QTreeWidgetItem( p_listViewItem, QStringList( i18n( "PhoneBook") ) ) )
+    ->setIcon( 0, KIcon( "kontact_contacts" ) );
+
+
+    p_smsItem = new QTreeWidgetItem( p_listViewItem, QStringList( i18n("SMS") ) );
+    p_smsItem->setIcon( 0, KIcon( "mail_generic" ) );
+    */
+
+    //p_listViewItem->setOpen(true);
+    //p_listViewItem->setPixmap(0,DEVCFG(objectName() )->deviceTypeIcon(DEVCFG(objectName() )->currentGroup(), KIconLoader::NoGroup, KIconLoader::SizeSmall ));
 //     (new K3ListViewItem(p_listViewItem, "Calls") )
-//             ->setPixmap(0,KIconLoader::global()->loadIcon("kaddressbook", K3Icon::NoGroup, K3Icon::SizeSmall) );
-    (new K3ListViewItem(p_listViewItem, i18n("PhoneBook") ) )
-            ->setPixmap(0,KIconLoader::global()->loadIcon("kontact_contacts", K3Icon::NoGroup, K3Icon::SizeSmall) );
-    p_smsItem = new K3ListViewItem(p_listViewItem, i18n("SMS") );
-    p_smsItem->setPixmap(0,KIconLoader::global()->loadIcon("mail_generic", K3Icon::NoGroup, K3Icon::SizeSmall) );
+//             ->setPixmap(0,KIconLoader::global()->loadIcon("kaddressbook", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
+    //(new K3ListViewItem(p_listViewItem, i18n("PhoneBook") ) )
+    //        ->setPixmap(0,KIconLoader::global()->loadIcon("kontact_contacts", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
+    //p_smsItem = new K3ListViewItem(p_listViewItem, i18n("SMS") );
+    //p_smsItem->setPixmap(0,KIconLoader::global()->loadIcon("mail_generic", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
 
     // SMS Tree ListView
-    SMSFolderListViewItem *sms_inbox= new SMSFolderListViewItem(ui.SMSFolderView, SMS::SIM | SMS::Phone, SMS::Unread | SMS::Read, i18n("Inbox") );
+    SMSFolderListViewItem *sms_inbox= new SMSFolderListViewItem(ui.SMSFolderView, SMS::Sim | SMS::Phone, SMS::Unread | SMS::Read, i18n("Inbox") );
     SMSFolderListViewItem *sms_inbox_phone= new SMSFolderListViewItem(sms_inbox, SMS::Phone, SMS::Unread | SMS::Read, i18n("Phone") );
-    SMSFolderListViewItem *sms_inbox_sim= new SMSFolderListViewItem(sms_inbox, SMS::SIM, SMS::Unread | SMS::Read, i18n("SIM") );
-    SMSFolderListViewItem *sms_outbox= new SMSFolderListViewItem(ui.SMSFolderView, SMS::SIM | SMS::Phone, SMS::Sent | SMS::Unsent, i18n("Outgoing") );
+    SMSFolderListViewItem *sms_inbox_sim= new SMSFolderListViewItem(sms_inbox, SMS::Sim, SMS::Unread | SMS::Read, i18n("Sim") );
+    SMSFolderListViewItem *sms_outbox= new SMSFolderListViewItem(ui.SMSFolderView, SMS::Sim | SMS::Phone, SMS::Sent | SMS::Unsent, i18n("Outgoing") );
     SMSFolderListViewItem *sms_outbox_phone= new SMSFolderListViewItem(sms_outbox, SMS::Phone, SMS::Sent | SMS::Unsent, i18n("Phone") );
-    SMSFolderListViewItem *sms_outbox_sim= new SMSFolderListViewItem(sms_outbox, SMS::SIM, SMS::Sent | SMS::Unsent, i18n("SIM") );
-    sms_inbox->setPixmap(0,KIconLoader::global()->loadIcon("mail_get", K3Icon::NoGroup, K3Icon::SizeSmall) );
-    sms_outbox->setPixmap(0,KIconLoader::global()->loadIcon("mail_send", K3Icon::NoGroup, K3Icon::SizeSmall) );
-    sms_inbox_phone->setPixmap(0,KIconLoader::global()->loadIcon("kmobiletools", K3Icon::NoGroup, K3Icon::SizeSmall) );
-    sms_outbox_phone->setPixmap(0,KIconLoader::global()->loadIcon("kmobiletools", K3Icon::NoGroup, K3Icon::SizeSmall) );
-    sms_inbox_sim->setPixmap(0,KIconLoader::global()->loadIcon("simcard", K3Icon::NoGroup, K3Icon::SizeSmall) );
-    sms_outbox_sim->setPixmap(0,KIconLoader::global()->loadIcon("simcard", K3Icon::NoGroup, K3Icon::SizeSmall) );
+    SMSFolderListViewItem *sms_outbox_sim= new SMSFolderListViewItem(sms_outbox, SMS::Sim, SMS::Sent | SMS::Unsent, i18n("Sim") );
+    sms_inbox->setPixmap(0,KIconLoader::global()->loadIcon("mail_get", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
+    sms_outbox->setPixmap(0,KIconLoader::global()->loadIcon("mail_send", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
+    sms_inbox_phone->setPixmap(0,KIconLoader::global()->loadIcon("kmobiletools", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
+    sms_outbox_phone->setPixmap(0,KIconLoader::global()->loadIcon("kmobiletools", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
+    sms_inbox_sim->setPixmap(0,KIconLoader::global()->loadIcon("simcard", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
+    sms_outbox_sim->setPixmap(0,KIconLoader::global()->loadIcon("simcard", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
 
     sms_inbox->setOpen(true);
     sms_outbox->setOpen(true);
@@ -271,7 +293,7 @@ void DeviceHome::setupWidgets()
     if(DEVCFG(objectName() )->calendar() )
     {
         (new K3ListViewItem(p_listViewItem, i18n("Calendar") ) )
-                ->setPixmap(0,KIconLoader::global()->loadIcon("date", K3Icon::NoGroup, K3Icon::SizeSmall) );
+                ->setPixmap(0,KIconLoader::global()->loadIcon("date", KIconLoader::NoGroup, KIconLoader::SizeSmall) );
         KParts::Factory *pfactory=(KParts::Factory *) (KLibLoader::self()->factory("libkorganizerpart") );
         QVBoxLayout *l1=new QVBoxLayout(ui.korg_frame);
         l1->setMargin(0);
@@ -309,12 +331,12 @@ void DeviceHome::loadEngine()
         return;
     }
     libName=infos.service()->library();
-    kDebug() << "**************** libname printable: " << qPrintable(libName) << endl;
+    kDebug() <<"**************** libname printable:" << qPrintable(libName);
     engine=KMobileTools::Engine::load(libName, this);
     if(!engine)
     {
         engine=0;
-        kDebug() << "Library error message: " << KLibLoader::self()->lastErrorMessage() << endl;
+        kDebug() <<"Library error message:" << KLibLoader::self()->lastErrorMessage();
         KMessageBox::error(m_widget, i18n("Could not load the device %1.\nIf this error persists, please restart KMobileTools.", objectName() ) );
         emit deleteThis( objectName() );
         return;
@@ -351,6 +373,8 @@ void DeviceHome::loadEngine()
     engine->slotSearchPhone();
 
     // setup status poll trigger
+    /// @todo this config entry has been removed, port or remove...
+    /*
     if( DEVCFG(objectName() )->status_poll() && DEVCFG(objectName() )->status_pollTimeout() > 0 )
     {
         statusPollTimer=new QTimer(this);
@@ -358,8 +382,11 @@ void DeviceHome::loadEngine()
         connect(statusPollTimer, SIGNAL(timeout() ), engine, SLOT(slotPollStatus()) );
         statusPollTimer->start( (int) DEVCFG(objectName() )->status_pollTimeout() * 1000 );
     }
+    */
 
     // setup sms poll trigger
+    /// @todo this config entry has been removed, port or remove...
+    /*
     if( DEVCFG(objectName() )->smsPoll() && DEVCFG(objectName() )->sms_pollTimeout() > 0 )
     {
         smsPollTimer=new QTimer(this);
@@ -371,14 +398,8 @@ void DeviceHome::loadEngine()
             // if we've a long timer for sms just retrieve them earlier the first time.
             QTimer::singleShot(15*1000, engine, SLOT(slotFetchSMS()));
     }
+    */
     updateSMSCount();
-
-    ErrorHandler::instance()->addError( new BaseError(ERROR_META_INFO) );
-
-    QHash<QString,QVariant> debugInfo;
-    debugInfo["Test"] = "Testinfo";
-    debugInfo["Bla"] = 3;
-    ErrorHandler::instance()->addError( new BaseError( QString("Test"), 10, QDateTime(), "Test", debugInfo ) );
 }
 
 
@@ -389,9 +410,8 @@ QString DeviceHome::friendlyName()
 
 DeviceHome::~DeviceHome()
 {
-    kDebug() << "DeviceHome::~DeviceHome()\n";
+    kDebug() <<"DeviceHome::~DeviceHome()";
     KMobileTools::EnginesList::instance()->unlock(objectName() );
-//     f_pidfile.remove();
 //     delete m_widget;
 //     delete m_statusbar;
 }
@@ -437,8 +457,8 @@ void DeviceHome::addSMSFolders()
     for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) 
     {
         int fn = 1;
-        K3ListViewItem* i = new K3ListViewItem(p_smsItem, *it );
-        i->setPixmap(0,KIconLoader::global()->loadIcon("mail_generic", K3Icon::NoGroup, K3Icon::SizeSmall) );
+        QTreeWidgetItem* i = new QTreeWidgetItem( p_smsItem, QStringList( *it ) );
+        i->setIcon( 0, KIcon("mail_generic") );
         i->setText( 1, "SMSFolder" );
         i->setText( 2, QString::number( fn ) );
      }
@@ -448,9 +468,11 @@ void DeviceHome::addSMSFolders()
 /*!
     \fn DeviceHome::clicked ( QListViewItem * item )
  */
-void DeviceHome::clicked ( Q3ListViewItem * item )
+void DeviceHome::clicked ( QTreeWidgetItem * item )
 {
-    if (! item) return;
+    if (! item)
+        return;
+
     if ( item->text(0) == i18n("PhoneBook") )
     {
         ui.widgetStack->raiseWidget(PHONEBOOK_WIDGET_ID);
@@ -490,7 +512,7 @@ void DeviceHome::updateAllContacts()
     {
         p_engine = *it;
         if( engine && QString(p_engine->objectName())==QString(engine->objectName())) continue;
-        kDebug() << "DevicePart " << objectName() << ": adding contacts from engine " << p_engine->objectName() << endl;
+        kDebug() <<"DevicePart" << objectName() <<": adding contacts from engine" << p_engine->objectName();
         updateAllContacts( p_engine->constEngineData()->contactsList() );
     }
 }
@@ -498,11 +520,11 @@ void DeviceHome::updateAllContacts()
 void DeviceHome::jobDone(KMobileTools::Job::JobType jobtype)
 {
     if(jobtype==KMobileTools::Job::fetchAddressBook) emit phonebookUpdated();
-    int newsmscnt=engine->constEngineData()->smsList()->count(SMS::Unread, SMS::SIM | SMS::Phone );
+    int newsmscnt=engine->constEngineData()->smsList()->count(SMS::Unread, SMS::Sim | SMS::Phone );
 
     if(newsmscnt && engine->ThreadWeaver()->isEmpty() && engine->ThreadWeaver()->isIdle() && newsmscnt!=smsnotifynum) {
         smsnotifynum=newsmscnt;
-        QString eventString(i18n("<qt>%1 New Messages.<br>Mobile Phone: %2</qt>", newsmscnt, DEVCFG(name() )->devicename() ) );
+        QString eventString(i18n("<qt>%1 New Messages.<br/>Mobile Phone: %2</qt>", newsmscnt, DEVCFG(name() )->devicename() ) );
         KNotification::event( QString("kmobiletools_sms"), eventString, QPixmap(),
             KMobileTools::KMobiletoolsHelper::instance()->systray()->contextMenu() );
     }
@@ -576,10 +598,11 @@ void DeviceHome::devDisconnected()
 
 void DeviceHome::devConnected()
 {
-//     kDebug() << "DeviceHome::devConnected()" << endl;
+//     kDebug() <<"DeviceHome::devConnected()";
     devIsConnected=true;
     emit connected();
-    DEVCFG(objectName() )->setLastpath(engine->currentDeviceName());
+    /// @todo this config entry has been removed, port or remove...
+    //DEVCFG(objectName() )->setLastpath(engine->currentDeviceName());
     home->printInfoPage(0, this->engine);
 }
 
@@ -793,7 +816,7 @@ void DeviceHome::raiseDevice()
  */
 void DeviceHome::smsModified(const QString & smsUID)
 {
-    kDebug( ) << "DeviceHome::smsModified(" << smsUID << ")\n";
+    kDebug( ) <<"DeviceHome::smsModified(" << smsUID <<")";
 }
 
 
@@ -804,7 +827,7 @@ void DeviceHome::smsAdded(const QString & smsUID)
 {
     updateSMSCount();
     home->printInfoPage( home->currentInfoPage(), engine );
-    kDebug( ) << "DeviceHome::smsAdded(" << smsUID << ")\n";
+    kDebug( ) <<"DeviceHome::smsAdded(" << smsUID <<")";
     const SMSList *smsList = engine->constEngineData()->smsList();
     int newSMSIndex=smsList->find( smsUID );
     if(newSMSIndex<0) return;
@@ -829,7 +852,7 @@ QString DeviceHome::currentDeviceName() const
  */
 void DeviceHome::smsRemoved(const QString & smsUID)
 {
-//     kDebug( ) << "DeviceHome::smsRemoved(" << smsUID << ")\n";
+//     kDebug( ) <<"DeviceHome::smsRemoved(" << smsUID <<")";
 //     updateSMSList();
 //     return;
     updateSMSCount();
@@ -917,7 +940,7 @@ void DeviceHome::storeSMS(const QString& number, const QString& text)
  */
 void DeviceHome::openURL(const KUrl &url)
 {
-    kDebug() << "Parsing url " << url << endl;
+    kDebug() <<"Parsing url" << url;
     if(url.path() == "sms") ui.widgetStack->raiseWidget(SMS_WIDGET_ID);
     if(url.path() == "phonebook") ui.widgetStack->raiseWidget(PHONEBOOK_WIDGET_ID);
     if(url.path() == "tryconnect")
@@ -929,7 +952,7 @@ void DeviceHome::openURL(const KUrl &url)
     if(url.path() == "configure")
     {
         emit command( QString("configure:") + objectName() );
-        kDebug() << "emitted command(" << QString("configure:") + objectName() << ")\n";
+        kDebug() <<"emitted command(" << QString("configure:") + objectName() <<")";
     }
 }
 
@@ -989,7 +1012,7 @@ void DeviceHome::slotCalendarFetched()
     QString savefile=KGlobal::dirs()->saveLocation( "data", "kmobiletools", true).append( "%1.vcs" ).arg(objectName() );
 
     korgpart->closeUrl();
-    kDebug() << "DeviceHome::slotCalendarFetched()\n";
+    kDebug() <<"DeviceHome::slotCalendarFetched()";
     Calendar *engineCal=constEngineData->calendar();
     p_calendar->deleteAllEvents ();
     for(Calendar::Iterator it=engineCal->begin(); it!=engineCal->end(); ++it)
@@ -1036,8 +1059,10 @@ void DeviceHome::slotExportSMSList()
 //     if ( KMobileTools::MainConfig::self()->maildir() )
     KMobileTools::KMobiletoolsHelper::createMailDir( objectName() );
     engine->constEngineData()->smsList()->saveToMailBox();
-    kDebug() << "STARTING SMS EXPORT\n";
-    KMessageBox::information( m_widget, i18n("<qt>SMS List for the mobile phone <b>%1</b> was exported to KMail default directory (%2).<br>To view exported messages, close and reopen KMail.</qt>", DEVCFG(objectName() )->devicename(), DEVCFG(objectName() )->maildir_path() ), i18n("SMS List Exported."), "smslistexported_infobox" );
+    kDebug() <<"STARTING SMS EXPORT";
+
+    /// @todo this config entry has been removed, port or remove...
+    //KMessageBox::information( m_widget, i18n("<qt><p>SMS List for the mobile phone <b>%1</b> was exported to KMail default directory (%2).</p><p>To view exported messages, close and reopen KMail.</p></qt>", DEVCFG(objectName() )->devicename(), DEVCFG(objectName() )->maildir_path() ), i18n("SMS List Exported."), "smslistexported_infobox" );
 }
 
 /*!
@@ -1047,7 +1072,7 @@ void DeviceHome::slotExportSMSListToCSV()
 {
     int result;
     
-    kDebug() << "STARTING SMS EXPORT TO CSV\n";
+    kDebug() <<"STARTING SMS EXPORT TO CSV";
     result = engine->constEngineData()->smsList()->saveToCSV();
     if (result >= 1) {
         KMessageBox::information( m_widget, i18n("<qt>SMS List for the mobile phone <b>%1</b> was exported to the selected Directory.</qt>", DEVCFG(objectName() )->devicename() ), i18n("SMS List Exported."), "smslistexportedtocsv_infobox" );
@@ -1122,7 +1147,7 @@ void DeviceHome::slotSaveAddressBook()
     KABC::Ticket *ticket=p_addressbook->requestSaveTicket( p_resourcefile );
     if(!ticket)
     {
-        kDebug() << "Error: Unable to save to KAddressBook (engine " << objectName() << ", " << DEVCFG(objectName() )->devicename() << "; filename: " << p_resourcefile->fileName() << ")\n";
+        kDebug() <<"Error: Unable to save to KAddressBook (engine" << objectName() <<"," << DEVCFG(objectName() )->devicename() <<"; filename:" << p_resourcefile->fileName() <<")";
         return;
     }
     p_addressbook->save( ticket );
@@ -1149,7 +1174,7 @@ void DeviceHome::slotSendStoredSMS( SMS *sms)
 void DeviceHome::slotRing( bool ringing)
 {
     if(!ringing) return;
-    kDebug() << "KNotify for ring event\n";
+    kDebug() <<"KNotify for ring event";
     KNotification::event( QString("kmobiletools_ring"), i18n("Incoming Call"), QPixmap(),
         KMobileTools::KMobiletoolsHelper::instance()->systray()->contextMenu() );
 }
@@ -1194,7 +1219,7 @@ void DeviceHome::switch2filesystem()
  */
 void DeviceHome::contactsTabChanged()
 {
-    kDebug() << "Contacts tab index: " <<ui.contactsTab->currentIndex() << endl;
+    kDebug() <<"Contacts tab index:" <<ui.contactsTab->currentIndex();
     if(ui.contactsTab->currentIndex())
         slwidget->searchLine()->setListView(ui.phonebookListViewFull);
     else slwidget->searchLine()->setListView(ui.phonebookListView);
