@@ -30,7 +30,7 @@
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <kactionmenu.h>
-#include <kaddrbook.h>
+#include <kaddrbookexternal.h>
 #include <kascii.h>
 #include <kbookmarkmanager.h>
 #include <kcharsets.h>
@@ -77,6 +77,7 @@
 #include "knsourceviewwindow.h"
 #include "nntpjobs.h"
 #include "settings.h"
+#include "kmutils.h"
 
 using namespace KNode;
 
@@ -113,7 +114,7 @@ ArticleWidget::ArticleWidget( QWidget *parent,
   mViewer->setMetaRefreshEnabled( false );
   mViewer->setOnlyLocalReferences( true );
   mViewer->view()->setFocusPolicy( Qt::WheelFocus );
-  connect( mViewer->browserExtension(), SIGNAL(openUrlRequestDelayed(const KUrl&, const KParts::URLArgs&)),
+  connect( mViewer->browserExtension(), SIGNAL(openUrlRequestDelayed(const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments&)),
            SLOT(slotURLClicked(const KUrl&)) );
   connect( mViewer, SIGNAL(popupMenu(const QString&, const QPoint&)),
            SLOT(slotURLPopup(const QString&, const QPoint&)) );
@@ -447,7 +448,7 @@ void ArticleWidget::displayArticle()
   if ( text && !canDecodeText( text->contentType()->charset() ) ) {
     html += QString("<table width=\"100%\" border=\"0\"><tr><td bgcolor=\"#FF0000\">%1</td></tr></table>")
       .arg( i18n("Unknown charset. Default charset is used instead.") );
-    kDebug(5003) << k_funcinfo << "unknown charset = " << text->contentType()->charset() << endl;
+    kDebug(5003) <<"unknown charset =" << text->contentType()->charset();
   }
 
   // if the article is pgp signed and the user asked for verifying the
@@ -506,7 +507,7 @@ void ArticleWidget::displayArticle()
 
   // partial message
   if(ct->isPartial()) {
-    mViewer->write( i18n("<br/><b>This article has the MIME type &quot;message/partial&quot;, which KNode cannot handle yet.<br>Meanwhile you can save the article as a text file and reassemble it by hand.</b>") );
+    mViewer->write( i18n("<br /><b>This article has the MIME type &quot;message/partial&quot;, which KNode cannot handle yet.<br />Meanwhile you can save the article as a text file and reassemble it by hand.</b>") );
   }
 
   // display body text
@@ -906,8 +907,12 @@ void ArticleWidget::displayAttachment( KMime::Content *att, int partNum )
   } else { // icon
     QByteArray mimetype = ct->mimeType();
     kAsciiToLower( mimetype.data() );
-    QString iconName = KMimeType::mimeType( mimetype )->iconName( QString() );
-    QString iconFile = KIconLoader::global()->iconPath( iconName, K3Icon::Desktop );
+    KMimeType::Ptr mimetypePtr = KMimeType::mimeType( mimetype );
+    if(mimetypePtr.isNull()) {
+      mimetypePtr = KMimeType::mimeType( "text/plain" );
+    }
+    QString iconName = mimetypePtr->iconName( QString() );
+    QString iconFile = KIconLoader::global()->iconPath( iconName, KIconLoader::Desktop );
     html += "<div><a href=\"" + href + "\"><img src=\"" +
             iconFile + "\" border=\"0\">" + label +
             "</a></div><div>" + comment + "</div><br>";
@@ -927,7 +932,7 @@ QString ArticleWidget::toHtmlString( const QString &line, int flags )
   QString text = line;
   if ( flags & ArticleWidget::AllowROT13 ) {
     if ( mRot13 )
-      text = KNHelper::rot13( line );
+      text = KPIM::KMUtils::rot13( line );
   }
   return KPIMUtils::LinkLocator::convertToHtml( text, llflags );
 }
@@ -971,7 +976,7 @@ bool ArticleWidget::inlinePossible( KMime::Content *c )
 
 bool ArticleWidget::canDecodeText( const QByteArray &charset ) const
 {
-  kDebug( 5003 ) << k_funcinfo << charset << endl;
+  kDebug( 5003 ) << charset;
   if ( charset.isEmpty() )
     return false;
   bool ok = true;
@@ -1180,7 +1185,7 @@ void ArticleWidget::slotURLClicked( const KUrl &url, bool forceOpen)
   }
   // handle news URL's
   if ( url.protocol() == "news" ) {
-    kDebug( 5003 ) << k_funcinfo << url << endl;
+    kDebug( 5003 ) << url;
     knGlobals.top->openURL( url );
     return;
   }
@@ -1448,18 +1453,18 @@ void ArticleWidget::slotAddBookmark()
   QString filename = KStandardDirs::locateLocal( "data", QString::fromLatin1("konqueror/bookmarks.xml") );
   KBookmarkManager *bookManager = KBookmarkManager::managerForFile( filename, "konqueror" );
   KBookmarkGroup group = bookManager->root();
-  group.addBookmark( bookManager, mCurrentURL.url(), mCurrentURL );
+  group.addBookmark( mCurrentURL.url(), mCurrentURL );
   bookManager->save();
 }
 
 void ArticleWidget::slotAddToAddressBook()
 {
-  KAddrBookExternal::addEmail( mCurrentURL.path(), this );
+  KPIM::KAddrBookExternal::addEmail( mCurrentURL.path(), this );
 }
 
 void ArticleWidget::slotOpenInAddressBook()
 {
-  KAddrBookExternal::openEmail( mCurrentURL.path(), mCurrentURL.path(), this );
+  KPIM::KAddrBookExternal::openEmail( mCurrentURL.path(), mCurrentURL.path(), this );
 }
 
 void ArticleWidget::slotOpenAttachment()
