@@ -110,7 +110,7 @@ void KNArticleFactory::createPosting(KNGroup *g)
 }
 
 
-void KNArticleFactory::createReply(KNRemoteArticle *a, QString selectedText, bool post, bool mail)
+void KNArticleFactory::createReply(KNRemoteArticle *a, const QString &selectedText, bool post, bool mail)
 {
   if(!a)
     return;
@@ -607,7 +607,7 @@ void KNArticleFactory::edit(KNLocalArticle *a)
   if(id->useSigGenerator() && !id->getSigGeneratorStdErr().isEmpty())
   KMessageBox::information(knGlobals.topWidget,
                             i18n("<qt>The signature generator program produced the "
-                                "following output:<br><br>%1</qt>",
+                                "following output:<br /><br />%1</qt>",
                                  id->getSigGeneratorStdErr()));
 
   mCompList.append( com );
@@ -781,7 +781,7 @@ void KNArticleFactory::processJob(KNJobData *j)
 }
 
 
-KNLocalArticle* KNArticleFactory::newArticle(KNCollection *col, QString &sig, QByteArray defChset, bool withXHeaders, KNArticle *origPost)
+KNLocalArticle* KNArticleFactory::newArticle(KNCollection *col, QString &sig, const QByteArray &defChset, bool withXHeaders, KNArticle *origPost)
 {
   if ( knGlobals.settings()->generateMessageID() && knGlobals.settings()->hostname().isEmpty() ) {
     KMessageBox::sorry(knGlobals.topWidget, i18n("Please set a hostname for the generation\nof the message-id or disable it."));
@@ -907,7 +907,7 @@ KNLocalArticle* KNArticleFactory::newArticle(KNCollection *col, QString &sig, QB
     if(id->useSigGenerator() && !id->getSigGeneratorStdErr().isEmpty())
       KMessageBox::information(knGlobals.topWidget,
                                i18n("<qt>The signature generator program produced the "
-                                   "following output:<br><br>%1</qt>",
+                                   "following output:<br /><br />%1</qt>",
                                     id->getSigGeneratorStdErr()));
   }
   else
@@ -1119,7 +1119,7 @@ void KNSendErrorDialog::slotHighlighted(int idx)
 {
   ErrorListItem *item = static_cast<ErrorListItem*>( mErrorList->item( idx ) );
   if ( item ) {
-    QString tmp = i18n("<b>Error message:</b><br>") + item->error();
+    QString tmp = i18n("<b>Error message:</b><br />") + item->error();
     mError->setText( tmp );
   }
 }
