@@ -99,7 +99,7 @@ KNode::IdentityWidget::IdentityWidget( Identity *d, const KComponentData &inst,
   topL->addWidget(l, 2,0);
   topL->addWidget(e_mail, 2, 1, 1,2);
   msg = i18n( "<qt><p>Your email address as it will appear to others "
-      "reading your articles</p><p>Ex: <b>nospam@please.com</b>.</qt>" );
+      "reading your articles</p><p>Ex: <b>nospam@please.com</b>.</p></qt>" );
   l->setWhatsThis( msg );
   e_mail->setWhatsThis( msg );
   connect( e_mail, SIGNAL(textChanged(const QString&)), SLOT(changed()) );
@@ -208,7 +208,7 @@ void KNode::IdentityWidget::textFileNameChanged(const QString &text)
 
 void KNode::IdentityWidget::load()
 {
-  kDebug() << "void KNConfig::IdentityWidget::load()" << endl;
+  kDebug() <<"void KNConfig::IdentityWidget::load()";
   n_ame->setText(d_ata->n_ame);
   o_rga->setText(d_ata->o_rga);
   e_mail->setText(d_ata->e_mail);
@@ -1260,7 +1260,7 @@ KNode::FilterListWidget::FilterListWidget( const KComponentData &inst, QWidget *
   topL->setRowStretch(11,1);
 
   a_ctive = SmallIcon("search-filter",16);
-  d_isabled = SmallIcon("search-filter",16,K3Icon::DisabledState);
+  d_isabled = SmallIcon("search-filter",16,KIconLoader::DisabledState);
 
   load();
 
@@ -1495,7 +1495,7 @@ void KNode::PostNewsTechnicalWidget::load()
 {
   KCModule::load();
 
-  kDebug(5003) << k_funcinfo << knGlobals.settings()->charset() << endl;
+  kDebug(5003) << knGlobals.settings()->charset();
   mCharset->setCurrentIndex( mCharset->findText( knGlobals.settings()->charset() ) );
   mEncoding->setCurrentIndex( knGlobals.settings()->allow8BitBody() ? 0 : 1 );
 
