@@ -14,7 +14,6 @@
 #include "knmainwidget.h"
 
 #include <QLayout>
-//Added by qt3to4:
 #include <Q3Accel>
 #include <QEvent>
 #include <QDropEvent>
@@ -49,13 +48,12 @@
 #include "broadcaststatus.h"
 #include "recentaddresses.h"
 using KPIM::BroadcastStatus;
-using KRecentAddress::RecentAddresses;
+using KPIM::RecentAddresses;
 
 #include <mailtransport/transportmanager.h>
 using MailTransport::TransportManager;
 
 //GUI
-#include "knmainwidget.h"
 #include "knarticlewindow.h"
 #include "kncollectionview.h"
 #include "kncollectionviewitem.h"
@@ -248,34 +246,34 @@ KNMainWidget::~KNMainWidget()
   h_drView->clear(); //avoid some random crashes in KNHdrViewItem::~KNHdrViewItem()
 
   delete knGlobals.scheduler();
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : Scheduler deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : Scheduler deleted";
 
   delete a_rtManager;
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : Article Manager deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : Article Manager deleted";
 
   delete a_rtFactory;
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : Article Factory deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : Article Factory deleted";
 
   delete g_rpManager;
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : Group Manager deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : Group Manager deleted";
 
   delete f_olManager;
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : Folder Manager deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : Folder Manager deleted";
 
   delete f_ilManager;
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : Filter Manager deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : Filter Manager deleted";
 
   delete a_ccManager;
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : Account Manager deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : Account Manager deleted";
 
   delete c_fgManager;
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : Config deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : Config deleted";
 
   delete m_emManager;
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : Memory Manager deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : Memory Manager deleted";
 
   delete p_gp;
-  kDebug(5003) << "KNMainWidget::~KNMainWidget() : PGP deleted" << endl;
+  kDebug(5003) <<"KNMainWidget::~KNMainWidget() : PGP deleted";
 }
 
 void KNMainWidget::initStatusBar()
@@ -431,7 +429,7 @@ void KNMainWidget::openURL(const QString &url)
 
 void KNMainWidget::openURL(const KUrl &url)
 {
-  kDebug(5003) << k_funcinfo << url << endl;
+  kDebug(5003) << url;
   QString host = url.host();
   unsigned short int port = url.port();
   KNNntpAccount *acc=0;
@@ -471,7 +469,7 @@ void KNMainWidget::openURL(const KUrl &url)
       if ( acc == 0 )
         acc = a_ccManager->first();
     } else {
-      kDebug(5003) << "KNMainWidget::openURL() URL is not a valid news URL" << endl;
+      kDebug(5003) <<"KNMainWidget::openURL() URL is not a valid news URL";
     }
   }
 
@@ -481,7 +479,7 @@ void KNMainWidget::openURL(const KUrl &url)
 
     if (!isMID) {
       QString groupname=url.path( KUrl::RemoveTrailingSlash );
-      while(groupname.startsWith("/"))
+      while(groupname.startsWith('/'))
         groupname.remove(0,1);
       Q3ListViewItem *item=0;
       if(groupname.isEmpty())
@@ -520,7 +518,7 @@ void KNMainWidget::openURL(const KUrl &url)
         }
       } else {
         // TODO: fetch without group
-        kDebug(5003) << "KNMainWidget::openURL() account has no groups" << endl;
+        kDebug(5003) <<"KNMainWidget::openURL() account has no groups";
       }
     }
   }
@@ -545,13 +543,13 @@ void KNMainWidget::initActions()
   a_ctNavNextArt->setIcon(KIcon("find-next"));
   a_ctNavNextArt->setText(i18n("&Next Article"));
   a_ctNavNextArt->setToolTip(i18n("Go to next article"));
-  a_ctNavNextArt->setShortcuts(KShortcut("N;Right"));
+  a_ctNavNextArt->setShortcuts(KShortcut("N; Right"));
   connect(a_ctNavNextArt, SIGNAL(triggered(bool)), h_drView, SLOT(nextArticle()));
 
   a_ctNavPrevArt = actionCollection()->addAction("go_prevArticle" );
   a_ctNavPrevArt->setIcon(KIcon("find-previous"));
   a_ctNavPrevArt->setText(i18n("&Previous Article"));
-  a_ctNavPrevArt->setShortcuts(KShortcut("P;Left"));
+  a_ctNavPrevArt->setShortcuts(KShortcut("P; Left"));
   a_ctNavPrevArt->setToolTip(i18n("Go to previous article"));
   connect(a_ctNavPrevArt, SIGNAL(triggered(bool)), h_drView, SLOT(prevArticle()));
 
@@ -626,7 +624,7 @@ void KNMainWidget::initActions()
   connect(a_ctAccRename, SIGNAL(triggered(bool)), SLOT(slotAccRename()));
 
   a_ctAccSubscribe = actionCollection()->addAction("account_subscribe");
-  a_ctAccSubscribe->setIcon(KIcon("news_subscribe"));
+  a_ctAccSubscribe->setIcon(KIcon("news-subscribe"));
   a_ctAccSubscribe->setText(i18n("&Subscribe to Newsgroups..."));
   connect(a_ctAccSubscribe, SIGNAL(triggered(bool)), SLOT(slotAccSubscribe()));
 
@@ -635,7 +633,7 @@ void KNMainWidget::initActions()
   connect(a_ctAccExpireAll, SIGNAL(triggered(bool) ), SLOT(slotAccExpireAll()));
 
   a_ctAccGetNewHdrs = actionCollection()->addAction("account_dnlHeaders");
-  a_ctAccGetNewHdrs->setIcon(KIcon("mail_get"));
+  a_ctAccGetNewHdrs->setIcon(KIcon("mail-get"));
   a_ctAccGetNewHdrs->setText(i18n("&Get New Articles in All Groups"));
   connect(a_ctAccGetNewHdrs, SIGNAL(triggered(bool)), SLOT(slotAccGetNewHdrs()));
 
@@ -650,7 +648,7 @@ void KNMainWidget::initActions()
   connect(a_ctAccDelete, SIGNAL(triggered(bool)), SLOT(slotAccDelete()));
 
   a_ctAccPostNewArticle = actionCollection()->addAction("article_postNew");
-  a_ctAccPostNewArticle->setIcon(KIcon("mail_new"));
+  a_ctAccPostNewArticle->setIcon(KIcon("mail-new"));
   a_ctAccPostNewArticle->setText(i18n("&Post to Newsgroup..."));
   connect(a_ctAccPostNewArticle, SIGNAL(triggered(bool)), SLOT(slotAccPostNewArticle()));
   a_ctAccPostNewArticle->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_N));
@@ -667,7 +665,7 @@ void KNMainWidget::initActions()
   connect(a_ctGrpRename, SIGNAL(triggered(bool)), SLOT(slotGrpRename()));
 
   a_ctGrpGetNewHdrs = actionCollection()->addAction("group_dnlHeaders");
-  a_ctGrpGetNewHdrs->setIcon(KIcon("mail_get"));
+  a_ctGrpGetNewHdrs->setIcon(KIcon("mail-get"));
   a_ctGrpGetNewHdrs->setText(i18n("&Get New Articles"));
   connect(a_ctGrpGetNewHdrs, SIGNAL(triggered(bool)), SLOT(slotGrpGetNewHdrs()));
 
@@ -681,7 +679,7 @@ void KNMainWidget::initActions()
   connect(a_ctGrpReorganize, SIGNAL(triggered(bool) ), SLOT(slotGrpReorganize()));
 
   a_ctGrpUnsubscribe = actionCollection()->addAction("group_unsubscribe");
-  a_ctGrpUnsubscribe->setIcon(KIcon("news_unsubscribe"));
+  a_ctGrpUnsubscribe->setIcon(KIcon("news-unsubscribe"));
   a_ctGrpUnsubscribe->setText(i18n("&Unsubscribe From Group"));
   connect(a_ctGrpUnsubscribe, SIGNAL(triggered(bool)), SLOT(slotGrpUnsubscribe()));
 
@@ -763,7 +761,7 @@ void KNMainWidget::initActions()
   connect(a_ctArtSortHeadersKeyb, SIGNAL(triggered(bool)), SLOT(slotArtSortHeadersKeyb()));
   a_ctArtSortHeadersKeyb->setShortcut(QKeySequence(Qt::Key_F7));
 
-  a_ctArtFilter             = new KNFilterSelectAction(i18n("&Filter"), "filter",
+  a_ctArtFilter             = new KNFilterSelectAction(i18n("&Filter"), "search-filter",
                               actionCollection(), "view_Filter");
   a_ctArtFilter->setShortcutConfigurable(false);
 
@@ -772,7 +770,7 @@ void KNMainWidget::initActions()
   a_ctArtFilterKeyb->setShortcut(QKeySequence(Qt::Key_F6));
 
   a_ctArtSearch = actionCollection()->addAction("article_search");
-  a_ctArtSearch->setIcon(KIcon("mail_find"));
+  a_ctArtSearch->setIcon(KIcon("mail-find"));
   a_ctArtSearch->setText(i18n("&Search Articles..."));
   connect(a_ctArtSearch, SIGNAL(triggered(bool)), SLOT(slotArtSearch()));
   a_ctArtSearch->setShortcut(QKeySequence(Qt::Key_F4));
@@ -965,7 +963,7 @@ void KNMainWidget::saveOptions()
 
 bool KNMainWidget::requestShutdown()
 {
-  kDebug(5003) << "KNMainWidget::requestShutdown()" << endl;
+  kDebug(5003) <<"KNMainWidget::requestShutdown()";
 
   if( a_rtFactory->jobsPending() &&
       KMessageBox::No==KMessageBox::warningYesNo(this, i18n(
@@ -983,7 +981,7 @@ articles.\nDo you want to quit anyway?"), QString(), KStandardGuiItem::quit(), K
 
 void KNMainWidget::prepareShutdown()
 {
-  kDebug(5003) << "KNMainWidget::prepareShutdown()" << endl;
+  kDebug(5003) <<"KNMainWidget::prepareShutdown()";
 
   //cleanup article-views
   ArticleWidget::cleanup();
@@ -1116,7 +1114,7 @@ void KNMainWidget::closeCurrentThread()
 
 void KNMainWidget::slotArticleSelected(Q3ListViewItem *i)
 {
-  kDebug(5003) << "KNMainWidget::slotArticleSelected(QListViewItem *i)" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArticleSelected(QListViewItem *i)";
   if(b_lockui)
     return;
   KNArticle *selectedArticle=0;
@@ -1178,7 +1176,7 @@ void KNMainWidget::slotArticleSelectionChanged()
 
 void KNMainWidget::slotCollectionSelected(Q3ListViewItem *i)
 {
-  kDebug(5003) << "KNMainWidget::slotCollectionSelected(QListViewItem *i)" << endl;
+  kDebug(5003) <<"KNMainWidget::slotCollectionSelected(QListViewItem *i)";
   if(b_lockui)
     return;
   KNCollection *c=0;
@@ -1254,7 +1252,8 @@ void KNMainWidget::slotCollectionSelected(Q3ListViewItem *i)
     a_ctAccGetNewHdrs->setEnabled(enabled);
     a_ctAccGetNewHdrsAll->setEnabled(enabled);
     a_ctAccDelete->setEnabled(enabled);
-    a_ctAccPostNewArticle->setEnabled(enabled);
+    //Laurent fix me
+    //a_ctAccPostNewArticle->setEnabled(enabled);
   }
 
   enabled=( selectedGroup!=0 );
@@ -1297,7 +1296,7 @@ void KNMainWidget::slotCollectionSelected(Q3ListViewItem *i)
 
 void KNMainWidget::slotCollectionRenamed(Q3ListViewItem *i)
 {
-  kDebug(5003) << "KNMainWidget::slotCollectionRenamed(QListViewItem *i)" << endl;
+  kDebug(5003) <<"KNMainWidget::slotCollectionRenamed(QListViewItem *i)";
 
   if (i) {
     (static_cast<KNCollectionViewItem*>(i))->coll->setName(i->text(0));
@@ -1312,7 +1311,7 @@ void KNMainWidget::slotCollectionRenamed(Q3ListViewItem *i)
 
 void KNMainWidget::slotCollectionViewDrop(QDropEvent* e, KNCollectionViewItem* after)
 {
-  kDebug(5003) << "KNMainWidget::slotCollectionViewDrop() : type = " << e->format(0) << endl;
+  kDebug(5003) <<"KNMainWidget::slotCollectionViewDrop() : type =" << e->format(0);
 
   KNCollectionViewItem *cvi=static_cast<KNCollectionViewItem*>(after);
   if (cvi && cvi->coll->type() != KNCollection::CTfolder)   // safety measure...
@@ -1443,7 +1442,7 @@ void KNMainWidget::slotNavNextUnreadThread()
 
 void KNMainWidget::slotNavReadThrough()
 {
-  kDebug(5003) << "KNMainWidget::slotNavReadThrough()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotNavReadThrough()";
   if ( !mArticleViewer->atBottom() )
     mArticleViewer->scrollNext();
   else if(g_rpManager->currentGroup() != 0)
@@ -1453,7 +1452,7 @@ void KNMainWidget::slotNavReadThrough()
 
 void KNMainWidget::slotAccProperties()
 {
-  kDebug(5003) << "KNMainWidget::slotAccProperties()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotAccProperties()";
   if(a_ccManager->currentAccount())
     a_ccManager->editProperties(a_ccManager->currentAccount());
   updateCaption();
@@ -1463,7 +1462,7 @@ void KNMainWidget::slotAccProperties()
 
 void KNMainWidget::slotAccRename()
 {
-  kDebug(5003) << "KNMainWidget::slotAccRename()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotAccRename()";
   if(a_ccManager->currentAccount()) {
     disableAccels(true);   // hack: global accels break the inplace renaming
     c_olView->rename(a_ccManager->currentAccount()->listItem(), 0);
@@ -1473,7 +1472,7 @@ void KNMainWidget::slotAccRename()
 
 void KNMainWidget::slotAccSubscribe()
 {
-  kDebug(5003) << "KNMainWidget::slotAccSubscribe()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotAccSubscribe()";
   if(a_ccManager->currentAccount())
     g_rpManager->showGroupDialog(a_ccManager->currentAccount());
 }
@@ -1481,7 +1480,7 @@ void KNMainWidget::slotAccSubscribe()
 
 void KNMainWidget::slotAccExpireAll()
 {
-  kDebug(5003) << "KNMainWidget::slotAccExpireAll()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotAccExpireAll()";
   if(a_ccManager->currentAccount())
     g_rpManager->expireAll(a_ccManager->currentAccount());
 }
@@ -1489,7 +1488,7 @@ void KNMainWidget::slotAccExpireAll()
 
 void KNMainWidget::slotAccGetNewHdrs()
 {
-  kDebug(5003) << "KNMainWidget::slotAccGetNewHdrs()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotAccGetNewHdrs()";
   if(a_ccManager->currentAccount())
     g_rpManager->checkAll(a_ccManager->currentAccount());
 }
@@ -1498,7 +1497,7 @@ void KNMainWidget::slotAccGetNewHdrs()
 
 void KNMainWidget::slotAccDelete()
 {
-  kDebug(5003) << "KNMainWidget::slotAccDelete()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotAccDelete()";
   if(a_ccManager->currentAccount()) {
     if (a_ccManager->removeAccount(a_ccManager->currentAccount()))
       slotCollectionSelected(0);
@@ -1514,7 +1513,7 @@ void KNMainWidget::slotAccGetNewHdrsAll()
 
 void KNMainWidget::slotAccPostNewArticle()
 {
-  kDebug(5003) << "KNMainWidget::slotAccPostNewArticle()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotAccPostNewArticle()";
   if(g_rpManager->currentGroup())
     a_rtFactory->createPosting(g_rpManager->currentGroup());
   else if(a_ccManager->currentAccount())
@@ -1524,7 +1523,7 @@ void KNMainWidget::slotAccPostNewArticle()
 
 void KNMainWidget::slotGrpProperties()
 {
-  kDebug(5003) << "slotGrpProperties()" << endl;
+  kDebug(5003) <<"slotGrpProperties()";
   if(g_rpManager->currentGroup())
     g_rpManager->showGroupProperties(g_rpManager->currentGroup());
   updateCaption();
@@ -1534,7 +1533,7 @@ void KNMainWidget::slotGrpProperties()
 
 void KNMainWidget::slotGrpRename()
 {
-  kDebug(5003) << "slotGrpRename()" << endl;
+  kDebug(5003) <<"slotGrpRename()";
   if(g_rpManager->currentGroup()) {
     disableAccels(true);   // hack: global accels break the inplace renaming
     c_olView->rename(g_rpManager->currentGroup()->listItem(), 0);
@@ -1544,7 +1543,7 @@ void KNMainWidget::slotGrpRename()
 
 void KNMainWidget::slotGrpGetNewHdrs()
 {
-  kDebug(5003) << "KNMainWidget::slotGrpGetNewHdrs()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotGrpGetNewHdrs()";
   if(g_rpManager->currentGroup())
     g_rpManager->checkGroupForNewHeaders(g_rpManager->currentGroup());
 }
@@ -1552,7 +1551,7 @@ void KNMainWidget::slotGrpGetNewHdrs()
 
 void KNMainWidget::slotGrpExpire()
 {
-  kDebug(5003) << "KNMainWidget::slotGrpExpire()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotGrpExpire()";
   if(g_rpManager->currentGroup())
     g_rpManager->expireGroupNow(g_rpManager->currentGroup());
 }
@@ -1560,14 +1559,14 @@ void KNMainWidget::slotGrpExpire()
 
 void KNMainWidget::slotGrpReorganize()
 {
-  kDebug(5003) << "KNMainWidget::slotGrpReorganize()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotGrpReorganize()";
   g_rpManager->reorganizeGroup(g_rpManager->currentGroup());
 }
 
 
 void KNMainWidget::slotGrpUnsubscribe()
 {
-  kDebug(5003) << "KNMainWidget::slotGrpUnsubscribe()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotGrpUnsubscribe()";
   if(g_rpManager->currentGroup()) {
     if(KMessageBox::Yes==KMessageBox::questionYesNo(knGlobals.topWidget,
        i18n("Do you really want to unsubscribe from %1?", g_rpManager->currentGroup()->groupname()), QString(), KGuiItem(i18n("Unsubscribe")), KStandardGuiItem::cancel()))
@@ -1579,7 +1578,7 @@ void KNMainWidget::slotGrpUnsubscribe()
 
 void KNMainWidget::slotGrpSetAllRead()
 {
-  kDebug(5003) << "KNMainWidget::slotGrpSetAllRead()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotGrpSetAllRead()";
 
   a_rtManager->setAllRead(true);
   if ( knGlobals.settings()->markAllReadGoNext() )
@@ -1589,13 +1588,13 @@ void KNMainWidget::slotGrpSetAllRead()
 
 void KNMainWidget::slotGrpSetAllUnread()
 {
-  kDebug(5003) << "KNMainWidget::slotGrpSetAllUnread()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotGrpSetAllUnread()";
   a_rtManager->setAllRead(false);
 }
 
 void KNMainWidget::slotGrpSetUnread()
 {
-  kDebug(5003) << "KNMainWidget::slotGrpSetUnread()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotGrpSetUnread()";
   int groupLength = g_rpManager->currentGroup()->length();
 
   bool ok = false;
@@ -1608,7 +1607,7 @@ void KNMainWidget::slotGrpSetUnread()
 
 void KNMainWidget::slotFolNew()
 {
-  kDebug(5003) << "KNMainWidget::slotFolNew()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFolNew()";
   KNFolder *f = f_olManager->newFolder(0);
 
   if (f) {
@@ -1622,7 +1621,7 @@ void KNMainWidget::slotFolNew()
 
 void KNMainWidget::slotFolNewChild()
 {
-  kDebug(5003) << "KNMainWidget::slotFolNew()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFolNew()";
   if(f_olManager->currentFolder()) {
     KNFolder *f = f_olManager->newFolder(f_olManager->currentFolder());
 
@@ -1638,7 +1637,7 @@ void KNMainWidget::slotFolNewChild()
 
 void KNMainWidget::slotFolDelete()
 {
-  kDebug(5003) << "KNMainWidget::slotFolDelete()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFolDelete()";
 
   if(!f_olManager->currentFolder() || f_olManager->currentFolder()->isRootFolder())
     return;
@@ -1660,7 +1659,7 @@ void KNMainWidget::slotFolDelete()
 
 void KNMainWidget::slotFolRename()
 {
-  kDebug(5003) << "KNMainWidget::slotFolRename()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFolRename()";
 
   if(f_olManager->currentFolder() && !f_olManager->currentFolder()->isRootFolder()) {
     if(f_olManager->currentFolder()->isStandardFolder())
@@ -1675,7 +1674,7 @@ void KNMainWidget::slotFolRename()
 
 void KNMainWidget::slotFolCompact()
 {
-  kDebug(5003) << "KNMainWidget::slotFolCompact()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFolCompact()";
   if(f_olManager->currentFolder() && !f_olManager->currentFolder()->isRootFolder())
     f_olManager->compactFolder(f_olManager->currentFolder());
 }
@@ -1683,14 +1682,14 @@ void KNMainWidget::slotFolCompact()
 
 void KNMainWidget::slotFolCompactAll()
 {
-  kDebug(5003) << "KNMainWidget::slotFolCompactAll()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFolCompactAll()";
   f_olManager->compactAll();
 }
 
 
 void KNMainWidget::slotFolEmpty()
 {
-  kDebug(5003) << "KNMainWidget::slotFolEmpty()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFolEmpty()";
   if(f_olManager->currentFolder() && !f_olManager->currentFolder()->isRootFolder()) {
     if(f_olManager->currentFolder()->lockedArticles()>0) {
       KMessageBox::sorry(this,
@@ -1706,7 +1705,7 @@ void KNMainWidget::slotFolEmpty()
 
 void KNMainWidget::slotFolMBoxImport()
 {
-  kDebug(5003) << "KNMainWidget::slotFolMBoxImport()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFolMBoxImport()";
   if(f_olManager->currentFolder() && !f_olManager->currentFolder()->isRootFolder()) {
      f_olManager->importFromMBox(f_olManager->currentFolder());
   }
@@ -1715,7 +1714,7 @@ void KNMainWidget::slotFolMBoxImport()
 
 void KNMainWidget::slotFolMBoxExport()
 {
-  kDebug(5003) << "KNMainWidget::slotFolMBoxExport()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFolMBoxExport()";
   if(f_olManager->currentFolder() && !f_olManager->currentFolder()->isRootFolder()) {
     f_olManager->exportToMBox(f_olManager->currentFolder());
   }
@@ -1724,14 +1723,14 @@ void KNMainWidget::slotFolMBoxExport()
 
 void KNMainWidget::slotArtSortHeaders(int i)
 {
-  kDebug(5003) << "KNMainWidget::slotArtSortHeaders(int i)" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtSortHeaders(int i)";
   h_drView->setSorting( i );
 }
 
 
 void KNMainWidget::slotArtSortHeadersKeyb()
 {
-  kDebug(5003) << "KNMainWidget::slotArtSortHeadersKeyb()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtSortHeadersKeyb()";
 
   int newCol = KNHelper::selectDialog(this, i18n("Select Sort Column"), a_ctArtSortHeaders->items(), a_ctArtSortHeaders->currentItem());
   if (newCol != -1)
@@ -1741,21 +1740,21 @@ void KNMainWidget::slotArtSortHeadersKeyb()
 
 void KNMainWidget::slotArtSearch()
 {
-  kDebug(5003) << "KNMainWidget::slotArtSearch()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtSearch()";
   a_rtManager->search();
 }
 
 
 void KNMainWidget::slotArtRefreshList()
 {
-  kDebug(5003) << "KNMainWidget::slotArtRefreshList()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtRefreshList()";
   a_rtManager->showHdrs(true);
 }
 
 
 void KNMainWidget::slotArtCollapseAll()
 {
-  kDebug(5003) << "KNMainWidget::slotArtCollapseAll()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtCollapseAll()";
 
   closeCurrentThread();
   a_rtManager->setAllThreadsOpen(false);
@@ -1766,7 +1765,7 @@ void KNMainWidget::slotArtCollapseAll()
 
 void KNMainWidget::slotArtExpandAll()
 {
-  kDebug(5003) << "KNMainWidget::slotArtExpandAll()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtExpandAll()";
 
   a_rtManager->setAllThreadsOpen(true);
   if (h_drView->currentItem())
@@ -1776,7 +1775,7 @@ void KNMainWidget::slotArtExpandAll()
 
 void KNMainWidget::slotArtToggleThread()
 {
-  kDebug(5003) << "KNMainWidget::slotArtToggleThread()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtToggleThread()";
   if( mArticleViewer->article() && mArticleViewer->article()->listItem()->isExpandable() ) {
     bool o = !(mArticleViewer->article()->listItem()->isOpen());
     mArticleViewer->article()->listItem()->setOpen( o );
@@ -1786,7 +1785,7 @@ void KNMainWidget::slotArtToggleThread()
 
 void KNMainWidget::slotArtToggleShowThreads()
 {
-  kDebug(5003) << "KNMainWidget::slotArtToggleShowThreads()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtToggleShowThreads()";
   if(g_rpManager->currentGroup()) {
     knGlobals.settings()->setShowThreads( !knGlobals.settings()->showThreads() );
     a_rtManager->showHdrs(true);
@@ -1796,7 +1795,7 @@ void KNMainWidget::slotArtToggleShowThreads()
 
 void KNMainWidget::slotArtSetArtRead()
 {
-  kDebug(5003) << "KNMainWidget::slotArtSetArtRead()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtSetArtRead()";
   if(!g_rpManager->currentGroup())
     return;
 
@@ -1808,7 +1807,7 @@ void KNMainWidget::slotArtSetArtRead()
 
 void KNMainWidget::slotArtSetArtUnread()
 {
-  kDebug(5003) << "KNMainWidget::slotArtSetArtUnread()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtSetArtUnread()";
   if(!g_rpManager->currentGroup())
     return;
 
@@ -1820,7 +1819,7 @@ void KNMainWidget::slotArtSetArtUnread()
 
 void KNMainWidget::slotArtSetThreadRead()
 {
-  kDebug(5003) << "slotArtSetThreadRead()" << endl;
+  kDebug(5003) <<"slotArtSetThreadRead()";
   if( !g_rpManager->currentGroup() )
     return;
 
@@ -1839,7 +1838,7 @@ void KNMainWidget::slotArtSetThreadRead()
 
 void KNMainWidget::slotArtSetThreadUnread()
 {
-  kDebug(5003) << "KNMainWidget::slotArtSetThreadUnread()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtSetThreadUnread()";
   if( !g_rpManager->currentGroup() )
     return;
 
@@ -1851,14 +1850,14 @@ void KNMainWidget::slotArtSetThreadUnread()
 
 void KNMainWidget::slotScoreEdit()
 {
-  kDebug(5003) << "KNMainWidget::slotScoreEdit()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotScoreEdit()";
   s_coreManager->configure();
 }
 
 
 void KNMainWidget::slotReScore()
 {
-  kDebug(5003) << "KNMainWidget::slotReScore()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotReScore()";
   if( !g_rpManager->currentGroup() )
     return;
 
@@ -1869,7 +1868,7 @@ void KNMainWidget::slotReScore()
 
 void KNMainWidget::slotScoreLower()
 {
-  kDebug(5003) << "KNMainWidget::slotScoreLower() start" << endl;
+  kDebug(5003) <<"KNMainWidget::slotScoreLower() start";
   if( !g_rpManager->currentGroup() )
     return;
 
@@ -1882,7 +1881,7 @@ void KNMainWidget::slotScoreLower()
 
 void KNMainWidget::slotScoreRaise()
 {
-  kDebug(5003) << "KNMainWidget::slotScoreRaise() start" << endl;
+  kDebug(5003) <<"KNMainWidget::slotScoreRaise() start";
   if( !g_rpManager->currentGroup() )
     return;
 
@@ -1895,7 +1894,7 @@ void KNMainWidget::slotScoreRaise()
 
 void KNMainWidget::slotArtToggleIgnored()
 {
-  kDebug(5003) << "KNMainWidget::slotArtToggleIgnored()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtToggleIgnored()";
   if( !g_rpManager->currentGroup() )
     return;
 
@@ -1915,7 +1914,7 @@ void KNMainWidget::slotArtToggleIgnored()
 
 void KNMainWidget::slotArtToggleWatched()
 {
-  kDebug(5003) << "KNMainWidget::slotArtToggleWatched()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtToggleWatched()";
   if( !g_rpManager->currentGroup() )
     return;
 
@@ -1928,7 +1927,7 @@ void KNMainWidget::slotArtToggleWatched()
 
 void KNMainWidget::slotArtOpenNewWindow()
 {
-  kDebug(5003) << "KNMainWidget::slotArtOpenNewWindow()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtOpenNewWindow()";
 
   if( mArticleViewer->article() ) {
     if ( !ArticleWindow::raiseWindowForArticle( mArticleViewer->article() ) ) {
@@ -1941,14 +1940,14 @@ void KNMainWidget::slotArtOpenNewWindow()
 
 void KNMainWidget::slotArtSendOutbox()
 {
-  kDebug(5003) << "KNMainWidget::slotArtSendOutbox()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtSendOutbox()";
   a_rtFactory->sendOutbox();
 }
 
 
 void KNMainWidget::slotArtDelete()
 {
-  kDebug(5003) << "KNMainWidget::slotArtDelete()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtDelete()";
   if (!f_olManager->currentFolder())
     return;
 
@@ -1965,7 +1964,7 @@ void KNMainWidget::slotArtDelete()
 
 void KNMainWidget::slotArtSendNow()
 {
-  kDebug(5003) << "KNMainWidget::slotArtSendNow()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotArtSendNow()";
   if (!f_olManager->currentFolder())
     return;
 
@@ -1979,7 +1978,7 @@ void KNMainWidget::slotArtSendNow()
 
 void KNMainWidget::slotArtEdit()
 {
-  kDebug(5003) << "KNodeVew::slotArtEdit()" << endl;
+  kDebug(5003) <<"KNodeVew::slotArtEdit()";
   if (!f_olManager->currentFolder())
     return;
 
@@ -1990,14 +1989,14 @@ void KNMainWidget::slotArtEdit()
 
 void KNMainWidget::slotNetCancel()
 {
-  kDebug(5003) << "KNMainWidget::slotNetCancel()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotNetCancel()";
   knGlobals.scheduler()->cancelJobs();
 }
 
 
 void KNMainWidget::slotFetchArticleWithID()
 {
-  kDebug(5003) << "KNMainWidget::slotFetchArticleWithID()" << endl;
+  kDebug(5003) <<"KNMainWidget::slotFetchArticleWithID()";
   if( !g_rpManager->currentGroup() )
     return;
 
@@ -2045,8 +2044,8 @@ KActionCollection* KNMainWidget::actionCollection() const
 
 KXMLGUIFactory* KNMainWidget::factory() const
 {
-  kDebug(5003)<<"m_guiclient is "<< m_GUIClient
-           <<", the factory is " << m_GUIClient->factory() <<endl;
+  kDebug(5003)<<"m_guiclient is"<< m_GUIClient
+           <<", the factory is" << m_GUIClient->factory();
   return m_GUIClient->factory();
 }
 
