@@ -26,8 +26,6 @@
 #include <QLabel>
 #include <QLayout>
 #include <QImage>
-
-//Added by qt3to4:
 #include <QPixmap>
 #include <QGridLayout>
 #include <QEvent>
@@ -91,7 +89,7 @@ SDSummaryWidget::SDSummaryWidget( Kontact::Plugin *plugin, QWidget *parent )
   mainLayout->setMargin( 3 );
 
   QPixmap icon = KIconLoader::global()->loadIcon( "cookie",
-                    K3Icon::Desktop, K3Icon::SizeMedium );
+                    KIconLoader::Desktop, KIconLoader::SizeMedium );
 
   QWidget *header = createHeader( this, icon, i18n( "Upcoming Special Dates" ) );
   mainLayout->addWidget(header);
@@ -109,7 +107,7 @@ SDSummaryWidget::SDSummaryWidget( Kontact::Plugin *plugin, QWidget *parent )
            this, SLOT( updateView() ) );
 
   // Setup the Calendar
-  mCalendar = new KCal::CalendarResources( KPimPrefs::timeSpec() );
+  mCalendar = new KCal::CalendarResources( KPIM::KPimPrefs::timeSpec() );
   mCalendar->readConfig();
 
   KCal::CalendarResourceManager *manager = mCalendar->resourceManager();
@@ -150,25 +148,25 @@ void SDSummaryWidget::configUpdated()
 {
   KConfig config( "kcmsdsummaryrc" );
 
-  config.setGroup( "Days" );
-  mDaysAhead = config.readEntry( "DaysToShow", 7 );
+  KConfigGroup group = config.group( "Days" );
+  mDaysAhead = group.readEntry( "DaysToShow", 7 );
 
-  config.setGroup( "Show" );
+  group = config.group( "Show" );
   mShowBirthdaysFromKAB =
-    config.readEntry( "BirthdaysFromContacts", true );
+    group.readEntry( "BirthdaysFromContacts", true );
   mShowBirthdaysFromCal =
-    config.readEntry( "BirthdaysFromCalendar", true );
+    group.readEntry( "BirthdaysFromCalendar", true );
 
   mShowAnniversariesFromKAB =
-    config.readEntry( "AnniversariesFromContacts", true );
+    group.readEntry( "AnniversariesFromContacts", true );
   mShowAnniversariesFromCal =
-    config.readEntry( "AnniversariesFromCalendar", true );
+    group.readEntry( "AnniversariesFromCalendar", true );
 
   mShowHolidays =
-    config.readEntry( "HolidaysFromCalendar", true );
+    group.readEntry( "HolidaysFromCalendar", true );
 
   mShowSpecialsFromCal =
-    config.readEntry( "SpecialsFromCalendar", true );
+    group.readEntry( "SpecialsFromCalendar", true );
 
   updateView();
 }
@@ -190,7 +188,7 @@ bool SDSummaryWidget::initHolidays()
 int SDSummaryWidget::span( KCal::Event *event )
 {
   int span=1;
-  if ( event->isMultiDay() && event->floats() ) {
+  if ( event->isMultiDay() && event->allDay() ) {
     QDate d = event->dtStart().date();
     if ( d < QDate::currentDate() ) {
       d = QDate::currentDate();
@@ -224,13 +222,19 @@ int SDSummaryWidget::dayof( KCal::Event *event, const QDate& date )
 
 void SDSummaryWidget::updateView()
 {
-  qDeleteAll(mLabels);
-  mLabels.clear();
-
   KABC::StdAddressBook *ab = KABC::StdAddressBook::self( true );
   QList<SDEntry> dates;
   QLabel *label = 0;
 
+  // Remove all special date labels from the layout and delete them, as we
+  // will re-create all labels below.
+  setUpdatesEnabled( false );
+  foreach( label, mLabels ) {
+    mLayout->removeWidget( label );
+    delete( label );
+  }
+  mLabels.clear();
+
   // No reason to show the date year
   QString savefmt = KGlobal::locale()->dateFormat();
   KGlobal::locale()->setDateFormat( KGlobal::locale()->
@@ -278,7 +282,7 @@ void SDSummaryWidget::updateView()
   for ( dt=QDate::currentDate();
         dt<=QDate::currentDate().addDays( mDaysAhead - 1 );
         dt=dt.addDays(1) ) {
-    KCal::Event::List events = mCalendar->events( dt,
+    KCal::Event::List events = mCalendar->events( dt, mCalendar->timeSpec(),
                                                   KCal::EventSortStartDate,
                                                   KCal::SortDirectionAscending );
     KCal::Event *ev;
@@ -430,7 +434,7 @@ void SDSummaryWidget::updateView()
       label = new QLabel( this );
       if ( icon_img.isNull() ) {
         label->setPixmap( KIconLoader::global()->loadIcon( icon_name,
-                                                           K3Icon::Small ) );
+                                                           KIconLoader::Small ) );
       } else {
         label->setPixmap( QPixmap::fromImage(icon_img) );
       }
@@ -547,7 +551,7 @@ void SDSummaryWidget::updateView()
     label = new QLabel(
         i18np( "No special dates within the next 1 day",
               "No special dates pending within the next %1 days",
-              mDaysAhead ) );
+              mDaysAhead ), this );
     label->setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
     mLayout->addWidget( label, 0, 0, 0, 4 );
     mLabels.append( label );
@@ -557,6 +561,7 @@ void SDSummaryWidget::updateView()
   for ( lit = mLabels.begin(); lit != mLabels.end() ; ++lit )
     (*lit)->show();
 
+  setUpdatesEnabled( true );
   KGlobal::locale()->setDateFormat( savefmt );
 }
 
@@ -565,7 +570,7 @@ void SDSummaryWidget::mailContact( const QString &uid )
   KABC::StdAddressBook *ab = KABC::StdAddressBook::self( true );
   QString email = ab->findByUid( uid ).fullEmail();
 
-  KToolInvocation::invokeMailer( email, QString::null );
+  KToolInvocation::invokeMailer( email, QString() );
 }
 
 void SDSummaryWidget::viewContact( const QString &uid )
@@ -582,9 +587,9 @@ void SDSummaryWidget::viewContact( const QString &uid )
 void SDSummaryWidget::popupMenu( const QString &uid )
 {
   KMenu popup( this );
-  QAction *sendMailAction = popup.addAction( KIconLoader::global()->loadIcon( "kmail", K3Icon::Small ),
+  QAction *sendMailAction = popup.addAction( KIconLoader::global()->loadIcon( "kmail", KIconLoader::Small ),
                     i18n( "Send &Mail" ));
-  QAction * viewContactAction = popup.addAction( KIconLoader::global()->loadIcon( "kaddressbook", K3Icon::Small ),
+  QAction * viewContactAction = popup.addAction( KIconLoader::global()->loadIcon( "kaddressbook", KIconLoader::Small ),
                     i18n( "View &Contact" ) );
 
   QAction *ret = popup.exec( QCursor::pos() );
@@ -601,7 +606,7 @@ bool SDSummaryWidget::eventFilter( QObject *obj, QEvent* e )
     if ( e->type() == QEvent::Enter )
       emit message( i18n( "Mail to:\"%1\"", label->text() ) );
     if ( e->type() == QEvent::Leave )
-      emit message( QString::null );
+      emit message( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
   }
 
   return Kontact::Summary::eventFilter( obj, e );
@@ -619,8 +624,10 @@ void SDSummaryWidget::dateDiff( const QDate &date, int &days, int &years )
     else
       eventDate = QDate( date.year(), date.month(), date.day() );
   } else {
-    currentDate = QDate( 0, QDate::currentDate().month(), QDate::currentDate().day() );
-    eventDate = QDate( 0, date.month(), date.day() );
+    currentDate = QDate( QDate::currentDate().year(),
+                         QDate::currentDate().month(),
+                         QDate::currentDate().day() );
+    eventDate = QDate( QDate::currentDate().year(), date.month(), date.day() );
   }
 
   int offset = currentDate.daysTo( eventDate );
