@@ -34,7 +34,9 @@
 #include <kactioncollection.h>
 #include <kapplication.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kdebug.h>
+#include <kdbusservicestarter.h>
 #include <kedittoolbar.h>
 #include <kguiitem.h>
 #include <khelpmenu.h>
@@ -81,10 +83,71 @@
 
 using namespace Kontact;
 
+// This class extends the normal KDBusServiceStarter.
+//
+// When a service start is requested, it asks all plugins
+// to create their dbus interfaces in addition to the normal
+// way of starting a service.
+class ServiceStarter : public KDBusServiceStarter
+{
+  public:
+
+    virtual int startServiceFor( const QString& serviceType,
+                                 const QString& constraint = QString(),
+                                 QString *error = 0, QString* dbusService = 0,
+                                 int flags = 0 );
+
+    // We need to keep track of the plugins which are loaded, so pass a pointer
+    // to the plugin list here. Be sure to reset it back to 0 with 
+    // setPluginList() as soon as the list gets destroyed.
+    ServiceStarter( PluginList *pluginList ) {
+      mPlugins = pluginList;
+    }
+
+    static void setPluginList( PluginList *pluginList ) {
+      mPlugins = pluginList;
+    }
+
+  protected:
+
+    virtual ~ServiceStarter() {}
+    static PluginList *mPlugins;
+};
+PluginList* ServiceStarter::mPlugins = 0;
+
+int ServiceStarter::startServiceFor( const QString& serviceType,
+                                     const QString& constraint,
+                                     QString *error, QString* dbusService,
+                                     int flags )
+{
+  if ( mPlugins ) {
+    PluginList::ConstIterator end = mPlugins->end();
+    for ( PluginList::ConstIterator it = mPlugins->begin(); it != end; ++it ) {
+      if ( (*it)->createDBUSInterface( serviceType ) ) {
+        kDebug(5600) <<"found interface for" << serviceType;
+        if( dbusService )
+          *dbusService = (*it)->registerClient();
+          //kDebug(5600) <<"appId=" << (*it)->dcopClient()->appId();
+        return 0; // success
+      }
+    }
+  }
+
+  kDebug(5600) <<
+      "Didn't find dbus interface, falling back to external process";
+  return KDBusServiceStarter::startServiceFor( serviceType, constraint,
+                                               error, dbusService, flags );
+}
+
+
 MainWindow::MainWindow()
   : Kontact::Core(), mTopWidget( 0 ), mSplitter( 0 ),
     mCurrentPlugin( 0 ), mAboutDialog( 0 ), mReallyClose( false ), mSyncActionsEnabled( true )
 {
+  // The ServiceStarter created here will be deleted by the KDbusServiceStarter
+  // base class, which is a global static.
+  new ServiceStarter( &mPlugins );
+
   // Set this to be the group leader for all subdialogs - this means
   // modal subdialogs will only affect this dialog, not the other windows
   setAttribute( Qt::WA_GroupLeader );
@@ -149,7 +212,7 @@ void MainWindow::initObject()
   showTip( false );
 
   // done initializing
-  slotShowStatusMsg( QString::null );
+  slotShowStatusMsg( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
 
   connect( KPIM::BroadcastStatus::instance(), SIGNAL( statusMsg( const QString& ) ),
            this, SLOT( slotShowStatusMsg( const QString&  ) ) );
@@ -167,6 +230,8 @@ void MainWindow::initObject()
 
 MainWindow::~MainWindow()
 {
+  createGUI( 0 );
+  ServiceStarter::setPluginList( 0 );
   saveSettings();
 
   QList<KParts::Part*> parts = mPartManager->parts();
@@ -291,11 +356,11 @@ void MainWindow::initAboutScreen()
   mIntroPart->view()->setLineWidth( 0 );
 
   connect( mIntroPart->browserExtension(),
-           SIGNAL( openUrlRequest( const KUrl&, const KParts::URLArgs& ) ),
+           SIGNAL( openUrlRequest( const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments& ) ),
            SLOT( slotOpenUrl( const KUrl& ) ) );
 
   connect( mIntroPart->browserExtension(),
-           SIGNAL( createNewWindow( const KUrl&, const KParts::URLArgs& ) ),
+           SIGNAL( createNewWindow( const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments& ) ),
            SLOT( slotOpenUrl( const KUrl& ) ) );
 }
 
@@ -308,9 +373,9 @@ actionCollection()->addAction(KStandardAction::Quit, this, SLOT( slotQuit() ));
   mNewActions->setShortcut(KShortcut(KStandardShortcut::New));
   connect(mNewActions, SIGNAL(triggered(bool)), this, SLOT( slotNewClicked() ));
 
-  KConfig* const cfg = Prefs::self()->config();
-  cfg->setGroup( "Kontact Groupware Settings" );
-  mSyncActionsEnabled = cfg->readBoolEntry( "GroupwareMailFoldersEnabled", false );
+  KConfig* const _cfg = Prefs::self()->config();
+  KConfigGroup cfg( _cfg, "Kontact Groupware Settings" );
+  mSyncActionsEnabled = cfg.readEntry( "GroupwareMailFoldersEnabled", false );
 
   if ( mSyncActionsEnabled ) {
     mSyncActions = new KToolBarPopupAction( KIcon( "view-refresh" ), i18n( "Synchronize" ), this );
@@ -329,9 +394,6 @@ actionCollection()->addAction(KStandardAction::Quit, this, SLOT( slotQuit() ));
     action  = new KAction(i18n("&Tip of the Day"), this);
     actionCollection()->addAction("help_tipofday", action );
   connect(action, SIGNAL(triggered(bool) ), SLOT( slotShowTip() ));
-    action  = new KAction(i18n("&Request Feature..."), this);
-    actionCollection()->addAction("help_requestfeature", action );
-  connect(action, SIGNAL(triggered(bool) ), SLOT( slotRequestFeature() ));
 
   QWidgetAction* spacerAction = new QWidgetAction(this);
   QWidget* stretchWidget = new QWidget( this );
@@ -372,7 +434,7 @@ void MainWindow::loadPlugins()
       continue;
     }
 
-    kDebug(5600) << "Loading Plugin: " << it->name() << endl;
+    kDebug(5600) <<"Loading Plugin:" << it->name();
     Kontact::Plugin *plugin =
       KService::createInstance<Kontact::Plugin>(
           it->service(), this );
@@ -392,7 +454,7 @@ void MainWindow::loadPlugins()
     if ( !loadOnStart.isNull() && loadOnStart.toBool() )
       mDelayedPreload.append( plugin );
 
-    kDebug(5600) << "LIBNAMEPART: " << libNameProp.toString() << endl;
+    kDebug(5600) <<"LIBNAMEPART:" << libNameProp.toString();
 
     plugin->setPartLibraryName( libNameProp.toString().toUtf8() );
     plugin->setExecutableName( exeNameProp.toString() );
@@ -415,14 +477,14 @@ void MainWindow::loadPlugins()
     QList<KAction*>::const_iterator listIt;
 
     for ( listIt = actionList->begin(); listIt != actionList->end(); ++listIt ) {
-      kDebug(5600) << "Plugging " << (*listIt)->objectName() << endl;
+      kDebug(5600) <<"Plugging" << (*listIt)->objectName();
       mNewActions->popupMenu()->addAction( (*listIt) );
     }
 
     actionList = plugin->syncActions();
     if ( mSyncActionsEnabled ) {
       Q_FOREACH( KAction* listIt, *actionList ) {
-        kDebug(5600) << "Plugging " << listIt->objectName() << endl;
+        kDebug(5600) <<"Plugging" << listIt->objectName();
         mSyncActions->popupMenu()->addAction( listIt );
       }
     }
@@ -455,14 +517,14 @@ bool MainWindow::removePlugin( const KPluginInfo &info )
       QList<KAction*>::const_iterator listIt;
 
       for ( listIt = actionList->begin(); listIt != actionList->end(); ++listIt ) {
-        kDebug(5600) << "Unplugging " << (*listIt)->objectName() << endl;
+        kDebug(5600) <<"Unplugging" << (*listIt)->objectName();
         mNewActions->popupMenu()->removeAction( *listIt );
       }
 
       if ( mSyncActionsEnabled ) {
         actionList = plugin->syncActions();
         for ( listIt = actionList->begin(); listIt != actionList->end(); ++listIt ) {
-            kDebug(5600) << "Unplugging " << (*listIt)->objectName() << endl;
+            kDebug(5600) <<"Unplugging" << (*listIt)->objectName();
             mSyncActions->popupMenu()->removeAction( *listIt );
         }
       }
@@ -492,7 +554,7 @@ bool MainWindow::removePlugin( const KPluginInfo &info )
 
 void MainWindow::addPlugin( Kontact::Plugin *plugin )
 {
-  kDebug(5600) << "Added plugin" << endl;
+  kDebug(5600) <<"Added plugin";
 
   mPlugins.append( plugin );
 
@@ -520,8 +582,8 @@ void MainWindow::slotActivePartChanged( KParts::Part *part )
     return;
   }
 
-  kDebug(5600) << "Part activated: " << part << " with stack id. "
-      << mPartsStack->indexOf( part->widget() )<< endl;
+  kDebug(5600) <<"Part activated:" << part << "with stack id."
+      << mPartsStack->indexOf( part->widget() );
 
   //createGUI( part ); // moved to selectPlugin()
 
@@ -530,15 +592,13 @@ void MainWindow::slotActivePartChanged( KParts::Part *part )
 
 void MainWindow::slotNewClicked()
 {
-  QAction *action = mCurrentPlugin->newActions()->first();
-  if ( action ) {
-    action->trigger();
-  } else {
+  if ( !mCurrentPlugin->newActions()->isEmpty() )
+    mCurrentPlugin->newActions()->first()->trigger();
+  else {
     PluginList::Iterator it;
     for ( it = mPlugins.begin(); it != mPlugins.end(); ++it ) {
-      action = (*it)->newActions()->first();
-      if ( action ) {
-        action->trigger();
+      if ( !(*it)->newActions()->isEmpty() ) {
+        (*it)->newActions()->first()->trigger();
         return;
       }
     }
@@ -547,15 +607,13 @@ void MainWindow::slotNewClicked()
 
 void MainWindow::slotSyncClicked()
 {
-  QAction *action = mCurrentPlugin->syncActions()->first();
-  if ( action ) {
-    action->trigger();
-  } else {
+  if ( !mCurrentPlugin->syncActions()->isEmpty() )
+    mCurrentPlugin->syncActions()->first()->trigger();
+  else {
     PluginList::Iterator it;
     for ( it = mPlugins.begin(); it != mPlugins.end(); ++it ) {
-      action = (*it)->syncActions()->first();
-      if ( action ) {
-        action->trigger();
+      if ( !(*it)->syncActions()->isEmpty() ) {
+        (*it)->syncActions()->first()->trigger();
         return;
       }
     }
@@ -735,11 +793,6 @@ void MainWindow::slotShowTip()
   showTip( true );
 }
 
-void MainWindow::slotRequestFeature()
-{
-  KToolInvocation::invokeBrowser( "http://kontact.org/shopping" );
-}
-
 void MainWindow::slotShowIntroduction()
 {
   mPartsStack->setCurrentWidget( 0 ); // ###
@@ -793,28 +846,6 @@ void MainWindow::slotPreferences()
   dlg->show();
 }
 
-int MainWindow::startServiceFor( const QString& serviceType,
-                                 const QString& constraint,
-                                 QString *error, QString* dbusService,
-                                 int flags )
-{
-  PluginList::ConstIterator end = mPlugins.end();
-  for ( PluginList::ConstIterator it = mPlugins.begin(); it != end; ++it ) {
-   if ( (*it)->createDBUSInterface( serviceType ) ) {
-	    kDebug(5600) << "found interface for " << serviceType << endl;
-	    if( dbusService )
-               *dbusService = (*it)->registerClient();
-            //kDebug(5600) << "appId=" << (*it)->dcopClient()->appId() << endl;
-            return 0; // success
-    }
-  }
-
-  kDebug(5600) <<
-    "Didn't find dbus interface, falling back to external process" << endl;
-  return KDBusServiceStarter::startServiceFor( serviceType, constraint,
-      error, dbusService, flags );
-}
-
 void MainWindow::pluginsChanged()
 {
   unplugActionList( "navigator_actionlist" );
@@ -826,7 +857,7 @@ void MainWindow::pluginsChanged()
 
 void MainWindow::updateConfig()
 {
-  kDebug( 5600 ) << k_funcinfo << endl;
+  kDebug( 5600 ) ;
 
   saveSettings();
   loadSettings();
@@ -954,21 +985,21 @@ void MainWindow::slotShowStatusMsg( const QString &msg )
 QString MainWindow::introductionString()
 {
   KIconLoader *iconloader = KIconLoader::global();
-  int iconSize = iconloader->currentSize( K3Icon::Desktop );
+  int iconSize = iconloader->currentSize( KIconLoader::Desktop );
 
-  QString handbook_icon_path = iconloader->iconPath( "contents2",  K3Icon::Desktop );
-  QString html_icon_path = iconloader->iconPath( "html",  K3Icon::Desktop );
-  QString wizard_icon_path = iconloader->iconPath( "wizard",  K3Icon::Desktop );
+  QString handbook_icon_path = iconloader->iconPath( "contents2",  KIconLoader::Desktop );
+  QString html_icon_path = iconloader->iconPath( "html",  KIconLoader::Desktop );
+  QString wizard_icon_path = iconloader->iconPath( "wizard",  KIconLoader::Desktop );
 
   QString info = ki18n( "<h2 style='text-align:center; margin-top: 0px;'>Welcome to Kontact %1</h2>"
       "<p>%2</p>"
       "<table align=\"center\">"
       "<tr><td><a href=\"%3\"><img width=\"%4\" height=\"%5\" src=\"%6\" /></a></td>"
-      "<td><a href=\"%7\">%8</a><br><span id=\"subtext\"><nobr>%9</td></tr>"
+      "<td><a href=\"%7\">%8</a><br /><span id=\"subtext\"><nobr>%9</nobr></span></td></tr>"
       "<tr><td><a href=\"%10\"><img width=\"%11\" height=\"%12\" src=\"%13\" /></a></td>"
-      "<td><a href=\"%14\">%15</a><br><span id=\"subtext\"><nobr>%16</td></tr>"
+      "<td><a href=\"%14\">%15</a><br /><span id=\"subtext\"><nobr>%16</nobr></span></td></tr>"
       "<tr><td><a href=\"%17\"><img width=\"%18\" height=\"%19\" src=\"%20\" /></a></td>"
-      "<td><a href=\"%21\">%22</a><br><span id=\"subtext\"><nobr>%23</td></tr>"
+      "<td><a href=\"%21\">%22</a><br /><span id=\"subtext\"><nobr>%23</nobr></span></td></tr>"
       "</table>"
       "<p style=\"margin-bottom: 0px\"> <a href=\"%24\">Skip this introduction</a></p>" )
       .subs( KGlobal::mainComponent().aboutData()->version() )
