@@ -120,7 +120,7 @@ CalendarView::CalendarView( QWidget *parent )
     mCalendar( CalendarNull::self() ),
     mChanger( 0 )
 {
-  kDebug(5850) << "CalendarView::CalendarView( Calendar )" << endl;
+  kDebug(5850) <<"CalendarView::CalendarView( Calendar )";
 
   mViewManager = new KOViewManager( this );
   mDialogManager = new KODialogManager( this );
@@ -156,7 +156,9 @@ CalendarView::CalendarView( QWidget *parent )
   mTodoList = new KOTodoView( CalendarNull::self(), mLeftSplitter );
   mTodoList->setObjectName( "todolist" );
 
-  mEventViewer = new KOEventViewer( mLeftSplitter );
+  mEventViewerBox = new KVBox( mLeftSplitter );
+  mEventViewerBox->setMargin( KDialog::marginHint() );
+  mEventViewer = new KOEventViewer( mEventViewerBox );
   mEventViewer->setObjectName( "EventViewer" );
 
   KVBox *rightBox = new KVBox( mPanner );
@@ -184,7 +186,8 @@ CalendarView::CalendarView( QWidget *parent )
                                        QDate::currentDate() );
   mTodoList = new KOTodoView( CalendarNull::self(), leftFrame, "todolist" );
 
-  mEventViewer = new KOEventViewer ( leftFrame, "EventViewer" );
+  mEventViewerBox = new KVBox( leftFrame );
+  mEventViewer = new KOEventViewer ( mEventViewerContainer, "EventViewer" );
 
   QWidget *rightBox = new QWidget( mainBox );
   QBoxLayout *rightLayout = new QVBoxLayout( rightBox );
@@ -289,12 +292,12 @@ CalendarView::CalendarView( QWidget *parent )
   disconnect( mTodoList, SIGNAL( incidenceSelected( Incidence * ) ),
            this, SLOT( processMainViewSelection( Incidence * ) ) );
 
-  kDebug(5850) << "CalendarView::CalendarView() done" << endl;
+  kDebug(5850) <<"CalendarView::CalendarView() done";
 }
 
 CalendarView::~CalendarView()
 {
-  kDebug(5850) << "~CalendarView()" << endl;
+  kDebug(5850) <<"~CalendarView()";
 
   mCalendar->unregisterObserver( this );
   qDeleteAll( mFilters );
@@ -303,12 +306,12 @@ CalendarView::~CalendarView()
   delete mDialogManager;
   delete mViewManager;
   delete mEventViewer;
-  kDebug(5850) << "~CalendarView() done" << endl;
+  kDebug(5850) <<"~CalendarView() done";
 }
 
 void CalendarView::setCalendar( Calendar *cal )
 {
-  kDebug(5850)<<"CalendarView::setCalendar"<<endl;
+  kDebug(5850)<<"CalendarView::setCalendar";
   mCalendar = cal;
 
   delete mHistory;
@@ -341,8 +344,8 @@ void CalendarView::setIncidenceChanger( IncidenceChangerBase *changer )
   connect( mChanger, SIGNAL( incidenceDeleted( Incidence * ) ),
            this, SLOT( incidenceDeleted( Incidence * ) ) );
 
-  connect( mChanger, SIGNAL( schedule( Scheduler::Method, Incidence*) ),
-           this, SLOT( schedule( Scheduler::Method, Incidence*) ) );
+  connect( mChanger, SIGNAL( schedule( iTIPMethod, Incidence*) ),
+           this, SLOT( schedule( iTIPMethod, Incidence*) ) );
 
 
   connect( this, SIGNAL( cancelAttendees( Incidence * ) ),
@@ -390,16 +393,16 @@ void CalendarView::createPrinter()
 
 bool CalendarView::openCalendar(const QString& filename, bool merge)
 {
-  kDebug(5850) << "CalendarView::openCalendar(): " << filename << endl;
+  kDebug(5850) <<"CalendarView::openCalendar():" << filename;
 
   if (filename.isEmpty()) {
-    kDebug(5850) << "CalendarView::openCalendar(): Error! Empty filename." << endl;
+    kDebug(5850) <<"CalendarView::openCalendar(): Error! Empty filename.";
     return false;
   }
 
   if (!QFile::exists(filename)) {
-    kDebug(5850) << "CalendarView::openCalendar(): Error! File '" << filename
-              << "' doesn't exist." << endl;
+    kDebug(5850) <<"CalendarView::openCalendar(): Error! File '" << filename
+              << "' doesn't exist.";
   }
 
   bool loadedSuccesfully = true;
@@ -445,7 +448,7 @@ bool CalendarView::openCalendar(const QString& filename, bool merge)
 
 bool CalendarView::saveCalendar( const QString& filename )
 {
-  kDebug(5850) << "CalendarView::saveCalendar(): " << filename << endl;
+  kDebug(5850) <<"CalendarView::saveCalendar():" << filename;
 
   // Store back all unsaved data into calendar object
   mViewManager->currentView()->flushView();
@@ -465,7 +468,7 @@ bool CalendarView::saveCalendar( const QString& filename )
 
 void CalendarView::closeCalendar()
 {
-  kDebug(5850) << "CalendarView::closeCalendar()" << endl;
+  kDebug(5850) <<"CalendarView::closeCalendar()";
 
   // child windows no longer valid
   emit closingDown();
@@ -483,7 +486,7 @@ void CalendarView::archiveCalendar()
 
 void CalendarView::readSettings()
 {
-//  kDebug(5850) << "CalendarView::readSettings()" << endl;
+//  kDebug(5850) <<"CalendarView::readSettings()";
 
   QString str;
 
@@ -526,7 +529,7 @@ void CalendarView::readSettings()
 
 void CalendarView::writeSettings()
 {
-//  kDebug(5850) << "CalendarView::writeSettings" << endl;
+//  kDebug(5850) <<"CalendarView::writeSettings";
 
   KConfig *config = KOGlobals::self()->config();
 
@@ -555,7 +558,7 @@ void CalendarView::writeSettings()
 
 void CalendarView::readFilterSettings( KConfig *config )
 {
-//  kDebug(5850) << "CalendarView::readFilterSettings()" << endl;
+//  kDebug(5850) <<"CalendarView::readFilterSettings()";
 
   qDeleteAll( mFilters );
   mFilters.clear();
@@ -568,7 +571,7 @@ void CalendarView::readFilterSettings( KConfig *config )
   QStringList::ConstIterator it = filterList.begin();
   QStringList::ConstIterator end = filterList.end();
   while( it != end ) {
-//    kDebug(5850) << "  filter: " << (*it) << endl;
+//    kDebug(5850) <<"  filter:" << (*it);
     CalFilter *filter;
     filter = new CalFilter( *it );
     KConfigGroup filterConfig( config, "Filter_" + (*it) );
@@ -592,12 +595,12 @@ void CalendarView::readFilterSettings( KConfig *config )
 
 void CalendarView::writeFilterSettings( KConfig *config )
 {
-//  kDebug(5850) << "CalendarView::writeFilterSettings()" << endl;
+//  kDebug(5850) <<"CalendarView::writeFilterSettings()";
 
   QStringList filterList;
 
   foreach ( CalFilter *filter, mFilters ) {
-//    kDebug(5850) << " fn: " << filter->name() << endl;
+//    kDebug(5850) <<" fn:" << filter->name();
     filterList << filter->name();
     KConfigGroup filterConfig( config, "Filter_" + filter->name() );
     filterConfig.writeEntry( "Criteria", filter->criteria() );
@@ -643,7 +646,7 @@ void CalendarView::goPrevious()
 void CalendarView::updateConfig( const QByteArray& receiver)
 {
   if ( receiver != "korganizer" ) return;
-  kDebug(5850) << "CalendarView::updateConfig()" << endl;
+  kDebug(5850) <<"CalendarView::updateConfig()";
 
   KOGlobals::self()->
     setHolidays( new KHolidays( KOPrefs::instance()->mHolidays ) );
@@ -697,7 +700,7 @@ void CalendarView::incidenceChanged( Incidence *oldIncidence,
   // FIXME: Make use of the what flag, which indicates which parts of the incidence have changed!
   KOIncidenceEditor *tmp = editorDialog( newIncidence );
   if ( tmp ) {
-    kDebug(5850) << "Incidence modified and open" << endl;
+    kDebug(5850) <<"Incidence modified and open";
     tmp->modified( what );
   }
   setModified( true );
@@ -758,7 +761,7 @@ void CalendarView::incidenceToBeDeleted( Incidence *incidence )
 {
   KOIncidenceEditor *tmp = editorDialog( incidence );
   if (tmp) {
-    kDebug(5850) << "Incidence to be deleted and open in editor" << endl;
+    kDebug(5850) <<"Incidence to be deleted and open in editor";
     tmp->delayedDestruct();
   }
   setModified( true );
@@ -913,8 +916,8 @@ void CalendarView::edit_paste()
     // only use selected area if event is of the same type (all-day or non-all-day
     // as the current selection is
     if ( aView && endDT.isValid() && useEndTime ) {
-      if ( (pastedEvent->floats() && aView->selectedIsAllDay()) ||
-           (!pastedEvent->floats() && ! aView->selectedIsAllDay()) ) {
+      if ( (pastedEvent->allDay() && aView->selectedIsAllDay()) ||
+           (!pastedEvent->allDay() && ! aView->selectedIsAllDay()) ) {
         pastedEvent->setDtEnd(KDateTime( endDT, KOPrefs::instance()->timeSpec() ));
       }
     }
@@ -978,7 +981,7 @@ KOEventEditor *CalendarView::newEventEditor( const QDateTime &startDtParam,
 
 void CalendarView::newEvent()
 {
-  kDebug(5850) << "CalendarView::newEvent()" << endl;
+  kDebug(5850) <<"CalendarView::newEvent()";
   newEvent( QDateTime(), QDateTime() );
 }
 
@@ -1017,7 +1020,7 @@ void CalendarView::newTodo( const QString &summary, const QString &description,
                             const QStringList &attachments, const QStringList &attendees,
                             const QStringList &attachmentMimetypes, bool inlineAttachment )
 {
-  kDebug(5850) << k_funcinfo << endl;
+  kDebug(5850) ;
   KOTodoEditor *todoEditor = mDialogManager->getTodoEditor();
   connectIncidenceEditor( todoEditor );
   todoEditor->newTodo();
@@ -1030,7 +1033,7 @@ void CalendarView::newTodo( const QString &summary, const QString &description,
 
 void CalendarView::newTodo()
 {
-  kDebug(5850) << k_funcinfo << endl;
+  kDebug(5850) ;
   QDateTime dtDue;
   bool allday = true;
   KOTodoEditor *todoEditor = mDialogManager->getTodoEditor();
@@ -1057,7 +1060,7 @@ void CalendarView::newTodo( const QDate &date )
 
 void CalendarView::newJournal()
 {
-  kDebug(5850) << "CalendarView::newJournal()" << endl;
+  kDebug(5850) <<"CalendarView::newJournal()";
   newJournal( QString(), QDate() );
 }
 
@@ -1071,7 +1074,9 @@ void CalendarView::newJournal( const QString &text, const QDate &date )
   KOJournalEditor *journalEditor = mDialogManager->getJournalEditor();
   connectIncidenceEditor( journalEditor );
   journalEditor->newJournal();
-  journalEditor->setTexts( text );
+  if ( !text.isEmpty() ) {
+    journalEditor->setTexts( text );
+  }
   if ( !date.isValid() ) {
     journalEditor->setDate( mNavigator->selectedDates().first() );
   } else {
@@ -1106,7 +1111,7 @@ void CalendarView::newFloatingEvent()
 
 bool CalendarView::addIncidence( const QString &ical )
 {
-  kDebug(5850) << "CalendarView::addIncidence:\n" << ical << endl;
+  kDebug(5850) <<"CalendarView::addIncidence:" << ical;
   ICalFormat format;
   format.setTimeSpec( mCalendar->timeSpec() );
   Incidence *incidence = format.fromString( ical );
@@ -1222,12 +1227,12 @@ bool CalendarView::deleteIncidence( const QString &uid, bool force )
 void CalendarView::toggleAlarm( Incidence *incidence )
 {
   if ( !incidence || !mChanger ) {
-    kDebug(5850) << "CalendarView::toggleAlarm() called without having a clicked item" << endl;
+    kDebug(5850) <<"CalendarView::toggleAlarm() called without having a clicked item";
     return;
   }
   Incidence*oldincidence = incidence->clone();
   if ( !mChanger->beginChange( incidence ) ) {
-    kDebug(5850) << "Unable to lock incidence " << endl;
+    kDebug(5850) <<"Unable to lock incidence";
     delete oldincidence;
     return;
   }
@@ -1251,17 +1256,17 @@ void CalendarView::toggleAlarm( Incidence *incidence )
 void CalendarView::dissociateOccurrence( Incidence *incidence, const QDate &date )
 {
   if ( !incidence || !mChanger ) {
-    kDebug(5850) << "CalendarView::toggleAlarm() called without having a clicked item" << endl;
+    kDebug(5850) <<"CalendarView::toggleAlarm() called without having a clicked item";
     return;
   }
   if ( !mChanger->beginChange( incidence ) ) {
-    kDebug(5850) << "Unable to lock incidence " << endl;
+    kDebug(5850) <<"Unable to lock incidence";
     return;
   }
   startMultiModify( i18n("Dissociate occurrence") );
   Incidence*oldincidence = incidence->clone();
 
-  Incidence* newInc = mCalendar->dissociateOccurrence( incidence, date, true );
+  Incidence* newInc = mCalendar->dissociateOccurrence( incidence, date, KOPrefs::instance()->timeSpec(), true );
 
   if ( newInc ) {
     // TODO: Use the same resource instead of asking again!
@@ -1279,17 +1284,17 @@ void CalendarView::dissociateOccurrence( Incidence *incidence, const QDate &date
 void CalendarView::dissociateFutureOccurrence( Incidence *incidence, const QDate &date )
 {
   if ( !incidence || !mChanger ) {
-    kDebug(5850) << "CalendarView::toggleAlarm() called without having a clicked item" << endl;
+    kDebug(5850) <<"CalendarView::toggleAlarm() called without having a clicked item";
     return;
   }
   if ( !mChanger->beginChange( incidence ) ) {
-    kDebug(5850) << "Unable to lock incidence " << endl;
+    kDebug(5850) <<"Unable to lock incidence";
     return;
   }
   startMultiModify( i18n("Dissociate future occurrences") );
   Incidence*oldincidence = incidence->clone();
 
-  Incidence* newInc = mCalendar->dissociateOccurrence( incidence, date, true );
+  Incidence* newInc = mCalendar->dissociateOccurrence( incidence, date, KOPrefs::instance()->timeSpec(), true );
   if ( newInc ) {
     // TODO: Use the same resource instead of asking again!
     mChanger->changeIncidence( oldincidence, incidence );
@@ -1345,37 +1350,37 @@ void CalendarView::schedule_publish(Incidence *incidence)
 
 void CalendarView::schedule_request(Incidence *incidence)
 {
-  schedule(Scheduler::Request,incidence);
+  schedule(iTIPRequest,incidence);
 }
 
 void CalendarView::schedule_refresh(Incidence *incidence)
 {
-  schedule(Scheduler::Refresh,incidence);
+  schedule(iTIPRefresh,incidence);
 }
 
 void CalendarView::schedule_cancel(Incidence *incidence)
 {
-  schedule(Scheduler::Cancel,incidence);
+  schedule(iTIPCancel,incidence);
 }
 
 void CalendarView::schedule_add(Incidence *incidence)
 {
-  schedule(Scheduler::Add,incidence);
+  schedule(iTIPAdd,incidence);
 }
 
 void CalendarView::schedule_reply(Incidence *incidence)
 {
-  schedule(Scheduler::Reply,incidence);
+  schedule(iTIPReply,incidence);
 }
 
 void CalendarView::schedule_counter(Incidence *incidence)
 {
-  schedule(Scheduler::Counter,incidence);
+  schedule(iTIPCounter,incidence);
 }
 
 void CalendarView::schedule_declinecounter(Incidence *incidence)
 {
-  schedule(Scheduler::Declinecounter,incidence);
+  schedule(iTIPDeclineCounter,incidence);
 }
 
 void CalendarView::schedule_forward(Incidence * incidence)
@@ -1393,7 +1398,7 @@ void CalendarView::schedule_forward(Incidence * incidence)
   if ( publishdlg.exec() == QDialog::Accepted ) {
     QString recipients = publishdlg.addresses();
     ICalFormat format;
-    QString messageText = format.createScheduleMessage( incidence, Scheduler::Request );
+    QString messageText = format.createScheduleMessage( incidence, iTIPRequest );
     KOMailClient mailer;
     if ( mailer.mailTo( incidence, recipients, messageText ) ) {
 
@@ -1414,9 +1419,9 @@ void CalendarView::mailFreeBusy( int daysToPublish )
   freebusy->setOrganizer( Person( KOPrefs::instance()->fullName(),
                       KOPrefs::instance()->email() ) );
 
-  kDebug(5850) << "calendarview: schedule_publish_freebusy: startDate: "
-     << KGlobal::locale()->formatDateTime( start ) << " End Date: "
-     << KGlobal::locale()->formatDateTime( end ) << endl;
+  kDebug(5850) <<"calendarview: schedule_publish_freebusy: startDate:"
+     << KGlobal::locale()->formatDateTime( start ) << "End Date:"
+     << KGlobal::locale()->formatDateTime( end );
 
   PublishDialog *publishdlg = new PublishDialog();
   if ( publishdlg->exec() == QDialog::Accepted ) {
@@ -1438,7 +1443,7 @@ void CalendarView::uploadFreeBusy()
   KOGroupware::instance()->freeBusyManager()->publishFreeBusy();
 }
 
-void CalendarView::schedule(Scheduler::Method method, Incidence *incidence)
+void CalendarView::schedule(iTIPMethod method, Incidence *incidence)
 {
   if ( !incidence ) {
     incidence = selectedIncidence();
@@ -1450,7 +1455,7 @@ void CalendarView::schedule(Scheduler::Method method, Incidence *incidence)
     return;
   }
 
-  if( incidence->attendeeCount() == 0 && method != Scheduler::Publish ) {
+  if( incidence->attendeeCount() == 0 && method != iTIPPublish ) {
     KMessageBox::information( this, i18n("The item has no attendees."),
                               "ScheduleNoIncidences" );
     return;
@@ -1641,10 +1646,10 @@ void CalendarView::checkClipboard()
 {
 #ifndef KORG_NODND
   if (ICalDrag::canDecode(QApplication::clipboard()->mimeData())) {
-    kDebug(5850) << "CalendarView::checkClipboard() true" << endl;
+    kDebug(5850) <<"CalendarView::checkClipboard() true";
     emit pasteEnabled(true);
   } else {
-    kDebug(5850) << "CalendarView::checkClipboard() false" << endl;
+    kDebug(5850) <<"CalendarView::checkClipboard() false";
     emit pasteEnabled(false);
   }
 #endif
@@ -1652,7 +1657,7 @@ void CalendarView::checkClipboard()
 
 void CalendarView::showDates(const DateList &selectedDates)
 {
-//  kDebug(5850) << "CalendarView::selectDates()" << endl;
+//  kDebug(5850) <<"CalendarView::selectDates()";
 
   if ( mViewManager->currentView() ) {
     updateView( selectedDates.first(), selectedDates.last() );
@@ -1663,10 +1668,10 @@ void CalendarView::showDates(const DateList &selectedDates)
 
 void CalendarView::editFilters()
 {
-  kDebug(5850) << "CalendarView::editFilters()" << endl;
+  kDebug(5850) <<"CalendarView::editFilters()";
 
   foreach ( CalFilter *filter, mFilters ) {
-    if ( filter ) kDebug(5850) << " Filter: " << filter->name() << endl;
+    if ( filter ) kDebug(5850) <<" Filter:" << filter->name();
   }
 
   mDialogManager->showFilterEditDialog(&mFilters);
@@ -1750,7 +1755,7 @@ void CalendarView::takeOverCalendar()
 
 void CalendarView::showIntro()
 {
-  kDebug(5850) << "To be implemented." << endl;
+  kDebug(5850) <<"To be implemented.";
 }
 
 void CalendarView::showDateNavigator( bool show )
@@ -1772,9 +1777,9 @@ void CalendarView::showTodoView( bool show )
 void CalendarView::showEventViewer( bool show )
 {
   if( show )
-    mEventViewer->show();
+    mEventViewerBox->show();
   else
-    mEventViewer->hide();
+    mEventViewerBox->hide();
 }
 
 
@@ -1868,7 +1873,7 @@ void CalendarView::editIncidence()
 
 bool CalendarView::editIncidence( const QString& uid )
 {
-  kDebug(5850) << "CalendarView::editIncidence()" << endl;
+  kDebug(5850) <<"CalendarView::editIncidence()";
   return editIncidence( mCalendar->incidence( uid ) );
 }
 
@@ -1918,7 +1923,7 @@ void CalendarView::showIncidenceContext( Incidence *incidence )
     if ( !viewManager()->currentView()->inherits( "KOEventView" ) )
       viewManager()->showAgendaView();
     // just select the appropriate date
-    mNavigator->selectWeek( incidence->dtStart().date() );
+    mNavigator->selectWeek( incidence->dtStart().toTimeSpec( KOPrefs::instance()->timeSpec() ).date() );
     return;
   } else if ( dynamic_cast<KCal::Journal *>( incidence ) ) {
     if ( !viewManager()->currentView()->inherits( "KOJournalView" ) )
@@ -1934,7 +1939,7 @@ void CalendarView::showIncidenceContext( Incidence *incidence )
 
 bool CalendarView::editIncidence( Incidence *incidence )
 {
-  kDebug(5850) << "CalendarView::editEvent()" << endl;
+  kDebug(5850) <<"CalendarView::editEvent()";
 
   if ( !incidence || !mChanger ) {
     KNotification::beep();
@@ -1942,7 +1947,7 @@ bool CalendarView::editIncidence( Incidence *incidence )
   }
   KOIncidenceEditor *tmp = editorDialog( incidence );
   if ( tmp ) {
-    kDebug(5850) << "CalendarView::editIncidence() in List" << endl;
+    kDebug(5850) <<"CalendarView::editIncidence() in List";
     tmp->reload();
     tmp->raise();
     tmp->show();
@@ -1960,7 +1965,7 @@ bool CalendarView::editIncidence( Incidence *incidence )
     return false;
   }
 
-  kDebug(5850) << "CalendarView::editIncidence() new IncidenceEditor" << endl;
+  kDebug(5850) <<"CalendarView::editIncidence() new IncidenceEditor";
   KOIncidenceEditor *incidenceEditor = mDialogManager->getEditor( incidence );
   connectIncidenceEditor( incidenceEditor );
 
@@ -2066,11 +2071,11 @@ void CalendarView::deleteIncidence(Incidence *incidence, bool force)
 
   if ( incidence->recurs() ) {
     QDate itemDate = mViewManager->currentSelectionDate();
-    kDebug(5850) << "Recurrence-Date: " << itemDate.toString() << endl;
+    kDebug(5850) <<"Recurrence-Date:" << itemDate.toString();
     int km = KMessageBox::Ok;
     if ( !force ) {
       if ( !itemDate.isValid() ) {
-        kDebug(5850) << "Date Not Valid" << endl;
+        kDebug(5850) <<"Date Not Valid";
         km = KMessageBox::warningContinueCancel(
           this,
           i18n("The calendar item \"%1\" recurs over multiple dates; "
@@ -2203,7 +2208,7 @@ void CalendarView::purgeCompleted()
 
 void CalendarView::slotCalendarChanged()
 {
-  kDebug(5850) << "CalendarView::slotCalendarChanged()" << endl;
+  kDebug(5850) <<"CalendarView::slotCalendarChanged()";
 
   updateView();
 }
