@@ -42,6 +42,8 @@
 class QStackedWidget;
 class QSplitter;
 
+class KVBox;
+
 class CalPrinter;
 class KOViewManager;
 class KODialogManager;
@@ -53,8 +55,13 @@ class KOIncidenceEditor;
 class NavigatorBar;
 class DateChecker;
 
-namespace KOrg { class History; class IncidenceChangerBase; }
-class HTMLExportSettings;
+namespace KOrg {
+  class History;
+  class IncidenceChangerBase;
+}
+namespace KCal {
+  class HTMLExportSettings;
+}
 
 using namespace KOrg;
 using namespace KCal;
@@ -537,7 +544,7 @@ class KORGANIZER_EXPORT CalendarView : public KOrg::CalendarViewBase, public Cal
     void slotAutoArchivingSettingsModified() { emit autoArchivingSettingsModified(); }
 
     void showErrorMessage( const QString & );
-    void schedule( Scheduler::Method, Incidence *incidence );
+    void schedule( iTIPMethod, Incidence *incidence );
     void addIncidenceOn( Incidence *, const QDate & );
     void moveIncidenceTo( Incidence *, const QDate & );
     void filterActivated( int filterNum );
@@ -606,6 +613,7 @@ class KORGANIZER_EXPORT CalendarView : public KOrg::CalendarViewBase, public Cal
     DateNavigator *mNavigator;
     DateChecker *mDateChecker;
 
+    KVBox *mEventViewerBox;
     KOEventViewer *mEventViewer;
     KOViewManager *mViewManager;
     KODialogManager *mDialogManager;
