@@ -82,7 +82,7 @@ MarcusBains::MarcusBains( KOAgenda *agenda )
   connect( mTimer, SIGNAL(timeout()), this, SLOT(updateLocation()) );
   mTimer->start( 0 );
 
-  mOldToday = -1;
+  mOldTodayCol = -1;
 }
 
 MarcusBains::~MarcusBains()
@@ -109,25 +109,25 @@ int MarcusBains::todayColumn()
 void MarcusBains::updateLocation( bool recalculate )
 {
   bool showSeconds = KOPrefs::instance()->marcusBainsShowSeconds();
-  QColor color = KOPrefs::instance()->agendaMarcusBainsLineColor();
+  QColor color = KOPrefs::instance()->agendaMarcusBainsLineLineColor();
 
   QTime tim = QTime::currentTime();
   if ( (tim.hour() == 0) && (mOldTime.hour()==23) )
     // We are on a new day
     recalculate = true;
-  int today = recalculate ? todayColumn() : mOldToday;
+  int todayCol = recalculate ? todayColumn() : mOldTodayCol;
 
   // Number of minutes since beginning of the day
   int minutes = tim.hour()*60 + tim.minute();
   int minutesPerCell = 24 * 60 / mAgenda->rows();
 
   mOldTime = tim;
-  mOldToday = today;
+  mOldTodayCol = todayCol;
 
   int y = int( minutes  *  mAgenda->gridSpacingY() / minutesPerCell );
-  int x = int( mAgenda->gridSpacingX() * today );
+  int x = int( mAgenda->gridSpacingX() * todayCol );
 
-  if ( !( KOPrefs::instance()->marcusBainsEnabled() ) || (today<0) ) {
+  if ( !( KOPrefs::instance()->marcusBainsEnabled() ) || (todayCol<0) ) {
     hide();
     mTimeBox->hide();
     return;
@@ -321,7 +321,7 @@ void KOAgenda::init()
 
 void KOAgenda::clear()
 {
-//  kDebug(5850) << "KOAgenda::clear()" << endl;
+//  kDebug(5850) <<"KOAgenda::clear()";
 
   foreach( KOAgendaItem *item, mItems ) { removeChild(item); }
   qDeleteAll( mItems );
@@ -351,7 +351,7 @@ void KOAgenda::marcus_bains()
 void KOAgenda::changeColumns(int columns)
 {
   if (columns == 0) {
-    kDebug(5850) << "KOAgenda::changeColumns() called with argument 0" << endl;
+    kDebug(5850) <<"KOAgenda::changeColumns() called with argument 0";
     return;
   }
 
@@ -372,7 +372,7 @@ void KOAgenda::changeColumns(int columns)
 */
 bool KOAgenda::eventFilter ( QObject *object, QEvent *event )
 {
-//  kDebug(5850) << "KOAgenda::eventFilter() " << int( event->type() ) << endl;
+//  kDebug(5850) <<"KOAgenda::eventFilter()" << int( event->type() );
 
   switch( event->type() ) {
     case QEvent::MouseButtonPress:
@@ -482,7 +482,7 @@ bool KOAgenda::eventFilter_drag( QObject *object, QDropEvent *de )
 
 bool KOAgenda::eventFilter_key( QObject *, QKeyEvent *ke )
 {
-  // kDebug(5850) << "KOAgenda::eventFilter_key() " << ke->type() << endl;
+  // kDebug(5850) <<"KOAgenda::eventFilter_key()" << ke->type();
 
   // If Return is pressed bring up an editor for the current selected time span.
   if ( ke->key() == Qt::Key_Return ) {
@@ -544,10 +544,10 @@ void KOAgenda::emitNewEventForSelection()
 
 void KOAgenda::finishTypeAhead()
 {
-//  kDebug(5850) << "KOAgenda::finishTypeAhead()" << endl;
+//  kDebug(5850) <<"KOAgenda::finishTypeAhead()";
   if ( typeAheadReceiver() ) {
     foreach( QEvent *e, mTypeAheadEvents ) {
-//      kDebug(5850) << "sendEvent() " << int( typeAheadReceiver() ) << endl;
+//      kDebug(5850) <<"sendEvent()" << int( typeAheadReceiver() );
       QApplication::sendEvent( typeAheadReceiver(), e );
     }
   }
@@ -566,8 +566,8 @@ bool KOAgenda::eventFilter_wheel ( QObject *object, QWheelEvent *e )
     } else {
       viewportPos = e->pos();
     }
-    //kDebug(5850)<< "KOAgenda::eventFilter_wheel: type:"<<
-    //  e->type()<<" delta: "<< e->delta()<< endl;
+    //kDebug(5850)<<"KOAgenda::eventFilter_wheel: type:"<<
+    //  e->type()<<"delta:"<< e->delta();
     emit zoomView( -e->delta() ,
       contentsToGrid( viewportToContents( viewportPos ) ),
       Qt::Horizontal );
@@ -601,7 +601,7 @@ bool KOAgenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
 
   switch (me->type())  {
     case QEvent::MouseButtonPress:
-//        kDebug(5850) << "koagenda: filtered button press" << endl;
+//        kDebug(5850) <<"koagenda: filtered button press";
       if (object != viewport()) {
         if (me->button() == Qt::RightButton) {
           mClickedItem = dynamic_cast<KOAgendaItem *>(object);
@@ -825,8 +825,8 @@ KOAgenda::MouseActionType KOAgenda::isInResizeArea( bool horizontal,
   QPoint contpos = gridToContents( gridpos +
       QPoint( (KOGlobals::self()->reverseLayout())?1:0, 0 ) );
 
-//kDebug(5850)<<"contpos="<<contpos<<", pos="<<pos<<", gpos="<<gpos<<endl;
-//kDebug(5850)<<"clXLeft="<<clXLeft<<", clXRight="<<clXRight<<endl;
+//kDebug(5850)<<"contpos="<<contpos<<", pos="<<pos<<", gpos="<<gpos;
+//kDebug(5850)<<"clXLeft="<<clXLeft<<", clXRight="<<clXRight;
 
   if ( horizontal ) {
     int clXLeft = item->cellXLeft();
@@ -883,14 +883,14 @@ void KOAgenda::startItemAction(const QPoint& viewportPos)
 
 void KOAgenda::performItemAction(const QPoint& viewportPos)
 {
-//  kDebug(5850) << "viewportPos: " << viewportPos.x() << "," << viewportPos.y() << endl;
+//  kDebug(5850) <<"viewportPos:" << viewportPos.x() <<"," << viewportPos.y();
 //  QPoint point = viewport()->mapToGlobal(viewportPos);
-//  kDebug(5850) << "Global: " << point.x() << "," << point.y() << endl;
+//  kDebug(5850) <<"Global:" << point.x() <<"," << point.y();
 //  point = clipper()->mapFromGlobal(point);
-//  kDebug(5850) << "clipper: " << point.x() << "," << point.y() << endl;
-//  kDebug(5850) << "visible height: " << visibleHeight() << endl;
+//  kDebug(5850) <<"clipper:" << point.x() <<"," << point.y();
+//  kDebug(5850) <<"visible height:" << visibleHeight();
   QPoint pos = viewportToContents( viewportPos );
-//  kDebug(5850) << "contents: " << x << "," << y << "\n" << endl;
+//  kDebug(5850) <<"contents:" << x <<"," << y;
   QPoint gpos = contentsToGrid( pos );
   QPoint clipperPos = clipper()->
                       mapFromGlobal(viewport()->mapToGlobal(viewportPos));
@@ -1068,7 +1068,7 @@ void KOAgenda::performItemAction(const QPoint& viewportPos)
 
 void KOAgenda::endItemAction()
 {
-//  kDebug(5850) << "KOAgenda::endItemAction() " << endl;
+//  kDebug(5850) <<"KOAgenda::endItemAction()";
   mActionType = NOP;
   mScrollUpTimer.stop();
   mScrollDownTimer.stop();
@@ -1104,12 +1104,13 @@ void KOAgenda::endItemAction()
             Incidence* oldInc = mActionItem->incidence();
             Incidence* oldIncSaved = mActionItem->incidence()->clone();
             Incidence* newInc = mCalendar->dissociateOccurrence(
-                oldInc, mActionItem->itemDate() );
+                oldInc, mActionItem->itemDate(), KOPrefs::instance()->timeSpec() );
             if ( newInc ) {
               // don't recreate items, they already have the correct position
               emit enableAgendaUpdate( false );
               mChanger->changeIncidence( oldIncSaved, oldInc );
               mActionItem->setIncidence( newInc );
+
               mActionItem->dissociateFromMultiItem();
               mChanger->addIncidence( newInc, this );
               emit enableAgendaUpdate( true );
@@ -1132,7 +1133,7 @@ void KOAgenda::endItemAction()
             Incidence* oldInc = mActionItem->incidence();
             Incidence* oldIncSaved = mActionItem->incidence()->clone();
             Incidence* newInc = mCalendar->dissociateOccurrence(
-                oldInc, mActionItem->itemDate(), false );
+                oldInc, mActionItem->itemDate(), KOPrefs::instance()->timeSpec(), false );
             if ( newInc ) {
               emit enableAgendaUpdate( false );
               mActionItem->dissociateFromMultiItem();
@@ -1185,7 +1186,7 @@ void KOAgenda::endItemAction()
 
   if ( multiModify ) emit endMultiModify();
 
-  kDebug(5850) << "KOAgenda::endItemAction() done" << endl;
+  kDebug(5850) <<"KOAgenda::endItemAction() done";
 }
 
 void KOAgenda::setActionCursor( int actionType, bool acting )
@@ -1210,11 +1211,11 @@ void KOAgenda::setActionCursor( int actionType, bool acting )
 
 void KOAgenda::setNoActionCursor( KOAgendaItem *moveItem, const QPoint& viewportPos )
 {
-//  kDebug(5850) << "viewportPos: " << viewportPos.x() << "," << viewportPos.y() << endl;
+//  kDebug(5850) <<"viewportPos:" << viewportPos.x() <<"," << viewportPos.y();
 //  QPoint point = viewport()->mapToGlobal(viewportPos);
-//  kDebug(5850) << "Global: " << point.x() << "," << point.y() << endl;
+//  kDebug(5850) <<"Global:" << point.x() <<"," << point.y();
 //  point = clipper()->mapFromGlobal(point);
-//  kDebug(5850) << "clipper: " << point.x() << "," << point.y() << endl;
+//  kDebug(5850) <<"clipper:" << point.x() <<"," << point.y();
 
   QPoint pos = viewportToContents( viewportPos );
   bool noResize = (moveItem && moveItem->incidence() &&
@@ -1259,8 +1260,8 @@ void KOAgenda::adjustItemPosition( KOAgendaItem *item )
 
 void KOAgenda::placeAgendaItem( KOAgendaItem *item, double subCellWidth )
 {
-//  kDebug(5850) << "KOAgenda::placeAgendaItem(): " << item->incidence()->summary()
-//            << " subCellWidth: " << subCellWidth << endl;
+//  kDebug(5850) <<"KOAgenda::placeAgendaItem():" << item->incidence()->summary()
+//            << "subCellWidth:" << subCellWidth;
 
   // "left" upper corner, no subcells yet, RTL layouts have right/left switched, widths are negative then
   QPoint pt = gridToContents( QPoint( item->cellXLeft(), item->cellYTop() ) );
@@ -1311,18 +1312,18 @@ void KOAgenda::placeAgendaItem( KOAgendaItem *item, double subCellWidth )
 void KOAgenda::placeSubCells( KOAgendaItem *placeItem )
 {
 #if 0
-  kDebug(5850) << "KOAgenda::placeSubCells()" << endl;
+  kDebug(5850) <<"KOAgenda::placeSubCells()";
   if ( placeItem ) {
     Incidence *event = placeItem->incidence();
     if ( !event ) {
-      kDebug(5850) << "  event is 0" << endl;
+      kDebug(5850) <<"  event is 0";
     } else {
-      kDebug(5850) << "  event: " << event->summary() << endl;
+      kDebug(5850) <<"  event:" << event->summary();
     }
   } else {
-    kDebug(5850) << "  placeItem is 0" << endl;
+    kDebug(5850) <<"  placeItem is 0";
   }
-  kDebug(5850) << "KOAgenda::placeSubCells()..." << endl;
+  kDebug(5850) <<"KOAgenda::placeSubCells()...";
 #endif
 
   QList<KOrg::CellItem*> cells;
@@ -1358,18 +1359,25 @@ int KOAgenda::columnWidth( int column ) const
 /*
   Draw grid in the background of the agenda.
 */
-void KOAgenda::drawContents(QPainter* p, int cx, int cy, int cw, int ch)
+void KOAgenda::drawContents( QPainter* p, int cx, int cy, int cw, int ch )
 {
-  QPixmap db(cw, ch);
-  db.fill(KOPrefs::instance()->agendaGridBackgroundColor());
-  QPainter dbp(&db);
-  dbp.translate(-cx,-cy);
+  QPixmap db( cw, ch );
+  db.fill(); // We don't want to see leftovers from previous paints
+  QPainter dbp( &db );
+  // TODO: CHECK THIS
+//  if ( ! KOPrefs::instance()->agendaGridBackgroundImage().isEmpty() ) {
+//    QPixmap bgImage( KOPrefs::instance()->agendaGridBackgroundImage() );
+//    dbp.drawPixmap( 0, 0, cw, ch, bgImage ); FIXME
+//  }
+  dbp.fillRect( cx, cy, cw, ch,
+                KOPrefs::instance()->agendaGridBackgroundColor() );
+  dbp.translate( -cx, -cy );
 
-//  kDebug(5850) << "KOAgenda::drawContents()" << endl;
+//  kDebug(5850) <<"KOAgenda::drawContents()";
   double lGridSpacingY = mGridSpacingY*2;
 
   // Highlight working hours
-  if (mWorkingHoursEnable) {
+  if ( mWorkingHoursEnable ) {
     QPoint pt1( cx, mWorkingHoursYTop );
     QPoint pt2( cx+cw, mWorkingHoursYBottom );
     if ( pt2.x() >= pt1.x() /*&& pt2.y() >= pt1.y()*/) {
@@ -1443,7 +1451,7 @@ void KOAgenda::drawContents(QPainter* p, int cx, int cy, int cw, int ch)
   dbp.setPen( hourPen );
 
   // Draw vertical lines of grid, start with the last line not yet visible
-  //  kDebug(5850) << "drawContents cx: " << cx << " cy: " << cy << " cw: " << cw << " ch: " << ch << endl;
+  //  kDebug(5850) <<"drawContents cx:" << cx <<" cy:" << cy <<" cw:" << cw <<" ch:" << ch;
   double x = ( int( cx / mGridSpacingX ) ) * mGridSpacingX;
   while (x < cx + cw) {
     dbp.drawLine( int( x ), cy, int( x ), cy + ch );
@@ -1453,14 +1461,14 @@ void KOAgenda::drawContents(QPainter* p, int cx, int cy, int cw, int ch)
   // Draw horizontal lines of grid
   double y = ( int( cy / (2*lGridSpacingY) ) ) * 2 * lGridSpacingY;
   while (y < cy + ch) {
-//    kDebug(5850) << " y: " << y << endl;
+//    kDebug(5850) <<" y:" << y;
     dbp.drawLine( cx, int( y ), cx + cw, int( y ) );
     y += 2 * lGridSpacingY;
   }
   y = ( 2 * int( cy / (2*lGridSpacingY) ) + 1) * lGridSpacingY;
   dbp.setPen( halfHourPen );
   while (y < cy + ch) {
-//    kDebug(5850) << " y: " << y << endl;
+//    kDebug(5850) <<" y:" << y;
     dbp.drawLine( cx, int( y ), cx + cw, int( y ) );
     y+=2*lGridSpacingY;
   }
@@ -1496,14 +1504,13 @@ QPoint KOAgenda::gridToContents( const QPoint &gpos ) const
 */
 int KOAgenda::timeToY( const QTime &time ) const
 {
-//  kDebug(5850) << "Time: " << time.toString() << endl;
+//  kDebug(5850) <<"Time:" << time.toString();
   int minutesPerCell = 24 * 60 / mRows;
-//  kDebug(5850) << "minutesPerCell: " << minutesPerCell << endl;
+//  kDebug(5850) <<"minutesPerCell:" << minutesPerCell;
   int timeMinutes = time.hour() * 60 + time.minute();
-//  kDebug(5850) << "timeMinutes: " << timeMinutes << endl;
+//  kDebug(5850) <<"timeMinutes:" << timeMinutes;
   int Y = (timeMinutes + (minutesPerCell / 2)) / minutesPerCell;
-//  kDebug(5850) << "y: " << Y << endl;
-//  kDebug(5850) << "\n" << endl;
+//  kDebug(5850) <<"y:" << Y;
   return Y;
 }
 
@@ -1514,7 +1521,7 @@ int KOAgenda::timeToY( const QTime &time ) const
 */
 QTime KOAgenda::gyToTime( int gy ) const
 {
-//  kDebug(5850) << "gyToTime: " << gy << endl;
+//  kDebug(5850) <<"gyToTime:" << gy;
   int secondsPerCell = 24 * 60 * 60/ mRows;
 
   int timeSeconds = secondsPerCell * gy;
@@ -1525,7 +1532,7 @@ QTime KOAgenda::gyToTime( int gy ) const
   } else {
     time.setHMS( 23, 59, 59 );
   }
-//  kDebug(5850) << "  gyToTime: " << time.toString() << endl;
+//  kDebug(5850) <<"  gyToTime:" << time.toString();
 
   return time;
 }
@@ -1577,13 +1584,12 @@ KOAgendaItem *KOAgenda::insertItem( Incidence *incidence, const QDate &qd, int X
                                     int YTop, int YBottom )
 {
 #if 0
-  kDebug(5850) << "KOAgenda::insertItem:" << event->summary() << "-"
-                << qd.toString() << " ;top, bottom:" << YTop << "," << YBottom
-                << endl;
+  kDebug(5850) <<"KOAgenda::insertItem:" << event->summary() <<"-"
+                << qd.toString() << ";top, bottom:" << YTop << "," << YBottom;
 #endif
 
   if ( mAllDayMode ) {
-    kDebug(5850) << "KOAgenda: calling insertItem in all-day mode is illegal." << endl;
+    kDebug(5850) <<"KOAgenda: calling insertItem in all-day mode is illegal.";
     return 0;
   }
 
@@ -1597,7 +1603,7 @@ KOAgendaItem *KOAgenda::insertItem( Incidence *incidence, const QDate &qd, int X
            SLOT( showAgendaItem( KOAgendaItem * ) ) );
 
   if ( YBottom <= YTop ) {
-    kDebug(5850) << "KOAgenda::insertItem(): Text: " << agendaItem->text() << " YSize<0" << endl;
+    kDebug(5850) <<"KOAgenda::insertItem(): Text:" << agendaItem->text() <<" YSize<0";
     YBottom = YTop;
   }
 
@@ -1629,7 +1635,7 @@ KOAgendaItem *KOAgenda::insertAllDayItem( Incidence *event, const QDate &qd,
                                           int XBegin, int XEnd )
 {
   if ( !mAllDayMode ) {
-    kDebug(5850) << "KOAgenda: calling insertAllDayItem in non all-day mode is illegal." << endl;
+    kDebug(5850) <<"KOAgenda: calling insertAllDayItem in non all-day mode is illegal.";
     return 0;
   }
 
@@ -1667,7 +1673,7 @@ void KOAgenda::insertMultiItem (Event *event,const QDate &qd,int XBegin,int XEnd
                                 int YTop,int YBottom)
 {
   if (mAllDayMode) {
-    kDebug(5850) << "KOAgenda: calling insertMultiItem in all-day mode is illegal." << endl;
+    kDebug(5850) <<"KOAgenda: calling insertMultiItem in all-day mode is illegal.";
     return;
   }
   mActionType = NOP;
@@ -1698,18 +1704,21 @@ void KOAgenda::insertMultiItem (Event *event,const QDate &qd,int XBegin,int XEnd
 
   QList<KOAgendaItem*>::iterator it = multiItems.begin();
   QList<KOAgendaItem*>::iterator e = multiItems.end();
-  KOAgendaItem *first = multiItems.first();
-  KOAgendaItem *last = multiItems.last();
-  KOAgendaItem *prev = 0, *next = 0;
 
-  while ( it != e ) {
-    KOAgendaItem *item = *it;
-    ++it;
-    next = (it == e ) ? 0 : (*it);
-    if ( item )
-      item->setMultiItem( (item == first) ? 0 : first, prev, next,
-        ( item == last ) ? 0 : last );
-    prev = item;
+  if ( it != e ) { // .first asserts if the list is empty
+    KOAgendaItem *first = multiItems.first();
+    KOAgendaItem *last = multiItems.last();
+    KOAgendaItem *prev = 0, *next = 0;
+
+    while ( it != e ) {
+      KOAgendaItem *item = *it;
+      ++it;
+      next = (it == e ) ? 0 : (*it);
+      if ( item )
+        item->setMultiItem( (item == first) ? 0 : first, prev, next,
+          ( item == last ) ? 0 : last );
+      prev = item;
+    }
   }
 
   marcus_bains();
@@ -1793,7 +1802,7 @@ void KOAgenda::deleteItemsToDelete()
 */
 void KOAgenda::resizeEvent ( QResizeEvent *ev )
 {
-//  kDebug(5850) << "KOAgenda::resizeEvent" << endl;
+//  kDebug(5850) <<"KOAgenda::resizeEvent";
 
   QSize newSize( ev->size() );
   if (mAllDayMode) {
@@ -1887,7 +1896,7 @@ void KOAgenda::checkScrollBoundaries( int v )
   int yMin = int( (v) / mGridSpacingY );
   int yMax = int( ( v + visibleHeight() ) / mGridSpacingY );
 
-//  kDebug(5850) << "--- yMin: " << yMin << "  yMax: " << yMax << endl;
+//  kDebug(5850) <<"--- yMin:" << yMin <<"  yMax:" << yMax;
 
   if ( yMin != mOldLowerScrollValue ) {
     mOldLowerScrollValue = yMin;
@@ -1999,7 +2008,7 @@ void KOAgenda::setHolidayMask(QVector<bool> *mask)
 
 void KOAgenda::contentsMousePressEvent ( QMouseEvent *event )
 {
-  kDebug(5850) << "KOagenda::contentsMousePressEvent(): type: " << event->type() << endl;
+  kDebug(5850) <<"KOagenda::contentsMousePressEvent(): type:" << event->type();
   Q3ScrollView::contentsMousePressEvent(event);
 }
 
