@@ -57,7 +57,7 @@
 
 #include "koagendaitem.moc"
 
-//--------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
 
 QPixmap *KOAgendaItem::alarmPxmp = 0;
 QPixmap *KOAgendaItem::recurPxmp = 0;
@@ -67,18 +67,17 @@ QPixmap *KOAgendaItem::groupPxmp = 0;
 QPixmap *KOAgendaItem::groupPxmpTentative = 0;
 QPixmap *KOAgendaItem::organizerPxmp = 0;
 
-//--------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
 
-KOAgendaItem::KOAgendaItem( Incidence *incidence, const QDate &qd, QWidget *parent,
-                             Qt::WFlags f ) :
-  // TODO_QT4: Use constructor without *name=0 param
-  QWidget( parent, f ), mIncidence( incidence ), mDate( qd ),
-  mLabelText( mIncidence->summary() ), mIconAlarm( false ),
-  mIconRecur( false ), mIconReadonly( false ), mIconReply( false ),
-  mIconGroup( false ), mIconGroupTentative( false ), mIconOrganizer( false ),
-  mMultiItemInfo( 0 ), mStartMoveInfo( 0 )
+KOAgendaItem::KOAgendaItem( Incidence *incidence, const QDate &qd,
+                            QWidget *parent )
+  : QWidget( parent ), mIncidence( incidence ), mDate( qd ),
+    mLabelText( mIncidence->summary() ), mIconAlarm( false ),
+    mIconRecur( false ), mIconReadonly( false ), mIconReply( false ),
+    mIconGroup( false ), mIconGroupTentative( false ), mIconOrganizer( false ),
+    mMultiItemInfo( 0 ), mStartMoveInfo( 0 )
 {
-  setAttribute(Qt::WA_NoSystemBackground, true);
+  setAttribute( Qt::WA_NoSystemBackground, true );
 
   setCellXY( 0, 0, 1 );
   setCellXRight( 0 );
@@ -86,7 +85,7 @@ KOAgendaItem::KOAgendaItem( Incidence *incidence, const QDate &qd, QWidget *pare
   mResourceColor = QColor();
   updateIcons();
 
-  // select() does nothing, if state hasn't change, so preset mSelected.
+  // select() does nothing if the state hasn't changed, so preset mSelected.
   mSelected = true;
   select( false );
 
@@ -167,6 +166,7 @@ bool KOAgendaItem::dissociateFromMultiItem()
                             lastItem );
   }
   delete mMultiItemInfo;
+  mMultiItemInfo = 0;
   return true;
 }
 
@@ -206,9 +206,9 @@ void KOAgendaItem::setCellXY( int X, int YTop, int YBottom )
   mCellYBottom = YBottom;
 }
 
-void KOAgendaItem::setCellXRight( int xright )
+void KOAgendaItem::setCellXRight( int XRight )
 {
-  mCellXRight = xright;
+  mCellXRight = XRight;
 }
 
 void KOAgendaItem::setCellX( int XLeft, int XRight )
@@ -545,7 +545,7 @@ void KOAgendaItem::dragEnterEvent( QDragEnterEvent *e )
     e->ignore();
     return;
   }
-  if ( KVCardDrag::canDecode( md ) || md->hasText() )
+  if ( KPIM::KVCardDrag::canDecode( md ) || md->hasText() )
     e->accept();
   else
     e->ignore();
@@ -554,7 +554,7 @@ void KOAgendaItem::dragEnterEvent( QDragEnterEvent *e )
 
 void KOAgendaItem::addAttendee( const QString &newAttendee )
 {
-  kDebug(5850) << " Email: " << newAttendee << endl;
+  kDebug(5850) <<" Email:" << newAttendee;
   QString name, email;
   KPIMUtils::extractEmailAddressAndName( newAttendee, email, name );
   if ( !( name.isEmpty() && email.isEmpty() ) ) {
@@ -580,7 +580,7 @@ void KOAgendaItem::dropEvent( QDropEvent *e )
 #ifndef KORG_NOKABC
   KABC::Addressee::List list;
 
-  if ( KVCardDrag::fromMimeData( md, list ) ) {
+  if ( KPIM::KVCardDrag::fromMimeData( md, list ) ) {
     KABC::Addressee::List::Iterator it;
     for ( it = list.begin(); it != list.end(); ++it ) {
       QString em( (*it).fullEmail() );
@@ -592,7 +592,7 @@ void KOAgendaItem::dropEvent( QDropEvent *e )
   }
 #else
   if( decoded ) {
-    kDebug(5850) << "Dropped : " << text << endl;
+    kDebug(5850) <<"Dropped :" << text;
 
     QStringList emails = text.split( ",", QString::SkipEmptyParts  );
     for( QStringList::ConstIterator it = emails.begin(); it != emails.end();
@@ -645,19 +645,11 @@ bool KOAgendaItem::overlaps( KOrg::CellItem *o ) const
   return false;
 }
 
-void KOAgendaItem::paintFrame( QPainter *p, const QColor &color )
-{
-  QColor oldpen(p->pen().color());
-  p->setPen( color );
-  p->drawRect( 0, 0, width(), height() );
-  p->drawRect( 1, 1, width() - 2, height() - 2 );
-  p->setPen( oldpen );
-}
 
-static void conditionalPaint( QPainter *p, bool cond, int &x, int ft,
+static void conditionalPaint( QPainter *p, bool condition, int &x, int ft,
                               const QPixmap &pxmp )
 {
-  if ( !cond ) return;
+  if ( !condition ) return;
 
   p->drawPixmap( x, ft, pxmp );
   x += pxmp.width() + ft;
@@ -668,8 +660,9 @@ void KOAgendaItem::paintTodoIcon( QPainter *p, int &x, int ft )
   if ( !mIncidence ) return;
   static const QPixmap todoPxmp = KOGlobals::self()->smallIcon("todo");
   static const QPixmap completedPxmp = KOGlobals::self()->smallIcon("checkedbox");
-  if ( mIncidence->type() != "Todo" )
-    return;
+
+  if ( mIncidence->type() != "Todo" ) return;
+
   bool b = ( static_cast<Todo *>( mIncidence ) )->isCompleted();
   conditionalPaint( p, !b, x, ft, todoPxmp );
   conditionalPaint( p, b, x, ft, completedPxmp );
@@ -689,14 +682,16 @@ void KOAgendaItem::paintIcons( QPainter *p, int &x, int ft )
 
 void KOAgendaItem::paintEvent( QPaintEvent * )
 {
-  if ( !mIncidence )return;
+  if ( !mIncidence ) return;
 
   QPainter p( this );
-  const int ft = 2; // frame thickness for layout, see paintFrame()
+  p.setRenderHint( QPainter::Antialiasing );
+  const int ft = 2; // frame thickness for layout, see drawRoundedRect(),
+                    // keep multiple of 2
   const int margin = 1 + ft; // frame + space between frame and content
 
   // General idea is to always show the icons (even in the all-day events).
-  // This creates a consistent fealing for the user when the view mode
+  // This creates a consistent feeling for the user when the view mode
   // changes and therefore the available width changes.
   // Also look at #17984
 
@@ -710,7 +705,7 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
     organizerPxmp      = new QPixmap( KOGlobals::self()->smallIcon("organizer") );
   }
 
-  QColor bgColor;
+  QColor bgColor = KOPrefs::instance()->agendaCalendarItemsEventsBackgroundColor();
   if ( mIncidence->type() == "Todo" ) {
     if ( static_cast<Todo*>(mIncidence)->isOverdue() )
       bgColor = KOPrefs::instance()->agendaCalendarItemsToDosOverdueBackgroundColor();
@@ -720,6 +715,7 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
   }
 
   if ( !bgColor.isValid() ) {
+    kDebug() <<"invalid bgColor:" << bgColor.name();
     QStringList categories = mIncidence->categories();
     QString cat;
     if ( !categories.isEmpty() ) cat = categories.first();
@@ -743,7 +739,7 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
   }
   QColor textColor = getTextColor(bgColor);
   p.setPen( textColor );
-  p.setBackground( QBrush( bgColor ) );
+
   p.setFont( KOPrefs::instance()->agendaCalendarItemsFont() );
   if ( mIncidence ) {
     if ( mIncidence->type() == "Event" )
@@ -756,7 +752,12 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
   int singleLineHeight = fm.boundingRect( mLabelText ).height();
 
   p.eraseRect( 0, 0, width(), height() );
-  paintFrame( &p, frameColor );
+
+  bool roundTop = !prevMultiItem();
+  bool roundBottom = !nextMultiItem();
+
+  drawRoundedRect( &p, QRect( ft, ft, width() - ft, height() - ft ),
+		   frameColor, bgColor, true, ft, roundTop, roundBottom );
 
   // calculate the height of the full version (case 4) to test whether it is
   // possible
@@ -764,17 +765,21 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
   QString shortH;
   QString longH;
   if ( !isMultiItem() ) {
-    shortH = KGlobal::locale()->formatTime(mIncidence->dtStart().time());
+    shortH = KGlobal::locale()->formatTime(
+    mIncidence->dtStart().toTimeSpec( KOPrefs::instance()->timeSpec() ).time());
     if (mIncidence->type() != "Todo")
       longH = i18n("%1 - %2", shortH,
-                KGlobal::locale()->formatTime(mIncidence->dtEnd().time()));
+                KGlobal::locale()->formatTime(
+                mIncidence->dtEnd().toTimeSpec( KOPrefs::instance()->timeSpec() ).time()));
     else
       longH = shortH;
   } else if ( !mMultiItemInfo->mFirstMultiItem ) {
-    shortH = KGlobal::locale()->formatTime(mIncidence->dtStart().time());
+    shortH = KGlobal::locale()->formatTime(
+             mIncidence->dtStart().toTimeSpec( KOPrefs::instance()->timeSpec() ).time());
     longH = shortH;
   } else {
-    shortH = KGlobal::locale()->formatTime(mIncidence->dtEnd().time());
+    shortH = KGlobal::locale()->formatTime(
+             mIncidence->dtEnd().toTimeSpec( KOPrefs::instance()->timeSpec() ).time());
     longH = i18n("- %1", shortH);
   }
 
@@ -809,7 +814,7 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
   if ( (2 * singleLineHeight) > (height() - 2 * margin) ) {
     int x = margin, txtWidth;
 
-    if ( mIncidence->floats() ) {
+    if ( mIncidence->allDay() ) {
       x += visRect.left();
       paintIcons( &p, x, ft );
       txtWidth = visRect.right() - margin - x;
@@ -831,7 +836,7 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
        (isMultiItem() && mMultiItemInfo->mNextMultiItem && mMultiItemInfo->mFirstMultiItem) ) {
     int x = margin, txtWidth;
 
-    if ( mIncidence->floats() ) {
+    if ( mIncidence->allDay() ) {
       x += visRect.left();
       paintIcons( &p, x, ft );
       txtWidth = visRect.right() - margin - x;
@@ -847,7 +852,7 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
                                 0,
                                 mLabelText );
 
-    //kDebug() << "SIZES for " << mLabelText <<  ": " << width() << " :: " << txtWidth << endl;
+    //kDebug() <<"SIZES for" << mLabelText <<":" << width() <<" ::" << txtWidth;
     ww->drawText( &p, x, margin, Qt::AlignHCenter | KWordWrap::FadeOut );
     delete ww;
     return;
@@ -861,19 +866,18 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
 
   int x = margin, txtWidth, hTxtWidth, eventX;
 
-  if ( mIncidence->floats() ) {
+  if ( mIncidence->allDay() ) {
     shortH = longH = "";
 
     if ( (mIncidence->type() != "Todo") &&
          (mIncidence->dtStart() != mIncidence->dtEnd()) ) { // multi days
       shortH = longH =
         i18n("%1 - %2",
-              KGlobal::locale()->formatDate(mIncidence->dtStart().date()),
-              KGlobal::locale()->formatDate(mIncidence->dtEnd().date()));
+              KGlobal::locale()->formatDate(mIncidence->dtStart().toTimeSpec( KOPrefs::instance()->timeSpec() ).date()),
+              KGlobal::locale()->formatDate(mIncidence->dtEnd().toTimeSpec( KOPrefs::instance()->timeSpec() ).date()));
 
       // paint headline
-      p.fillRect( 0, 0, width(), (ft/2) + margin + hlHeight,
-                  QBrush( frameColor ) );
+      drawRoundedRect( &p, QRect( ft/2, ft/2, width(), - ft/2 + margin + hlHeight), frameColor, frameColor, false, ft, roundTop, false );
     }
 
     x += visRect.left();
@@ -884,9 +888,7 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
   }
   else {
     // paint headline
-    p.fillRect( 0, 0, width(), (ft/2) + margin + hlHeight,
-                QBrush( frameColor ) );
-
+    drawRoundedRect( &p, QRect( ft/2, ft/2, width(), - ft/2 + margin + hlHeight), frameColor, frameColor, false, ft, roundTop, false );
     txtWidth = width() - margin - x;
     eventX = x;
     paintIcons( &p, x, ft );
@@ -924,5 +926,64 @@ void KOAgendaItem::paintEvent( QPaintEvent * )
     ww->drawText( &p, eventX + (txtWidth-ww->boundingRect().width()-2*margin)/2,
                   y, Qt::AlignHCenter | KWordWrap::FadeOut );
   delete ww;
+
+  setMask( QRegion( roundedRect( QRect( ft/2, ft/2, width(), height() ),
+				 roundTop, roundBottom ).toFillPolygon().toPolygon() ) );
 }
 
+QPainterPath KOAgendaItem::roundedRect( const QRect& rect, bool roundTop, bool roundBottom )
+{
+  int xRnd = 10;
+  int yRnd = 10;
+  int xDiam = 2 * xRnd;
+  int yDiam = 2 * yRnd;
+
+  int x1, y1, x2, y2;
+  rect.getCoords( &x1, &y1, &x2, &y2 );
+
+  QPainterPath path;
+  if ( roundTop ) {
+    path.moveTo( x2, y1 + yRnd );
+    path.arcTo( QRect( x2 - xDiam, y1, xDiam, yDiam ), 0, +90.0 );
+    path.lineTo( x1 + xRnd, y1 );
+    path.arcTo( QRect( x1, y1, xDiam, yDiam ), 90.0, +90.0 );
+  } else {
+    path.moveTo( x2, y1 );
+    path.lineTo( x1, y1 );
+  }
+
+  if ( roundBottom ) {
+    path.lineTo( x1, y2 - yRnd );
+    path.arcTo( QRect(x1, y2 - yDiam, xDiam, yDiam), 180.0, +90.0 );
+    path.lineTo( x1 + xRnd, y2 );
+    path.arcTo( QRect(x2 - xDiam, y2 - yDiam, xDiam, yDiam), 270.0, +90.0 );
+  } else {
+    path.lineTo( x1, y2 );
+    path.lineTo( x2, y2 );
+  }
+  path.closeSubpath();
+
+  return path;
+}
+
+void KOAgendaItem::drawRoundedRect( QPainter *p, const QRect& rect,
+				    const QColor& color, const QColor& bgcolor,
+				    bool frame, int ft, bool roundTop, bool roundBottom )
+{
+  QPainterPath path = roundedRect( rect, roundTop, roundBottom );
+
+  QColor oldPen(p->pen().color());
+  QColor oldBrush(p->brush().color());
+  if ( frame ) {
+    QPen pen( color );
+    pen.setWidth( ft );
+    p->setPen( pen );
+  }
+  else
+    p->setPen( Qt::NoPen );
+
+  p->setBrush( bgcolor );
+  p->drawPath( path );
+  p->setPen( oldPen );
+  p->setBrush( oldBrush );
+}
