@@ -89,8 +89,8 @@ void DynamicTip::maybeTip( const QPoint &pos )
 
   QRect rct( col * dwidth, row * dheight, dwidth, dheight );
 
-//  kDebug(5850) << "DynamicTip::maybeTip matrix cell index [" <<
-//                col << "][" << row << "] => " <<(col+row*7) << endl;
+//  kDebug(5850) <<"DynamicTip::maybeTip matrix cell index [" <<
+//                col << "][" << row << "] =>" <<(col+row*7);
 
   //show holiday names only
   QString str = mMatrix->getHolidayLabel( col + row * 7 );
@@ -162,7 +162,7 @@ KODayMatrix::~KODayMatrix()
 
 void KODayMatrix::addSelectedDaysTo( DateList &selDays )
 {
-  kDebug(5850) << "KODayMatrix::addSelectedDaysTo() - " << "mSelStart:" << mSelStart << endl;
+  kDebug(5850) <<"KODayMatrix::addSelectedDaysTo() -" <<"mSelStart:" << mSelStart;
 
   if ( mSelStart == NOSELECTION ) {
     return;
@@ -221,7 +221,7 @@ void KODayMatrix::recalculateToday()
       mToday = i;
     }
   }
-  // kdDegug(5850) << "Today is visible at "<< today << "." << endl;
+  // kDebug(5850) << "Today is visible at "<< today << ".";
 }
 
 /* slot */ void KODayMatrix::updateView()
@@ -231,7 +231,7 @@ void KODayMatrix::recalculateToday()
 
 void KODayMatrix::updateView( const QDate &actdate )
 {
-//   kDebug(5850) << "KODayMatrix::updateView() " << actdate << ", day start="<<mStartDate<< endl;
+//   kDebug(5850) <<"KODayMatrix::updateView()" << actdate <<", day start="<<mStartDate;
   if ( !actdate.isValid() ) return;
 
   //flag to indicate if the starting day of the matrix has changed by this call
@@ -243,7 +243,7 @@ void KODayMatrix::updateView( const QDate &actdate )
     // reset index of selection according to shift of starting date from startdate to actdate
     if ( mSelStart != NOSELECTION ) {
       int tmp = actdate.daysTo( mStartDate );
-      //kDebug(5850) << "Shift of Selection1: " << mSelStart << " - " << mSelEnd << " -> " << tmp << "(" << offset << ")" << endl;
+      //kDebug(5850) <<"Shift of Selection1:" << mSelStart <<" -" << mSelEnd <<" ->" << tmp <<"(" << offset <<")";
       // shift selection if new one would be visible at least partly !
 
       if ( mSelStart + tmp < NUMDAYS && mSelEnd + tmp >= 0 ) {
@@ -291,7 +291,7 @@ void KODayMatrix::updateEvents()
 
   for( int i = 0; i < NUMDAYS; i++ ) {
     // if events are set for the day then remember to draw it bold
-    Event::List eventlist = mCalendar->events( mDays[ i ] );
+    Event::List eventlist = mCalendar->events( mDays[ i ], mCalendar->timeSpec() );
     int numEvents = eventlist.count();
     Event::List::ConstIterator it;
     for( it = eventlist.begin(); it != eventlist.end(); ++it ) {
@@ -311,7 +311,7 @@ void KODayMatrix::updateEvents()
 const QDate& KODayMatrix::getDate( int offset ) const
 {
   if ( offset < 0 || offset > NUMDAYS - 1 ) {
-    kDebug(5850) << "Wrong offset (" << offset << ") in KODayMatrix::getDate(int)" << endl;
+    kDebug(5850) <<"Wrong offset (" << offset <<") in KODayMatrix::getDate(int)";
     return mDays[ 0 ];
   }
   return mDays[ offset ];
@@ -320,7 +320,7 @@ const QDate& KODayMatrix::getDate( int offset ) const
 QString KODayMatrix::getHolidayLabel( int offset ) const
 {
   if ( offset < 0 || offset > NUMDAYS - 1 ) {
-    kDebug(5850) << "Wrong offset (" << offset << ") in KODayMatrix::getHolidayLabel(int)" << endl;
+    kDebug(5850) <<"Wrong offset (" << offset <<") in KODayMatrix::getHolidayLabel(int)";
     return 0;
   }
   return mHolidays[ offset ];
@@ -448,7 +448,7 @@ void KODayMatrix::dragLeaveEvent( QDragLeaveEvent * /*dl*/ )
 void KODayMatrix::dropEvent( QDropEvent *e )
 {
 #ifndef KORG_NODND
-  kDebug(5850) << "KODayMatrix::dropEvent(e) begin" << endl;
+  kDebug(5850) <<"KODayMatrix::dropEvent(e) begin";
 
   if ( !mCalendar ) {
     e->ignore();
@@ -527,7 +527,7 @@ void KODayMatrix::dropEvent( QDropEvent *e )
 
 void KODayMatrix::paintEvent( QPaintEvent * )
 {
-// kDebug(5850) << "KODayMatrix::paintEvent() BEGIN" << endl;
+// kDebug(5850) <<"KODayMatrix::paintEvent() BEGIN";
 
   QPainter p;
   QRect sz = frameRect();
