@@ -28,7 +28,6 @@
 
 #include <kcal/incidence.h>
 #include <libkdepim/kdepimprotocols.h>
-#include <libkdepim/kpimurlrequesterdlg.h>
 #include <libkdepim/kvcarddrag.h>
 
 #include <kio/job.h>
@@ -150,8 +149,8 @@ class AttachmentIconItem : public K3IconViewItem
         overlays << "link";
       }
 
-      return KIconLoader::global()->loadIcon( iconStr, K3Icon::Desktop, 0,
-                                              K3Icon::DefaultState,
+      return KIconLoader::global()->loadIcon( iconStr, KIconLoader::Desktop, 0,
+                                              KIconLoader::DefaultState,
                                               overlays  );
     }
 
@@ -337,7 +336,7 @@ protected:
     }
     QPixmap pixmap;
     if( urls.count() > 1 )
-        pixmap = KIconLoader::global()->loadIcon( "kmultiple", K3Icon::Desktop );
+        pixmap = KIconLoader::global()->loadIcon( "kmultiple", KIconLoader::Desktop );
     if( pixmap.isNull() )
         pixmap = static_cast<AttachmentIconItem *>( currentItem() )->icon();
 
@@ -498,9 +497,9 @@ void KOEditorAttachments::dropEvent( QDropEvent* event ) {
   const QMimeData *md = event->mimeData();
   QStringList labels;
 
-  if ( KVCardDrag::canDecode( md ) ) {
+  if ( KPIM::KVCardDrag::canDecode( md ) ) {
     KABC::Addressee::List addressees;
-    KVCardDrag::fromMimeData( md, addressees );
+    KPIM::KVCardDrag::fromMimeData( md, addressees );
     for ( KABC::Addressee::List::ConstIterator it = addressees.constBegin();
           it != addressees.constEnd(); ++it ) {
       urls.append( KDEPIMPROTOCOL_CONTACT + ( *it ).uid() );
