@@ -26,7 +26,6 @@
 #include "koeditordetails.h"
 
 #include <QCheckBox>
-#include <QComboBox>
 #include <QDateTime>
 #include <QLabel>
 #include <QLayout>
@@ -44,6 +43,7 @@
 #include <QVBoxLayout>
 #include <QDragEnterEvent>
 
+#include <KComboBox>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -114,7 +114,7 @@ void KOAttendeeListView::contentsDragMoveEvent( QDragMoveEvent *e )
 {
 #ifndef KORG_NODND
   const QMimeData *md = e->mimeData();
-  if ( KVCardDrag::canDecode( md ) || md->hasText() ) {
+  if ( KPIM::KVCardDrag::canDecode( md ) || md->hasText() ) {
     e->accept();
   } else {
     e->ignore();
@@ -126,7 +126,7 @@ void KOAttendeeListView::dragEnterEvent( QDragEnterEvent *e )
 {
 #ifndef KORG_NODND
   const QMimeData *md = e->mimeData();
-  if ( KVCardDrag::canDecode( md ) || md->hasText() ) {
+  if ( KPIM::KVCardDrag::canDecode( md ) || md->hasText() ) {
     e->accept();
   } else {
     e->ignore();
@@ -136,7 +136,7 @@ void KOAttendeeListView::dragEnterEvent( QDragEnterEvent *e )
 
 void KOAttendeeListView::addAttendee( const QString &newAttendee )
 {
-  kDebug(5850) << " Email: " << newAttendee << endl;
+  kDebug(5850) <<" Email:" << newAttendee;
   QString name;
   QString email;
   KPIMUtils::extractEmailAddressAndName( newAttendee, email, name );
@@ -154,9 +154,9 @@ void KOAttendeeListView::dropEvent( QDropEvent *e )
   const QMimeData *md = e->mimeData();
 
 #ifndef KORG_NOKABC
-  if ( KVCardDrag::canDecode( md ) ) {
+  if ( KPIM::KVCardDrag::canDecode( md ) ) {
     KABC::Addressee::List list;
-    KVCardDrag::fromMimeData( md, list );
+    KPIM::KVCardDrag::fromMimeData( md, list );
 
     KABC::Addressee::List::Iterator it;
     for ( it = list.begin(); it != list.end(); ++it ) {
@@ -170,7 +170,7 @@ void KOAttendeeListView::dropEvent( QDropEvent *e )
 #endif // KORG_NOKABC
   if ( md->hasText() ) {
     QString text = md->text();
-    kDebug(5850) << "Dropped : " << text << endl;
+    kDebug(5850) <<"Dropped :" << text;
     QStringList emails = text.split(",", QString::SkipEmptyParts);
     for(QStringList::ConstIterator it = emails.begin();it!=emails.end();++it) {
       addAttendee(*it);
@@ -206,7 +206,7 @@ KOEditorDetails::KOEditorDetails( int spacing, QWidget *parent )
 			   "KOrganizer configuration.");
   mOrganizerLabel = new QLabel( i18n( "Identity as organizer:" ),
                                 mOrganizerHBox );
-  mOrganizerCombo = new QComboBox( mOrganizerHBox );
+  mOrganizerCombo = new KComboBox( mOrganizerHBox );
   mOrganizerLabel->setWhatsThis( whatsThis );
   mOrganizerCombo->setWhatsThis( whatsThis );
   fillOrganizerCombo();
@@ -262,7 +262,7 @@ KOEditorDetails::KOEditorDetails( int spacing, QWidget *parent )
   attendeeRoleLabel->setWhatsThis( whatsThis );
   attendeeRoleLabel->setText( i18n("Ro&le:") );
 
-  mRoleCombo = new QComboBox( this );
+  mRoleCombo = new KComboBox( this );
   mRoleCombo->setWhatsThis( whatsThis );
   mRoleCombo->addItems( Attendee::roleList() );
   attendeeRoleLabel->setBuddy( mRoleCombo );
@@ -275,7 +275,7 @@ KOEditorDetails::KOEditorDetails( int spacing, QWidget *parent )
   statusLabel->setWhatsThis( whatsThis );
   statusLabel->setText( i18n("Stat&us:") );
 
-  mStatusCombo = new QComboBox( this );
+  mStatusCombo = new KComboBox( this );
   mStatusCombo->setWhatsThis( whatsThis );
   mStatusCombo->addItems( Attendee::statusList() );
   statusLabel->setBuddy( mStatusCombo );
@@ -480,7 +480,7 @@ void KOEditorDetails::readEvent( Incidence *event )
 
   if ( KOPrefs::instance()->thatIsMe( event->organizer().email() ) ) {
     if ( !mOrganizerCombo ) {
-      mOrganizerCombo = new QComboBox( mOrganizerHBox );
+      mOrganizerCombo = new KComboBox( mOrganizerHBox );
       fillOrganizerCombo();
     }
     mOrganizerLabel->setText( i18n( "Identity as organizer:" ) );
