@@ -40,11 +40,11 @@
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
+#include <KComboBox>
 
 #include <QToolTip>
 #include <QLayout>
 #include <QLabel>
-#include <QComboBox>
 #include <QPushButton>
 #include <QFrame>
 #include <QHBoxLayout>
@@ -217,7 +217,7 @@ KOEditorFreeBusy::KOEditorFreeBusy( int spacing, QWidget *parent )
   label->setWhatsThis( whatsThis );
   controlLayout->addWidget( label );
 
-  scaleCombo = new QComboBox( this );
+  scaleCombo = new KComboBox( this );
   scaleCombo->setWhatsThis( whatsThis );
   scaleCombo->addItem( i18n( "Hour" ) );
   scaleCombo->addItem( i18n( "Day" ) );
@@ -391,7 +391,7 @@ void KOEditorFreeBusy::readEvent( Event *event )
 
 void KOEditorFreeBusy::slotIntervalColorRectangleMoved( const QDateTime& start, const QDateTime& end )
 {
-  kDebug() << k_funcinfo << "slotIntervalColorRectangleMoved " << start << "," << end << endl;
+  kDebug() <<"slotIntervalColorRectangleMoved" << start <<"," << end;
   mDtStart = start;
   mDtEnd = end;
   emit dateTimesChanged( start, end );
@@ -456,7 +456,7 @@ void KOEditorFreeBusy::timerEvent( QTimerEvent *event )
 void KOEditorFreeBusy::slotInsertFreeBusy( KCal::FreeBusy *fb,
                                            const QString &email )
 {
-  kDebug(5850) << "KOEditorFreeBusy::slotInsertFreeBusy() " << email << endl;
+  kDebug(5850) <<"KOEditorFreeBusy::slotInsertFreeBusy()" << email;
 
   if ( fb ) {
     fb->sortList();
@@ -689,7 +689,7 @@ void KOEditorFreeBusy::autoReload()
 
 void KOEditorFreeBusy::reload()
 {
-  kDebug(5850) << "KOEditorFreeBusy::reload()" << endl;
+  kDebug(5850) <<"KOEditorFreeBusy::reload()";
 
   FreeBusyItem *item = static_cast<FreeBusyItem *>( mGanttView->firstChild() );
   while ( item ) {
