@@ -27,6 +27,7 @@
 #include "ktimeedit.h"
 
 #include <libkdepim/kdateedit.h>
+#include <libkdepim/ktimezonecombobox.h>
 
 #include <kcal/todo.h>
 
@@ -38,6 +39,7 @@
 #include <kstandarddirs.h>
 #include <kfiledialog.h>
 #include <ktextedit.h>
+#include <KComboBox>
 
 #include <QLayout>
 #include <QDateTime>
@@ -56,7 +58,7 @@
 
 KOEditorGeneralTodo::KOEditorGeneralTodo(QObject* parent,
                                          const char* name)
-  : KOEditorGeneral( parent, name)
+  : KOEditorGeneral( parent, name )
 {
 }
 
@@ -93,7 +95,7 @@ void KOEditorGeneralTodo::finishSetup()
 
 void KOEditorGeneralTodo::initTime(QWidget *parent,QBoxLayout *topLayout)
 {
-  kDebug(5850) << k_funcinfo << endl;
+  kDebug(5850) ;
   QBoxLayout *timeLayout = new QVBoxLayout();
   topLayout->addItem(timeLayout);
 
@@ -106,19 +108,31 @@ void KOEditorGeneralTodo::initTime(QWidget *parent,QBoxLayout *topLayout)
   QGridLayout *layoutTimeBox = new QGridLayout( timeGroupBox );
   layoutTimeBox->setSpacing( KDialog::spacingHint() );
 
-  QString whatsThis = i18n("Sets the start date for this to-do");
+  /*
+    Timezone
+  */
+  QString whatsThis = i18n( "Select the timezone for this event. "
+                                "It will also affect recurrences" );
+  mTimeZoneComboStart = new KPIM::KTimeZoneComboBox( timeGroupBox );
+  mTimeZoneComboDue = new KPIM::KTimeZoneComboBox( timeGroupBox );
+  layoutTimeBox->addWidget( mTimeZoneComboStart, 0, 3 );
+  layoutTimeBox->addWidget( mTimeZoneComboDue, 1, 3 );
+  mTimeZoneComboStart->setWhatsThis( whatsThis );
+  mTimeZoneComboDue->setWhatsThis( whatsThis );
+
+  whatsThis = i18n("Sets the start date for this to-do");
   mStartCheck = new QCheckBox(i18n("Sta&rt:"),timeGroupBox);
   mStartCheck->setWhatsThis( whatsThis );
   layoutTimeBox->addWidget(mStartCheck,0,0);
   connect(mStartCheck,SIGNAL(toggled(bool)),SLOT(enableStartEdit(bool)));
   connect(mStartCheck,SIGNAL(toggled(bool)),SLOT(startDateModified()));
 
-  mStartDateEdit = new KDateEdit(timeGroupBox);
+  mStartDateEdit = new KPIM::KDateEdit(timeGroupBox);
   mStartDateEdit->setWhatsThis( whatsThis );
   layoutTimeBox->addWidget(mStartDateEdit,0,1);
   connect(mStartDateEdit,SIGNAL(dateChanged(const QDate&)),SLOT(startDateModified()));
 
-  mStartTimeEdit = new KTimeEdit(timeGroupBox);
+  mStartTimeEdit = new KPIM::KTimeEdit(timeGroupBox);
   mStartTimeEdit->setWhatsThis(
                    i18n("Sets the start time for this to-do.") );
   layoutTimeBox->addWidget(mStartTimeEdit,0,2);
@@ -133,12 +147,12 @@ void KOEditorGeneralTodo::initTime(QWidget *parent,QBoxLayout *topLayout)
   connect(mDueCheck,SIGNAL(toggled(bool)),SIGNAL(dueDateEditToggle(bool)));
   connect(mDueCheck,SIGNAL(toggled(bool)),SLOT(dateChanged()));
 
-  mDueDateEdit = new KDateEdit(timeGroupBox);
+  mDueDateEdit = new KPIM::KDateEdit(timeGroupBox);
   mDueDateEdit->setWhatsThis( whatsThis );
   layoutTimeBox->addWidget(mDueDateEdit,1,1);
   connect(mDueDateEdit,SIGNAL(dateChanged(const QDate&)),SLOT(dateChanged()));
 
-  mDueTimeEdit = new KTimeEdit(timeGroupBox);
+  mDueTimeEdit = new KPIM::KTimeEdit(timeGroupBox);
   mDueTimeEdit->setWhatsThis(
                    i18n("Sets the due time for this to-do.") );
   layoutTimeBox->addWidget(mDueTimeEdit,1,2);
@@ -153,6 +167,11 @@ void KOEditorGeneralTodo::initTime(QWidget *parent,QBoxLayout *topLayout)
   connect(mTimeButton,SIGNAL(toggled(bool)),SLOT(enableTimeEdits(bool)));
   connect(mTimeButton,SIGNAL(toggled(bool)),SLOT(dateChanged()));
 
+  connect(mTimeZoneComboStart, SIGNAL(currentIndexChanged(int)),
+	  this, SLOT(startDateModified()) );
+  connect(mTimeZoneComboDue, SIGNAL(currentIndexChanged(int)),
+	  this, SLOT(dateChanged()) );
+
   // some more layouting
   layoutTimeBox->setColumnStretch(3,1);
 }
@@ -162,7 +181,7 @@ void KOEditorGeneralTodo::initCompletion(QWidget *parent, QBoxLayout *topLayout)
 {
   QString whatsThis = i18n("Sets the current completion status of this to-do "
                            "as a percentage.");
-  mCompletedCombo = new QComboBox(parent);
+  mCompletedCombo = new KComboBox(parent);
   mCompletedCombo->setWhatsThis( whatsThis );
   for (int i = 0; i <= 100; i+=10) {
     // xgettext:no-c-format
@@ -175,9 +194,9 @@ void KOEditorGeneralTodo::initCompletion(QWidget *parent, QBoxLayout *topLayout)
   mCompletedLabel = new QLabel(i18n("co&mpleted"),parent);
   topLayout->addWidget(mCompletedLabel);
   mCompletedLabel->setBuddy( mCompletedCombo );
-  mCompletionDateEdit = new KDateEdit( parent );
+  mCompletionDateEdit = new KPIM::KDateEdit( parent );
   topLayout->addWidget( mCompletionDateEdit );
-  mCompletionTimeEdit = new KTimeEdit( parent, QTime() );
+  mCompletionTimeEdit = new KPIM::KTimeEdit( parent, QTime() );
   topLayout->addWidget( mCompletionTimeEdit );
 }
 
@@ -192,7 +211,7 @@ void KOEditorGeneralTodo::initPriority(QWidget *parent, QBoxLayout *topLayout)
   QLabel *priorityLabel = new QLabel(i18n("&Priority:"),parent);
   topLayout->addWidget(priorityLabel);
 
-  mPriorityCombo = new QComboBox(parent);
+  mPriorityCombo = new KComboBox(parent);
   mPriorityCombo->addItem( i18n("unspecified") );
   mPriorityCombo->addItem( i18n("1 (highest)") );
   mPriorityCombo->addItem( i18n("2") );
@@ -222,7 +241,7 @@ void KOEditorGeneralTodo::initStatus(QWidget *parent,QBoxLayout *topLayout)
 
 void KOEditorGeneralTodo::setDefaults( const QDateTime &due, bool allDay )
 {
-  kDebug(5850) << k_funcinfo << due <<endl;
+  kDebug(5850) << due;
   KOEditorGeneral::setDefaults(allDay);
 
   mTimeButton->setChecked( !allDay );
@@ -265,13 +284,14 @@ void KOEditorGeneralTodo::readTodo(Todo *todo)
 
   QDateTime dueDT;
 
-  KDateTime::Spec timeSpec = KOPrefs::instance()->timeSpec();
   if (todo->hasDueDate()) {
     enableAlarm( true );
-    dueDT = todo->dtDue().toTimeSpec(timeSpec).dateTime();
+    dueDT = todo->dtDue().dateTime();
     mDueDateEdit->setDate(dueDT.date());
     mDueTimeEdit->setTime(dueDT.time());
     mDueCheck->setChecked(true);
+    mDueSpec = todo->dtDue().timeSpec();
+    mTimeZoneComboDue->selectTimeSpec( todo->dtDue().timeSpec() );
   } else {
     enableAlarm( false );
     mDueDateEdit->setEnabled(false);
@@ -282,10 +302,12 @@ void KOEditorGeneralTodo::readTodo(Todo *todo)
   }
 
   if (todo->hasStartDate()) {
-    QDateTime start = todo->dtStart().toTimeSpec(timeSpec).dateTime();
+    QDateTime start = todo->dtStart().dateTime();
     mStartDateEdit->setDate(start.date());
     mStartTimeEdit->setTime(start.time());
     mStartCheck->setChecked(true);
+    mStartSpec = todo->dtStart().timeSpec();
+    mTimeZoneComboStart->selectTimeSpec( todo->dtStart().timeSpec() );
   } else {
     mStartDateEdit->setEnabled(false);
     mStartTimeEdit->setEnabled(false);
@@ -294,12 +316,12 @@ void KOEditorGeneralTodo::readTodo(Todo *todo)
     mStartCheck->setChecked(false);
   }
 
-  mTimeButton->setChecked( !todo->floats() );
+  mTimeButton->setChecked( !todo->allDay() );
 
   mAlreadyComplete = false;
   mCompletedCombo->setCurrentIndex(todo->percentComplete() / 10);
   if (todo->isCompleted() && todo->hasCompletedDate()) {
-    mCompleted = todo->completed().toTimeSpec(timeSpec).dateTime();
+    mCompleted = todo->completed().toTimeSpec( KOPrefs::instance()->timeSpec() ).dateTime();
     mAlreadyComplete = true;
   }
   setCompletedDate();
@@ -318,17 +340,21 @@ void KOEditorGeneralTodo::writeTodo(Todo *todo)
   todo->setHasDueDate(mDueCheck->isChecked());
   todo->setHasStartDate(mStartCheck->isChecked());
 
+  KDateTime::Spec startSpec = mTimeZoneComboStart->selectedTimeSpec();
+  KDateTime::Spec dueSpec = mTimeZoneComboDue->selectedTimeSpec();
+
   QDate tmpSDate, tmpDDate;
   QTime tmpSTime, tmpDTime;
-  QDateTime tmpStartDT, tmpDueDT;
+  KDateTime tmpStartDT, tmpDueDT;
   if ( mTimeButton->isChecked() ) {
-    todo->setFloats(false);
+    todo->setAllDay(false);
 
     // set due date/time
     tmpDDate = mDueDateEdit->date();
     tmpDTime = mDueTimeEdit->getTime();
     tmpDueDT.setDate(tmpDDate);
     tmpDueDT.setTime(tmpDTime);
+    tmpDueDT.setTimeSpec( dueSpec );
 
     // set start date/time
     if ( mStartCheck->isChecked() ) {
@@ -336,38 +362,35 @@ void KOEditorGeneralTodo::writeTodo(Todo *todo)
       tmpSTime = mStartTimeEdit->getTime();
       tmpStartDT.setDate(tmpSDate);
       tmpStartDT.setTime(tmpSTime);
+      tmpStartDT.setTimeSpec( startSpec );
     } else {
       tmpStartDT = tmpDueDT;
     }
   } else {
-    todo->setFloats(true);
+    todo->setAllDay(true);
+    tmpDueDT.setDateOnly( true );
+    tmpStartDT.setDateOnly( true );
 
     // need to change this.
     tmpDDate = mDueDateEdit->date();
-    tmpDTime.setHMS(0,0,0);
     tmpDueDT.setDate(tmpDDate);
-    tmpDueDT.setTime(tmpDTime);
 
     if ( mStartCheck->isChecked() ) {
       tmpSDate = mStartDateEdit->date();
-      tmpSTime.setHMS(0,0,0);
       tmpStartDT.setDate(tmpSDate);
-      tmpStartDT.setTime(tmpSTime);
     } else {
       tmpStartDT = tmpDueDT;
     }
   }
 
   // TODO: Don't use the due date for the recurrence, but the start date (cf. rfc 2445)
-  KDateTime::Spec timeSpec = KOPrefs::instance()->timeSpec();
   if ( todo->recurs() && !mStartDateModified ) {
-    todo->setDtDue( KDateTime(tmpDueDT, timeSpec) );
+    todo->setDtDue( tmpDueDT );
   } else {
-      todo->setDtDue( KDateTime(tmpDueDT, timeSpec), true );
-      todo->setDtStart( KDateTime(tmpStartDT, timeSpec) );
-      todo->setDtRecurrence( KDateTime(tmpDueDT, timeSpec) );
+    todo->setDtDue( tmpDueDT, true );
+    todo->setDtStart( tmpStartDT );
+    todo->setDtRecurrence( tmpDueDT );
   }
-
   todo->setPriority( mPriorityCombo->currentIndex() );
 
   // set completion state
@@ -383,7 +406,8 @@ void KOEditorGeneralTodo::writeTodo(Todo *todo)
       // truncated, but that's an effect done by KTimeEdit automatically).
       completed = mCompleted;
     }
-    todo->setCompleted( KDateTime(completed, timeSpec) );
+    // TODO: should we add the ability to choose this timezone ?
+    todo->setCompleted( KDateTime(completed, KOPrefs::instance()->timeSpec() ) );
   }
 }
 
@@ -399,9 +423,13 @@ void KOEditorGeneralTodo::enableDueEdit(bool enable)
 
   if (enable) {
     mDueTimeEdit->setEnabled( mTimeButton->isChecked() );
+    mTimeZoneComboDue->setEnabled( mTimeButton->isChecked() );
   } else {
     mDueTimeEdit->setEnabled( false );
+    mTimeZoneComboDue->setEnabled( false );
   }
+
+  mTimeZoneComboDue->setFloating( !mTimeZoneComboDue->isEnabled() );
 }
 
 void KOEditorGeneralTodo::enableStartEdit( bool enable )
@@ -418,18 +446,26 @@ void KOEditorGeneralTodo::enableStartEdit( bool enable )
 
   if (enable) {
     mStartTimeEdit->setEnabled( mTimeButton->isChecked() );
+    mTimeZoneComboStart->setEnabled( mTimeButton->isChecked() );
   } else {
     mStartTimeEdit->setEnabled( false );
+    mTimeZoneComboStart->setEnabled( false );
   }
+
+  mTimeZoneComboStart->setFloating( !mTimeZoneComboStart->isEnabled() );
 }
 
 void KOEditorGeneralTodo::enableTimeEdits(bool enable)
 {
   if(mStartCheck->isChecked()) {
     mStartTimeEdit->setEnabled( enable );
+    mTimeZoneComboStart->setEnabled( enable );
+    mTimeZoneComboStart->setFloating( !enable, mStartSpec );
   }
   if(mDueCheck->isChecked()) {
     mDueTimeEdit->setEnabled( enable );
+    mTimeZoneComboDue->setEnabled( enable );
+    mTimeZoneComboDue->setFloating( !enable, mDueSpec );
   }
 }
 
@@ -501,19 +537,26 @@ void KOEditorGeneralTodo::dateChanged()
   if ( mStartCheck->isChecked() ) {
     dateTimeStr += i18n("Start: %1",
                                      l->formatDate( mStartDateEdit->date() ) );
-    if ( mTimeButton->isChecked() )
+    if ( mTimeButton->isChecked() ) {
       dateTimeStr += QString(" %1").arg(
                                    l->formatTime( mStartTimeEdit->getTime() ) );
+
+      dateTimeStr += mTimeZoneComboStart->selectedTimeSpec().timeZone().name();
+    }
   }
 
   if ( mDueCheck->isChecked() ) {
     dateTimeStr += i18n("   Due: %1",
                                       l->formatDate( mDueDateEdit->date() ) );
-    if ( mTimeButton->isChecked() )
+    if ( mTimeButton->isChecked() ) {
       dateTimeStr += QString(" %1").arg(
                                     l->formatTime( mDueTimeEdit->getTime() ) );
+      dateTimeStr += mTimeZoneComboDue->selectedTimeSpec().timeZone().name();
+    }
   }
 
+  mDueSpec = mTimeZoneComboDue->selectedTimeSpec();
+
   emit dateTimeStrChanged( dateTimeStr );
   QDateTime endDt( mDueDateEdit->date(), mDueTimeEdit->getTime() );
   emit signalDateTimeChanged( endDt, endDt );
@@ -522,6 +565,8 @@ void KOEditorGeneralTodo::dateChanged()
 void KOEditorGeneralTodo::startDateModified()
 {
   mStartDateModified = true;
+  mStartSpec = mTimeZoneComboStart->selectedTimeSpec();
+
   dateChanged();
 }
 
