@@ -85,9 +85,9 @@ int RecurBase::frequency()
   return mFrequencyEdit->value();
 }
 
-QComboBox *RecurBase::createWeekCountCombo( QWidget *parent )
+KComboBox *RecurBase::createWeekCountCombo( QWidget *parent )
 {
-  QComboBox *combo = new QComboBox( parent );
+  KComboBox *combo = new KComboBox( parent );
   if ( !combo ) return 0;
   combo->setWhatsThis(
                    i18n("The number of the week from the beginning "
@@ -106,9 +106,9 @@ QComboBox *RecurBase::createWeekCountCombo( QWidget *parent )
   return combo;
 }
 
-QComboBox *RecurBase::createWeekdayCombo( QWidget *parent )
+KComboBox *RecurBase::createWeekdayCombo( QWidget *parent )
 {
-  QComboBox *combo = new QComboBox( parent );
+  KComboBox *combo = new KComboBox( parent );
   if ( !combo ) return 0;
   combo->setWhatsThis(
                    i18n("The weekday on which this event or to-do "
@@ -120,9 +120,9 @@ QComboBox *RecurBase::createWeekdayCombo( QWidget *parent )
   return combo;
 }
 
-QComboBox *RecurBase::createMonthNameCombo( QWidget *parent )
+KComboBox *RecurBase::createMonthNameCombo( QWidget *parent )
 {
-  QComboBox *combo = new QComboBox( parent );
+  KComboBox *combo = new KComboBox( parent );
   combo->setWhatsThis(
                    i18n("The month during which this event or to-do "
                         "should recur.") );
@@ -257,7 +257,7 @@ RecurMonthly::RecurMonthly( QWidget *parent ) : RecurBase( parent )
 
   QString whatsThis = i18n("The day of the month on which this event or to-do "
                            "should recur.");
-  mByDayCombo = new QComboBox( buttonGroup );
+  mByDayCombo = new KComboBox( buttonGroup );
   mByDayCombo->setWhatsThis( whatsThis );
   mByDayCombo->setMaxVisibleItems( 7 );
   mByDayCombo->addItem( i18n("1st") );
@@ -598,7 +598,7 @@ ExceptionsWidget::ExceptionsWidget( QWidget *parent ) : QWidget( parent )
 
   QGridLayout *boxLayout = new QGridLayout( groupBox );
 
-  mExceptionDateEdit = new KDateEdit( groupBox );
+  mExceptionDateEdit = new KPIM::KDateEdit( groupBox );
   mExceptionDateEdit->setWhatsThis(
        i18n("A date that should be considered an exception "
       "to the recurrence rules for this event or to-do.") );
@@ -772,7 +772,7 @@ RecurrenceRangeWidget::RecurrenceRangeWidget( QWidget *parent ) : QWidget( paren
   rangeButtonGroup->addButton( mEndDateButton );
   endDateLayout->addWidget( mEndDateButton );
 
-  mEndDateEdit = new KDateEdit( mRangeGroupBox );
+  mEndDateEdit = new KPIM::KDateEdit( mRangeGroupBox );
   mEndDateEdit->setWhatsThis( i18n("Date after which the event or to-do should stop "
                         "recurring") );
   endDateLayout->addWidget( mEndDateEdit );
@@ -891,7 +891,7 @@ RecurrenceChooser::RecurrenceChooser( QWidget *parent ) : QWidget( parent )
   QBoxLayout *topLayout = new QVBoxLayout( this );
 
   if ( KOPrefs::instance()->mCompactDialogs ) {
-    mTypeCombo = new QComboBox( this );
+    mTypeCombo = new KComboBox( this );
     mTypeCombo->setWhatsThis(
                      i18n("Sets the type of recurrence this event or to-do "
                           "should have.") );
@@ -1099,7 +1099,7 @@ KOEditorRecurrence::~KOEditorRecurrence()
 
 void KOEditorRecurrence::setRecurrenceEnabled( bool enabled )
 {
-//  kDebug(5850) << "KOEditorRecurrence::setRecurrenceEnabled(): " << (enabled ? "on" : "off") << endl;
+//  kDebug(5850) <<"KOEditorRecurrence::setRecurrenceEnabled():" << (enabled ?"on" :"off");
 
   mTimeGroupBox->setEnabled( enabled );
   mRuleBox->setEnabled( enabled );
@@ -1130,7 +1130,7 @@ void KOEditorRecurrence::showCurrentRule( int current )
 
 void KOEditorRecurrence::setDateTimes( const QDateTime &start, const QDateTime &end )
 {
-//  kDebug(5850) << "KOEditorRecurrence::setDateTimes" << endl;
+//  kDebug(5850) <<"KOEditorRecurrence::setDateTimes";
 
   mEventStartDt = start;
   mRecurrenceRange->setDateTimes( start, end );
@@ -1206,10 +1206,10 @@ void KOEditorRecurrence::readIncidence(Incidence *incidence)
   if ( incidence->type() == "Todo" ) {
     Todo *todo = static_cast<Todo *>(incidence);
     setDefaults( todo->dtStart(true).toTimeSpec(timeSpec).dateTime(),
-                 todo->dtDue().toTimeSpec(timeSpec).dateTime(), todo->floats() );
+                 todo->dtDue().toTimeSpec(timeSpec).dateTime(), todo->allDay() );
   } else {
     setDefaults( incidence->dtStart().toTimeSpec(timeSpec).dateTime(),
-                 incidence->dtEnd().toTimeSpec(timeSpec).dateTime(), incidence->floats() );
+                 incidence->dtEnd().toTimeSpec(timeSpec).dateTime(), incidence->allDay() );
   }
 
   uint recurs = incidence->recurrenceType();
