@@ -22,10 +22,15 @@
   without including the source code for Qt in the source distribution.
 */
 #include "komonthview.h"
+
 #include "koprefs.h"
 #include "koglobals.h"
 #include "koeventpopupmenu.h"
 #include "kohelper.h"
+#ifndef KORG_NOPLUGINS
+#include "kocore.h"
+#include "kodecorationlabel.h"
+#endif
 
 #include <kcal/calfilter.h>
 #include <kcal/calendar.h>
@@ -59,6 +64,8 @@
 
 #include "komonthview.moc"
 
+using namespace KOrg;
+
 //--------------------------------------------------------------------------
 
 #ifdef __GNUC__
@@ -202,15 +209,19 @@ MonthViewItem::MonthViewItem( Incidence *incidence, const KDateTime &dt,
   mIncidence = incidence;
   mDateTime = dt;
 
+  mEventPixmap     = KOGlobals::self()->smallIcon("event");
   mTodoPixmap      = KOGlobals::self()->smallIcon("todo");
   mTodoDonePixmap  = KOGlobals::self()->smallIcon("checkedbox");
+  mJournalPixmap   = KOGlobals::self()->smallIcon("journal");
   mAlarmPixmap     = KOGlobals::self()->smallIcon("bell");
   mRecurPixmap     = KOGlobals::self()->smallIcon("recur");
   mReplyPixmap     = KOGlobals::self()->smallIcon("mail-reply-sender");
 
   mResourceColor = QColor();
+  mEvent     = false;
   mTodo      = false;
   mTodoDone  = false;
+  mJournal   = false;
   mRecur     = false;
   mAlarm     = false;
   mReply     = false;
@@ -234,13 +245,17 @@ void MonthViewItem::paint( QPainter *p )
     p->eraseRect( offset, offset, listBox()->maxItemWidth()-2*offset, height( listBox() )-2*offset );
   }
   int x = 3;
+  if ( mEvent ) {
+    p->drawPixmap( x, 0, mEventPixmap );
+    x += mEventPixmap.width() + 2;
+  }
   if ( mTodo ) {
     p->drawPixmap( x, 0, mTodoPixmap );
     x += mTodoPixmap.width() + 2;
   }
   if ( mTodoDone ) {
     p->drawPixmap( x, 0, mTodoDonePixmap );
-    x += mTodoPixmap.width() + 2;
+    x += mTodoDonePixmap.width() + 2;
   }
   if ( mRecur ) {
     p->drawPixmap( x, 0, mRecurPixmap );
@@ -341,7 +356,7 @@ MonthViewCell::MonthViewCell( KOMonthView *parent)
 
 void MonthViewCell::setDate( const QDate &date )
 {
-//  kDebug(5850) << "MonthViewCell::setDate(): " << date.toString() << endl;
+//  kDebug(5850) <<"MonthViewCell::setDate():" << date.toString();
 
   mDate = date;
 
@@ -470,7 +485,7 @@ class MonthViewCell::CreateItemVisitor :
       KDateTime::Spec timeSpec = KOPrefs::instance()->timeSpec();
       KDateTime dt( mDate, timeSpec );
       // take the time 0:00 into account, which is non-inclusive
-      QDate dtEnd = event->dtEnd().toTimeSpec( timeSpec ).addSecs( event->floats() ? 0 : -1).date();
+      QDate dtEnd = event->dtEnd().toTimeSpec( timeSpec ).addSecs( event->allDay() ? 0 : -1).date();
       KDateTime dtStart = event->dtStart().toTimeSpec( timeSpec );
       int length = dtStart.date().daysTo( dtEnd );
       if ( event->isMultiDay() ) {
@@ -488,7 +503,7 @@ class MonthViewCell::CreateItemVisitor :
           text = "----------------";
         }
       } else {
-        if (event->floats())
+        if (event->allDay())
           text = event->summary();
         else {
 	  QTime startTime = event->dtStart().toTimeSpec( timeSpec ).time();
@@ -511,6 +526,7 @@ class MonthViewCell::CreateItemVisitor :
       } else {
         mItem->setPalette( mStandardPalette );
       }
+      mItem->setEvent( true );
 
       Attendee *me = event->attendeeByMails( KOPrefs::instance()->allEmails() );
       if ( me != 0 ) {
@@ -524,7 +540,7 @@ class MonthViewCell::CreateItemVisitor :
       if ( !KOPrefs::instance()->showAllDayTodo() )
         return false;
       KDateTime dt( mDate, KOPrefs::instance()->timeSpec() );
-      if ( todo->hasDueDate() && !todo->floats() ) {
+      if ( todo->hasDueDate() && !todo->allDay() ) {
         QTime dueTime = todo->dtDue().toTimeSpec( KOPrefs::instance()->timeSpec() ).time();
         text += KGlobal::locale()->formatTime( dueTime );
         text += ' ';
@@ -746,14 +762,16 @@ KOMonthView::KOMonthView( Calendar *calendar, QWidget *parent )
   QFont mfont = bfont;
   mfont.setPointSize( 20 );
 
-  // month name on top
-  mLabel = new QLabel( this );
+  // Top box with month name and decorations
+  mTopBox = new KHBox( this );
+  mLabel = new QLabel( mTopBox );
   mLabel->setFont( mfont );
   mLabel->setAlignment( Qt::AlignCenter );
   mLabel->setLineWidth( 0 );
   mLabel->setFrameStyle( QFrame::Plain );
+  mDecorationsFrame = 0;
 
-  dayLayout->addWidget( mLabel, 0, 0, 1, mDaysPerWeek );
+  dayLayout->addWidget( mTopBox, 0, 0, 1, mDaysPerWeek );
 
   // create the day of the week labels (Sun, Mon, etc) and add them to
   // the layout.
@@ -872,7 +890,7 @@ void KOMonthView::updateConfig()
 
 void KOMonthView::updateDayLabels()
 {
-  kDebug(5850) << "KOMonthView::updateDayLabels()" << endl;
+  kDebug(5850) <<"KOMonthView::updateDayLabels()";
 
   const KCalendarSystem*calsys=KOGlobals::self()->calendarSystem();
   int currDay;
@@ -889,7 +907,7 @@ void KOMonthView::updateDayLabels()
 
 void KOMonthView::showDates( const QDate &start, const QDate & )
 {
-//  kDebug(5850) << "KOMonthView::showDates(): " << start.toString() << endl;
+//  kDebug(5850) <<"KOMonthView::showDates():" << start.toString();
 
   const KCalendarSystem *calSys = KOGlobals::self()->calendarSystem();
 
@@ -905,6 +923,35 @@ void KOMonthView::showDates( const QDate &start, const QDate & )
                      calSys->monthName( start ) ,
                      calSys->year( start ) ) );
 
+  delete mDecorationsFrame;
+  mDecorationsFrame = new QFrame( mTopBox );
+  mDecorationsFrame->setLineWidth( 0 );
+  mDecorationsFrame->setFrameStyle( QFrame::NoFrame | QFrame::Plain );
+#ifndef KORG_NOPLUGINS
+  // Month decoration labels
+  foreach ( QString decoName, KOPrefs::instance()->decorationsAtMonthViewTop() ) {
+    if ( KOPrefs::instance()->selectedPlugins().contains( decoName ) ) {
+      CalendarDecoration::Decoration* deco
+          = KOCore::self()->loadCalendarDecoration( decoName );
+
+      CalendarDecoration::Element::List elements;
+      elements = deco->monthElements( start );
+      if ( elements.count() > 0 ) {
+        KHBox *decoHBox = new KHBox( mDecorationsFrame );
+        decoHBox->setFrameShape( QFrame::StyledPanel );
+        decoHBox->setMinimumWidth( 1 );
+
+        foreach ( CalendarDecoration::Element* it, elements ) {
+          kDebug() << "adding Element " << it->id() << " of Decoration "
+                   << deco->info() << " to the top of the month view";
+          KODecorationLabel *label = new KODecorationLabel( it, decoHBox );
+          label->setAlignment( Qt::AlignBottom );
+        }
+      }
+    }
+  }
+#endif
+
   bool primary = false;
   int i;
   for( i = 0; i < mCells.size(); ++i ) {
@@ -934,7 +981,7 @@ void KOMonthView::showDates( const QDate &start, const QDate & )
 
 void KOMonthView::showIncidences( const Incidence::List & )
 {
-  kDebug(5850) << "KOMonthView::showIncidences( const Incidence::List & ) is not implemented yet." << endl;
+  kDebug(5850) <<"KOMonthView::showIncidences( const Incidence::List & ) is not implemented yet.";
 }
 
 class KOMonthView::GetDateVisitor : public IncidenceBase::Visitor
@@ -980,19 +1027,18 @@ void KOMonthView::changeIncidenceDisplayAdded( Incidence *incidence )
   GetDateVisitor gdv;
 
   if ( !gdv.act( incidence ) ) {
-    kDebug(5850) << "Visiting GetDateVisitor failed." << endl;
+    kDebug(5850) <<"Visiting GetDateVisitor failed.";
     return;
   }
 
-  bool floats = incidence->floats();
+  bool allDay = incidence->allDay();
 
   KDateTime::Spec timeSpec = KOPrefs::instance()->timeSpec();
   if ( incidence->recurs() ) {
     for ( int i = 0; i < mCells.count(); ++i ) {
       if ( incidence->recursOn( mCells[i]->date(), timeSpec ) ) {
-
         // handle multiday events
-        int length = gdv.startDate().date().daysTo( gdv.endDate().addSecs( floats ? 0 : -1 ).date() );
+        int length = gdv.startDate().date().daysTo( gdv.endDate().addSecs( allDay ? 0 : -1 ).date() );
         for ( int j = 0; j <= length && i+j < mCells.count(); ++j ) {
           mCells[i+j]->addIncidence( incidence, j );
         }
@@ -1001,8 +1047,8 @@ void KOMonthView::changeIncidenceDisplayAdded( Incidence *incidence )
   } else {
     // addSecs(-1) is added to handle 0:00 cases (because it's non-inclusive according to rfc)
     if ( gdv.endDate().isValid() ) {
-      QDate endDate = gdv.endDate().addSecs( floats ? 0 : -1).date();
-      for ( QDate date = gdv.startDate().date();
+      QDate endDate = gdv.endDate().toTimeSpec( KOPrefs::instance()->timeSpec() ).addSecs( allDay ? 0 : -1).date();
+      for ( QDate date = gdv.startDate().toTimeSpec( KOPrefs::instance()->timeSpec() ).date();
             date <= endDate; date = date.addDays( 1 ) ) {
         MonthViewCell *mvc = mDateToCell[ date ];
         if ( mvc ) mvc->addIncidence( incidence );
@@ -1043,7 +1089,6 @@ void KOMonthView::updateView()
   for ( it = incidences.begin(); it != incidences.end(); ++it )
     changeIncidenceDisplayAdded( *it );
 
-/* TODO: Add code for the loading of the decorations around here? */
   processSelectionChange();
 }
 
