@@ -29,6 +29,7 @@
 #include "calprintdefaultplugins.h"
 
 #include <libkdepim/kdateedit.h>
+#include <libkdepim/kpimprefs.h>
 
 #include <kcal/todo.h>
 #include <kcal/calendar.h>
@@ -69,7 +70,7 @@ QWidget *CalPrintIncidence::createConfigWidget( QWidget *w )
 void CalPrintIncidence::readSettingsWidget()
 {
   CalPrintIncidenceConfig *cfg =
-      dynamic_cast<CalPrintIncidenceConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintIncidenceConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     mUseColors = cfg->mColors->isChecked();
     mShowOptions = cfg->mShowDetails->isChecked();
@@ -82,7 +83,7 @@ void CalPrintIncidence::readSettingsWidget()
 void CalPrintIncidence::setSettingsWidget()
 {
   CalPrintIncidenceConfig *cfg =
-      dynamic_cast<CalPrintIncidenceConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintIncidenceConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     cfg->mColors->setChecked( mUseColors );
     cfg->mShowDetails->setChecked(mShowOptions);
@@ -95,11 +96,12 @@ void CalPrintIncidence::setSettingsWidget()
 void CalPrintIncidence::loadConfig()
 {
   if ( mConfig ) {
-    mUseColors = mConfig->readEntry( "Use Colors", false );
-    mShowOptions = mConfig->readEntry( "Show Options", false );
-    mShowSubitemsNotes = mConfig->readEntry( "Show Subitems and Notes", false );
-    mShowAttendees = mConfig->readEntry( "Use Attendees", false );
-    mShowAttachments = mConfig->readEntry( "Use Attachments", false );
+    KConfigGroup grp( mConfig, mConfig->group() );
+    mUseColors = grp.readEntry( "Use Colors", false );
+    mShowOptions = grp.readEntry( "Show Options", false );
+    mShowSubitemsNotes = grp.readEntry( "Show Subitems and Notes", false );
+    mShowAttendees = grp.readEntry( "Use Attendees", false );
+    mShowAttachments = grp.readEntry( "Use Attachments", false );
   }
   setSettingsWidget();
 }
@@ -108,11 +110,12 @@ void CalPrintIncidence::saveConfig()
 {
   readSettingsWidget();
   if ( mConfig ) {
-    mConfig->writeEntry( "Use Colors", mUseColors );
-    mConfig->writeEntry( "Show Options", mShowOptions );
-    mConfig->writeEntry( "Show Subitems and Notes", mShowSubitemsNotes );
-    mConfig->writeEntry( "Use Attendees", mShowAttendees );
-    mConfig->writeEntry( "Use Attachments", mShowAttachments );
+    KConfigGroup grp( mConfig, mConfig->group() );
+    grp.writeEntry( "Use Colors", mUseColors );
+    grp.writeEntry( "Show Options", mShowOptions );
+    grp.writeEntry( "Show Subitems and Notes", mShowSubitemsNotes );
+    grp.writeEntry( "Use Attendees", mShowAttendees );
+    grp.writeEntry( "Use Attachments", mShowAttachments );
   }
 }
 
@@ -134,7 +137,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
       if ( event->dtStart().isValid() ) {
         mStartCaption =  i18n("Start date: ");
         // Show date/time or only date, depending on whether it's an all-day event
-        mStartString = (event->floats()) ? (event->dtStartDateStr(false)) : (event->dtStartStr(false));
+        mStartString = (event->allDay()) ? (event->dtStartDateStr(false)) : (event->dtStartStr(false));
       } else {
         mStartCaption = i18n("No start date");
         mStartString.clear();
@@ -142,7 +145,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
 
       if ( event->hasEndDate() ) {
         mEndCaption = i18n("End date: ");
-        mEndString = (event->floats()) ? (event->dtEndDateStr(false)) : (event->dtEndStr(false));
+        mEndString = (event->allDay()) ? (event->dtEndDateStr(false)) : (event->dtEndStr(false));
       } else if ( event->hasDuration() ) {
         mEndCaption = i18n("Duration: ");
         int mins = event->duration().asSeconds() / 60;
@@ -162,7 +165,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
       if ( todo->hasStartDate() ) {
         mStartCaption =  i18n("Start date: ");
         // Show date/time or only date, depending on whether it's an all-day event
-        mStartString = (todo->floats()) ? (todo->dtStartDateStr(false)) : (todo->dtStartStr(false));
+        mStartString = (todo->allDay()) ? (todo->dtStartDateStr(false)) : (todo->dtStartStr(false));
       } else {
         mStartCaption = i18n("No start date");
         mStartString.clear();
@@ -170,7 +173,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
 
       if ( todo->hasDueDate() ) {
         mEndCaption = i18n("Due date: ");
-        mEndString = (todo->floats()) ? (todo->dtDueDateStr(false)) : (todo->dtDueStr(false));
+        mEndString = (todo->allDay()) ? (todo->dtDueDateStr(false)) : (todo->dtDueStr(false));
       } else {
         mEndCaption = i18n("No due date");
         mEndString.clear();
@@ -179,7 +182,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
     }
     bool visit( Journal *journal ) {
       mStartCaption = i18n("Start date: ");
-      mStartString = (journal->floats()) ? (journal->dtStartDateStr(false)) : (journal->dtStartStr(false));
+      mStartString = (journal->allDay()) ? (journal->dtStartDateStr(false)) : (journal->dtStartStr(false));
       mEndCaption.clear();
       mEndString.clear();
       return true;
@@ -492,7 +495,7 @@ QWidget *CalPrintDay::createConfigWidget( QWidget *w )
 void CalPrintDay::readSettingsWidget()
 {
   CalPrintDayConfig *cfg =
-      dynamic_cast<CalPrintDayConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintDayConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     mFromDate = cfg->mFromDate->date();
     mToDate = cfg->mToDate->date();
@@ -509,7 +512,7 @@ void CalPrintDay::readSettingsWidget()
 void CalPrintDay::setSettingsWidget()
 {
   CalPrintDayConfig *cfg =
-      dynamic_cast<CalPrintDayConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintDayConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     cfg->mFromDate->setDate( mFromDate );
     cfg->mToDate->setDate( mToDate );
@@ -526,14 +529,15 @@ void CalPrintDay::setSettingsWidget()
 void CalPrintDay::loadConfig()
 {
   if ( mConfig ) {
+    KConfigGroup grp( mConfig, mConfig->group() );
     QDate dt;
     QTime tm1( dayStart() );
     QDateTime startTm( dt, tm1 );
     QDateTime endTm( dt, tm1.addSecs( 12 * 60 * 60 ) );
-    mStartTime = mConfig->readEntry( "Start time", startTm ).time();
-    mEndTime = mConfig->readEntry( "End time", endTm ).time();
-    mIncludeTodos = mConfig->readEntry( "Include todos", false );
-    mIncludeAllEvents = mConfig->readEntry( "Include all events", false );
+    mStartTime = grp.readEntry( "Start time", startTm ).time();
+    mEndTime = grp.readEntry( "End time", endTm ).time();
+    mIncludeTodos = grp.readEntry( "Include todos", false );
+    mIncludeAllEvents = grp.readEntry( "Include all events", false );
   }
   setSettingsWidget();
 }
@@ -542,10 +546,11 @@ void CalPrintDay::saveConfig()
 {
   readSettingsWidget();
   if ( mConfig ) {
-    mConfig->writeEntry( "Start time", QDateTime( QDate(), mStartTime ) );
-    mConfig->writeEntry( "End time", QDateTime( QDate(), mEndTime ) );
-    mConfig->writeEntry( "Include todos", mIncludeTodos );
-    mConfig->writeEntry( "Include all events", mIncludeAllEvents );
+    KConfigGroup grp( mConfig, mConfig->group() );
+    grp.writeEntry( "Start time", QDateTime( QDate(), mStartTime ) );
+    grp.writeEntry( "End time", QDateTime( QDate(), mEndTime ) );
+    grp.writeEntry( "Include todos", mIncludeTodos );
+    grp.writeEntry( "Include all events", mIncludeAllEvents );
   }
 }
 
@@ -553,7 +558,7 @@ void CalPrintDay::setDateRange( const QDate& from, const QDate& to )
 {
   CalPrintPluginBase::setDateRange( from, to );
   CalPrintDayConfig *cfg =
-      dynamic_cast<CalPrintDayConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintDayConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     cfg->mFromDate->setDate( from );
     cfg->mToDate->setDate( to );
@@ -564,6 +569,7 @@ void CalPrintDay::print( QPainter &p, int width, int height )
 {
   QDate curDay( mFromDate );
 
+  KDateTime::Spec timeSpec = KPIM::KPimPrefs::timeSpec();
   do {
     QTime curStartTime( mStartTime );
     QTime curEndTime( mEndTime );
@@ -580,7 +586,7 @@ void CalPrintDay::print( QPainter &p, int width, int height )
 
 
     drawHeader( p, local->formatDate( curDay ), curDay, QDate(), headerBox );
-    Event::List eventList = mCalendar->events( curDay,
+    Event::List eventList = mCalendar->events( curDay, timeSpec,
                                                EventSortStartDate,
                                                SortDirectionAscending );
 
@@ -629,7 +635,7 @@ QWidget *CalPrintWeek::createConfigWidget( QWidget *w )
 void CalPrintWeek::readSettingsWidget()
 {
   CalPrintWeekConfig *cfg =
-      dynamic_cast<CalPrintWeekConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintWeekConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     mFromDate = cfg->mFromDate->date();
     mToDate = cfg->mToDate->date();
@@ -655,7 +661,7 @@ void CalPrintWeek::readSettingsWidget()
 void CalPrintWeek::setSettingsWidget()
 {
   CalPrintWeekConfig *cfg =
-      dynamic_cast<CalPrintWeekConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintWeekConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     cfg->mFromDate->setDate( mFromDate );
     cfg->mToDate->setDate( mToDate );
@@ -675,14 +681,15 @@ void CalPrintWeek::setSettingsWidget()
 void CalPrintWeek::loadConfig()
 {
   if ( mConfig ) {
+    KConfigGroup grp( mConfig, mConfig->group() );
     QDate dt;
     QTime tm1( dayStart() );
     QDateTime startTm( dt, tm1  );
     QDateTime endTm( dt, tm1.addSecs( 43200 ) );
-    mStartTime = mConfig->readEntry( "Start time", startTm ).time();
-    mEndTime = mConfig->readEntry( "End time", endTm ).time();
-    mIncludeTodos = mConfig->readEntry( "Include todos", false );
-    mWeekPrintType =(eWeekPrintType)( mConfig->readEntry( "Print type", (int)Filofax ) );
+    mStartTime = grp.readEntry( "Start time", startTm ).time();
+    mEndTime = grp.readEntry( "End time", endTm ).time();
+    mIncludeTodos = grp.readEntry( "Include todos", false );
+    mWeekPrintType =(eWeekPrintType)( grp.readEntry( "Print type", (int)Filofax ) );
   }
   setSettingsWidget();
 }
@@ -691,10 +698,11 @@ void CalPrintWeek::saveConfig()
 {
   readSettingsWidget();
   if ( mConfig ) {
-    mConfig->writeEntry( "Start time", QDateTime( QDate(), mStartTime ) );
-    mConfig->writeEntry( "End time", QDateTime( QDate(), mEndTime ) );
-    mConfig->writeEntry( "Include todos", mIncludeTodos );
-    mConfig->writeEntry( "Print type", int( mWeekPrintType ) );
+    KConfigGroup grp( mConfig, mConfig->group() );
+    grp.writeEntry( "Start time", QDateTime( QDate(), mStartTime ) );
+    grp.writeEntry( "End time", QDateTime( QDate(), mEndTime ) );
+    grp.writeEntry( "Include todos", mIncludeTodos );
+    grp.writeEntry( "Print type", int( mWeekPrintType ) );
   }
 }
 
@@ -709,7 +717,7 @@ void CalPrintWeek::setDateRange( const QDate &from, const QDate &to )
 {
   CalPrintPluginBase::setDateRange( from, to );
   CalPrintWeekConfig *cfg =
-      dynamic_cast<CalPrintWeekConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintWeekConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     cfg->mFromDate->setDate( from );
     cfg->mToDate->setDate( to );
@@ -828,7 +836,7 @@ QWidget *CalPrintMonth::createConfigWidget( QWidget *w )
 void CalPrintMonth::readSettingsWidget()
 {
   CalPrintMonthConfig *cfg =
-      dynamic_cast<CalPrintMonthConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintMonthConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     mFromDate = QDate( cfg->mFromYear->value(), cfg->mFromMonth->currentItem()+1, 1 );
     mToDate = QDate( cfg->mToYear->value(), cfg->mToMonth->currentItem()+1, 1 );
@@ -844,7 +852,7 @@ void CalPrintMonth::readSettingsWidget()
 void CalPrintMonth::setSettingsWidget()
 {
   CalPrintMonthConfig *cfg =
-      dynamic_cast<CalPrintMonthConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintMonthConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     setDateRange( mFromDate, mToDate );
 
@@ -859,10 +867,11 @@ void CalPrintMonth::setSettingsWidget()
 void CalPrintMonth::loadConfig()
 {
   if ( mConfig ) {
-    mWeekNumbers = mConfig->readEntry( "Print week numbers", true );
-    mRecurDaily = mConfig->readEntry( "Print daily incidences", true );
-    mRecurWeekly = mConfig->readEntry( "Print weekly incidences", true );
-    mIncludeTodos = mConfig->readEntry( "Include todos", false );
+    KConfigGroup grp( mConfig, mConfig->group() );
+    mWeekNumbers = grp.readEntry( "Print week numbers", true );
+    mRecurDaily = grp.readEntry( "Print daily incidences", true );
+    mRecurWeekly = grp.readEntry( "Print weekly incidences", true );
+    mIncludeTodos = grp.readEntry( "Include todos", false );
   }
   setSettingsWidget();
 }
@@ -871,10 +880,11 @@ void CalPrintMonth::saveConfig()
 {
   readSettingsWidget();
   if ( mConfig ) {
-    mConfig->writeEntry( "Print week numbers", mWeekNumbers );
-    mConfig->writeEntry( "Print daily incidences", mRecurDaily );
-    mConfig->writeEntry( "Print weekly incidences", mRecurWeekly );
-    mConfig->writeEntry( "Include todos", mIncludeTodos );
+    KConfigGroup grp( mConfig, mConfig->group() );
+    grp.writeEntry( "Print week numbers", mWeekNumbers );
+    grp.writeEntry( "Print daily incidences", mRecurDaily );
+    grp.writeEntry( "Print weekly incidences", mRecurWeekly );
+    grp.writeEntry( "Include todos", mIncludeTodos );
   }
 }
 
@@ -882,7 +892,7 @@ void CalPrintMonth::setDateRange( const QDate &from, const QDate &to )
 {
   CalPrintPluginBase::setDateRange( from, to );
   CalPrintMonthConfig *cfg =
-      dynamic_cast<CalPrintMonthConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintMonthConfig *>( ( QWidget* )mConfigWidget );
   const KCalendarSystem *calSys = calendarSystem();
   if ( cfg && calSys ) {
     cfg->mFromMonth->clear();
@@ -960,7 +970,7 @@ QWidget *CalPrintTodos::createConfigWidget( QWidget *w )
 void CalPrintTodos::readSettingsWidget()
 {
   CalPrintTodoConfig *cfg =
-      dynamic_cast<CalPrintTodoConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintTodoConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     mPageTitle = cfg->mTitle->text();
 
@@ -992,7 +1002,7 @@ void CalPrintTodos::readSettingsWidget()
 void CalPrintTodos::setSettingsWidget()
 {
   CalPrintTodoConfig *cfg =
-      dynamic_cast<CalPrintTodoConfig *>( mConfigWidget );
+      dynamic_cast<CalPrintTodoConfig *>( ( QWidget* )mConfigWidget );
   if ( cfg ) {
     cfg->mTitle->setText( mPageTitle );
 
@@ -1032,16 +1042,17 @@ void CalPrintTodos::setSettingsWidget()
 void CalPrintTodos::loadConfig()
 {
   if ( mConfig ) {
-    mPageTitle = mConfig->readEntry( "Page title", i18n("To-do list") );
-    mTodoPrintType = (eTodoPrintType)mConfig->readEntry( "Print type", (int)TodosAll );
-    mIncludeDescription = mConfig->readEntry( "Include description", true );
-    mIncludePriority = mConfig->readEntry( "Include priority", true );
-    mIncludeDueDate = mConfig->readEntry( "Include due date", true );
-    mIncludePercentComplete = mConfig->readEntry( "Include percentage completed", true );
-    mConnectSubTodos = mConfig->readEntry( "Connect subtodos", true );
-    mStrikeOutCompleted = mConfig->readEntry( "Strike out completed summaries",  true );
-    mTodoSortField = (eTodoSortField)mConfig->readEntry( "Sort field", (int)TodoFieldSummary );
-    mTodoSortDirection = (eTodoSortDirection)mConfig->readEntry( "Sort direction", (int)TodoDirectionAscending );
+    KConfigGroup grp( mConfig, mConfig->group() );
+    mPageTitle = grp.readEntry( "Page title", i18n("To-do list") );
+    mTodoPrintType = (eTodoPrintType)grp.readEntry( "Print type", (int)TodosAll );
+    mIncludeDescription = grp.readEntry( "Include description", true );
+    mIncludePriority = grp.readEntry( "Include priority", true );
+    mIncludeDueDate = grp.readEntry( "Include due date", true );
+    mIncludePercentComplete = grp.readEntry( "Include percentage completed", true );
+    mConnectSubTodos = grp.readEntry( "Connect subtodos", true );
+    mStrikeOutCompleted = grp.readEntry( "Strike out completed summaries",  true );
+    mTodoSortField = (eTodoSortField)grp.readEntry( "Sort field", (int)TodoFieldSummary );
+    mTodoSortDirection = (eTodoSortDirection)grp.readEntry( "Sort direction", (int)TodoDirectionAscending );
   }
   setSettingsWidget();
 }
@@ -1050,16 +1061,17 @@ void CalPrintTodos::saveConfig()
 {
   readSettingsWidget();
   if ( mConfig ) {
-    mConfig->writeEntry( "Page title", mPageTitle );
-    mConfig->writeEntry( "Print type", int( mTodoPrintType ) );
-    mConfig->writeEntry( "Include description", mIncludeDescription );
-    mConfig->writeEntry( "Include priority", mIncludePriority );
-    mConfig->writeEntry( "Include due date", mIncludeDueDate );
-    mConfig->writeEntry( "Include percentage completed", mIncludePercentComplete );
-    mConfig->writeEntry( "Connect subtodos", mConnectSubTodos );
-    mConfig->writeEntry( "Strike out completed summaries", mStrikeOutCompleted );
-    mConfig->writeEntry( "Sort field", (int)mTodoSortField );
-    mConfig->writeEntry( "Sort direction", (int)mTodoSortDirection );
+    KConfigGroup grp( mConfig, mConfig->group() );
+    grp.writeEntry( "Page title", mPageTitle );
+    grp.writeEntry( "Print type", int( mTodoPrintType ) );
+    grp.writeEntry( "Include description", mIncludeDescription );
+    grp.writeEntry( "Include priority", mIncludePriority );
+    grp.writeEntry( "Include due date", mIncludeDueDate );
+    grp.writeEntry( "Include percentage completed", mIncludePercentComplete );
+    grp.writeEntry( "Connect subtodos", mConnectSubTodos );
+    grp.writeEntry( "Strike out completed summaries", mStrikeOutCompleted );
+    grp.writeEntry( "Sort field", (int)mTodoSortField );
+    grp.writeEntry( "Sort direction", (int)mTodoSortDirection );
   }
 }
 
