@@ -87,12 +87,12 @@ class PrintCellItem : public KOrg::CellItem
       PrintCellItem *other = static_cast<PrintCellItem *>( o );
 
 #if 0
-      kDebug(5850) << "PrintCellItem::overlaps() " << event()->summary()
-                    << " <-> " << other->event()->summary() << endl;
-      kDebug(5850) << "  start     : " << start.toString() << endl;
-      kDebug(5850) << "  end       : " << end.toString() << endl;
-      kDebug(5850) << "  otherStart: " << otherStart.toString() << endl;
-      kDebug(5850) << "  otherEnd  : " << otherEnd.toString() << endl;
+      kDebug(5850) <<"PrintCellItem::overlaps()" << event()->summary()
+                    << "<->" << other->event()->summary();
+      kDebug(5850) <<"  start     :" << start.toString();
+      kDebug(5850) <<"  end       :" << end.toString();
+      kDebug(5850) <<"  otherStart:" << otherStart.toString();
+      kDebug(5850) <<"  otherEnd  :" << otherEnd.toString();
 #endif
 
       return !( other->start() >= end() || other->end() <= start() );
@@ -186,7 +186,7 @@ void CalPrintPluginBase::doLoadConfig()
     setUseColors( mUseColors );
     loadConfig();
   } else {
-    kDebug(5850) << "No config available in loadConfig!!!!" << endl;
+    kDebug(5850) <<"No config available in loadConfig!!!!";
   }
 }
 
@@ -200,7 +200,7 @@ void CalPrintPluginBase::doSaveConfig()
     group.writeEntry( "UseColors", mUseColors );
     mConfig->sync();
   } else {
-    kDebug(5850) << "No config available in saveConfig!!!!" << endl;
+    kDebug(5850) <<"No config available in saveConfig!!!!";
   }
 }
 
@@ -275,13 +275,13 @@ Event *CalPrintPluginBase::holiday( const QDate &dt )
   QString hstring( holidayString( dt ) );
   if ( !hstring.isEmpty() ) {
     //FIXME: KOPrefs::instance()->timeSpec()?
-    KDateTime::Spec timeSpec = KPimPrefs::timeSpec();
+    KDateTime::Spec timeSpec = KPIM::KPimPrefs::timeSpec();
     KDateTime kdt( dt, QTime(), timeSpec );
     Event*holiday=new Event();
     holiday->setSummary( hstring );
     holiday->setDtStart( kdt );
     holiday->setDtEnd( kdt );
-    holiday->setFloats( true );
+    holiday->setAllDay( true );
     holiday->setCategories( i18n("Holiday") );
     return holiday;
   }
@@ -717,12 +717,12 @@ int CalPrintPluginBase::drawAllDayBox(QPainter &p, Event::List &eventList,
 
   it = eventList.begin();
   Event *currEvent = 0;
-  // First, print all floating events
+  // First, print the all-day events
   while( it!=eventList.end() ) {
     currEvent=*it;
     itold=it;
     ++it;
-    if ( currEvent && currEvent->floats() ) {
+    if ( currEvent && currEvent->allDay() ) {
       // set the colors according to the categories
       if ( expandable ) {
         QRect eventBox( box );
@@ -917,7 +917,7 @@ void CalPrintPluginBase::drawDayBox( QPainter &p, const QDate &qd,
   p.setFont(QFont("sans-serif", 10, QFont::Bold));
   p.drawText( headerTextBox, Qt::AlignRight | Qt::AlignVCenter, dayNumStr);
 
-  Event::List eventList = mCalendar->events( qd,
+  Event::List eventList = mCalendar->events( qd, KPIM::KPimPrefs::timeSpec(),
                                              EventSortStartDate,
                                              SortDirectionAscending );
   QString text;
@@ -931,7 +931,7 @@ void CalPrintPluginBase::drawDayBox( QPainter &p, const QDate &qd,
     if ( ( !printRecurDaily  && currEvent->recurrenceType() == Recurrence::rDaily  ) ||
          ( !printRecurWeekly && currEvent->recurrenceType() == Recurrence::rWeekly ) ) {
       continue; }
-    if ( currEvent->floats() || currEvent->isMultiDay() )
+    if ( currEvent->allDay() || currEvent->isMultiDay() )
       text = "";
     else
       text = local->formatTime( currEvent->dtStart().time() );
@@ -947,7 +947,7 @@ void CalPrintPluginBase::drawDayBox( QPainter &p, const QDate &qd,
       if ( ( !printRecurDaily  && todo->recurrenceType() == Recurrence::rDaily  ) ||
            ( !printRecurWeekly && todo->recurrenceType() == Recurrence::rWeekly ) )
         continue;
-      if ( todo->hasDueDate() && !todo->floats() )
+      if ( todo->hasDueDate() && !todo->allDay() )
         text += KGlobal::locale()->formatTime(todo->dtDue().time()) + ' ';
       else
         text = "";
@@ -961,7 +961,7 @@ void CalPrintPluginBase::drawDayBox( QPainter &p, const QDate &qd,
 // TODO TODO TODO
 void CalPrintPluginBase::drawIncidence( QPainter &p, const QRect &dayBox, const QString &time, const QString &summary, int &textY )
 {
-  kDebug(5850) << "summary = " << summary << endl;
+  kDebug(5850) <<"summary =" << summary;
 
   int flags = Qt::AlignLeft;
   QFontMetrics fm = p.fontMetrics();
@@ -1036,6 +1036,7 @@ void CalPrintPluginBase::drawTimeTable(QPainter &p,
 
   // draw each day
   QDate curDate(fromDate);
+  KDateTime::Spec timeSpec = KPIM::KPimPrefs::timeSpec();
   int i=0;
   double cellWidth = double(dowBox.width()) / double(fromDate.daysTo(toDate)+1);
   while (curDate<=toDate) {
@@ -1044,7 +1045,7 @@ void CalPrintPluginBase::drawTimeTable(QPainter &p,
     QRect dayBox( allDayBox );
     dayBox.setTop( tlBox.top() );
     dayBox.setBottom( box.bottom() );
-    Event::List eventList = mCalendar->events(curDate,
+    Event::List eventList = mCalendar->events(curDate, timeSpec,
                                               EventSortStartDate,
                                               SortDirectionAscending);
     alldayHeight = drawAllDayBox( p, eventList, curDate, false, allDayBox );
@@ -1067,7 +1068,7 @@ class MonthEventStruct
       event = ev;
       start = s;
       end = e;
-      if ( event->floats() ) {
+      if ( event->allDay() ) {
         start = KDateTime( start.date(), QTime(0,0,0) );
         end = KDateTime( end.date().addDays(1), QTime(0,0,0) ).addSecs(-1);
       }
@@ -1161,7 +1162,7 @@ void CalPrintPluginBase::drawMonth( QPainter &p, const QDate &dt, const QRect &b
   QList<MonthEventStruct> monthentries;
 
   //FIXME: KOPrefs::instance()->timeSpec()?
-  KDateTime::Spec timeSpec = KPimPrefs::timeSpec();
+  KDateTime::Spec timeSpec = KPIM::KPimPrefs::timeSpec();
   for ( Event::List::ConstIterator evit = events.begin();
         evit != events.end(); ++evit ) {
     Event *e = (*evit);
