@@ -1,7 +1,7 @@
 /* RecordConduit.cc			KPilot
 **
-** Copyright (C) 2007 by Bertjan Broeksema
-** Copyright (C) 2007 by Jason "vanRijn" Kasper
+** Copyright (C) 2007 by Bertjan Broeksema <b.broeksema@kdemail.net>
+** Copyright (C) 2007 by Jason "vanRijn" Kasper <vr@movingparts.net>
 */
 
 /*
@@ -26,6 +26,12 @@
 */
 
 #include "recordconduit.h"
+
+#include "options.h"
+#include "pilotDatabase.h"
+#include "pilotRecord.h"
+#include "kpilotSettings.h"
+
 #include "idmapping.h"
 #include "cudcounter.h"
 #include "dataproxy.h"
@@ -34,19 +40,17 @@
 #include "hhrecord.h"
 #include "recordconduitSettings.h"
 
-#include "options.h"
-#include "kpilotSettings.h"
-
 #include <KMessageBox>
 
-RecordConduit::RecordConduit( KPilotLink *o, const QStringList &a
+RecordConduit::RecordConduit( KPilotLink *o, const QVariantList &a
 	, const QString &databaseName, const QString &conduitName ) :
-	ConduitAction(o, a),
-	fHHDataProxy(0L),
-	fBackupDataProxy(0L),
-	fPCDataProxy(0L)
+	ConduitAction( o, conduitName.toLatin1(), a ),
+	fDatabaseName( databaseName ),
+	fHHDataProxy( 0L ),
+	fBackupDataProxy( 0L ),
+	fPCDataProxy( 0L )
+	
 {
-	fDatabaseName = databaseName;
 	fConduitName = conduitName;
 }
 
@@ -67,23 +71,21 @@ RecordConduit::~RecordConduit()
 	bool retrieved = false;
 	
 	bool hhDatabaseOpen = openDatabases( fDatabaseName, &retrieved );
-	// If retrieved is true there is no local backup database so a first sync 
-		// should be done then (see 6.3.2).
+	// If retrieved is true there was no local backup database so a first sync 
+	// should be done then (see 6.3.2).
 	bool backupDatabaseOpen = !retrieved;
 	setFirstSync( retrieved );
 	
 	// NOTE: Do not forget that the HHData proxy and the backup proxy must use
-	// the opened databases, maybe we should pass them for clearity to this method.
-	initDataProxies();
-	
-	// Make sure that the implementing class did initialize all proxies.
-	if( !fPCDataProxy || !fHHDataProxy || !fBackupDataProxy )
+	// the opened databases, maybe we should pass them for clarity to this method.
+	if( !initDataProxies() )
 	{
-		DEBUGKPILOT << fname << ": One of the dataproxies was not initialized" << endl;
+		DEBUGKPILOT << "One of the data proxies could not be initialized.";
+		emit logError(i18n("One of the data proxies could not be initialized."));
 		return false;
 	}
 	
-	// For the pc data proxy we can only after initilisation know if it could be
+	// For the pc data proxy we can only after initialization know if it could be
 	// opened.
 	bool pcDatabaseOpen = fPCDataProxy->isOpen();
 	
@@ -91,41 +93,56 @@ RecordConduit::~RecordConduit()
 	fMapping = new IDMapping( KPilotSettings::userName(), fConduitName );
 	if( !fMapping->isValid( fBackupDataProxy->ids() ) )
 	{
+		DEBUGKPILOT << "Invalid record mapping. Doing first sync.";
 		setFirstSync( true );
 	}
 	
 	// Determine syncmode, see 6.3
 	// FIXME: Is this the most efficient way, or is it even possible what i do 
 	//        here?
+	DEBUGKPILOT << "Databases open [hh,pc,bu]: [" << hhDatabaseOpen << "," 
+		<< pcDatabaseOpen << "," << backupDatabaseOpen << "]";
+	
 	if( hhDatabaseOpen && pcDatabaseOpen && backupDatabaseOpen )
 	{
+		DEBUGKPILOT << "All proxies are initialized and open.";
 		// So what are we going to do this time?!
-		switch( syncMode().mode() ) {
-			case SyncMode::eHotSync:
-				hotSync();
-				break;
-			case SyncMode::eFullSync:
-				//FIXME: fullSync();
-				break;
-			case SyncMode::eCopyPCToHH:
-				copyPCToHH();
-				break;
-			case SyncMode::eCopyHHToPC:
-				copyHHToPC();
-				break;
-			// Backup and restore should not happen here, if so default to hotsync.
-			default:
-				hotSync();
-				break;
+		if( isFirstSync() )
+		{
+			firstSync();
+		}
+		else
+		{
+			switch( syncMode().mode() ) {
+				case SyncMode::eHotSync:
+					hotOrFullSync();
+					break;
+				case SyncMode::eFullSync:
+					hotOrFullSync();
+					break;
+				case SyncMode::eCopyPCToHH:
+					copyPCToHH();
+					break;
+				case SyncMode::eCopyHHToPC:
+					copyHHToPC();
+					break;
+				// Backup and restore should not happen here, if so default to hotsync.
+				default:
+					changeSync( SyncMode::eHotSync );
+					hotOrFullSync();
+					break;
+			}
 		}
 	}
 	else if( hhDatabaseOpen && pcDatabaseOpen && !backupDatabaseOpen )
 	{
+		DEBUGKPILOT << "HHDatabase open, PCDatabase open, Backupdatabase closed.";
 		setFirstSync( true ); // 6.3.2
 		firstSync();
 	}
 	else if( hhDatabaseOpen && !pcDatabaseOpen )
 	{
+		DEBUGKPILOT << "Pc database not open, trying to create an empty datastore.";
 		if( fPCDataProxy->createDataStore() )
 		{
 			changeSync( SyncMode::eCopyHHToPC ); // 6.3.3 and 6.3.4
@@ -133,13 +150,15 @@ RecordConduit::~RecordConduit()
 		}
 		else
 		{
-			DEBUGKPILOT << fname << ": Could not open pc data store and was not able"
-			 << " to create a new one." << endl;
+			DEBUGKPILOT << "Could not open or create pc data store.";
+			emit logError(i18n("Could not open or create PC data store."));
 			return false;
 		}
 	}
 	else if( !hhDatabaseOpen && pcDatabaseOpen )
 	{
+		DEBUGKPILOT << "HHDatabase closed, PCDatabase open.";
+		
 		if( fHHDataProxy->createDataStore() )
 		{
 			changeSync( SyncMode::eCopyPCToHH ); // 6.3.5 and 6.3.6
@@ -147,33 +166,42 @@ RecordConduit::~RecordConduit()
 		}
 		else
 		{
-			DEBUGKPILOT << fname << ": Could not open hand held data store and was "
-			 << "not able to create a new one." << endl;
+			DEBUGKPILOT << "Could not open or create hand held data store.";
+			emit logError(i18n("Could not open or create Palm data store."));
 			return false;
 		}
-		
 	}
 	else
 	{
+		DEBUGKPILOT <<  "Failed to open the pc database and the handheld "
+		"database, no data to sync.";
 		emit logError( i18n( "Failed to open the pc database and the handheld "
-			"datbase, no data to sync." ) );
+			"database, no data to sync." ) );
 		return false; // 6.3.7 and 6.3.8
 	}
 	
-	// Sync finished, clean up things.
-	fHHDataProxy->syncFinished();
-	fPCDataProxy->syncFinished();
+	// Sync finished, set the endcount of the CUD counters
+	fHHDataProxy->setEndcount();
+	fPCDataProxy->setEndcount();
+
+	addSyncLogEntry(fHHDataProxy->counter()->moo() +'\n');
+	DEBUGKPILOT << fHHDataProxy->counter();
+	addSyncLogEntry(fPCDataProxy->counter()->moo() +'\n');
+	DEBUGKPILOT << fPCDataProxy->counter();
 	
 	fMapping->setLastSyncedDate( QDateTime::currentDateTime() );
 	if( !fMapping->isValid( fHHDataProxy->ids() ) )
 	{
-		// TODO: Warn the user.
+		DEBUGKPILOT <<  "Data mapping invalid after sync. Sync failed.";
+		emit logError( i18n( "Data mapping invalid after sync. Sync failed." ) );
 		return false;
 	}
 	
 	if( !checkVolatility() )
 	{
 		// volatility bounds are exceeded or the user did not want to proceed.
+		DEBUGKPILOT <<  "Changes are too volatile. Sync failed.";
+		emit logError( i18n( "Changes are too volatile. Sync failed." ) );
 		return false;
 	}
 	
@@ -184,16 +212,19 @@ RecordConduit::~RecordConduit()
 	 */
 	if( !fHHDataProxy->commit() )
 	{
+		DEBUGKPILOT << "Couldn't save Palm changes. Sync failed";
+		emit logError( i18n( "Couldn't save Palm changes Sync failed." ) );
 		fHHDataProxy->rollback();
-		// TODO: notify user.
 		return false;
 	}
 	
 	if( !fPCDataProxy->commit() )
 	{
+		DEBUGKPILOT << "Couldn't save PC changes. Sync failed";
+		emit logError( i18n( "Couldn't save PC changes Sync failed." ) );
+		
 		fPCDataProxy->rollback();
 		fHHDataProxy->rollback();
-		// TODO: notify user.
 		return false;
 	}
 	
@@ -212,27 +243,21 @@ RecordConduit::~RecordConduit()
 		fMapping->changePCId( it.key(), it.value() );
 	}
 	
-	// Now we can commit the mapping.
+	// Now we can commit the mapping.  If this fails but everything else worked,
+	// don't fail everything else.  We'll recreate the id mapping at next sync.
 	if( !fMapping->commit() )
 	{
-		fMapping->rollback();
-		fPCDataProxy->rollback();
-		fHHDataProxy->rollback();
-		return false;
+		DEBUGKPILOT << "Commit of ID mapping failed.";
 	}
 	
-	// If commit fails every commit should be undone and the user should be 
-	// notified about the failure.
-	if( !createBackupDatabase() )
-	{
-		fMapping->rollback();
-		fPCDataProxy->rollback();
-		fHHDataProxy->rollback();
-		// TODO: notify user.
-		return false;
-	}
+	// Clean up things like modified flags.
+	fHHDataProxy->syncFinished();
+	fPCDataProxy->syncFinished();
+
+	// Make sure the backup database is an exact copy of the pilot database.
+	updateBackupDatabase();
 	
-	return true;
+	return delayDone();
 }
 
 bool RecordConduit::checkVolatility()
@@ -242,11 +267,6 @@ bool RecordConduit::checkVolatility()
 	const CUDCounter *fCtrHH = fHHDataProxy->counter();
 	const CUDCounter *fCtrPC = fPCDataProxy->counter();
 
-	addSyncLogEntry(fCtrHH->moo() +'\n',false);
-	DEBUGKPILOT << fname << ": " << fCtrHH->moo() << endl;
-	addSyncLogEntry(fCtrPC->moo() +'\n',false);
-	DEBUGKPILOT << fname << ": " << fCtrPC->moo() << endl;
-
 	// STEP2 of making sure we don't delete our little user's
 	// precious data...
 	// sanity checks for handheld...
@@ -277,8 +297,7 @@ bool RecordConduit::checkVolatility()
 			.subs( fCtrHH->moo() )
 			.toString();
 		
-		DEBUGKPILOT << fname << ": high volatility."
-			<< " Check with user: [" << query << "]." << endl;
+		DEBUGKPILOT << "High volatility." << " Check with user: [" << query << ']';
 		
 		rc = questionYesNo( query, caption, QString(), 0 );
 	}
@@ -291,8 +310,7 @@ bool RecordConduit::checkVolatility()
 			.subs( fCtrPC->moo() )
 			.toString();
 		
-		DEBUGKPILOT << fname << ": high volatility."
-			<< "  Check with user: [" << query << "]." << endl;
+		DEBUGKPILOT << "High volatility." << " Check with user: [" << query << ']';
 		
 		rc = questionYesNo( query, caption, QString(), 0 );
 	}
@@ -307,20 +325,66 @@ bool RecordConduit::checkVolatility()
 	return false;
 }
 
-
-// 4.1
-void RecordConduit::hotSync()
+void RecordConduit::updateBackupDatabase()
 {
 	FUNCTIONSETUP;
 	
-	// A hotsync only does modified records.
-	fHHDataProxy->setIterateMode( DataProxy::Modified );
-	fPCDataProxy->setIterateMode( DataProxy::Modified );
+	int index = 0;
+	PilotRecord *rec = fDatabase->readRecordByIndex( index );
+	QList<recordid_t> addedIds;
+	
+	// Copy all records from the pilot database to the local copy of it.
+	while( rec )
+	{
+		fLocalDatabase->writeRecord( rec );
+		addedIds.append( rec->id() );
+		rec = fDatabase->readRecordByIndex( ++index );
+	}
+	
+	index = 0;
+	rec = fLocalDatabase->readRecordByIndex( index );
+	
+	// Remove all records that are not explicitly added in the previous loop.
+	while( rec )
+	{
+		if( !addedIds.contains( rec->id() ) )
+		{
+			fLocalDatabase->deleteRecord( rec->id() );
+		}
+		
+		rec = fLocalDatabase->readRecordByIndex( ++index );
+	}
+	fLocalDatabase->cleanup();
+	fLocalDatabase->resetSyncFlags();
+}
+
+
+// 4.1 || 5.2
+void RecordConduit::hotOrFullSync()
+{
+	FUNCTIONSETUP;
+	
+	fSyncedPcRecords = new QStringList();
+	
+	if( syncMode().mode() == SyncMode::eHotSync )
+	{
+		// A hotsync only does modified records.
+		DEBUGKPILOT << "Doing HotSync";
+		fHHDataProxy->setIterateMode( DataProxy::Modified );
+		fPCDataProxy->setIterateMode( DataProxy::Modified );
+	}
+	else
+	{
+		DEBUGKPILOT << "Doing FullSync";
+		// Fullsync, all records.
+		fHHDataProxy->setIterateMode( DataProxy::All );
+		fPCDataProxy->setIterateMode( DataProxy::All );
+	}
 	
 	// Walk through all modified hand held records. The proxy is responsible for
 	// serving the right records.
 	
-	DEBUGKPILOT << fname << ": Walking over modified hh records." << endl;
+	DEBUGKPILOT << "Walking over hh records.";
 	
 	fHHDataProxy->resetIterator();
 	while( fHHDataProxy->hasNext() )
@@ -331,36 +395,53 @@ void RecordConduit::hotSync()
 		Record *pcRecord = 0L;
 		
 		QString pcRecordId = fMapping->pcRecordId( hhRecord->id() );
-		if( !pcRecordId.isNull() ) {
+		if( !pcRecordId.isEmpty() ) {
 			// There is a mapping.
 			pcRecord = fPCDataProxy->find( pcRecordId );
 		}
 		
 		syncRecords( pcRecord, backupRecord, hhRecord );
+		
+		// Keep track of the pc records that are in sync. Which is needed to avoid
+		// strange result when iterating over the pc records. Getting the pc id from
+		// the mapping assures that create pc records are taken also.
+		QString pcId = fMapping->pcRecordId( hhRecord->id() );
+		if( !pcId.isEmpty() )
+		{
+			fSyncedPcRecords->append( pcId );
+		}
 	}
 	
 	// Walk through all modified pc records. The proxy is responsible for
 	// serving the right records.
 	
-	DEBUGKPILOT << fname << ": Walking over modified pc records." << endl;
+	DEBUGKPILOT << "Walking over pc records.";
 	
 	fPCDataProxy->resetIterator();
 	while( fPCDataProxy->hasNext() )
 	{
 		Record *pcRecord = fPCDataProxy->next();
-		HHRecord *backupRecord = 0L;
-		HHRecord *hhRecord = 0L;
 		
-		QString hhRecordId = fMapping->hhRecordId( pcRecord->id() );
-		
-		if( !hhRecordId.isNull() ) {
-			// There is a mapping.
-			backupRecord = static_cast<HHRecord*>( fBackupDataProxy->find( hhRecordId ) );
-			hhRecord = static_cast<HHRecord*>( fHHDataProxy->find( hhRecordId ) );
+		// Only sync those records which wheren't touched by the iteration over
+		// hand held records.
+		if( !fSyncedPcRecords->contains( pcRecord->id() ) )
+		{
+			HHRecord *backupRecord = 0L;
+			HHRecord *hhRecord = 0L;
+			
+			QString hhRecordId = fMapping->hhRecordId( pcRecord->id() );
+			
+			if( !hhRecordId.isEmpty() ) {
+				// There is a mapping.
+				backupRecord = static_cast<HHRecord*>( fBackupDataProxy->find( hhRecordId ) );
+				hhRecord = static_cast<HHRecord*>( fHHDataProxy->find( hhRecordId ) );
+			}
+			
+			syncRecords( pcRecord, backupRecord, hhRecord );
 		}
-		
-		syncRecords( pcRecord, backupRecord, hhRecord );
 	}
+	
+	delete fSyncedPcRecords;
 }
 
 // 5.1
@@ -372,7 +453,7 @@ void RecordConduit::firstSync()
 	fHHDataProxy->setIterateMode( DataProxy::All );
 	fPCDataProxy->setIterateMode( DataProxy::All );
 	
-	DEBUGKPILOT << fname << ": Walking over all hh records." << endl;
+	DEBUGKPILOT << "Walking over all hh records.";
 	
 	fHHDataProxy->resetIterator();
 	while( fHHDataProxy->hasNext() )
@@ -384,26 +465,39 @@ void RecordConduit::firstSync()
 		{
 			// TODO: Make this configurable or something, maybe pcRecord should
 			// overide or user should be asked which record should be used. In this
-			// case it might even be usefull to let the user select per field which
+			// case it might even be useful to let the user select per field which
 			// record should be used. For now the handheld record overides.
 			
 			// Overide pcRecord values with hhRecord values.
-			DEBUGKPILOT << fname << ": Match found: " << pcRecord->id() 
-				<< hhRecord->id() << endl;
-			syncFields( pcRecord, hhRecord );
+			//  ( from    , to       );
+			copy( hhRecord, pcRecord );
+			// Both records are in sync so they are no longer modified.
+			hhRecord->synced();
+			pcRecord->synced();
 			
 			fMapping->map( hhRecord->id(), pcRecord->id() );
 		}
 		else
 		{
-			DEBUGKPILOT << fname << ": No match found for: " << hhRecord->id() << endl;
-			Record *pcRecord = newPCRecord( hhRecord );
-			fPCDataProxy->create( pcRecord );
-			fMapping->map( hhRecord->id(), pcRecord->id() );
+			DEBUGKPILOT << "No match found for id: [" << hhRecord->id() << "]";
+			// TODO: need a way to allow the user to configure us to archive deleted
+			if ( hhRecord->isDeleted() )
+			{
+				DEBUGKPILOT << "hhRecord deleted.  Removing.";
+				fHHDataProxy->remove( hhRecord->id() );
+			}
+			else
+			{
+				DEBUGKPILOT << "hhRecord not deleted.  Adding to PC";
+				Record *pcRecord = createPCRecord( hhRecord );
+				fPCDataProxy->create( pcRecord );
+				fMapping->map( hhRecord->id(), pcRecord->id() );
+				
+			}
 		}
 	}
 	
-	DEBUGKPILOT << fname << ": Walking over all pc records." << endl;
+	DEBUGKPILOT << "Walking over all pc records.";
 	
 	fPCDataProxy->resetIterator();
 	while( fPCDataProxy->hasNext() )
@@ -412,7 +506,7 @@ void RecordConduit::firstSync()
 		
 		if( !fMapping->containsPCId( pcRecord->id() ) )
 		{
-			HHRecord *hhRecord = newHHRecord( pcRecord );
+			HHRecord *hhRecord = createHHRecord( pcRecord );
 			fHHDataProxy->create( hhRecord );
 			
 			fMapping->map( hhRecord->id(), pcRecord->id() );
@@ -428,7 +522,8 @@ void RecordConduit::copyHHToPC()
 	fHHDataProxy->setIterateMode( DataProxy::All );
 	fPCDataProxy->setIterateMode( DataProxy::All );
 	
-	DEBUGKPILOT << fname << ": Walking over all hh records." << endl;
+	DEBUGKPILOT << "Walking over all (" << fHHDataProxy->recordCount()
+		<< ") hh records.";
 	
 	// 5.3.4
 	fHHDataProxy->resetIterator();
@@ -442,22 +537,33 @@ void RecordConduit::copyHHToPC()
 		
 		if( fMapping->containsHHId( hhId ) )
 		{
-			DEBUGKPILOT << fname << ": Mapping exists, syncing records." << endl;
+			DEBUGKPILOT << "Mapping exists, syncing records.";
 			backupRecord = static_cast<HHRecord*>( fBackupDataProxy->find( hhId ) );
 			pcRecord = fPCDataProxy->find( fMapping->pcRecordId( hhId ) );
 			syncRecords( pcRecord, backupRecord, hhRecord );
 		}
 		else
 		{
-			DEBUGKPILOT << fname << ": Mapping does not exists, copy hh to pc." << endl;
-			
-			Record *pcRecord = newPCRecord( hhRecord );
-			fPCDataProxy->create( pcRecord );
-			fMapping->map( hhRecord->id(), pcRecord->id() );
+			DEBUGKPILOT << "No match found for id: [" << hhRecord->id() << "]";
+			// TODO: need a way to allow the user to configure us to archive deleted
+			if ( hhRecord->isDeleted() )
+			{
+				DEBUGKPILOT << "hhRecord deleted.  Removing.";
+				fHHDataProxy->remove( hhRecord->id() );
+			}
+			else
+			{
+				DEBUGKPILOT << "hhRecord not deleted.  Adding to PC";
+				Record *pcRecord = createPCRecord( hhRecord );
+				fPCDataProxy->create( pcRecord );
+				fMapping->map( hhRecord->id(), pcRecord->id() );
+				
+			}
 		}
 	}
 	
-	DEBUGKPILOT << fname << ": Walking over all pc records." << endl;
+	DEBUGKPILOT << "Walking over all (" << fPCDataProxy->recordCount() 
+		<< ") pc records.";
 	
 	fPCDataProxy->resetIterator();
 	// 5.3.5
@@ -493,7 +599,7 @@ void RecordConduit::copyPCToHH()
 	fHHDataProxy->setIterateMode( DataProxy::All );
 	fPCDataProxy->setIterateMode( DataProxy::All );
 	
-	DEBUGKPILOT << fname << ": Walking over all pc records." << endl;
+	DEBUGKPILOT << "Walking over all pc records.";
 	
 	// 5.4.4
 	fPCDataProxy->resetIterator();
@@ -507,7 +613,7 @@ void RecordConduit::copyPCToHH()
 		
 		if( fMapping->containsPCId( pcId ) )
 		{
-			DEBUGKPILOT << fname << ": Mapping exists, syncing records." << endl;
+			DEBUGKPILOT << "Mapping exists, syncing records.";
 			
 			QString hhId = fMapping->hhRecordId( pcId );
 			
@@ -517,15 +623,24 @@ void RecordConduit::copyPCToHH()
 		}
 		else
 		{
-			DEBUGKPILOT << fname << ": Mapping does not exists, copy pc to hh." << endl;
-			
-			HHRecord *hhRecord = newHHRecord( pcRecord );
-			fHHDataProxy->create( hhRecord );
-			fMapping->map( hhRecord->id(), pcRecord->id() );
+			DEBUGKPILOT << "No match found for:" << pcRecord->id();
+			// TODO: need a way to allow the user to configure us to archive deleted
+			if ( pcRecord->isDeleted() )
+			{
+				DEBUGKPILOT << "pcRecord deleted.  Removing.";
+				fPCDataProxy->remove( pcRecord->id() );
+			}
+			else
+			{
+				DEBUGKPILOT << "pcRecord not deleted.  Adding to HH";
+				HHRecord *hhRecord = createHHRecord( pcRecord );
+				fHHDataProxy->create( hhRecord );
+				fMapping->map( hhRecord->id(), pcRecord->id() );
+			}
 		}
 	}
 	
-	DEBUGKPILOT << fname << ": Walking over all hh records." << endl;
+	DEBUGKPILOT << "Walking over all hh records.";
 	
 	fHHDataProxy->resetIterator();
 	// 5.4.5
@@ -563,7 +678,7 @@ Record* RecordConduit::findMatch( HHRecord *hhRec )
 	{
 		Record *pcRec = fPCDataProxy->next();
 		
-		if( equal( pcRec, hhRec ) )
+		if( pcRec->equal( hhRec ) )
 		{
 			return pcRec;
 		}
@@ -580,20 +695,20 @@ void RecordConduit::syncRecords( Record *pcRecord, HHRecord *backupRecord,
 	// Two records for which we seem to have a mapping.
 	if( hhRecord && pcRecord )
 	{
-		if( hhRecord->isModified() || isFullSync() )
+		if( hhRecord->isModified() )
 		{
 			if( pcRecord->isModified() )
 			{
 				if( pcRecord->isDeleted() && hhRecord->isDeleted() )
 				{
 					// Case: 6.5.12
-					DEBUGKPILOT << fname << ": Case 6.5.12" << endl;
+					DEBUGKPILOT << "Case 6.5.12";
 					deleteRecords( pcRecord, hhRecord );
 				}
 				else
 				{
 					// Case: 6.5.9, 6.5.10 or 6.5.11
-					DEBUGKPILOT << fname << ": Case 6.5.9, 6.5.10 or 6.5.11" << endl;
+					DEBUGKPILOT << "Case 6.5.9, 6.5.10 or 6.5.11";
 					solveConflict( pcRecord, hhRecord );
 				}
 			}
@@ -602,16 +717,20 @@ void RecordConduit::syncRecords( Record *pcRecord, HHRecord *backupRecord,
 				if( hhRecord->isDeleted() )
 				{
 					// Case 6.5.4
-					DEBUGKPILOT << fname << ": Case 6.5.4" << endl;
+					DEBUGKPILOT << "Case 6.5.4";
 					deleteRecords( pcRecord, hhRecord );
 				}
 				else
 				{
 					// Case 6.5.3 or 6.5.1 (fullSync)
-					DEBUGKPILOT << fname << ": Case 6.5.3 or 6.5.1 (fullSync)" << endl;
+					DEBUGKPILOT << "Case 6.5.3 or 6.5.1 (fullSync)";
 
 					// Keep hhRecord values.
-					syncFields( pcRecord, hhRecord );
+					copy( hhRecord, pcRecord );
+					fPCDataProxy->update( pcRecord->id(), pcRecord );
+					// Both records are in sync so they are no longer modified.
+					hhRecord->synced();
+					pcRecord->synced();
 				}
 			}
 		}
@@ -620,21 +739,54 @@ void RecordConduit::syncRecords( Record *pcRecord, HHRecord *backupRecord,
 			if( pcRecord->isDeleted() )
 			{
 				//  Case: 6.5.7
-				DEBUGKPILOT << fname << ": Case 6.5.7" << endl;
+				DEBUGKPILOT << "Case 6.5.7";
 				deleteRecords( pcRecord, hhRecord );
 			}
 			else
 			{
 				// Case: 6.5.6
-				DEBUGKPILOT << fname << ": Case 6.5.6" << endl;
+				DEBUGKPILOT << "Case 6.5.6";
 				// Keep pc record values.
-				syncFields( pcRecord, hhRecord, false );
+				copy( pcRecord, hhRecord );
+				fHHDataProxy->update( hhRecord->id(), hhRecord );
+				// Both records are in sync so they are no longer modified.
+				hhRecord->synced();
+				pcRecord->synced();
+			}
+		} 
+		else if( isFullSync() )
+		{
+			if( !equal( pcRecord, backupRecord ) )
+			{
+				// Two handheld records.
+				if( !hhRecord->equal( backupRecord ) )
+				{
+					solveConflict( pcRecord, hhRecord );
+				}
+				else
+				{
+					//  ( from    , to       )
+					copy( pcRecord, hhRecord );
+					// Both records are in sync so they are no longer modified.
+					fHHDataProxy->update( hhRecord->id(), hhRecord );
+					hhRecord->synced();
+					pcRecord->synced();
+				}
+			}
+			else if( !hhRecord->equal( backupRecord ) )
+			{
+				//  ( from    , to       )
+				copy( hhRecord, pcRecord );
+				// Both records are in sync so they are no longer modified.
+				fPCDataProxy->update( pcRecord->id(), pcRecord );
+				hhRecord->synced();
+				pcRecord->synced();
 			}
 		}
 		else
 		{
 			// Case: 6.5.1 (hotSync)
-			DEBUGKPILOT << fname << ": Case 6.5.1" << endl;
+			DEBUGKPILOT << "Case 6.5.1";
 		}
 	}
 	else if( hhRecord )
@@ -643,7 +795,7 @@ void RecordConduit::syncRecords( Record *pcRecord, HHRecord *backupRecord,
 		// Warning id is a temporary id. Only after commit we know what id is
 		// assigned to the record. So on commit the proxy should get the mapping
 		// so that it can change the mapping.
-		DEBUGKPILOT << fname << ": Case 6.5.2 and 6.5.8" << endl;
+		DEBUGKPILOT << "Case 6.5.2 and 6.5.8";
 		pcRecord = createPCRecord( hhRecord );
 		QString id = fPCDataProxy->create( pcRecord );
 		fMapping->map( hhRecord->id(), id );
@@ -655,14 +807,14 @@ void RecordConduit::syncRecords( Record *pcRecord, HHRecord *backupRecord,
 	{
 		if( fMapping->containsPCId( pcRecord->id() ) && pcRecord->isDeleted() )
 		{
-			DEBUGKPILOT << fname << ": Case 6.5.17" << endl;
+			DEBUGKPILOT << "Case 6.5.17 - pc:" << pcRecord->id();
 			fMapping->removePCId( pcRecord->id() );
 			fPCDataProxy->remove( pcRecord->id() );
 		}
 		else
 		{
 			// Case: 6.5.5 or 6.5.8
-			DEBUGKPILOT << fname << ": Case 6.5.5 or 6.5.8" << endl;
+			DEBUGKPILOT << "Case 6.5.5 or 6.5.8";
 			hhRecord = createHHRecord( pcRecord );
 			QString id = fHHDataProxy->create( hhRecord );
 			fMapping->map( id, pcRecord->id() );
@@ -673,7 +825,7 @@ void RecordConduit::syncRecords( Record *pcRecord, HHRecord *backupRecord,
 	}
 	else
 	{
-		DEBUGKPILOT << fname << ": This should not happen." << endl;
+		DEBUGKPILOT << "This should not happen.";
 	}
 }
 
@@ -691,41 +843,57 @@ void RecordConduit::syncConflictedRecords( Record *pcRecord, HHRecord *hhRecord
 		else
 		{
 			// Keep pcRecord. The hhRecord is changed so undo that changes.
-			syncFields( pcRecord, hhRecord, false );
+			copy( pcRecord, hhRecord );
+			fHHDataProxy->update( hhRecord->id(), hhRecord );
+			// Both records are in sync so they are no longer modified.
+			hhRecord->synced();
+			pcRecord->synced();
 		}
 	}
 	else
 	{
 		if( hhRecord->isDeleted() )
 		{
-			if( pcRecord->isModified() )
+			if( pcRecord->isModified() && hhRecord->isArchived() )
 			{
-				DEBUGKPILOT << fname << ": Case 6.5.16" << endl;
+				DEBUGKPILOT << "Case 6.5.16";
 				// Keep hhRecordValues.
-				syncFields( pcRecord, hhRecord );
+				copy( hhRecord, pcRecord );
+				fPCDataProxy->update( pcRecord->id(), pcRecord );
+				// Both records are in sync so they are no longer modified.
+				hhRecord->synced();
+				pcRecord->synced();
 			}
-			// else { DEBUGKPILOT << fname << ": Case 6.5.15" << endl; }
+			// else { DEBUGKPILOT << "Case 6.5.15"; }
 			deleteRecords( pcRecord, hhRecord );
 		}
 		else
 		{
 			// Keep hhRecord. The pcRecord is changed so undo that changes.
-			syncFields( pcRecord, hhRecord );
+			copy( hhRecord, pcRecord );
+			fPCDataProxy->update( pcRecord->id(), pcRecord );
+			// Both records are in sync so they are no longer modified.
+			hhRecord->synced();
+			pcRecord->synced();
 		}
 	}
 }
 
 void RecordConduit::deleteRecords( Record *pcRecord, HHRecord *hhRecord )
 {
+	FUNCTIONSETUP;
+	
 	fHHDataProxy->remove( hhRecord->id() );
 	
 	if( !hhRecord->isArchived() )
 	{
+		DEBUGKPILOT << "record not archived:" << hhRecord->id();
 		fPCDataProxy->remove( pcRecord->id() );
 		fMapping->removePCId( pcRecord->id() );
 	}
 	else
 	{
+		DEBUGKPILOT << "record archived:" << hhRecord->id();
 		fMapping->archiveRecord( hhRecord->id() );
 	}
 }
@@ -736,8 +904,8 @@ void RecordConduit::solveConflict( Record *pcRecord, HHRecord *hhRecord )
 	
 	// NOTE: One of the two records might be 0L, which means that it's deleted.
 	
-	DEBUGKPILOT << fname << ": solving conflict for pc: " << pcRecord->id() 
-		<< " and hh: " << hhRecord->id() << endl;
+	DEBUGKPILOT << "Solving conflict for pc " << pcRecord->id() 
+		<< " and hh " << hhRecord->id();
 	
 	int res = getConflictResolution();
 	if ( res == SyncAction::eAskUser )
@@ -751,7 +919,7 @@ void RecordConduit::solveConflict( Record *pcRecord, HHRecord *hhRecord )
 		}
 		else
 		{
-			query += i18n( "deleted" );
+			query += i18nc( "The pc record is deleted.", "deleted" );
 		}
 		query += i18n( "\nHandheld entry:\n\t" );
 		if( hhRecord )
@@ -760,7 +928,7 @@ void RecordConduit::solveConflict( Record *pcRecord, HHRecord *hhRecord )
 		}
 		else
 		{
-			query += i18n( "deleted" );
+			query += i18nc( "The pilot record is deleted.", "deleted" );
 		}
 		query += i18n( "\n\nWhich entry do you want to keep? It will "
 			"overwrite the other entry." );
@@ -816,3 +984,126 @@ void RecordConduit::solveConflict( Record *pcRecord, HHRecord *hhRecord )
 	// else: eDoNothing
 	//return true;
 }
+
+void RecordConduit::copy( const Record *from, HHRecord *to )
+{
+	FUNCTIONSETUP;
+	
+	copyCategory( from, to );
+	
+	// Let implementing classes do the rest of the copying.
+	_copy( from, to );
+}
+	
+void RecordConduit::copy( const HHRecord *from, Record *to  )
+{
+	FUNCTIONSETUP;
+	
+	copyCategory( from, to );
+	
+	// Let implementing classes do the rest of the copying.
+	_copy( from, to );
+}
+
+void RecordConduit::copyCategory( const Record *from, HHRecord *to )
+{
+	FUNCTIONSETUP;
+	
+	DEBUGKPILOT << "(Record *from, HHRecord *to)";
+		
+	if( !from || !to )
+	{
+		return;
+	}
+
+	QStringList pcCategories = to->categoryNames();
+	if( pcCategories.size() < 1 )
+	{
+		// The pc record has no categories.
+		to->setCategory( Pilot::Unfiled, i18nc( "No category set for this record"
+			, "Unfiled" ) );
+		return;
+	}
+
+	// Quick check: does the record (not unfiled) have an entry
+	// in the categories list? If so, use that.
+	if( to->categoryId() != Pilot::Unfiled )
+	{
+		QString hhCat = to->categoryName();
+		
+		if( pcCategories.contains( hhCat ) )
+		{
+			// Found, so leave the category unchanged.
+			return;
+		}
+	}
+
+	QStringList availableHandheldCategories = fHHDataProxy->categoryNames();
+
+	// Either the record is unfiled, and should be filed, or
+	// it has a category set which is not in the list of
+	// categories that the event has. So go looking for
+	// a category that is available both for the event
+	// and on the handheld.
+	for ( QStringList::ConstIterator it = pcCategories.begin();
+		it != pcCategories.end(); ++it )
+	{
+		// Odd, an empty category string.
+		if( (*it).isEmpty() )
+		{
+			continue;
+		}
+
+		if( availableHandheldCategories.contains( *it ) )
+		{
+			// Since the string is in the list of available categories,
+			// this *can't* fail.
+			int c = fHHDataProxy->categoryId( *it );
+			Q_ASSERT( Pilot::validCategory(c) );
+			to->setCategory( c, *it );
+			return;
+		}
+	}
+
+	to->setCategory( Pilot::Unfiled, i18nc( "No category set for this record"
+			, "Unfiled" ) );
+}
+
+void RecordConduit::copyCategory( const HHRecord *from, Record *to  )
+{
+	FUNCTIONSETUP;
+	
+	DEBUGKPILOT << "(HHRecord *from, Record  *to)";
+	
+	if( !from || !to )
+	{
+		return;
+	}
+
+	QStringList pcCategories = to->categoryNames();
+	QString hhCategory = from->categoryName();
+	int cat = from->categoryId();
+
+	DEBUGKPILOT << "HH category id " << cat << " label: [" << hhCategory << ']';
+
+	if( Pilot::validCategory( cat ) && ( cat != Pilot::Unfiled ) )
+	{
+		if( !pcCategories.contains( hhCategory ) )
+		{
+			// if this event only has one category associated with it, then we can
+			// safely assume that what we should be doing here is changing it to match
+			// the palm. if there's already more than one category in the event,
+			// however, we won't cause data loss--we'll just append what the palm has
+			// to the event's categories.
+			if( pcCategories.count() <= 1 )
+			{
+				pcCategories.clear();
+			}
+
+			pcCategories.append( hhCategory );
+			to->setCategoryNames( pcCategories );
+		}
+	}
+
+	DEBUGKPILOT << "PC categories now: [" << pcCategories.join( "," ) << ']';
+}
