@@ -1,8 +1,9 @@
 /* KPilot
 **
-** Copyright (C) 1998-2001 by Dan Pilone
-** Copyright (C) 2001-2004 by Adriaan de Groot
+** Copyright (C) 1998-2001 by Dan Pilone <dan@kpilot.org>
+** Copyright (C) 2001-2007 by Adriaan de Groot <groot@kde.org>
 ** Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+** Copyright (C) 2006-2007 Jason 'vanRijn' Kasper <vr@movingparts.net>
 **
 ** This is the KPilot Daemon, which does the actual communication with
 ** the Pilot and with the conduits.
@@ -33,30 +34,22 @@
 
 #include <stdlib.h>
 
-#include <qtimer.h>
-#include <qtooltip.h>
-#include <qpixmap.h>
-//Added by qt3to4:
-#include <Q3Dict>
-#include <QDragEnterEvent>
-#include <QDropEvent>
-#include <QMouseEvent>
-#include <QCloseEvent>
-#include <QMenu>
+#include <QtCore/QTimer>
+#include <QtCore/QProcess>
+#include <QtCore/QHash>
+#include <QtGui/QAction>
+#include <QtGui/QMenu>
 
-#include <kuniqueapplication.h>
-#include <k3aboutapplication.h>
-#include <kcmdlineargs.h>
-#include <kurl.h>
-#include <kmenu.h>
 #include <kiconloader.h>
-#include <kdebug.h>
-#include <QProcess>
-#include <kservice.h>
 #include <khelpmenu.h>
+#include <kmenu.h>
+#include <kicon.h>
+#include <kaboutapplicationdialog.h>
 #include <ktoolinvocation.h>
-#include <K3AboutApplication>
+#include <kuniqueapplication.h>
+#include <kservice.h>
 #include <kaboutdata.h>
+#include <kcmdlineargs.h>
 
 #include "pilotRecord.h"
 
@@ -69,7 +62,6 @@
 #include "actions.h"
 
 #include "hotSync.h"
-#include "internalEditorAction.h"
 #include "logFile.h"
 
 #include "kpilotConfig.h"
@@ -91,113 +83,95 @@ PilotDaemonTray::PilotDaemonTray(PilotDaemon * p) :
 	kap(0L),
 	fBlinkTimer(0L)
 {
+	FUNCTIONSETUP;
 	setObjectName("pilotDaemon");
-	FUNCTIONSETUP;
 	setupWidget();
-#ifdef __GNUC__
-#warning "kde4 port it"
-#endif
-	//setAcceptDrops(true);
-}
-
-/* virtual */ void PilotDaemonTray::dragEnterEvent(QDragEnterEvent * e)
-{
-	FUNCTIONSETUP;
-	e->setAccepted(KUrl::List::canDecode(e->mimeData()));
-}
-
-/* virtual */ void PilotDaemonTray::dropEvent(QDropEvent * e)
-{
-	FUNCTIONSETUP;
-
-	KUrl::List list = KUrl::List::fromMimeData(e->mimeData());
-
-	QStringList files;
-	for(KUrl::List::ConstIterator it = list.begin(); it != list.end(); ++it)
-	{
-	 	if ((*it).isLocalFile())
-	 	{
-	 		files << (*it).path();
-	 	}
-	}
-
-	daemon->addInstallFiles(files);
-}
-
-/* virtual */ void PilotDaemonTray::mousePressEvent(QMouseEvent * e)
-{
-	FUNCTIONSETUP;
-#ifdef __GNUC__
-#warning "kde4 port"
-#endif
-	if ( e->button() == Qt::RightButton )
-	{
-		QMenu *menu = contextMenu();
-		menu->popup(e->globalPos());
-		e->accept();
-	}
-}
-
-/* virtual */ void PilotDaemonTray::closeEvent(QCloseEvent *)
-{
-	FUNCTIONSETUP;
-	daemon->quitNow();
 }
 
 void PilotDaemonTray::setupWidget()
 {
 	FUNCTIONSETUP;
 	KIconLoader::global()->addAppDir( CSL1("kpilot") );
+
 #define L(idx,name) \
-	icons[idx]=loadIcon( CSL1(name) ).pixmap(); \
-	if (icons[idx].isNull()) { WARNINGKPILOT << fname << ": No icon " << name << endl; } \
-	else { DEBUGKPILOT << fname << ": Loaded icon " << name << endl; }
+	icons[idx]=loadIcon( CSL1(name) ); \
+	if (icons[idx].isNull()) { WARNINGKPILOT << "No icon" << name; } \
+	else { DEBUGKPILOT << "Loaded icon" << name; }
 
 	L(Normal,"kpilotDaemon")
 	L(Busy,"kpilot_busysync")
 	L(NotListening,"kpilot_nosync")
+#undef L
+
 	slotShowNotListening();
 	QTimer::singleShot(2000,this,SLOT(slotShowNormal()));
 
 	QMenu *menu = contextMenu();
 
-	menuKPilotItem = menu->insertItem(i18n("Start &KPilot"), daemon,
-		SLOT(slotRunKPilot()));
-	menuConfigureConduitsItem = menu->insertItem(i18n("&Configure KPilot..."),
-		daemon, SLOT(slotRunConfig()));
+	menuKPilotItem = new QAction( i18n( "Start &KPilot" ), this );
+	connect( menuKPilotItem, SIGNAL( triggered() ), this, SLOT( slotRunKPilot() ) );
+	menu->addAction( menuKPilotItem );
+
+	menuConfigureConduitsItem = new QAction( i18n("&Configure KPilot..."), this );
+	connect( menuConfigureConduitsItem, SIGNAL( triggered() ), this
+		, SLOT( slotRunConfig() ) );
+	menu->addAction( menuConfigureConduitsItem );
+	
 	menu->addSeparator();
 
-	fSyncTypeMenu = new QMenu(menu);
-	fSyncTypeMenu->setObjectName("sync_type_menu");
-	QString once = i18nc("Appended to names of sync types to indicate the sync will happen just one time"," (once)");
-#define MI(a) fSyncTypeMenu->insertItem( \
-		SyncAction::SyncMode::name(SyncAction::SyncMode::a) + once, \
-		(int)(SyncAction::SyncMode::a));
-	fSyncTypeMenu->insertItem(i18n("Default (%1)",SyncAction::SyncMode::name((SyncAction::SyncMode::Mode)KPilotSettings::syncType())),
-		0);
+	// Configured default sync
+	menuDefaultSyncActionItem = new QAction( i18n("Default (%1)"
+		, SyncAction::SyncMode::name( (SyncAction::SyncMode::Mode)
+			KPilotSettings::syncType() ) ), this );
+	menuDefaultSyncActionItem->setCheckable( true );
+	menuDefaultSyncActionItem->setData( (int) 0 );
+	
+	connect( menuDefaultSyncActionItem, SIGNAL( toggled( bool ) ), daemon
+		, SLOT( toggleDefaultSync( bool ) ) );
+
+	fSyncTypeMenu = new QMenu( i18n( "Next &Sync" ), menu );
+	fSyncTypeMenu->setObjectName( "sync_type_menu" );
+	fSyncTypeMenu->addAction( menuDefaultSyncActionItem );
 	fSyncTypeMenu->addSeparator();
+	QString once = i18nc("Appended to names of sync types to indicate the sync"
+		" will happen just one time"," (once)");
 
-        // Keep this synchronized with kpilotui.rc and kpilot.cc if at all possible.
-	MI(eHotSync);
-	MI(eFullSync);
-	MI(eBackup);
-	MI(eRestore);
-	MI(eCopyHHToPC);
-	MI(eCopyPCToHH);
+	QActionGroup *syncTypeActions = new QActionGroup( this );
+	QAction *action;
+	QString syncModeName;
 
-	fSyncTypeMenu->setCheckable(true);
-	fSyncTypeMenu->setItemChecked(0,true);
+#define MI(a,b) \
+	syncModeName = SyncAction::SyncMode::name( a ); \
+	action = new QAction( syncModeName, this ); \
+	action->setCheckable( true ); \
+	action->setChecked( b ); \
+	action->setData( (int) a ); \
+	syncTypeActions->addAction( action ); \
+	fSyncTypeMenu->addAction( action ); \
+
+	// Keep this synchronized with kpilotui.rc and kpilot.cc if at all possible.
+	MI( SyncAction::SyncMode::eHotSync, true );
+	MI( SyncAction::SyncMode::eFullSync, false );
+	MI( SyncAction::SyncMode::eBackup, false );
+	MI( SyncAction::SyncMode::eRestore, false );
+	MI( SyncAction::SyncMode::eCopyHHToPC, false );
+	MI( SyncAction::SyncMode::eCopyPCToHH, false );
 #undef MI
-	connect(fSyncTypeMenu,SIGNAL(activated(int)),daemon,SLOT(requestSync(int)));
-	menu->insertItem(i18n("Next &Sync"),fSyncTypeMenu);
 
-	KHelpMenu *help = new KHelpMenu(menu,aboutData);
-	menu->insertItem(KIcon(CSL1("help")),i18n("&Help"),help->menu());
+	connect( syncTypeActions, SIGNAL( triggered( QAction* ) ), daemon
+		, SLOT( requestSync( QAction* ) ) );
+	
+	// See toggleDefaultSync(). This is only useful now all other action are
+	// added to syncTypeActions.
+	menuDefaultSyncActionItem->setChecked( true );
 
+	menu->addMenu( fSyncTypeMenu );
 
-#ifdef DEBUG
-	DEBUGKPILOT << fname << ": Finished getting icons" << endl;
-#endif
+	KHelpMenu *helpMenu = new KHelpMenu( menu, aboutData );
+	helpMenu->menu()->setIcon( KIcon( CSL1( "help" ) ) );
+	menu->addMenu( helpMenu->menu() );
+
+	DEBUGKPILOT << "Finished getting icons";
 }
 
 void PilotDaemonTray::slotShowAbout()
@@ -206,7 +180,7 @@ void PilotDaemonTray::slotShowAbout()
 
 	if (!kap)
 	{
-		kap = new K3AboutApplication(0, false);
+		kap = new KAboutApplicationDialog(aboutData, false);
 	}
 
 	kap->show();
@@ -216,8 +190,9 @@ void PilotDaemonTray::slotShowAbout()
 void PilotDaemonTray::enableRunKPilot(bool b)
 {
 	FUNCTIONSETUP;
-	contextMenu()->setItemEnabled(menuKPilotItem, b);
-	contextMenu()->setItemEnabled(menuConfigureConduitsItem, b);
+	
+	menuKPilotItem->setEnabled( b );
+	menuConfigureConduitsItem->setEnabled( b );
 }
 
 
@@ -226,7 +201,7 @@ void PilotDaemonTray::changeIcon(IconShape i)
 	FUNCTIONSETUP;
 	if (icons[i].isNull())
 	{
-		WARNINGKPILOT << "Icon #"<<i<<" is NULL!" << endl;
+		WARNINGKPILOT << "Icon #"<<i<< " is NULL!";
 	}
 	setIcon ( icons[i] );
 	fCurrentIcon = i;
@@ -282,6 +257,59 @@ void PilotDaemonTray::endHotSync()
 	}
 }
 
+void PilotDaemonTray::slotRunKPilot()
+{
+	FUNCTIONSETUP;
+
+	QString kpilotError;
+	QString kpilotPID;
+
+	if (KToolInvocation::startServiceByDesktopName(CSL1("kpilot"),
+			QStringList(), &kpilotError, &kpilotPID
+		))
+	{
+		WARNINGKPILOT << "Couldn't start KPilot!" << kpilotError;
+	}
+}
+
+void PilotDaemonTray::slotRunConfig()
+{
+	FUNCTIONSETUP;
+
+	// This function tries to send the raise() call to kpilot.
+	// If it succeeds, we can assume kpilot is running and then try
+	// to send the configure() call.
+	// If it fails (probably because kpilot isn't running) it tries
+	// to start kpilot (using a command line switch to
+	// only bring up the configure dialog).
+	//
+	// Implementing the function this way catches all cases.
+	// ie 1 KPilot running with configure dialog open (raise())
+	//    2 KPilot running with dialog NOT open (configureConduits())
+	//    3 KPilot NOT running (start it)
+
+	// This call to kpilot's raise function solves the final case
+	// ie when kpilot already has the dialog open
+
+	if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( "org.kde.kpilot.kpilot" ) )
+	{
+		DEBUGKPILOT << "kpilot running. telling it to raise/configure.";
+
+		OrgKdeKpilotKpilotInterface * kpilot = new OrgKdeKpilotKpilotInterface("org.kde.kpilot.kpilot", "/KPilot",QDBusConnection::sessionBus());
+		kpilot->raise();
+		kpilot->configure();
+	}
+	else
+	{
+		DEBUGKPILOT << "kpilot not running. starting it.";
+		// KPilot not running
+		QProcess *p = new QProcess;
+		QStringList arguments;
+		arguments<< "-s";
+		p->start("kpilot", arguments);
+	}
+}
+
 
 PilotDaemon::PilotDaemon() :
 	fDaemonStatus(INIT),
@@ -292,41 +320,34 @@ PilotDaemon::PilotDaemon() :
 	fTray(0L),
 	fInstaller(0L),
 	fLogFile(0L),
-	/*fLogStub(new LoggerDCOP_stub("kpilot", "LogIface")),
-	fLogFileStub(new LoggerDCOP_stub("kpilotDaemon", "LogIface")),
-	fKPilotStub(new KPilotDCOP_stub("kpilot", "KPilotIface")),*/
-	fTempDevice(QString::null)
+	fTempDevice(QString())
 {
+	FUNCTIONSETUP;
+
         new DaemonAdaptor(this);
         QDBusConnection::sessionBus().registerObject("/Daemon", this);
 
 	//TODO verify it
-        fLogInterface = new OrgKdeKpilotLoggerInterface("org.kde.kpilot.kpilot", "/KPilot", QDBusConnection::sessionBus());
-	fLogFileInterface = new OrgKdeKpilotLoggerInterface("org.kde.kpilot.daemon", "/Daemon", QDBusConnection::sessionBus());
+        fLogInterface = new OrgKdeKpilotLoggerInterface("org.kde.kpilot.kpilot", "/LoggerGUI", QDBusConnection::sessionBus());
+	fLogFileInterface = new OrgKdeKpilotLoggerInterface("org.kde.kpilot.daemon", "/LoggerFile", QDBusConnection::sessionBus());
 	fKPilotInterface = new OrgKdeKpilotKpilotInterface("org.kde.kpilot.kpilot", "/KPilot",QDBusConnection::sessionBus());
-	FUNCTIONSETUP;
 
 	setupPilotLink();
 	reloadSettings();
 
 	if (fDaemonStatus == ERROR)
 	{
-		WARNINGKPILOT << "Connecting to device failed." << endl;
+		WARNINGKPILOT << "Connecting to device failed.";
 		return;
 	}
 
 	fInstaller = new FileInstaller;
 	fLogFile = new LogFile;
-	connect(fInstaller, SIGNAL(filesChanged()),
-		this, SLOT(slotFilesChanged()));
 
 	fNextSyncType.setMode( KPilotSettings::syncType() );
 
-#ifdef DEBUG
-	DEBUGKPILOT << fname
-		<< ": The daemon is ready with status "
-		<< statusString() << " (" << (int) fDaemonStatus << ")" << endl;
-#endif
+	DEBUGKPILOT << "The daemon is ready with status "
+		<< statusString() << " (" << (int) fDaemonStatus << ')';
 }
 
 PilotDaemon::~PilotDaemon()
@@ -340,15 +361,6 @@ PilotDaemon::~PilotDaemon()
 	(void) PilotDatabase::instanceCount();
 }
 
-void PilotDaemon::addInstallFiles(const QStringList &l)
-{
-	FUNCTIONSETUP;
-#ifdef __GNUC__
-#warning "kde4 port it"
-#endif
-	//fInstaller->addFiles( l, fTray );
-}
-
 int PilotDaemon::getPilotSpeed()
 {
 	FUNCTIONSETUP;
@@ -383,11 +395,8 @@ int PilotDaemon::getPilotSpeed()
 		speedname = "PILOTRATE=9600";
 	}
 
-#ifdef DEBUG
-	DEBUGKPILOT << fname
-		<< ": Speed set to "
-		<< speedname << " (" << speed << ")" << endl;
-#endif
+	DEBUGKPILOT << "Speed set to "
+		<< speedname << " (" << speed << ')';
 
 	putenv((char *) speedname);
 
@@ -401,29 +410,17 @@ void PilotDaemon::showTray()
 
 	if (!fTray)
 	{
-#ifdef DEBUG
-		DEBUGKPILOT << fname << ": No tray icon to display!" << endl;
-#endif
+		DEBUGKPILOT << "No tray icon to display!";
 
 		return;
 	}
-#ifdef __GNUC__
-#warning "kde4 port it"
-#endif
-#if 0
-	// Copied from Klipper
-	KWM::setSystemTrayWindowFor(fTray->winId(), 0);
-	fTray->setGeometry(-100, -100, 42, 42);
 	fTray->show();
-#endif
-#ifdef DEBUG
-	DEBUGKPILOT << fname << ": Tray icon displayed." << endl;
-#endif
+	DEBUGKPILOT << "Tray icon displayed.";
 
 	updateTrayStatus();
 }
 
-void PilotDaemon::setTempDevice(QString d)
+void PilotDaemon::setTempDevice(const QString &d)
 {
 	if ( !d.isEmpty() ){
 		fTempDevice = d;
@@ -454,49 +451,31 @@ void PilotDaemon::reloadSettings()
 		break;
 	}
 
-	// TODO: Is this bunch of calls really necessary to reload the settings???
 	KPilotSettings::self()->config()->reparseConfiguration();
 	KPilotSettings::self()->readConfig();
 	getPilotSpeed();
 
 	(void) Pilot::setupPilotCodec(KPilotSettings::encoding());
 
-#ifdef DEBUG
-	DEBUGKPILOT << fname
-		<< ": Got configuration "
-		<< KPilotSettings::pilotDevice()
-		<< endl;
-	DEBUGKPILOT << fname
-		<< ": Got conduit list "
-		<< (KPilotSettings::installedConduits().join(CSL1(",")))
-		<< endl;
-#endif
+	DEBUGKPILOT << "Got configuration "
+		<< KPilotSettings::pilotDevice();
+	DEBUGKPILOT << "Got conduit list "
+		<< (KPilotSettings::installedConduits().join(CSL1(",")));
 
 	requestSync(0);
 
 
 	if (fPilotLink)
 	{
-#ifdef DEBUG
-		DEBUGKPILOT << fname
-			<< ": Resetting with device "
-			<< KPilotSettings::pilotDevice()
-			<< endl;
-#endif
+		DEBUGKPILOT << "Resetting with device "
+			<< KPilotSettings::pilotDevice();
 
 		fPilotLink->reset( KPilotSettings::pilotDevice() );
-#ifdef DEBUG
-		DEBUGKPILOT << fname
-			<< ": Using workarounds "
-			<< KPilotSettings::workarounds()
-			<< endl;
-#endif
+		DEBUGKPILOT << "Using workarounds "
+			<< KPilotSettings::workarounds();
 		if ( KPilotSettings::workarounds() == KPilotSettings::eWorkaroundUSB )
 		{
-#ifdef DEBUG
-			DEBUGKPILOT << fname
-				<< ": Using Zire31 USB workaround." << endl;
-#endif
+			DEBUGKPILOT << "Using USB connect/disconnect/connect workaround.";
 			fPilotLink->setWorkarounds(true);
 		}
 	}
@@ -506,12 +485,8 @@ void PilotDaemon::reloadSettings()
 		if (!fTray)
 		{
 			fTray = new PilotDaemonTray(this);
-			fTray->show();
-		}
-		else
-		{
-			fTray->show();
 		}
+		fTray->show();
 	}
 	else
 	{
@@ -525,7 +500,7 @@ void PilotDaemon::reloadSettings()
 	}
 
 	updateTrayStatus();
-	logProgress(QString::null,0);
+	logProgress(QString(),0);
 }
 
 void PilotDaemon::stopListening()
@@ -606,7 +581,7 @@ bool PilotDaemon::setupPilotLink()
 	fPilotLink = new KPilotDeviceLink( 0, 0, fTempDevice );
 	if (!fPilotLink)
 	{
-		WARNINGKPILOT << "Can't get pilot link." << endl;
+		WARNINGKPILOT << "Can't get pilot link.";
 		return false;
 	}
 
@@ -647,10 +622,8 @@ void PilotDaemon::quitNow()
 		fPostSyncAction |= Quit;
 		break;
 	}
-#ifdef __GNUC__
-#warning "kde4 port"
-#endif
-	//emitDCOPSignal( "kpilotDaemonStatusChanged()", QByteArray() );
+	QDBusMessage message = QDBusMessage::createSignal( "/Daemon", "org.kde.kpilot.daemon", "kpilotDaemonStatusChanged");
+	QDBusConnection::sessionBus().send( message );
 }
 
 void PilotDaemon::requestRegularSyncNext()
@@ -658,8 +631,30 @@ void PilotDaemon::requestRegularSyncNext()
 	requestSync(SyncAction::SyncMode::eHotSync);
 }
 
+void PilotDaemon::requestSync( QAction *action )
+{
+	FUNCTIONSETUP;
+	
+	if( !action )
+	{
+		WARNINGKPILOT << "Ignored OL action pointer";
+		return;
+	}
+	
+	unsigned int actionData = action->data().toInt();
+	
+	requestSync( actionData );
+	
+	if( fTray )
+	{
+		if( actionData != 0 && actionData != KPilotSettings::syncType() )
+		{
+			fTray->menuDefaultSyncActionItem->setChecked( false );
+		}
+	}
+}
 
-void PilotDaemon::requestSync(int mode)
+void PilotDaemon::requestSync( int mode )
 {
 	FUNCTIONSETUP;
 
@@ -670,27 +665,43 @@ void PilotDaemon::requestSync(int mode)
 
 	if ( !fNextSyncType.setMode(mode) )
 	{
-		WARNINGKPILOT << "Ignored fake sync type " << mode << endl;
+		WARNINGKPILOT << "Ignored fake sync type" << mode;
 		return;
 	}
 
 	updateTrayStatus();
 
-	if (fTray && (fTray->fSyncTypeMenu))
-	{
-		for (int i=((int)SyncAction::SyncMode::eHotSync);
-			i<=((int)SyncAction::SyncMode::eRestore) /* Restore */ ;
-			++i)
-		{
-			fTray->fSyncTypeMenu->setItemChecked(i,mode==i);
-		}
-	}
-
 	getLogger().logMessage(i18n("Next HotSync will be: %1. ",fNextSyncType.name()) +
 		i18n("Please press the HotSync button."));
 }
 
-void PilotDaemon::requestSyncType(QString s)
+void PilotDaemon::toggleDefaultSync( bool toggled )
+{
+	// If the default
+	if( toggled )
+	{
+		if( fTray && (fTray->fSyncTypeMenu) )
+		{
+			QList<QAction*> actions = fTray->fSyncTypeMenu->actions();
+			
+			QListIterator<QAction*> i( actions );
+			bool finished = false;
+			QAction *a;
+			
+			while( i.hasNext() && !finished )
+			{
+				a = i.next();
+				if( a->data().toInt() == (int) SyncAction::SyncMode::eHotSync )
+				{
+					a->setChecked( true );
+					finished = true;
+				}
+			}
+		}
+	}
+}
+
+void PilotDaemon::requestSyncType(const QString &s)
 {
 	FUNCTIONSETUP;
 
@@ -705,8 +716,7 @@ void PilotDaemon::requestSyncType(QString s)
 	else if (s.startsWith(CSL1("D"))) requestSync(0);
 	else
 	{
-		WARNINGKPILOT << "Unknown sync type " << ( s.isEmpty() ? CSL1("<none>") : s )
-			<< endl;
+		WARNINGKPILOT << "Unknown sync type " << ( s.isEmpty() ? CSL1("<none>") : s );
 	}
 }
 
@@ -719,7 +729,7 @@ void PilotDaemon::requestSyncOptions(bool test, bool local)
 			<< ' '
 			<< (local ? "local" : "nolocal")
 			<< " in mode "
-			<< fNextSyncType.name() << endl;
+			<< fNextSyncType.name();
 	}
 }
 
@@ -729,7 +739,7 @@ int PilotDaemon::nextSyncType() const
 }
 
 /**
-* DCOP Functions reporting some status data, e.g. for the kontact plugin.
+* Functions reporting some status data, e.g. for the kontact plugin.
 */
 QDateTime PilotDaemon::lastSyncDate()
 {
@@ -737,14 +747,13 @@ QDateTime PilotDaemon::lastSyncDate()
 }
 
 
-static Q3Dict<QString> *conduitNameMap = 0L;
+static QHash<QString, QString*> *conduitNameMap = 0L;
 
 static void fillConduitNameMap()
 {
 	if ( !conduitNameMap )
 	{
-		conduitNameMap = new Q3Dict<QString>;
-		conduitNameMap->setAutoDelete(true);
+		conduitNameMap = new QHash<QString, QString*>;
 	}
 	conduitNameMap->clear();
 
@@ -758,13 +767,13 @@ static void fillConduitNameMap()
 	QStringList::ConstIterator end = l.end();
 	for (QStringList::ConstIterator i = l.begin(); i != end; ++i)
 	{
-		if (!conduitNameMap->find(*i))
+		if (!conduitNameMap->value(*i))
 		{
 			QString readableName = CSL1("<unknown>");
 			KSharedPtr < KService > o = KService::serviceByDesktopName(*i);
 			if (!o)
 			{
-				WARNINGKPILOT << "No service for " << *i << endl;
+				WARNINGKPILOT << "No service for" << *i;
 			}
 			else
 			{
@@ -780,20 +789,14 @@ QStringList PilotDaemon::configuredConduitList()
 {
 	fillConduitNameMap();
 
-	QStringList keys;
-
-	Q3DictIterator<QString> it(*conduitNameMap);
-	for ( ; *it; ++it)
-	{
-		keys << it.currentKey();
-	}
+	QStringList keys = conduitNameMap->keys();
 	keys.sort();
 
 	QStringList::ConstIterator end = keys.end();
 	QStringList result;
 	for (QStringList::ConstIterator i = keys.begin(); i != end; ++i)
 	{
-		result << *(conduitNameMap->find(*i));
+		result << *(conduitNameMap->value(*i));
 	}
 
 	return result;
@@ -818,57 +821,38 @@ bool PilotDaemon::killDaemonOnExit()
 	return KPilotSettings::killDaemonAtExit();
 }
 
-typedef enum { NotLocked=0, Locked=1, DCOPError=2 } KDesktopLockStatus;
+typedef enum { KDL_NotLocked=0, KDL_Locked=1, KDL_Error=2 } KDesktopLockStatus;
 static KDesktopLockStatus isKDesktopLockRunning()
 {
+	FUNCTIONSETUP;
+
 	if (!KPilotSettings::screenlockSecure())
 	{
-		return NotLocked;
+		return KDL_NotLocked;
 	}
 
-#ifdef __GNUC__
-#warning "kde4 port it"
-#endif
-#if 0
-	DCOPClient *dcopptr = KApplication::kApplication()->dcopClient();
+	QDBusInterface screensaver("org.freedesktop.ScreenSaver", "/ScreenSaver",
+				   "org.freedesktop.ScreenSaver");
+	QDBusReply<bool> reply = screensaver.call( "GetActive" );
 
-	// Can't tell, very weird, err on the side of safety.
-	if (!dcopptr || !dcopptr->isAttached())
+	bool locked = true;
+
+	if ( reply.isValid() )
 	{
-		WARNINGKPILOT << "Could not make DCOP connection. "
-			<< "Assuming screensaver is active." << endl;
-		return DCOPError;
-	}
-
-	QByteArray data,returnValue;
-	Q3CString returnType;
-
-	if (!dcopptr->call("kdesktop","KScreensaverIface","isBlanked()",
-		data,returnType,returnValue,true))
-	{
-		WARNINGKPILOT << "Check for screensaver failed."
-			<< "Assuming screensaver is active." << endl;
-		// Err on the side of safety again.
-		return DCOPError;
-	}
-
-	if (returnType == "bool")
-	{
-		bool b;
-		QDataStream reply(returnValue,QIODevice::ReadOnly);
-		reply >> b;
-		return (b ? Locked : NotLocked);
+		locked = reply.value();
+		DEBUGKPILOT << "isDesktopLockRunning: reply from screensaver.GetActive: [" << locked << "]";
 	}
 	else
 	{
-		WARNINGKPILOT << "Strange return value from screensaver. "
-			<< "Assuming screensaver is active." << endl;
-		// Err on the side of safety.
-		return DCOPError;
+		WARNINGKPILOT << "isDesktopLockRunning: Could not make DBUS connection. "
+			<< "Error: [" << reply.error().type() << "], message: ["<< reply.error().message()
+			<< "], name: [" << reply.error().name()
+			<< "]. Assuming screensaver is active.";
+		return KDL_Error;
 	}
-#endif
 
-	return Locked;
+	return (locked ? KDL_Locked : KDL_NotLocked);
+
 }
 
 
@@ -894,31 +878,24 @@ static bool isSyncPossible(ActionQueue *fSyncStack,
 	*/
 	QDBusReply<int> val = kpilot.kpilotStatus();
 	int kpilotstatus=0;
-#ifdef DEBUG
 	if (!val.isValid())
 	{
-		DEBUGKPILOT << fname <<
-			": Could not call KPilot for status." << endl;
+		DEBUGKPILOT << "Could not call KPilot for status.";
 	}
 	else
 	{
-		DEBUGKPILOT << fname << ": KPilot status " << kpilotstatus << endl;
+		DEBUGKPILOT << "KPilot status" << kpilotstatus;
 	}
-#endif
 	/**
 	* If the call fails, then KPilot is probably not running
 	* and we can behave normally.
 	*/
-	if(val.isValid())
-	{
-		kpilotstatus = val;
-	}
 	if (val.isValid())
 	{
 		kpilotstatus = val;
 		if(kpilotstatus != KPilotInstaller::WaitingForDaemon)
 		{
-			WARNINGKPILOT << "KPilot returned status " << kpilotstatus << endl;
+			WARNINGKPILOT << "KPilot returned status" << kpilotstatus;
 
 			fSyncStack->queueInit();
 			fSyncStack->addAction(new SorryAction(pilotLink));
@@ -927,14 +904,14 @@ static bool isSyncPossible(ActionQueue *fSyncStack,
 	}
 	switch (isKDesktopLockRunning())
 	{
-	case NotLocked :
+	case KDL_NotLocked :
 		break; /* Fall through to return true below */
-	case Locked :
+	case KDL_Locked :
 		fSyncStack->queueInit();
 		fSyncStack->addAction(new SorryAction(pilotLink,
 			i18n("HotSync is disabled while the screen is locked.")));
 		return false;
-	case DCOPError :
+	case KDL_Error :
 		fSyncStack->queueInit();
 		fSyncStack->addAction(new SorryAction(pilotLink,
 			i18n("HotSync is disabled because KPilot could not "
@@ -958,14 +935,6 @@ static void queueInstaller(ActionQueue *fSyncStack,
 	}
 }
 
-static void queueEditors(ActionQueue *fSyncStack, KPilotLink *pilotLink)
-{
-	if (KPilotSettings::internalEditors())
-	{
-		fSyncStack->addAction(new InternalEditorAction(pilotLink));
-	}
-}
-
 static void queueConduits(ActionQueue *fSyncStack,
 	const QStringList &conduits,
 	SyncAction::SyncMode e)
@@ -973,9 +942,6 @@ static void queueConduits(ActionQueue *fSyncStack,
 	if (conduits.count() > 0)
 	{
 		fSyncStack->queueConduits(conduits,e);
-		// QString s = i18n("Conduit flags: ");
-		// s.append(ConduitProxy::flagsForMode(e).join(CSL1(" ")));
-		// logMessage(s);
 	}
 }
 
@@ -987,10 +953,7 @@ bool PilotDaemon::shouldBackup()
 	bool ret = false;
 	int backupfreq = KPilotSettings::backupFrequency();
 
-#ifdef DEBUG
-	DEBUGKPILOT << fname << ": Backup Frequency is: [" << backupfreq <<
-	"]. " << endl;
-#endif
+	DEBUGKPILOT << "Backup Frequency is: " << backupfreq;
 
 	if ( (fNextSyncType == SyncAction::SyncMode::eHotSync) ||
 		(fNextSyncType == SyncAction::SyncMode::eFullSync) )
@@ -1000,16 +963,12 @@ bool PilotDaemon::shouldBackup()
 		 */
 		if ( backupfreq == SyncAction::eOnRequestOnly )
 		{
-#ifdef DEBUG
-	DEBUGKPILOT << fname << ": Should not do backup..." << endl;
-#endif
+	DEBUGKPILOT << "Should not do backup...";
 			ret = false;
 		}
 		else if ( backupfreq == SyncAction::eEveryHotSync )
 		{
-#ifdef DEBUG
-	DEBUGKPILOT << fname << ": Should do backup..." << endl;
-#endif
+	DEBUGKPILOT << "Should do backup...";
 			ret = true;
 		}
 	}
@@ -1027,13 +986,9 @@ bool PilotDaemon::shouldBackup()
 	QStringList conduits ; // list of conduits to run
 	QString s; // a generic string for stuff
 
-#ifdef DEBUG
-	DEBUGKPILOT << fname
-		<< ": Starting Sync with type "
-		<< fNextSyncType.name() << endl;
-	DEBUGKPILOT << fname << ": Status is " << shortStatusString() << endl;
+	DEBUGKPILOT << "Starting Sync with type " << fNextSyncType.name();
+	DEBUGKPILOT << "Status is " << shortStatusString();
 	(void) PilotDatabase::instanceCount();
-#endif
 
 	fDaemonStatus = HOTSYNC_START ;
 	if (fTray)
@@ -1065,22 +1020,16 @@ bool PilotDaemon::shouldBackup()
 
 		if (pcchanged)
 		{
-#ifdef DEBUG
-			DEBUGKPILOT << fname << ": PC changed. Last sync PC: [" << usr.getLastSyncPC()
-				<< "], me: [" << (unsigned long) gethostid() << "]" << endl;
-#endif
+			DEBUGKPILOT << "PC changed. Last sync PC: " << usr.getLastSyncPC()
+				<< ", me: " << (unsigned long) gethostid();
  			if ( KPilotSettings::fullSyncOnPCChange() )
 			{
-#ifdef DEBUG
-				DEBUGKPILOT << fname << ": Setting sync mode to full sync. " << endl;
-#endif
-				fNextSyncType = SyncAction::SyncMode::eFullSync;
+				DEBUGKPILOT << "Setting sync mode to full sync.";
+				fNextSyncType = SyncAction::SyncMode( SyncAction::SyncMode::eFullSync );
 			}
 			else
 			{
-#ifdef DEBUG
-				DEBUGKPILOT << fname << ": Not changing sync mode because of settings. " << endl;
-#endif
+				DEBUGKPILOT << "Not changing sync mode because of settings.";
 			}
 		}
 	}
@@ -1115,10 +1064,7 @@ bool PilotDaemon::shouldBackup()
 			// first install the files, and only then do the conduits
 			// (conduits might want to sync a database that will be installed
 			queueInstaller(fSyncStack,pilotLink,fInstaller,conduits);
-			queueEditors(fSyncStack,pilotLink);
 			queueConduits(fSyncStack,conduits,fNextSyncType);
-			// After running the conduits, install new databases
-			queueInstaller(fSyncStack,pilotLink,fInstaller,conduits);
 			// And sync the remaining databases if needed.
 			if (shouldBackup())
 			{
@@ -1126,10 +1072,12 @@ bool PilotDaemon::shouldBackup()
 			}
 			break;
 		case SyncAction::SyncMode::eCopyPCToHH:
-			queueConduits(fSyncStack,conduits,SyncAction::SyncMode::eCopyPCToHH);
+			queueConduits(fSyncStack,conduits
+				,SyncAction::SyncMode(SyncAction::SyncMode::eCopyPCToHH));
 			break;
 		case SyncAction::SyncMode::eCopyHHToPC:
-			queueConduits(fSyncStack,conduits,SyncAction::SyncMode::eCopyHHToPC);
+			queueConduits(fSyncStack,conduits
+				,SyncAction::SyncMode(SyncAction::SyncMode::eCopyHHToPC));
 			break;
 		}
 	}
@@ -1191,11 +1139,11 @@ launch:
 		fTray->endHotSync();
 	}
 
-	KPILOT_DELETE(fSyncStack);
+	fSyncStack->deleteLater();
 	fPilotLink->close();
 
-	getLogger().logProgress(i18n("HotSync Completed.<br>"), 100);
-	getFileLogger().logProgress(i18n("HotSync Completed.<br>"), 100);
+	getLogger().logProgress(i18n("HotSync Completed.<br/>"), 100);
+	getFileLogger().logProgress(i18n("HotSync Completed.<br/>"), 100);
 	getLogger().logEndSync();
 	getFileLogger().logEndSync();
 	getKPilot().daemonStatus(KPilotInstaller::EndOfHotSync);
@@ -1227,71 +1175,7 @@ launch:
 }
 
 
-void PilotDaemon::slotFilesChanged()
-{
-	FUNCTIONSETUP;
-}
 
-void PilotDaemon::slotRunKPilot()
-{
-	FUNCTIONSETUP;
-
-	QString kpilotError;
-	QString kpilotPID;
-
-	if (KToolInvocation::startServiceByDesktopName(CSL1("kpilot"),
-			QStringList(), &kpilotError, &kpilotPID
-		))
-	{
-		WARNINGKPILOT << "Couldn't start KPilot! " << kpilotError << endl;
-	}
-	else
-	{
-#ifdef DEBUG
-		//DEBUGKPILOT << fname
-		//	<< ": Started KPilot with DCOP name "
-		//	<< kpilotDCOP << " (pid " << kpilotPID << ")" << endl;
-#endif
-	}
-}
-
-void PilotDaemon::slotRunConfig()
-{
-	FUNCTIONSETUP;
-
-	// This function tries to send the raise() DCOP call to kpilot.
-	// If it succeeds, we can assume kpilot is running and then try
-	// to send the configure() DCOP call.
-	// If it fails (probably because kpilot isn't running) it tries
-	// to call kpilot via K3Process (using a command line switch to
-	// only bring up the configure dialog).
-	//
-	// Implementing the function this way catches all cases.
-	// ie 1 KPilot running with configure dialog open (raise())
-	//    2 KPilot running with dialog NOT open (configureConduits())
-	//    3 KPilot NOT running (K3Process)
-
-	// This DCOP call to kpilot's raise function solves the final case
-	// ie when kpilot already has the dialog open
-
-	//TODO verify
-	if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( "org.kde.kpilot" ) )
-	{
-#ifdef __GNUC__
-#warning "kde4 port it"
-#endif
-		//client->send("kpilot", "kpilot-mainwindow#1", "raise()",QString::null);
-		//client->send("kpilot", "KPilotIface", "configure()", QString::null);
-	}
-	else
-	{
-		// KPilot not running
-		QProcess *p = new QProcess;
-		QStringList arguments;
-		arguments<<"-s";
-		p->start("kpilot", arguments);
-	}
-}
 
 void PilotDaemon::updateTrayStatus(const QString &s)
 {
@@ -1304,12 +1188,16 @@ void PilotDaemon::updateTrayStatus(const QString &s)
 	tipText.append( CSL1("</qt>") );
 
 	fTray->setToolTip(tipText);
-#ifdef __GNUC__
-#warning "kde4 port it"
-#endif
-#if 0
-	emitDCOPSignal( "kpilotDaemonStatusChanged()", QByteArray() );
-	// emit the same dcop signal but including the information needed by Kontact to update its kpilot summary widget
+	QDBusMessage message = QDBusMessage::createSignal( "/Daemon", "org.kde.kpilot.daemon", "kpilotDaemonStatusChanged");
+	QDBusConnection::sessionBus().send( message );
+
+	// emit the same signal but including the information needed by Kontact to update its kpilot summary widget
+	/*
+	* not going to finish doing this since we don't have a kontact component yet, but if
+	* we want one, here's how to get it working (from the dcop code):
+	*/
+	/*
+	message = QDBusMessage::createSignal( "/Daemon", "org.kde.kpilot.daemon", "kpilotDaemonStatusDetails()");
 	QByteArray data;
 	QDataStream arg(data, QIODevice::WriteOnly);
 	arg << lastSyncDate();
@@ -1319,8 +1207,9 @@ void PilotDaemon::updateTrayStatus(const QString &s)
 	arg << userName();
 	arg << pilotDevice();
 	arg << killDaemonOnExit();
+
 	emitDCOPSignal( "kpilotDaemonStatusDetails(QDateTime,QString,QStringList,QString,QString,QString,bool)", data );
-#endif
+	*/
 }
 
 
@@ -1330,42 +1219,39 @@ int main(int argc, char **argv)
 
 	KLocale::setMainCatalog("kpilot");
 
-	KAboutData about("kpilotDaemon", 0,
+	// a non-intuitive note about this... now that we're using dbus, the way that the path
+	// is constructed to communicate with our objects on the bus are of 2 pieces...
+	// in the dbus interface string "org.kde.kpilot.foo",
+	// the "org.kde.kpilot" part comes from setOrganizationDomain, found in
+	// KPILOT_ABOUT_INIT.  the "foo" part comes in the first argument to KAboutData below...
+	KAboutData about("daemon", 0,
 		ki18n("KPilot Daemon"),
 		KPILOT_VERSION,
-		ki18n("KPilot - HotSync software for KDE\n\n"),
+		ki18n("KPilot - HotSync software for KDE"),
 		KAboutData::License_GPL,
-		ki18n("(c) 1998-2000,2001, Dan Pilone (c) 2000-2004, Adriaan de Groot"),
+		KPILOT_ABOUT_AUTHORS,
 		ki18n(0L),
 		"http://www.kpilot.org/"
 		);
-	about.addAuthor(ki18n("Dan Pilone"),
-		ki18n("Project Leader"),
-		"pilone@slac.com");
-	about.addAuthor(ki18n("Adriaan de Groot"),
-		ki18n("Maintainer"),
-		"groot@kde.org", "http://www.kpilot.org/");
-	about.addAuthor(ki18n("Reinhold Kainhofer"),
-		ki18n("Developer"),
-		"reinhold@kainhofer.com", "http://reinhold.kainhofer.com/Linux/");
+	KPILOT_ABOUT_INIT(about);
+
 	aboutData = &about;
 
 
 	KCmdLineArgs::init(argc, argv, &about);
 
 	KCmdLineOptions daemonoptions;
-	#ifdef DEBUG
+#ifdef DEBUG
 	daemonoptions.add("debug <level>", ki18n("Set debugging level"), "0");
-	#endif
+#endif
 	daemonoptions.add("device <device>", ki18n("Device to try first"));
 	daemonoptions.add("fail-silently", ki18n("Exit instead of complaining about bad configuration files"));
 	KCmdLineArgs::addCmdLineOptions(daemonoptions, ki18n("kpilotconfig"));
 	KUniqueApplication::addCmdLineOptions();
 	KCmdLineArgs *p = KCmdLineArgs::parsedArgs();
 
-#ifdef DEBUG
 	KPilotConfig::getDebugLevel(p);
-#endif
+
 	if (!KUniqueApplication::start())
 	{
 		if (p->isSet("device")){
@@ -1376,17 +1262,13 @@ int main(int argc, char **argv)
 		return 0;
 	}
 	KUniqueApplication a(true, true);
+	a.setQuitOnLastWindowClosed(false);
 
 	// A block just to keep variables local.
-	//
-	//
 	{
-//		KPilotSettings::self()->config()->setReadOnly(false);
-
 		if (KPilotSettings::configVersion() < KPilotConfig::ConfigurationVersion)
 		{
-			WARNINGKPILOT << "Is still not configured for use."
-				<< endl;
+			WARNINGKPILOT << "Still not configured for use.";
 			if (!p->isSet("fail-silently"))
 			{
 				KPilotConfig::sorryVersionOutdated(KPilotSettings::configVersion());
@@ -1394,30 +1276,27 @@ int main(int argc, char **argv)
 			return 1;
 		}
 
-#ifdef DEBUG
-		DEBUGKPILOT << fname
-			<< ": Configuration version "
-			<< KPilotSettings::configVersion() << endl;
-#endif
+		DEBUGKPILOT << "Configuration version "
+			<< KPilotSettings::configVersion();
 	}
 
 
-	PilotDaemon *gPilotDaemon = new PilotDaemon();
+	PilotDaemon *pilotDaemon = new PilotDaemon();
 
 	if (p->isSet("device"))
-		gPilotDaemon->setTempDevice(p->getOption("device"));
+		pilotDaemon->setTempDevice(p->getOption("device"));
 
-	if (gPilotDaemon->status() == PilotDaemon::ERROR)
+	if (pilotDaemon->status() == PilotDaemon::ERROR)
 	{
-		delete gPilotDaemon;
+		delete pilotDaemon;
 
-		gPilotDaemon = 0;
+		pilotDaemon = 0;
 		WARNINGKPILOT << "Failed to start up daemon "
-			"due to errors constructing it." << endl;
+			"due to errors constructing it.";
 		return 2;
 	}
 
-	gPilotDaemon->showTray();
+	pilotDaemon->showTray();
 
 	return a.exec();
 }
