@@ -1,6 +1,6 @@
 /* KPilot
 **
-** Copyright (C) 1998-2001 by Dan Pilone
+** Copyright (C) 1998-2001 by Dan Pilone <dan@kpilot.org>
 ** Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 ** Copyright (C) 2006-2007 Adriaan de Groot <groot@kde.org>
 ** Copyright (C) 2007 Jason 'vanRijn' Kasper <vR@movingparts.net>
@@ -47,11 +47,11 @@
 #include <pi-file.h>
 #include <pi-buffer.h>
 
-#include <qdir.h>
-#include <qtimer.h>
-#include <qdatetime.h>
-#include <qthread.h>
-#include <QApplication>
+#include <QtCore/QDateTime>
+#include <QtCore/QDir>
+#include <QtCore/QThread>
+#include <QtCore/QTimer>
+#include <QtGui/QApplication>
 
 #include <kconfig.h>
 #include <kmessagebox.h>
@@ -110,10 +110,10 @@ private:
 	{
 		if ( !(mBoundDevices.count() > 0) ) return;
 		FUNCTIONSETUPL(3);
-		DEBUGKPILOT << fname << ": Bound devices: ["
+		DEBUGKPILOT << "Bound devices: ["
 			<< ((mBoundDevices.count() > 0) ?
 			mBoundDevices.join(CSL1(", ")) : CSL1("<none>")) 
-			<< "]" << endl;
+			<< ']';
 	}
 } ;
 
@@ -253,9 +253,9 @@ private:
 		else
 		{
 			FUNCTIONSETUP;
-			WARNINGKPILOT << "Link asked for, but either I'm "
+			WARNINGKPILOT << "Link asked for, but either I'm"
 				<< "done or I don't have a valid handle.  "
-				<< "Shutting down comm thread." << endl;
+				<< "Shutting down comm thread.";
 			QThread::exit();
 			return 0;
 		}
@@ -283,7 +283,7 @@ protected:
 	* Does the low-level opening of the device and handles the
 	* pilot-link library initialisation.
 	*/
-	bool open( const QString &device = QString::null );
+	bool open( const QString &device = QString() );
 	
 private:
 	inline QString errorMessage(int e) 
@@ -338,8 +338,8 @@ bool DeviceCommThread::openDevice()
 	// path...
 	if (!fDone && link()->fPilotPath.length() > 0)
 	{
-		DEBUGKPILOT << fname << ": Opening main pilot path: [" 
-			<< link()->fPilotPath << "]." << endl;
+		DEBUGKPILOT << ": Opening main pilot path: [" 
+			<< link()->fPilotPath << "].";
 		deviceOpened = open( link()->fPilotPath ); 
 	}
 
@@ -354,9 +354,9 @@ bool DeviceCommThread::openDevice()
 	// device, try the temp device...
 	if (!fDone && tryTemp)
 	{
-		DEBUGKPILOT << fname << ": Couldn't open main pilot path. "
+		DEBUGKPILOT << ": Couldn't open main pilot path."
 			<< "Now trying temp device: [" 
-			<< link()->fTempDevice << "]." << endl;
+			<< link()->fTempDevice << "].";
 		deviceOpened = open( link()->fTempDevice );
 	}
 
@@ -377,8 +377,8 @@ bool DeviceCommThread::open(const QString &device)
 		msg = i18n("Already listening on that device");
 		
 		WARNINGKPILOT << "Pilot Path: ["
-			<< link()->fRealPilotPath << "] already connected." << endl;
-		WARNINGKPILOT << msg << endl;
+			<< link()->fRealPilotPath << "] already connected.";
+		WARNINGKPILOT << msg;
 
 		link()->fLinkStatus = PilotLinkError;
 
@@ -389,8 +389,6 @@ bool DeviceCommThread::open(const QString &device)
 	}
 
 
-	DEBUGKPILOT << fname << ": Trying to create socket." << endl;
-
 	fTempSocket = pi_socket(PI_AF_PILOT, PI_SOCK_STREAM, PI_PF_DLP);
 
 	if (fTempSocket < 0)
@@ -398,8 +396,7 @@ bool DeviceCommThread::open(const QString &device)
 		e = errno;
 		msg = i18n("Cannot create socket for communicating "
 			"with the Pilot (%1)",errorMessage(e));
-		WARNINGKPILOT << msg << endl;
-		WARNINGKPILOT << "(" << strerror(e) << ")" << endl;
+		DEBUGKPILOT << msg << " (" << strerror(e) << ')';
 	
 		link()->fLinkStatus = PilotLinkError;
 		
@@ -409,25 +406,23 @@ bool DeviceCommThread::open(const QString &device)
 		return false;
 	}
 
-	DEBUGKPILOT << fname << ": Got socket: [" << fTempSocket << "]" << endl;
+	DEBUGKPILOT << "Got socket: [" << fTempSocket << ']' ;
 
 	link()->fLinkStatus = CreatedSocket;
 
-	DEBUGKPILOT << fname << ": Binding to path: [" 
-		<< link()->fRealPilotPath << "]" << endl;
+	DEBUGKPILOT << "Binding to path: [" 
+		<< link()->fRealPilotPath << ']';
 
 	ret = pi_bind(fTempSocket, QFile::encodeName(link()->fRealPilotPath));
 
 	if (ret < 0)
 	{
-		DEBUGKPILOT << fname
-			<< ": pi_bind error: ["
-			<< strerror(errno) << "]" << endl;
+		DEBUGKPILOT << "pi_bind error [" << strerror(errno) << ']';
 
 		e = errno;
 		msg = i18n("Cannot open Pilot port \"%1\". ",link()->fRealPilotPath);
 		
-		DEBUGKPILOT << msg << " (" << strerror(e) << ')' << endl;
+		DEBUGKPILOT << msg << " (" << strerror(e) << ')';
 	
 		link()->fLinkStatus = PilotLinkError;
 		
@@ -443,17 +438,16 @@ bool DeviceCommThread::open(const QString &device)
 	link()->fLinkStatus = DeviceOpen;
 	DeviceMap::self()->bindDevice( link()->fRealPilotPath );
 
-	DEBUGKPILOT << fname
-		<< ": Current status: ["
+	DEBUGKPILOT << "Current status: ["
 		<< link()->statusString()
-		<< "] and socket: [" << fTempSocket << "]" << endl;
+		<< "] and socket: [" << fTempSocket << ']';
 
 	ret = pi_listen(fTempSocket, 1);
 	if (ret < 0)
 	{
 		char *s = strerror(errno);
 
-		WARNINGKPILOT << "pi_listen returned: [" << s << "]" << endl;
+		WARNINGKPILOT << "pi_listen returned: [" << s << ']';
 
 		// Presumably, strerror() returns things in
 		// local8Bit and not latin1.
@@ -466,10 +460,9 @@ bool DeviceCommThread::open(const QString &device)
 	}
 
 	QApplication::postEvent(link(),
-		new DeviceCommEvent(EventLogProgress, QString::null, 10));
+		new DeviceCommEvent(EventLogProgress, QString(), 10));
 
-	DEBUGKPILOT << fname <<
-		": Listening to pilot. Now trying accept..." << endl;
+	DEBUGKPILOT << ": Listening to pilot. Now trying accept...";
 
 	int timeout=20;
 	if (link()->fWorkaroundUSB)
@@ -481,7 +474,7 @@ bool DeviceCommThread::open(const QString &device)
 	{
 		char *s = strerror(errno);
 
-		WARNINGKPILOT << "pi_accept returned: [" << s << "]" << endl;
+		WARNINGKPILOT << "pi_accept returned message [" << s << ']';
 
 		QApplication::postEvent(link(),
 			new DeviceCommEvent(EventLogError, i18n("Cannot accept Pilot (%1)",QString::fromLocal8Bit(s))));
@@ -490,12 +483,12 @@ bool DeviceCommThread::open(const QString &device)
 		return false;
 	}
 
-	DEBUGKPILOT << fname << ": Link accept done." << endl;
+	DEBUGKPILOT << ": Link accept done.";
 
 	if ((link()->fLinkStatus != DeviceOpen) || (fPilotSocket == -1))
 	{
 		link()->fLinkStatus = PilotLinkError;
-		WARNINGKPILOT << "Already connected or unable to connect!" << endl;
+		WARNINGKPILOT << "Already connected or unable to connect!";
 
 		QApplication::postEvent(link(),
 			new DeviceCommEvent(EventLogError, i18n("Cannot accept Pilot (%1)",i18n("already connected"))));
@@ -504,9 +497,9 @@ bool DeviceCommThread::open(const QString &device)
 	}
 
 	QApplication::postEvent(link(),
-		new DeviceCommEvent(EventLogProgress, QString::null, 30));
+		new DeviceCommEvent(EventLogProgress, QString(), 30));
 
-	DEBUGKPILOT << fname << ": doing dlp_ReadSysInfo..." << endl;
+	DEBUGKPILOT << ": doing dlp_ReadSysInfo...";
 
 	struct SysInfo sys_info;
 	if (dlp_ReadSysInfo(fPilotSocket, &sys_info) < 0)
@@ -520,31 +513,29 @@ bool DeviceCommThread::open(const QString &device)
 	}
 	else
 	{
-		DEBUGKPILOT << fname << ": dlp_ReadSysInfo successful..." << endl;
+		DEBUGKPILOT << "dlp_ReadSysInfo successful...";
 
         	KPILOT_DELETE(link()->fPilotSysInfo);
 		link()->fPilotSysInfo = new KPilotSysInfo(&sys_info);
-		DEBUGKPILOT << fname
-			<< ": RomVersion: [" << link()->fPilotSysInfo->getRomVersion()
+		DEBUGKPILOT << "RomVersion: [" << link()->fPilotSysInfo->getRomVersion()
 			<< "] Locale: [" << link()->fPilotSysInfo->getLocale()
 			<< "] Product: [" << link()->fPilotSysInfo->getProductID()
-			<< "]" << endl;
+			<< ']';
 	}
 
 	QApplication::postEvent(link(),
-		new DeviceCommEvent(EventLogProgress, QString::null, 60));
+		new DeviceCommEvent(EventLogProgress, QString(), 60));
 
         KPILOT_DELETE(link()->fPilotUser);
 	link()->fPilotUser = new KPilotUser;
 
-	DEBUGKPILOT << fname << ": doing dlp_ReadUserInfo..." << endl;
+	DEBUGKPILOT << "doing dlp_ReadUserInfo...";
 
 	/* Ask the pilot who it is.  And see if it's who we think it is. */
 	dlp_ReadUserInfo(fPilotSocket, link()->fPilotUser->data());
 
 	QString n = link()->getPilotUser().name();
-	DEBUGKPILOT << fname
-		<< ": Read user name: [" << n << "]" << endl;
+	DEBUGKPILOT << "Read user name: [" << n << ']';
 
 	QApplication::postEvent(link(),
 		new DeviceCommEvent(EventLogProgress, i18n("Checking last PC..."), 90));
@@ -552,8 +543,7 @@ bool DeviceCommThread::open(const QString &device)
 	/* Tell user (via Pilot) that we are starting things up */
 	if ((ret=dlp_OpenConduit(fPilotSocket)) < 0)
 	{
-		DEBUGKPILOT << fname
-			<< ": dlp_OpenConduit returned: [" << ret << "]" << endl;
+		DEBUGKPILOT << "dlp_OpenConduit returned: [" << ret << ']';
 
 		QApplication::postEvent(link(),
 			new DeviceCommEvent(EventLogError,
@@ -564,22 +554,21 @@ bool DeviceCommThread::open(const QString &device)
 	link()->fLinkStatus = AcceptedDevice;
 
 	QApplication::postEvent(link(),
-		new DeviceCommEvent(EventLogProgress, QString::null, 100));
+		new DeviceCommEvent(EventLogProgress, QString(), 100));
 
 	return true;
 }
 
 void DeviceCommThread::close()
 {
-	FUNCTIONSETUPL(4);
+	FUNCTIONSETUPL(2);
 
 	pi_close(fTempSocket);
 
 	if (fPilotSocket != -1)
 	{
-		DEBUGKPILOT << fname
-			<< ": device comm thread closing socket: ["
-			<< fPilotSocket << "]" << endl;
+		DEBUGKPILOT << "Device comm thread closing socket: ["
+			<< fPilotSocket << ']';
 
 		pi_close(fPilotSocket);
 	}
@@ -595,8 +584,8 @@ void DeviceCommThread::run()
 	int sleepBetweenPoll = SecondsBetweenPoll;
 	fDone = false;
 
-	DEBUGKPILOT << fname << ": Polling every: ["
-		<< sleepBetweenPoll << "] seconds." << endl;
+	DEBUGKPILOT << ": Polling every: ["
+		<< sleepBetweenPoll << "] seconds.";
 
 	while (!fDone)
 	{
@@ -625,7 +614,7 @@ void DeviceCommThread::run()
 		}
 	}
 
-	DEBUGKPILOT << fname << ": comm thread waiting to be done..." << endl;
+	DEBUGKPILOT << "comm thread waiting to be done...";
 
 	// keep the thread alive until we're supposed to be done
 	while (!fDone)
@@ -638,7 +627,7 @@ void DeviceCommThread::run()
 	// pilot-link (potentially, if it's libusb) is done before we exit
 	QThread::sleep(1);
 
-	DEBUGKPILOT << fname << ": comm thread now done..." << endl;
+	DEBUGKPILOT << "comm thread now done...";
 }
 
 
@@ -655,9 +644,7 @@ KPilotDeviceLink::KPilotDeviceLink(QObject * parent, const char *name, const QSt
 {
 	FUNCTIONSETUP;
 
-	DEBUGKPILOT << fname
-		<< ": Pilot-link version: [" << PILOT_LINK_NUMBER
-		<< "]" << endl;
+	DEBUGKPILOT << ": Pilot-link version: " << PILOT_LINK_NUMBER;
 }
 
 KPilotDeviceLink::~KPilotDeviceLink()
@@ -688,8 +675,7 @@ void KPilotDeviceLink::customEvent(QEvent *e)
 		}
 		else
 		{
-			DEBUGKPILOT << fname
-				<< ": unable to cast event: [" << e << "]" << endl;
+			DEBUGKPILOT << "Unable to cast event: [" << e << ']';
 		}
 	}
 	else if ((int)e->type() == EventLogMessage)
@@ -701,8 +687,7 @@ void KPilotDeviceLink::customEvent(QEvent *e)
 		}
 		else
 		{
-			DEBUGKPILOT << fname
-				<< ": unable to cast event: [" << e << "]" << endl;
+			DEBUGKPILOT << "Unable to cast event: [" << e << ']';
 		}
 	}
 	else if ((int)e->type() == EventLogError)
@@ -714,8 +699,7 @@ void KPilotDeviceLink::customEvent(QEvent *e)
 		}
 		else
 		{
-			DEBUGKPILOT << fname
-				<< ": unable to cast event: [" << e << "]" << endl;
+			DEBUGKPILOT << "Unable to cast event: [" << e << ']';
 		}
 	}
 	else if ((int)e->type() == EventLogProgress)
@@ -727,8 +711,7 @@ void KPilotDeviceLink::customEvent(QEvent *e)
 		}
 		else
 		{
-			DEBUGKPILOT << fname
-				<< ": unable to cast event: [" << e << "]" << endl;
+			DEBUGKPILOT << "Unable to cast event: [" << e << ']';
 		}
 	}
 	else
@@ -748,17 +731,15 @@ void KPilotDeviceLink::stopCommThread()
 		// block the main thread forever
 		if (fDeviceCommThread->isRunning()) 
 		{
-			DEBUGKPILOT << fname
-				<< ": comm thread still running. "
-				<< "waiting for it to complete." << endl;
+			DEBUGKPILOT
+				<< "comm thread still running. Waiting for it to complete.";
 			bool done = fDeviceCommThread->wait(30000);
 			if (!done)
 			{
-				DEBUGKPILOT << fname
-					<< ": comm thread still running "
+				DEBUGKPILOT
+					<< "comm thread still running "
 					<< "after wait(). "
-					<< "going to have to terminate it."
-					<< endl;
+					<< "going to have to terminate it.";
 				// not normally to be done, but we must make sure
 				// that this device doesn't come back alive
 				fDeviceCommThread->terminate();
@@ -774,7 +755,7 @@ void KPilotDeviceLink::stopCommThread()
 
 void KPilotDeviceLink::close()
 {
-	FUNCTIONSETUP;
+	FUNCTIONSETUPL(2);
 
 	stopCommThread();
 
@@ -790,7 +771,7 @@ void KPilotDeviceLink::reset(const QString & dP)
 	// Release all resources
 	//
 	close();
-	fPilotPath = QString::null;
+	fPilotPath = QString();
 
 	fPilotPath = dP;
 	if (fPilotPath.isEmpty())
@@ -809,11 +790,10 @@ void KPilotDeviceLink::startCommThread()
 
 	if (fTempDevice.isEmpty() && pilotPath().isEmpty())
 	{
-		WARNINGKPILOT << "No point in trying empty device."
-			<< endl;
+		WARNINGKPILOT << "No point in trying empty device.";
 
 		QString msg = i18n("The Pilot device is not configured yet.");
-		WARNINGKPILOT << msg << endl;
+		WARNINGKPILOT << msg;
 
 
 		fLinkStatus = PilotLinkError;
@@ -893,20 +873,21 @@ bool KPilotDeviceLink::installFile(const QString & f, const bool deleteFile)
 {
 	FUNCTIONSETUP;
 
-	DEBUGKPILOT << fname << ": Installing file " << f << endl;
+	DEBUGKPILOT << "Installing file [" << f << ']';
 
 	if (!QFile::exists(f))
+	{
 		return false;
+	}
 
 	char buffer[PATH_MAX];
 	memset(buffer,0,PATH_MAX);
 	strlcpy(buffer,QFile::encodeName(f),PATH_MAX);
-	struct pi_file *pf =
-		pi_file_open(buffer);
+	struct pi_file *pf = pi_file_open(buffer);
 
 	if (f.isEmpty())
 	{
-		WARNINGKPILOT << "Cannot open file " << f << endl;
+		WARNINGKPILOT << "Cannot open file [" << f << ']';
 		emit logError(i18n
 			("<qt>Cannot install the file &quot;%1&quot;.</qt>", f));
 		return false;
@@ -914,7 +895,7 @@ bool KPilotDeviceLink::installFile(const QString & f, const bool deleteFile)
 
 	if (pi_file_install(pf, fPilotSocket, 0, 0L) < 0)
 	{
-		WARNINGKPILOT << "Cannot pi_file_install " << f << endl;
+		WARNINGKPILOT << "Cannot pi_file_install" << f;
 		emit logError(i18n
 			("<qt>Cannot install the file &quot;%1&quot;.</qt>", f));
 		return false;
@@ -984,7 +965,7 @@ void KPilotDeviceLink::endSync( EndOfSyncFlags f )
 		getPilotUser().setLastSyncPC((unsigned long) gethostid());
 		getPilotUser().setLastSyncDate(time(0));
 
-		DEBUGKPILOT << fname << ": Writing username " << getPilotUser().name() << endl;
+		DEBUGKPILOT << "Writing username" << getPilotUser().name();
 
 		dlp_WriteUserInfo(pilotSocket(),getPilotUser().data());
 		addSyncLogEntry(i18n("End of HotSync\n"));
@@ -1028,21 +1009,21 @@ bool KPilotDeviceLink::retrieveDatabase(const QString &fullBackupName,	DBInfo *i
 		return false;
 	}
 
-	DEBUGKPILOT << fname << ": Writing DB <" << info->name << "> "
-		<< " to " << fullBackupName << endl;
+	DEBUGKPILOT << "Writing DB [" << info->name << ']'
+		<< " to [" << fullBackupName << ']';
 
 	QByteArray encodedName = QFile::encodeName(fullBackupName);
 	struct pi_file *f = pi_file_create(encodedName,info);
 
 	if (!f)
 	{
-		WARNINGKPILOT << "Failed, unable to create file" << endl;
+		WARNINGKPILOT << "Failed, unable to create file.";
 		return false;
 	}
 
 	if (pi_file_retrieve(f, pilotSocket(), 0, 0L) < 0)
 	{
-		WARNINGKPILOT << "Failed, unable to back up database" << endl;
+		WARNINGKPILOT << "Failed, unable to back up database.";
 
 		pi_file_close(f);
 		return false;
@@ -1091,8 +1072,7 @@ const KPilotCard *KPilotDeviceLink::getCardInfo(int card)
 	KPilotCard *cardinfo=new KPilotCard();
 	if (dlp_ReadStorageInfo(pilotSocket(), card, cardinfo->cardInfo())<0)
 	{
-		WARNINGKPILOT << "Could not get info for card "
-			<< card << endl;
+		WARNINGKPILOT << "Could not get info for card " << card;
 
 		KPILOT_DELETE(cardinfo);
 		return 0L;
