@@ -177,7 +177,7 @@ void ResourceXMLRPC::writeConfig( KConfigGroup &group )
 
 bool ResourceXMLRPC::doOpen()
 {
-  kDebug(5800) << "ResourceXMLRPC::doOpen()" << endl;
+  kDebug(5800) <<"ResourceXMLRPC::doOpen()";
 
   delete mServer;
 
@@ -201,7 +201,7 @@ bool ResourceXMLRPC::doOpen()
 
 void ResourceXMLRPC::doClose()
 {
-  kDebug(5800) << "ResourceXMLRPC::doClose()" << endl;
+  kDebug(5800) <<"ResourceXMLRPC::doClose()";
 
   QMap<QString, QVariant> args;
   args.insert( "sessionid", mSessionID );
@@ -216,7 +216,7 @@ void ResourceXMLRPC::doClose()
 
 bool ResourceXMLRPC::doLoad( bool )
 {
-  kDebug() << "ResourceXMLRPC::load()" << endl;
+  kDebug() <<"ResourceXMLRPC::load()";
 
   calendar()->close();
 
@@ -377,17 +377,19 @@ Event *ResourceXMLRPC::event( const QString& uid )
 }
 
 Event::List ResourceXMLRPC::rawEventsForDate( const QDate& qd,
+                                              const KDateTime::Spec& timespec,
                                               EventSortField sortField,
                                               SortDirection sortDirection )
 {
-  return calendar()->rawEventsForDate( qd, sortField, sortDirection );
+  return calendar()->rawEventsForDate( qd, timespec, sortField, sortDirection );
 }
 
 
 Event::List ResourceXMLRPC::rawEvents( const QDate& start, const QDate& end,
+                                       const KDateTime::Spec& timespec,
                                        bool inclusive )
 {
-  return calendar()->rawEvents( start, end, inclusive );
+  return calendar()->rawEvents( start, end, timespec, inclusive );
 }
 
 Event::List ResourceXMLRPC::rawEventsForDate( const KDateTime& dt )
@@ -533,7 +535,7 @@ void ResourceXMLRPC::logoutFinished( const QList<QVariant>& variant,
   QMap<QString, QVariant> map = variant[ 0 ].toMap();
 
   if ( map[ "GOODBYE" ].toString() != "XOXO" )
-    kError() << "logout failed" << endl;
+    kError() <<"logout failed";
 
   KUrl url = KUrl( mPrefs->url() );
   mSessionID = mKp3 = "";
@@ -559,7 +561,7 @@ void ResourceXMLRPC::listEventsFinished( const QList<QVariant>& list,
     QMap<QString, QVariant> map = (*eventIt).toMap();
 
     Event *event = new Event;
-    event->setFloats( false );
+    event->setAllDay( false );
 
     QString uid;
     readEvent( map, event, uid );
@@ -641,7 +643,7 @@ void ResourceXMLRPC::loadEventCategoriesFinished( const QList<QVariant> &mapList
   const QMap<QString, QVariant> map = mapList[ 0 ].toMap();
   QMap<QString, QVariant>::ConstIterator it;
 
-  KPimPrefs prefs( "korganizerrc" );
+  KPIM::KPimPrefs prefs( "korganizerrc" );
   for ( it = map.begin(); it != map.end(); ++it ) {
     mEventCategoryMap.insert( it.value().toString(), it.key().toInt() );
 
@@ -746,7 +748,7 @@ void ResourceXMLRPC::loadTodoCategoriesFinished( const QList<QVariant> &mapList,
   const QMap<QString, QVariant> map = mapList[ 0 ].toMap();
   QMap<QString, QVariant>::ConstIterator it;
 
-  KPimPrefs prefs( "korganizerrc" );
+  KPIM::KPimPrefs prefs( "korganizerrc" );
   for ( it = map.begin(); it != map.end(); ++it ) {
     mTodoCategoryMap.insert( it.value().toString(), it.key().toInt() );
 
@@ -763,7 +765,7 @@ void ResourceXMLRPC::loadTodoCategoriesFinished( const QList<QVariant> &mapList,
 void ResourceXMLRPC::fault( int error, const QString& errorMsg,
                             const QVariant& )
 {
-  kError() << "Server send error " << error << ": " << errorMsg << endl;
+  kError() <<"Server send error" << error <<":" << errorMsg;
   mSynchronizer->stop();
 }
 
@@ -793,7 +795,7 @@ void ResourceXMLRPC::readEvent( const QMap<QString, QVariant> &args, Event *even
            start.time().hour() == 0 && start.time().minute() == 0 &&
            start.time().second() == 0 ) {
         event->setDtEnd( end.addDays( -1 ) );
-        event->setFloats( true );
+        event->setAllDay( true );
       } else {
         event->setDtEnd( end );
         event->setHasEndDate( true );
@@ -935,7 +937,7 @@ void ResourceXMLRPC::writeEvent( Event *event, QMap<QString, QVariant> &args )
   args.insert( "start", event->dtStart().toTimeSpec( timeSpec() ).dateTime() );
 
   // handle all day events
-  if ( event->floats() )
+  if ( event->allDay() )
     args.insert( "end", event->dtEnd().addDays( 1 ).dateTime() );
   else
     args.insert( "end", event->dtEnd().toTimeSpec( timeSpec() ).dateTime() );
@@ -1144,13 +1146,13 @@ void ResourceXMLRPC::readTodo( const QMap<QString, QVariant>& args, Todo *todo,
 
   todo->setLastModified( KDateTime( args[ "datemodified" ].toDateTime(), timeSpec() ) );
 
-  todo->setFloats( true );
+  todo->setAllDay( true );
   KDateTime dateTime( args[ "startdate" ].toDateTime(), timeSpec() );
   if ( dateTime.isValid() ) {
     todo->setDtStart( dateTime );
     todo->setHasStartDate( true );
     if ( !dateTime.time().isNull() )
-      todo->setFloats( false );
+      todo->setAllDay( false );
   }
 
   dateTime = KDateTime( args[ "enddate" ].toDateTime(), timeSpec() );
@@ -1158,7 +1160,7 @@ void ResourceXMLRPC::readTodo( const QMap<QString, QVariant>& args, Todo *todo,
     todo->setDtDue( dateTime );
     todo->setHasDueDate( true );
     if ( !dateTime.time().isNull() )
-      todo->setFloats( false );
+      todo->setAllDay( false );
   }
 
   // SUBTODO
