@@ -40,6 +40,7 @@
 #include <ktemporaryfile.h>
 #include <kabc/vcardconverter.h>
 #include <kmainwindow.h>
+#include <kconfiggroup.h>
 
 #include <QObject>
 #include <QTimer>
@@ -78,7 +79,7 @@ static const char* s_attachmentMimeTypeDistList = "application/x-vnd.kolab.conta
 static const char* s_inlineMimeType = "text/x-vcard"; // the new mimetype name is text/directory, but keep this for compat
 
 KABC::ResourceKolab::ResourceKolab()
-  : KPIM::ResourceABC(),
+  : KABC::ResourceABC(),
     Kolab::ResourceKolabBase( "ResourceKolab_KABC" ),
     mCachedSubresource( QString() ), mLocked( false )
 {
@@ -86,7 +87,7 @@ KABC::ResourceKolab::ResourceKolab()
 }
 
 KABC::ResourceKolab::ResourceKolab( const KConfigGroup& config )
-  : KPIM::ResourceABC( config ),
+  : KABC::ResourceABC( config ),
     Kolab::ResourceKolabBase( "ResourceKolab_KABC" ),
     mCachedSubresource( QString() ), mLocked( false )
 {
@@ -95,7 +96,7 @@ KABC::ResourceKolab::ResourceKolab( const KConfigGroup& config )
 
 KABC::ResourceKolab::~ResourceKolab()
 {
-  // The resource is deleted on exit (StdAddressBook's KStaticDeleter),
+  // The resource is deleted on exit (StdAddressBook's K3StaticDeleter),
   // and it wasn't closed before that, so close here to save the config.
   if ( isOpen() ) {
     close();
@@ -136,7 +137,7 @@ void KABC::ResourceKolab::doClose()
   KConfig config( configFile() );
 
   Kolab::ResourceMap::ConstIterator it;
-  for ( it = mSubResources.begin(); it != mSubResources.end(); ++it ) { 
+  for ( it = mSubResources.begin(); it != mSubResources.end(); ++it ) {
     KConfigGroup group = config.group( it.key() );
     group.writeEntry( "Active", it.value().active() );
     group.writeEntry( "CompletionWeight", it.value().completionWeight() );
@@ -146,7 +147,7 @@ void KABC::ResourceKolab::doClose()
 KABC::Ticket * KABC::ResourceKolab::requestSaveTicket()
 {
   if ( !addressBook() ) {
-    kError() << "no addressbook" << endl;
+    kError() <<"no addressbook";
     return 0;
   }
   mLocked = true;
@@ -179,7 +180,7 @@ QString KABC::ResourceKolab::loadContact( const QString& contactData,
   addr.setChanged( false );
   KABC::Resource::insertAddressee( addr ); // same as mAddrMap.insert( addr.uid(), addr );
   mUidMap[ addr.uid() ] = StorageReference( subResource, sernum );
-  kDebug(5650) << "Loaded contact uid=" << addr.uid() << " sernum=" << sernum << " fullName=" << addr.name() << endl;
+  kDebug(5650) <<"Loaded contact uid=" << addr.uid() <<" sernum=" << sernum <<" fullName=" << addr.name();
   return addr.uid();
 }
 
@@ -193,8 +194,8 @@ static const struct { const char* mimetype; KMail::StorageFormat format; } s_for
 bool KABC::ResourceKolab::loadSubResource( const QString& subResource )
 {
   int count = 0;
-  if ( !kmailIncidencesCount( count, QString::null, subResource ) ) {
-    kError() << "Communication problem in KABC::ResourceKolab::loadSubResourceHelper()\n";
+  if ( !kmailIncidencesCount( count, QString(), subResource ) ) {
+    kError() <<"Communication problem in KABC::ResourceKolab::loadSubResourceHelper()";
     return false;
   }
   if ( !count )
@@ -227,7 +228,7 @@ bool KABC::ResourceKolab::loadSubResource( const QString& subResource )
       KMail::StorageFormat format = s_formats[indexFormat].format;
       QMap<quint32, QString> lst;
       if ( !kmailIncidences( lst, mimetype, subResource, startIndex, nbMessages ) ) {
-        kError() << "Communication problem in KABC::ResourceKolab::loadSubResource()\n";
+        kError() <<"Communication problem in KABC::ResourceKolab::loadSubResource()";
 #if 0 // TODO port progress dialog
         if ( progressId )
           uiserver.jobFinished( progressId );
@@ -253,7 +254,7 @@ bool KABC::ResourceKolab::loadSubResource( const QString& subResource )
 
   }
 
-  kDebug(5650) << "Contacts kolab resource: got " << count << " contacts in " << subResource << endl;
+  kDebug(5650) <<"Contacts kolab resource: got" << count <<" contacts in" << subResource;
 
 #if 0 // TODO port progress dialog
   if ( progressId )
@@ -290,7 +291,7 @@ bool KABC::ResourceKolab::save( Ticket* )
     }
 
   if ( !rc )
-    kDebug(5650) << k_funcinfo << " failed." << endl;
+    kDebug(5650) <<" failed.";
   return rc;
 }
 
@@ -323,7 +324,7 @@ void AttachmentList::updatePictureAttachment( const QImage& image, const QString
     image.save( &tempFile, "PNG" );
     KUrl url;
     url.setPath( tempFile.fileName() );
-    kDebug(5650) << "picture saved to " << url.path() << endl;
+    kDebug(5650) <<"picture saved to" << url.path();
     addAttachment( url.url(), name, "image/png" );
   } else {
     deletedAttachments.append( name );
@@ -340,7 +341,7 @@ void AttachmentList::updateAttachment( const QByteArray& data, const QString& na
     tempFile.write( data );
     KUrl url;
     url.setPath( tempFile.fileName() );
-    kDebug(5650) << "data saved to " << url.path() << endl;
+    kDebug(5650) <<"data saved to" << url.path();
     addAttachment( url.url(), name, mimetype );
   } else {
     deletedAttachments.append( name );
@@ -355,7 +356,7 @@ bool KABC::ResourceKolab::kmailUpdateAddressee( const Addressee& addr )
   if ( mUidMap.find( uid ) != mUidMap.end() ) {
     subResource = mUidMap[ uid ].resource();
     if ( !subresourceWritable( subResource ) ) {
-      kWarning() << "Wow! Something tried to update a non-writable addressee! Fix this caller: " << kBacktrace() << endl;
+      kWarning() <<"Wow! Something tried to update a non-writable addressee! Fix this caller:" << kBacktrace();
       return false;
     }
     sernum = mUidMap[ uid ].serialNumber();
@@ -400,9 +401,9 @@ bool KABC::ResourceKolab::kmailUpdateAddressee( const Addressee& addr )
                          att.attachmentURLs, att.attachmentMimeTypes, att.attachmentNames,
                          att.deletedAttachments );
   if ( !rc )
-    kDebug(5650) << "kmailUpdate returned false!" << endl;
+    kDebug(5650) <<"kmailUpdate returned false!";
   if ( rc ) {
-    kDebug(5650) << "kmailUpdate returned, now sernum=" << sernum << " for uid=" << uid << endl;
+    kDebug(5650) <<"kmailUpdate returned, now sernum=" << sernum <<" for uid=" << uid;
     mUidMap[ uid ] = StorageReference( subResource, sernum );
     // This is ugly, but it's faster than doing
     // mAddrMap.find(addr.uid()), which would give the same :-(
@@ -421,7 +422,7 @@ bool KABC::ResourceKolab::kmailUpdateAddressee( const Addressee& addr )
 void KABC::ResourceKolab::insertAddressee( const Addressee& addr )
 {
   const QString uid = addr.uid();
-  //kDebug(5650) << k_funcinfo << uid << endl;
+  //kDebug(5650) << uid;
   bool ok = false;
   if ( mUidMap.contains( uid ) ) {
     mUidsPendingUpdate.append( uid );
@@ -439,10 +440,10 @@ void KABC::ResourceKolab::removeAddressee( const Addressee& addr )
 {
   const QString uid = addr.uid();
   if ( mUidMap.find( uid ) == mUidMap.end() ) return;
-  //kDebug(5650) << k_funcinfo << uid << endl;
+  //kDebug(5650) << uid;
   const QString resource = mUidMap[ uid ].resource();
   if ( !subresourceWritable( resource ) ) {
-    kWarning() << "Wow! Something tried to delete a non-writable addressee! Fix this caller: " << kBacktrace() << endl;
+    kWarning() <<"Wow! Something tried to delete a non-writable addressee! Fix this caller:" << kBacktrace();
     return;
   }
   /* The user told us to delete, tell KMail */
@@ -472,7 +473,7 @@ bool KABC::ResourceKolab::fromKMailAddIncidence( const QString& type,
   const QString uid = loadContact( contactXML, subResource, sernum,
       ( KMail::StorageFormat )format );
 
-  //kDebug(5650) << k_funcinfo << uid << endl;
+  //kDebug(5650) << uid;
 
   // Emit "addressbook changed" if this comes from kmail and not from the GUI
   if ( !mUidsPendingAdding.contains( uid )
@@ -494,7 +495,7 @@ void KABC::ResourceKolab::fromKMailDelIncidence( const QString& type,
   if( type != s_kmailContentsType || !subresourceActive( subResource ) )
     return;
 
-  //kDebug(5650) << k_funcinfo << uid << endl;
+  //kDebug(5650) << uid;
 
   // Can't be in both, by contract
   if ( mUidsPendingDeletion.contains( uid ) ) {
@@ -516,7 +517,7 @@ void KABC::ResourceKolab::fromKMailRefresh( const QString& type,
   // Check if this is a contact
   if( type != s_kmailContentsType ) return;
 
-  //kDebug(5650) << k_funcinfo << endl;
+  //kDebug(5650) ;
 
   load(); // ### should call loadSubResource(subResource) probably
   addressBook()->emitAddressBookChanged();
@@ -592,7 +593,7 @@ void KABC::ResourceKolab::fromKMailAsyncLoadResult( const QMap<quint32, QString>
     loadContact( it.value(), folder, it.key(), format );
   }
   if ( !addressBook() ){
-    kDebug(5650) << "asyncLoadResult() : addressBook() returning NULL pointer.\n";
+    kDebug(5650) <<"asyncLoadResult() : addressBook() returning NULL pointer.";
   }else
     addressBook()->emitAddressBookChanged();
 }
@@ -609,7 +610,7 @@ bool KABC::ResourceKolab::subresourceActive( const QString& subresource ) const
   }
 
   // Safe default bet:
-  kDebug(5650) << "subresourceActive( " << subresource << " ): Safe bet\n";
+  kDebug(5650) <<"subresourceActive(" << subresource <<" ): Safe bet";
 
   return true;
 }
@@ -628,7 +629,7 @@ int KABC::ResourceKolab::subresourceCompletionWeight( const QString& subresource
     return mSubResources[ subresource ].completionWeight();
   }
 
-  kDebug(5650) << "subresourceCompletionWeight( " << subresource << " ): not found, using default\n";
+  kDebug(5650) <<"subresourceCompletionWeight(" << subresource <<" ): not found, using default";
 
   return 80;
 }
@@ -639,7 +640,7 @@ QString KABC::ResourceKolab::subresourceLabel( const QString& subresource ) cons
     return mSubResources[ subresource ].label();
   }
 
-  kDebug(5650) << "subresourceLabel( " << subresource << " ): not found!\n";
+  kDebug(5650) <<"subresourceLabel(" << subresource <<" ): not found!";
   return QString();
 }
 
@@ -648,7 +649,7 @@ void KABC::ResourceKolab::setSubresourceCompletionWeight( const QString& subreso
   if ( mSubResources.contains( subresource ) ) {
     mSubResources[ subresource ].setCompletionWeight( completionWeight );
   } else {
-    kDebug(5650) << "setSubresourceCompletionWeight: subresource " << subresource << " not found" << endl;
+    kDebug(5650) <<"setSubresourceCompletionWeight: subresource" << subresource <<" not found";
   }
 }
 
@@ -668,7 +669,7 @@ void KABC::ResourceKolab::setSubresourceActive( const QString &subresource, bool
     mSubResources[ subresource ].setActive( active );
     load();
   } else {
-    kDebug(5650) << "setSubresourceCompletionWeight: subresource " << subresource << " not found" << endl;
+    kDebug(5650) <<"setSubresourceCompletionWeight: subresource" << subresource <<" not found";
   }
 }
 
