@@ -53,6 +53,7 @@
 #include <assert.h>
 
 using namespace KCal;
+using namespace KPIM;
 using namespace Kolab;
 
 static const char* kmailCalendarContentsType = "Calendar";
@@ -86,7 +87,7 @@ ResourceKolab::ResourceKolab()
 
 ResourceKolab::~ResourceKolab()
 {
-  // The resource is deleted on exit (StdAddressBook's KStaticDeleter),
+  // The resource is deleted on exit (StdAddressBook's K3StaticDeleter),
   // and it wasn't closed before that, so close here to save the config.
   if ( mOpen ) {
     close();
@@ -164,7 +165,7 @@ bool ResourceKolab::loadSubResource( const QString& subResource,
 {
   int count = 0;
   if ( !kmailIncidencesCount( count, mimetype, subResource ) ) {
-    kError(5650) << "Communication problem in ResourceKolab::load()\n";
+    kError(5650) <<"Communication problem in ResourceKolab::load()";
     return false;
   }
 
@@ -205,7 +206,7 @@ bool ResourceKolab::loadSubResource( const QString& subResource,
   for ( int startIndex = 0; startIndex < count; startIndex += nbMessages ) {
     QMap<quint32, QString> lst;
     if ( !kmailIncidences( lst, mimetype, subResource, startIndex, nbMessages ) ) {
-      kError(5650) << "Communication problem in ResourceKolab::load()\n";
+      kError(5650) <<"Communication problem in ResourceKolab::load()";
 #if  0
       if ( progressId )
         uiserver.call( "jobFinished",  progressId, errorCode ); //TODO
@@ -324,7 +325,7 @@ void ResourceKolab::incidenceUpdatedSilent( KCal::IncidenceBase* incidencebase)
 {
   if ( incidencebase->isReadOnly() ) return; // Should not happen (TM)
   const QString uid = incidencebase->uid();
-  //kDebug() << k_funcinfo << uid << endl;
+  //kDebug() << uid;
 
   if ( mUidsPendingUpdate.contains( uid ) || mUidsPendingAdding.contains( uid ) ) {
     /* We are currently processing this event ( removing and readding or
@@ -448,7 +449,7 @@ bool ResourceKolab::sendKMailUpdate( KCal::IncidenceBase* incidencebase, const Q
     } else {
       mimetype = incidenceInlineMimeType;
       data = mFormat.createScheduleMessage( static_cast<KCal::Event *>(incidencebase),
-          Scheduler::Request );
+          iTIPRequest );
     }
   } else if ( type == "Todo" ) {
     if( isXMLStorageFormat ) {
@@ -458,7 +459,7 @@ bool ResourceKolab::sendKMailUpdate( KCal::IncidenceBase* incidencebase, const Q
     } else {
       mimetype = incidenceInlineMimeType;
       data = mFormat.createScheduleMessage( static_cast<KCal::Todo *>(incidencebase),
-          Scheduler::Request );
+          iTIPRequest );
     }
   } else if ( type == "Journal" ) {
     if( isXMLStorageFormat ) {
@@ -468,13 +469,13 @@ bool ResourceKolab::sendKMailUpdate( KCal::IncidenceBase* incidencebase, const Q
     } else {
       mimetype = incidenceInlineMimeType;
       data = mFormat.createScheduleMessage( static_cast<KCal::Journal *>(incidencebase),
-          Scheduler::Request );
+          iTIPRequest );
     }
   } else {
-    kWarning(5006) << "Can't happen: unhandled type=" << type << endl;
+    kWarning(5006) <<"Can't happen: unhandled type=" << type;
   }
 
-//  kDebug() << k_funcinfo << "Data string:\n" << data << endl;
+//  kDebug() <<"Data string:" << data;
 
   KCal::Incidence* incidence = static_cast<KCal::Incidence *>( incidencebase );
 
@@ -538,7 +539,7 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
   else if ( type == "Journal" )
     map = &mJournalSubResources;
   else
-    kWarning() << "unknown type " << type << endl;
+    kWarning() <<"unknown type" << type;
 
   if ( !mSilent ) { /* We got this one from the user, tell KMail. */
     // Find out if this event was previously stored in KMail
@@ -558,7 +559,7 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
       if ( !incidence->location().isEmpty() )
         text += i18n( "<b>Location:</b> %1", incidence->location() );
       text += "<br>";
-      if ( !incidence->recurrence()->floats() )
+      if ( !incidence->recurrence()->allDay() )
         text += i18n( "<b>Start:</b> %1, %2" )
                 .arg( incidence->dtStartDateStr(), incidence->dtStartTimeStr() );
       else
@@ -567,7 +568,7 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
       if ( incidence->type() == "Event" ) {
         Event* event = static_cast<Event*>( incidence );
         if ( event->hasEndDate() )
-          if ( !event->recurrence()->floats() )
+          if ( !event->recurrence()->allDay() )
             text += i18n( "<b>End:</b> %1, %2" )
                     .arg( event->dtEndDateStr(), event->dtEndTimeStr() );
           else
@@ -583,7 +584,7 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
     mNewIncidencesMap.insert( uid, subResource );
 
     if ( !sendKMailUpdate( incidence, subResource, sernum ) ) {
-      kError(5650) << "Communication problem in ResourceKolab::addIncidence()\n";
+      kError(5650) <<"Communication problem in ResourceKolab::addIncidence()";
       return false;
     } else {
       // KMail is doing it's best to add the event now, put a sticker on it,
@@ -619,8 +620,8 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
           if ( (*map)[ subResource ].writable() ) {
             resolveConflict( incidence, subResource, sernum );
           } else {
-            kWarning( 5650 ) << "Duplicate event in a read-only folder detected! "
-              "Please inform the owner of the folder. " << endl;
+            kWarning( 5650 ) <<"Duplicate event in a read-only folder detected!"
+              "Please inform the owner of the folder.";
           }
           return true;
         } else {
@@ -716,10 +717,11 @@ KCal::Event::List ResourceKolab::rawEvents( EventSortField sortField, SortDirect
 }
 
 KCal::Event::List ResourceKolab::rawEventsForDate( const QDate& date,
+                                                   const KDateTime::Spec& timespec,
                                                    EventSortField sortField,
                                                    SortDirection sortDirection )
 {
-  return mCalendar.rawEventsForDate( date, sortField, sortDirection );
+  return mCalendar.rawEventsForDate( date, timespec, sortField, sortDirection );
 }
 
 KCal::Event::List ResourceKolab::rawEventsForDate( const KDateTime& dt )
@@ -729,9 +731,10 @@ KCal::Event::List ResourceKolab::rawEventsForDate( const KDateTime& dt )
 
 KCal::Event::List ResourceKolab::rawEvents( const QDate& start,
                                             const QDate& end,
+                                            const KDateTime::Spec& timespec,
                                             bool inclusive )
 {
-  return mCalendar.rawEvents( start, end, inclusive );
+  return mCalendar.rawEvents( start, end, timespec, inclusive );
 }
 
 bool ResourceKolab::addTodo( KCal::Todo* todo )
@@ -829,7 +832,7 @@ KCal::Alarm::List ResourceKolab::relevantAlarms( const KCal::Alarm::List &alarms
        if ( subResource->alarmRelevant() )
            relevantAlarms.append ( a );
        else {
-         kDebug(5650) << "Alarm skipped, not relevant." << endl;
+         kDebug(5650) <<"Alarm skipped, not relevant.";
        }
      }
   }
@@ -931,7 +934,7 @@ void ResourceKolab::fromKMailRefresh( const QString& type,
   else if ( type == "Journal" )
     loadAllJournals();
   else
-    kWarning(5006) << "KCal Kolab resource: fromKMailRefresh: unknown type " << type << endl;
+    kWarning(5006) <<"KCal Kolab resource: fromKMailRefresh: unknown type" << type;
   mResourceChangedTimer.start( 100 );
 }
 
@@ -1001,8 +1004,7 @@ QStringList ResourceKolab::subresources() const
          + mJournalSubResources.keys() );
 }
 
-const QString
-ResourceKolab::labelForSubresource( const QString& subresource ) const
+QString ResourceKolab::labelForSubresource( const QString& subresource ) const
 {
   if ( mEventSubResources.contains( subresource ) )
     return mEventSubResources[ subresource ].label();
@@ -1036,7 +1038,7 @@ bool ResourceKolab::subresourceActive( const QString& subresource ) const
     return mJournalSubResources[ subresource ].active();
 
   // Safe default bet:
-  kDebug(5650) << "subresourceActive( " << subresource << " ): Safe bet\n";
+  kDebug(5650) <<"subresourceActive(" << subresource <<" ): Safe bet";
 
   return true;
 }
@@ -1071,7 +1073,7 @@ void ResourceKolab::setSubresourceActive( const QString &subresource, bool v )
 
 void ResourceKolab::slotEmitResourceChanged()
 {
-   kDebug(5650) << "KCal Kolab resource: emitting resource changed " << endl;
+   kDebug(5650) <<"KCal Kolab resource: emitting resource changed";
    mResourceChangedTimer.stop();
    emit resourceChanged( this );
 }
@@ -1099,7 +1101,7 @@ Kolab::ResourceMap* ResourceKolab::subResourceMap( const QString& contentsType )
 /*virtual*/
 bool ResourceKolab::addSubresource( const QString& resource, const QString& parent )
 {
-   kDebug(5650) << "KCal Kolab resource - adding subresource: " << resource << endl;
+   kDebug(5650) <<"KCal Kolab resource - adding subresource:" << resource;
    QString contentsType = kmailCalendarContentsType;
    if ( !parent.isEmpty() ) {
      if ( mEventSubResources.contains( parent ) )
@@ -1112,7 +1114,7 @@ bool ResourceKolab::addSubresource( const QString& resource, const QString& pare
      QStringList contentTypeChoices;
      contentTypeChoices << i18n("Calendar") << i18n("Tasks") << i18n("Journals");
      const QString caption = i18n("Which kind of subresource should this be?");
-     const QString choice = KInputDialog::getItem( caption, QString::null, contentTypeChoices );
+     const QString choice = KInputDialog::getItem( caption, QString(), contentTypeChoices );
      if ( choice == contentTypeChoices[0] )
        contentsType = kmailCalendarContentsType;
      else if ( choice == contentTypeChoices[1] )
@@ -1127,7 +1129,7 @@ bool ResourceKolab::addSubresource( const QString& resource, const QString& pare
 /*virtual*/
 bool ResourceKolab::removeSubresource( const QString& resource )
 {
-   kDebug(5650) << "KCal Kolab resource - removing subresource: " << resource << endl;
+   kDebug(5650) <<"KCal Kolab resource - removing subresource:" << resource;
    return kmailRemoveSubresource( resource );
 }
 
