@@ -1,6 +1,6 @@
 /*
- *   This file only:
- *     Copyright (C) 2003, 2004  Mark Bucciarelli <mark@hubcapconsulting.com>
+ *     Copyright (C) 2003, 2004 by Mark Bucciarelli <mark@hubcapconsutling.com>
+ *                   2007 the ktimetracker developers
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@
  *
  */
 
+#include "karmstorage.h"
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -54,82 +56,85 @@
 #include <kcal/resourcecalendar.h>
 #include <kcal/resourcelocal.h>
 #include <resourceremote.h>
-#include <kpimprefs.h>
+#include <kpimprefs.h>  // for timezone
 #include <kio/netaccess.h>
 
 #include "taskview.h"
 #include "timekard.h"
 #include "karmutility.h"
-#include "karmstorage.h"
-#include "preferences.h"
+#include "ktimetracker.h"
 #include "task.h"
 
-KarmStorage *KarmStorage::_instance = 0;
 static long linenr;  // how many lines written by printTaskHistory so far
 
+//@cond PRIVATE
+class KarmStorage::Private {
+  public:
+    Private() : mCalendar( 0 ) {}
 
-KarmStorage *KarmStorage::instance()
+    KCal::ResourceCalendar *mCalendar;
+    QString mICalFile;
+};
+//@endcond
+
+KarmStorage::KarmStorage() : d( new Private() )
 {
-  if (_instance == 0) _instance = new KarmStorage();
-  return _instance;
 }
 
-KarmStorage::KarmStorage()
-{
-  _calendar = 0;
-}
-
-QString KarmStorage::load (TaskView* view, const Preferences* preferences, QString fileName )
+QString KarmStorage::load( TaskView* view, const QString &fileName )
 // loads data from filename into view. If no filename is given, filename from preferences is used.
 // filename might be of use if this program is run as embedded konqueror plugin.
 {
-  kDebug(5970) << "Entering KarmStorage::load" << endl;
+  kDebug(5970) <<"Entering KarmStorage::load";
   QString err;
   KEMailSettings settings;
-  if ( fileName.isEmpty() ) fileName = preferences->iCalFile();
+  QString lFileName = fileName;
+
+  assert( !( lFileName.isEmpty() ) );
 
   // If same file, don't reload
-  if ( fileName == _icalfile ) return err;
+  if ( lFileName == d->mICalFile ) return err;
 
 
   // If file doesn't exist, create a blank one to avoid ResourceLocal load
   // error.  We make it user and group read/write, others read.  This is
   // masked by the users umask.  (See man creat)
-  if ( ! remoteResource( _icalfile ) )
-  {
+  if ( !( remoteResource( lFileName ) ) ) {
     int handle;
     handle = open (
-        QFile::encodeName( fileName ),
-        O_CREAT|O_EXCL|O_WRONLY,
-        S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH
-        );
-    if (handle != -1) close(handle);
+               QFile::encodeName( lFileName ),
+               O_CREAT | O_EXCL | O_WRONLY,
+               S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH
+             );
+    if ( handle != -1 ) {
+      close( handle );
+    }
   }
 
-  if ( _calendar)
+  if ( d->mCalendar)
     closeStorage(view);
 
   // Create local file resource and add to resources
-  _icalfile = fileName;
+  d->mICalFile = lFileName;
 
   KCal::ResourceCached *resource;
-  if ( remoteResource( _icalfile ) )
+  if ( remoteResource( d->mICalFile ) )
   {
-    KUrl url( _icalfile );
+    KUrl url( d->mICalFile );
     resource = new KCal::ResourceRemote( url, url ); // same url for upload and download
   }
   else
   {
-    resource = new KCal::ResourceLocal( _icalfile );
+    resource = new KCal::ResourceLocal( d->mICalFile );
   }
-  _calendar = resource;
+  d->mCalendar = resource;
 
-  QObject::connect (_calendar, SIGNAL(resourceChanged(ResourceCalendar *)),
+  QObject::connect (d->mCalendar, SIGNAL(resourceChanged(ResourceCalendar *)),
   	            view, SLOT(iCalFileModified(ResourceCalendar *)));
-  _calendar->setTimeSpec( KPimPrefs::timeSpec() );
-  _calendar->setResourceName( QString::fromLatin1("KTimeTracker") );
-  _calendar->open();
-  _calendar->load();
+  d->mCalendar->setTimeSpec( KPIM::KPimPrefs::timeSpec() );
+  d->mCalendar->setResourceName( QString::fromLatin1("KTimeTracker") );
+  d->mCalendar->open();
+  d->mCalendar->load();
 
   // Claim ownership of iCalendar file if no one else has.
   KCal::Person owner = resource->owner();
@@ -149,10 +154,10 @@ QString KarmStorage::load (TaskView* view, const Preferences* preferences, QStri
 
     // Build dictionary to look up Task object from Todo uid.  Each task is a
     // QListViewItem, and is initially added with the view as the parent.
-    todoList = _calendar->rawTodos();
-    kDebug(5970) << "KarmStorage::load "
+    todoList = d->mCalendar->rawTodos();
+    kDebug(5970) <<"KarmStorage::load"
       << "rawTodo count (includes completed todos) ="
-      << todoList.count() << endl;
+      << todoList.count();
     for( todo = todoList.begin(); todo != todoList.end(); ++todo )
     {
       // Initially, if a task was complete, it was removed from the view.
@@ -198,18 +203,18 @@ QString KarmStorage::load (TaskView* view, const Preferences* preferences, QStri
       }
     }
 
-    kDebug(5970) << "KarmStorage::load - loaded " << view->count()
-      << " tasks from " << _icalfile << endl;
+    kDebug(5970) << "KarmStorage::load - loaded" << view->count()
+      << "tasks from" << d->mICalFile;
   }
 
-  buildTaskView(_calendar, view);
+  buildTaskView(d->mCalendar, view);
   return err;
 }
 
 QString KarmStorage::icalfile()
 {
-  kDebug(5970) << "Entering KarmStorage::icalfile" << endl;
-  return _icalfile;
+  kDebug(5970) <<"Entering KarmStorage::icalfile";
+  return d->mICalFile;
 }
 
 QString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
@@ -223,18 +228,18 @@ QString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
   QVector<QDateTime> startTimes;
 
   // remember tasks that are running and their start times
-  for ( int i=0; i<view->count(); i++)
-  {
-    if ( view->item_at_index(i)->isRunning() )
-    {
-      runningTasks.append( view->item_at_index(i)->uid() );
-      startTimes.append( view->item_at_index(i)->lastStart() );
+  QTreeWidgetItemIterator it( view );
+  while ( *it ) {
+    Task *task = static_cast< Task* >( *it );
+    if ( task->isRunning() ) {
+      runningTasks.append( task->uid() );
+      startTimes.append( task->startTime() );
     }
   }
 
   // delete old tasks
 
-  while (view->item_at_index(0)) view->item_at_index(0)->cut();
+  while (view->itemAt(0)) view->itemAt(0)->cut();
 
   todoList = rc->rawTodos();
   for( todo = todoList.begin(); todo != todoList.end(); ++todo )
@@ -269,8 +274,8 @@ QString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
   // restart tasks that have been running with their start times
   for ( int i=0; i<view->count(); i++) {
     for ( int n = 0; n < runningTasks.count(); ++n ) {
-      if ( runningTasks[n] == view->item_at_index(i)->uid() ) {
-        view->startTimerFor( view->item_at_index(i), startTimes[n] );
+      if ( runningTasks[n] == view->itemAt(i)->uid() ) {
+        view->startTimerFor( view->itemAt(i), startTimes[n] );
       }
     }
   }
@@ -282,11 +287,11 @@ QString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
 
 void KarmStorage::closeStorage(TaskView* view)
 {
-  if ( _calendar )
+  if ( d->mCalendar )
   {
-    _calendar->close();
-    delete _calendar;
-    _calendar = 0;
+    d->mCalendar->close();
+    delete d->mCalendar;
+    d->mCalendar = 0;
 
     view->clear();
   }
@@ -294,20 +299,21 @@ void KarmStorage::closeStorage(TaskView* view)
 
 KCal::Event::List KarmStorage::rawevents()
 {
-  kDebug(5970) << "Entering KarmStorage::listallevents" << endl;
-  return _calendar->rawEvents();
+  kDebug(5970) <<"Entering KarmStorage::listallevents";
+  return d->mCalendar->rawEvents();
 }
 
 QString KarmStorage::save(TaskView* taskview)
 {
-  kDebug(5970) << "entering KarmStorage::save" << endl;
+  kDebug(5970) <<"entering KarmStorage::save";
   QString err;
 
   QStack<KCal::Todo*> parents;
 
-  for (Task* task=taskview->first_child(); task; task = task->nextSibling())
-  {
-    err=writeTaskAsTodo(task, 1, parents );
+  for (int i = 0; i < taskview->topLevelItemCount(); ++i ) {
+    Task *task = static_cast< Task* >( taskview->topLevelItem( i ) );
+    kDebug( 5970 ) << "write task" << task->name();
+    err = writeTaskAsTodo( task, parents );
   }
 
   if ( !saveCalendar() )
@@ -318,12 +324,12 @@ QString KarmStorage::save(TaskView* taskview)
   if ( err.isEmpty() )
   {
     kDebug(5970)
-      << "KarmStorage::save : wrote "
-      << taskview->count() << " tasks to " << _icalfile << endl;
+      << "KarmStorage::save : wrote"
+      << taskview->count() << "tasks to" << d->mICalFile;
   }
   else
   {
-    kWarning(5970) << "KarmStorage::save : " << err << endl;
+    kWarning(5970) <<"KarmStorage::save :" << err;
   }
 
   return err;
@@ -331,37 +337,35 @@ QString KarmStorage::save(TaskView* taskview)
 
 QString KarmStorage::setTaskParent( Task* task, Task* parent )
 {
-  kDebug(5970) << "Entering KarmStorage::setTaskParent" << endl;
+  kDebug(5970) <<"Entering KarmStorage::setTaskParent";
   QString err=QString();
   KCal::Todo* toDo;
-  toDo = _calendar->todo(task->uid());
+  toDo = d->mCalendar->todo(task->uid());
   if (parent==0) toDo->removeRelation(toDo->relatedTo());
-  else toDo->setRelatedTo(_calendar->todo(parent->uid()));
- // buildTaskView(_calendar, _view);
-  kDebug(5970) << "Leaving KarmStorage::setTaskParent" << endl;
+  else toDo->setRelatedTo(d->mCalendar->todo(parent->uid()));
+ // buildTaskView(d->mCalendar, _view);
+  kDebug(5970) <<"Leaving KarmStorage::setTaskParent";
   return err;
 }
 
-QString KarmStorage::writeTaskAsTodo(Task* task, const int level,
-    QStack<KCal::Todo*>& parents )
+QString KarmStorage::writeTaskAsTodo(Task* task, QStack<KCal::Todo*>& parents )
 {
   QString err;
   KCal::Todo* todo;
 
-  todo = _calendar->todo(task->uid());
+  todo = d->mCalendar->todo(task->uid());
   if ( !todo )
   {
-    kDebug(5970) << "Could not get todo from calendar" << endl;
+    kDebug(5970) <<"Could not get todo from calendar";
     return "Could not get todo from calendar";
   }
   task->asTodo(todo);
   if ( !parents.isEmpty() ) todo->setRelatedTo( parents.top() );
   parents.push( todo );
 
-  for ( Task* nextTask = task->firstChild(); nextTask;
-        nextTask = nextTask->nextSibling() )
-  {
-    err = writeTaskAsTodo(nextTask, level+1, parents );
+  for ( int i = 0; i < task->childCount(); ++i ) {
+    Task *nextTask = static_cast< Task* >( task->child( i ) );
+    err = writeTaskAsTodo( nextTask, parents );
   }
 
   parents.pop();
@@ -372,16 +376,10 @@ bool KarmStorage::isEmpty()
 {
   KCal::Todo::List todoList;
 
-  todoList = _calendar->rawTodos();
+  todoList = d->mCalendar->rawTodos();
   return todoList.empty();
 }
 
-bool KarmStorage::isNewStorage(const Preferences* preferences) const
-{
-  if ( !_icalfile.isNull() ) return preferences->iCalFile() != _icalfile;
-  else return false;
-}
-
 //----------------------------------------------------------------------------
 // Routines that handle Comma-Separated Values export file format.
 //
@@ -398,7 +396,7 @@ QString KarmStorage::exportcsvFile( TaskView *taskview,
   int maxdepth=0;
 
   kDebug(5970)
-    << "KarmStorage::exportcsvFile: " << rc.url << endl;
+    << "KarmStorage::exportcsvFile:" << rc.url;
 
   QString title = i18n("Export Progress");
   KProgressDialog dialog( taskview, 0, title );
@@ -422,8 +420,8 @@ QString KarmStorage::exportcsvFile( TaskView *taskview,
   {
     dialog.progressBar()->setValue( dialog.progressBar()->value() + 1 );
     if ( tasknr % 15 == 0 ) kapp->processEvents(); // repainting is slow
-    if ( taskview->item_at_index(tasknr)->depth() > maxdepth )
-      maxdepth = taskview->item_at_index(tasknr)->depth();
+    if ( taskview->itemAt(tasknr)->depth() > maxdepth )
+      maxdepth = taskview->itemAt(tasknr)->depth();
     tasknr++;
   }
 
@@ -431,7 +429,7 @@ QString KarmStorage::exportcsvFile( TaskView *taskview,
   tasknr = 0;
   while ( tasknr < taskview->count() && !dialog.wasCancelled() )
   {
-    task = taskview->item_at_index( tasknr );
+    task = taskview->itemAt( tasknr );
     dialog.progressBar()->setValue( dialog.progressBar()->value() + 1 );
     if ( tasknr % 15 == 0 ) kapp->processEvents();
 
@@ -469,7 +467,7 @@ QString KarmStorage::exportcsvFile( TaskView *taskview,
                                    rc.decimalMinutes )
            + delim + formatTime( task->totalTime(),
                                    rc.decimalMinutes )
-           + "\n";
+           + '\n';
     tasknr++;
   }
 
@@ -520,11 +518,11 @@ QString KarmStorage::addTask(const Task* task, const Task* parent)
   QString uid;
 
   todo = new KCal::Todo();
-  if ( _calendar->addTodo( todo ) )
+  if ( d->mCalendar->addTodo( todo ) )
   {
     task->asTodo( todo  );
     if (parent)
-      todo->setRelatedTo(_calendar->todo(parent->uid()));
+      todo->setRelatedTo(d->mCalendar->todo(parent->uid()));
     uid = todo->uid();
   }
   else
@@ -541,7 +539,7 @@ bool KarmStorage::removeTask(Task* task)
 {
 
   // delete history
-  KCal::Event::List eventList = _calendar->rawEvents();
+  KCal::Event::List eventList = d->mCalendar->rawEvents();
   for(KCal::Event::List::iterator i = eventList.begin();
       i != eventList.end();
       ++i)
@@ -550,13 +548,13 @@ bool KarmStorage::removeTask(Task* task)
         || ( (*i)->relatedTo()
             && (*i)->relatedTo()->uid() == task->uid()))
     {
-      _calendar->deleteEvent(*i);
+      d->mCalendar->deleteEvent(*i);
     }
   }
 
   // delete todo
-  KCal::Todo *todo = _calendar->todo(task->uid());
-  _calendar->deleteTodo(todo);
+  KCal::Todo *todo = d->mCalendar->todo(task->uid());
+  d->mCalendar->deleteTodo(todo);
 
   // Save entire file
   saveCalendar();
@@ -569,7 +567,7 @@ void KarmStorage::addComment(const Task* task, const QString& comment)
 
   KCal::Todo* todo;
 
-  todo = _calendar->todo(task->uid());
+  todo = d->mCalendar->todo(task->uid());
 
   // Do this to avoid compiler warnings about comment not being used.  once we
   // transition to using the addComment method, we need this second param.
@@ -595,7 +593,7 @@ long KarmStorage::printTaskHistory (
 // to>=from is precondition
 {
   long ownline=linenr++; // the how many-th instance of this function is this
-  long colrectot=0;      // colum where to write the task's total recursive time
+  long colrectot=0;      // column where to write the task's total recursive time
   QVector<QString> cell; // each line of the matrix is stored in an array of cells, one containing the recursive total
   long add;              // total recursive time of all subtasks
   QString delim = rc.delimiter;
@@ -624,7 +622,7 @@ long KarmStorage::printTaskHistory (
     if (taskdaytotals.contains(daytaskkey))
     {
       cell.append(
-        QString::fromLatin1( "%1" ).arg( 
+        QString::fromLatin1( "%1" ).arg(
           formatTime( taskdaytotals[ daytaskkey ] / 60, rc.decimalMinutes )
         )
       );
@@ -642,7 +640,7 @@ long KarmStorage::printTaskHistory (
 
   // Total for task
   cell.append(
-    QString::fromLatin1( "%1" ).arg( 
+    QString::fromLatin1( "%1" ).arg(
       formatTime( sum / 60, rc.decimalMinutes )
     )
   );
@@ -674,10 +672,8 @@ long KarmStorage::printTaskHistory (
   cell.append( cr );
 
   add=0;
-  for (Task* subTask = task->firstChild();
-      subTask;
-      subTask = subTask->nextSibling())
-  {
+  for ( int i = 0; i < task->childCount(); ++i ) {
+    Task *subTask = static_cast< Task* >( task->child( i ) );
     add += printTaskHistory( subTask, taskdaytotals, daytotals, from, to , level+1, matrix,
                       rc );
   }
@@ -700,12 +696,12 @@ QString KarmStorage::report( TaskView *taskview, const ReportCriteria &rc )
   {
     if ( !rc.bExPortToClipBoard )
       err = exportcsvFile( taskview, rc );
-    else 
+    else
       err = taskview->clipTotals( rc );
   }
   else {
       // hmmmm ... assert(0)?
-  }   
+  }
   return err;
 }
 
@@ -802,16 +798,15 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
   {
     if ( rc.allTasks )
     {
-      for ( Task* task= taskview->item_at_index(0);
-            task; task= task->nextSibling() )
-      {
+      for ( int i = 0; i < taskview->topLevelItemCount(); ++i ) {
+        Task *task = static_cast< Task* >( taskview->topLevelItem( i ) );
         printTaskHistory( task, taskdaytotals, daytotals, from, to, 0,
                           matrix, rc );
       }
     }
     else
     {
-      printTaskHistory( taskview->current_item(), taskdaytotals, daytotals,
+      printTaskHistory( taskview->currentItem(), taskdaytotals, daytotals,
                         from, to, 0, matrix, rc );
     }
     for (int i=0; i<matrix.count(); i++) retval+=matrix[i];
@@ -837,7 +832,7 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
     retval += QString::fromLatin1("%1%2%3%4")
         .arg( formatTime( sum/60, rc.decimalMinutes ) )
         .arg( delim ).arg( delim )
-        .arg( i18n( "Total" ) );
+        .arg( i18nc( "total time of all tasks", "Total" ) );
   }
 
   // above taken from timekard.cpp
@@ -878,19 +873,41 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
   return err;
 }
 
-void KarmStorage::stopTimer(const Task* task, QDateTime when)
+void KarmStorage::startTimer( const Task* task, const KDateTime &when )
 {
-  kDebug(5970) << "Entering stopTimer when=" << when << endl;
-  kDebug(5970) << "task->startTime=" << task->startTime() << endl;
-  long delta = task->startTime().secsTo(when);
-  changeTime(task, delta);
+  KCal::Event* e;
+  e = baseEvent(task);
+  e->setDtStart(when);
+  d->mCalendar->addEvent(e);
+  task->taskView()->scheduleSave();
+}
+
+void KarmStorage::stopTimer( const Task* task, const QDateTime &when )
+{
+  kDebug(5970) <<"Entering stopTimer when=" << when;
+  KCal::Event::List eventList = d->mCalendar->rawEvents();
+  for(KCal::Event::List::iterator i = eventList.begin();
+      i != eventList.end();
+      ++i)
+  {
+    if ( (*i)->relatedToUid() == task->uid() )
+    {
+      if (!(*i)->hasEndDate())
+      {
+	QString s=when.toString("yyyy-MM-ddThh:mm:ss.zzzZ"); // need the KDE standard from the ISO standard, not the QT one
+	KDateTime kwhen=KDateTime::fromString(s);
+	kDebug() << "kwhen ==" <<  kwhen;
+        (*i)->setDtEnd(kwhen);
+      }
+    };
+  }
 }
 
 bool KarmStorage::bookTime(const Task* task,
                            const QDateTime& startDateTime,
                            const long durationInSeconds)
 {
-  kDebug(5970) << "Entering KarmStorage::bookTime" << endl;
+  kDebug(5970) <<"Entering KarmStorage::bookTime";
   // Ignores preferences setting re: logging history.
   KCal::Event* e;
   QDateTime end;
@@ -905,19 +922,15 @@ bool KarmStorage::bookTime(const Task* task,
       QByteArray("duration"),
       QString::number(durationInSeconds));
 
-  return _calendar->addEvent(e);
+  return d->mCalendar->addEvent(e);
 }
 
 void KarmStorage::changeTime(const Task* task, const long deltaSeconds)
 {
-  kDebug(5970) << "Entering KarmStorage::changeTime deltaSeconds=" <<deltaSeconds << endl;
+  kDebug(5970) <<"Entering KarmStorage::changeTime deltaSeconds=" <<deltaSeconds;
   KCal::Event* e;
   QDateTime end;
 
-  // Don't write events (with timer start/stop duration) if user has turned
-  // this off in the settings dialog.
-  if ( ! task->taskView()->preferences()->logging() ) return;
-
   e = baseEvent(task);
 
   // Don't use duration, as ICalFormatImpl::writeIncidence never writes a
@@ -931,16 +944,8 @@ void KarmStorage::changeTime(const Task* task, const long deltaSeconds)
       QByteArray("duration"),
       QString::number(deltaSeconds));
 
-  _calendar->addEvent(e);
+  d->mCalendar->addEvent(e);
 
-  // This saves the entire iCal file each time, which isn't efficient but
-  // ensures no data loss.  A faster implementation would be to append events
-  // to a file, and then when KArm closes, append the data in this file to the
-  // iCal file.
-  //
-  // Meanwhile, we simply use a timer to delay the full-saving until the GUI
-  // has updated, for better user feedback. Feel free to get rid of this
-  // if/when implementing the faster saving (DF).
   task->taskView()->scheduleSave();
 }
 
@@ -954,13 +959,13 @@ KCal::Event* KarmStorage::baseEvent(const Task * task)
   e->setSummary(task->name());
 
   // Can't use setRelatedToUid()--no error, but no RelatedTo written to disk
-  e->setRelatedTo(_calendar->todo(task->uid()));
+  e->setRelatedTo(d->mCalendar->todo(task->uid()));
 
   // Debugging: some events where not getting a related-to field written.
   assert(e->relatedTo()->uid() == task->uid());
 
   // Have to turn this off to get datetimes in date fields.
-  e->setFloats(false);
+  e->setAllDay(false);
   e->setDtStart(KDateTime(task->startTime(), KDateTime::Spec::LocalZone()));
 
   // So someone can filter this mess out of their calendar display
@@ -970,8 +975,9 @@ KCal::Event* KarmStorage::baseEvent(const Task * task)
   return e;
 }
 
-HistoryEvent::HistoryEvent(QString uid, QString name, long duration,
-        KDateTime start, KDateTime stop, QString todoUid)
+HistoryEvent::HistoryEvent( const QString &uid, const QString &name,
+                            long duration, const KDateTime &start,
+                            const KDateTime &stop, const QString &todoUid )
 {
   _uid = uid;
   _name = name;
@@ -991,14 +997,13 @@ QList<HistoryEvent> KarmStorage::getHistory(const QDate& from,
   KCal::Event::List::iterator event;
   QString duration;
 
-  for(QDate d = from; d <= to; d = d.addDays(1))
-  {
-    events = _calendar->rawEventsForDate( d );
-    for (event = events.begin(); event != events.end(); ++event)
+  for( QDate date = from; date <= to; date = date.addDays( 1 ) ) {
+    events = d->mCalendar->rawEventsForDate( date, KPIM::KPimPrefs::timeSpec() );
+    for (event = events.begin(); event != events.end(); ++event) 
     {
 
       // KArm events have the custom property X-KDE-Karm-duration
-      if (! processed.contains( (*event)->uid()))
+      if (! processed.contains( (*event)->uid())) 
       {
         // If an event spans multiple days, CalendarLocal::rawEventsForDate
         // will return the same event on both days.  To avoid double-counting
@@ -1007,6 +1012,18 @@ QList<HistoryEvent> KarmStorage::getHistory(const QDate& from,
         // an easy fix for a (hopefully) rare situation.
         processed.append( (*event)->uid());
 
+        // ktimetracker was name karm till KDE 3 incl.
+        // if a KDE-karm-duRation exists and no KDE-ktimetracker-Duration, change this
+        if (
+          (*event)->customProperty( KGlobal::mainComponent().componentName().toUtf8(),
+          QByteArray( "duration" )) == QString::null && (*event)->customProperty( "karm",
+          QByteArray( "duration" )) != QString::null )
+
+          (*event)->setCustomProperty(  
+            KGlobal::mainComponent().componentName().toUtf8(),
+            QByteArray( "duration" ), (*event)->customProperty( "karm",
+            QByteArray( "duration" )));
+
         duration = (*event)->customProperty(KGlobal::mainComponent().componentName().toUtf8(),
             QByteArray("duration"));
         if ( ! duration.isNull() )
@@ -1027,9 +1044,9 @@ QList<HistoryEvent> KarmStorage::getHistory(const QDate& from,
             // Something is screwy with the ics file, as this KArm history event
             // does not have a todo related to it.  Could have been deleted
             // manually?  We'll continue with report on with report ...
-            kDebug(5970) << "KarmStorage::getHistory(): "
-              << "The event " << (*event)->uid()
-              << " is not related to a todo.  Dropped." << endl;
+            kDebug(5970) <<"KarmStorage::getHistory():"
+              << "The event" << (*event)->uid()
+              << "is not related to a todo.  Dropped.";
         }
       }
     }
@@ -1043,19 +1060,19 @@ bool KarmStorage::remoteResource( const QString& file ) const
   QString f = file.toLower();
   bool rval = f.startsWith( "http://" ) || f.startsWith( "ftp://" );
 
-  kDebug(5970) << "KarmStorage::remoteResource( " << file << " ) returns " << rval  << endl;
+  kDebug(5970) <<"KarmStorage::remoteResource(" << file <<" ) returns" << rval;
   return rval;
 }
 
 bool KarmStorage::saveCalendar()
 {
-  kDebug(5970) << "KarmStorage::saveCalendar" << endl;
+  kDebug(5970) <<"KarmStorage::saveCalendar";
 
-  KABC::Lock *lock = _calendar->lock();
+  KABC::Lock *lock = d->mCalendar->lock();
   if ( !lock || !lock->lock() )
     return false;
 
-  if ( _calendar->save() ) {
+  if ( d->mCalendar->save() ) {
     lock->unlock();
     return true;
   }
