@@ -24,17 +24,16 @@
 */
 
 #include "addresseelineedit.h"
-
-#include "resourceabc.h"
 #include "completionordereditor.h"
 #include "ldapclient.h"
 
+#include <kabc/resourceabc.h>
+
 #include <config.h> // KDEPIM_NEW_DISTRLISTS
 
 #ifdef KDEPIM_NEW_DISTRLISTS
 #include "distributionlist.h"
 #else
-#include <kabc/distributionlist.h>
 #endif
 
 #include <kabc/stdaddressbook.h>
@@ -43,7 +42,7 @@
 #include <kcompletionbox.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
-#include <kstaticdeleter.h>
+#include <k3staticdeleter.h>
 #include <kstandardshortcut.h>
 #include <kurl.h>
 #include <klocale.h>
@@ -71,12 +70,12 @@ KPIM::LdapSearch* AddresseeLineEdit::s_LDAPSearch = 0L;
 QString* AddresseeLineEdit::s_LDAPText = 0L;
 AddresseeLineEdit* AddresseeLineEdit::s_LDAPLineEdit = 0L;
 
-static KStaticDeleter<KMailCompletion> completionDeleter;
-static KStaticDeleter<KPIM::CompletionItemsMap> completionItemsDeleter;
-static KStaticDeleter<QTimer> ldapTimerDeleter;
-static KStaticDeleter<KPIM::LdapSearch> ldapSearchDeleter;
-static KStaticDeleter<QString> ldapTextDeleter;
-static KStaticDeleter<QStringList> completionSourcesDeleter;
+static K3StaticDeleter<KMailCompletion> completionDeleter;
+static K3StaticDeleter<KPIM::CompletionItemsMap> completionItemsDeleter;
+static K3StaticDeleter<QTimer> ldapTimerDeleter;
+static K3StaticDeleter<KPIM::LdapSearch> ldapSearchDeleter;
+static K3StaticDeleter<QString> ldapTextDeleter;
+static K3StaticDeleter<QStringList> completionSourcesDeleter;
 
 // needs to be unique, but the actual name doesn't matter much
 static QByteArray newLineEditObjectName()
@@ -160,7 +159,7 @@ void AddresseeLineEdit::init()
      if ( !QDBusConnection::sessionBus().connect( "kde.org.pim.completionorder", "/",
                  "kde.org.pim.CompletionOrder", "completionOrderChanged",
                  this, SLOT( slotIMAPCompletionOrderChanged() ) ) )
-         kError() << "AddresseeLineEdit: connection to orderChanged() failed" << endl;
+         kError() <<"AddresseeLineEdit: connection to orderChanged() failed";
 
       connect( s_LDAPTimer, SIGNAL( timeout() ), SLOT( slotStartLDAPLookup() ) );
       connect( s_LDAPSearch, SIGNAL( searchData( const KPIM::LdapResultList& ) ),
@@ -232,7 +231,7 @@ void AddresseeLineEdit::insert( const QString &t )
     return;
   }
 
-  //kDebug(5300) << "     AddresseeLineEdit::insert( \"" << t << "\" )" << endl;
+  //kDebug(5300) <<"     AddresseeLineEdit::insert( \"" << t <<"\" )";
 
   QString newText = t.trimmed();
   if ( newText.isEmpty() )
@@ -437,7 +436,7 @@ void AddresseeLineEdit::doCompletion( bool ctrlT )
         //if only our \" is left, remove it since user has not typed it either
         if ( m_searchExtended && m_searchString == "\"" ){
           m_searchExtended = false;
-          m_searchString = QString::null;
+          m_searchString = QString();
           setText( m_previousAddresses );
           break;
         }
@@ -515,7 +514,7 @@ void AddresseeLineEdit::loadContacts()
   QListIterator<KABC::Resource*> resit( resources );
   while ( resit.hasNext() ) {
     KABC::Resource* resource = resit.next();
-    KPIM::ResourceABC* resabc = dynamic_cast<ResourceABC *>( resource );
+    KABC::ResourceABC* resabc = dynamic_cast<KABC::ResourceABC *>( resource );
     if ( resabc ) { // IMAP KABC resource; need to associate each contact with the subresource
       const QMap<QString, QString> uidToResourceMap = resabc->uidToResourceMap();
       KABC::Resource::Iterator it;
@@ -529,7 +528,7 @@ void AddresseeLineEdit::loadContacts()
           idx = s_completionSources->size() -1;
         }
         int weight = ( wit != uidToResourceMap.end() ) ? resabc->subresourceCompletionWeight( *wit ) : 80;
-        //kDebug(5300) << (*it).fullEmail() << " subres=" << *wit << " weight=" << weight << endl;
+        //kDebug(5300) << (*it).fullEmail() <<" subres=" << *wit <<" weight=" << weight;
         addContact( *it, weight, idx );
       }
     } else { // KABC non-imap resource
@@ -544,9 +543,9 @@ void AddresseeLineEdit::loadContacts()
 
 #ifndef KDEPIM_NEW_DISTRLISTS // new distr lists are normal contact, already done above
   int weight = config.readEntry( "DistributionLists", 60 );
-  KABC::DistributionListManager manager( addressBook );
-  manager.load();
-  const QStringList distLists = manager.listNames();
+
+  const QStringList distLists = addressBook->allDistributionListNames();
+
   QStringList::const_iterator listIt;
   int idx = addCompletionSource( i18n( "Distribution Lists" ) );
   for ( listIt = distLists.begin(); listIt != distLists.end(); ++listIt ) {
@@ -573,7 +572,7 @@ void AddresseeLineEdit::addContact( const KABC::Addressee& addr, int weight, int
 {
 #ifdef KDEPIM_NEW_DISTRLISTS
   if ( KPIM::DistributionList::isDistributionList( addr ) ) {
-    //kDebug(5300) << "AddresseeLineEdit::addContact() distribution list \"" << addr.formattedName() << "\" weight=" << weight << endl;
+    //kDebug(5300) <<"AddresseeLineEdit::addContact() distribution list \"" << addr.formattedName() <<"\" weight=" << weight;
 
     //for CompletionAuto
     addCompletionItem( addr.formattedName(), weight, source );
@@ -665,7 +664,7 @@ void AddresseeLineEdit::addContact( const KABC::Addressee& addr, int weight, int
       --len;
     const QString tmp = (*it).left( len );
     const QString fullEmail = addr.fullEmail( tmp );
-    //kDebug(5300) << "AddresseeLineEdit::addContact() \"" << fullEmail << "\" weight=" << weight << endl;
+    //kDebug(5300) <<"AddresseeLineEdit::addContact() \"" << fullEmail <<"\" weight=" << weight;
     addCompletionItem( fullEmail.simplified(), weight, source );
     // Try to guess the last name: if found, we add an extra
     // entry to the list to make sure completion works even
@@ -695,7 +694,7 @@ void AddresseeLineEdit::addContact( const KABC::Addressee& addr, int weight, int
         QString sExtraEntry( sLastName );
         sExtraEntry.append( tmp.isEmpty() ? addr.preferredEmail() : tmp );
         sExtraEntry.append( ">" );
-        //kDebug(5300) << "AddresseeLineEdit::addContact() added extra \"" << sExtraEntry.simplified() << "\" weight=" << weight << endl;
+        //kDebug(5300) <<"AddresseeLineEdit::addContact() added extra \"" << sExtraEntry.simplified() <<"\" weight=" << weight;
         addCompletionItem( sExtraEntry.simplified(), weight, source );
         bDone = true;
       }
@@ -922,15 +921,13 @@ int KPIM::AddresseeLineEdit::addCompletionSource( const QString &source )
 
 bool KPIM::AddresseeLineEdit::eventFilter(QObject *obj, QEvent *e)
 {
-#ifdef __GNUC__
-#warning Port me!
-#endif
-  // FIXME Temporary avoid the constructor in the IF because of endless loops!
-  //if ( obj == completionBox() ) {
-  if (  0 && obj == completionBox() ) {
-    if ( e->type() == QEvent::MouseButtonPress
-      || e->type() == QEvent::MouseMove
-      || e->type() == QEvent::MouseButtonRelease ) {
+  if ( m_completionInitialized &&
+       ( obj == completionBox() ||
+         completionBox()->findChild<QWidget*>( obj->objectName() ) == obj ) ) {
+    if ( e->type() == QEvent::MouseButtonPress ||
+         e->type() == QEvent::MouseMove ||
+         e->type() == QEvent::MouseButtonRelease ||
+         e->type() == QEvent::MouseButtonDblClick ) {
       QMouseEvent* me = static_cast<QMouseEvent*>( e );
       // find list box item at the event position
       QListWidgetItem *item = completionBox()->itemAt( me->pos() );
@@ -943,9 +940,10 @@ bool KPIM::AddresseeLineEdit::eventFilter(QObject *obj, QEvent *e)
       // avoid selection of headers on button press, or move or release while
       // a button is pressed
       Qt::MouseButtons btns = me->buttons();
-      if ( e->type() == QEvent::MouseButtonPress
-          || btns & Qt::LeftButton || btns & Qt::MidButton
-          || btns & Qt::RightButton ) {
+      if ( e->type() == QEvent::MouseButtonPress ||
+           e->type() == QEvent::MouseButtonDblClick ||
+           btns & Qt::LeftButton || btns & Qt::MidButton ||
+           btns & Qt::RightButton ) {
         if ( itemIsHeader(item) ) {
           return true; // eat the event, we don't want anything to happen
         } else {
@@ -974,7 +972,7 @@ bool KPIM::AddresseeLineEdit::eventFilter(QObject *obj, QEvent *e)
     QKeyEvent *ke = static_cast<QKeyEvent*>( e );
     unsigned int currentIndex = completionBox()->currentRow();
     if ( ke->key() == Qt::Key_Up ) {
-      //kDebug() << "EVENTFILTER: Key_Up currentIndex=" << currentIndex << endl;
+      //kDebug() <<"EVENTFILTER: Key_Up currentIndex=" << currentIndex;
       // figure out if the item we would be moving to is one we want
       // to ignore. If so, go one further
       QListWidgetItem *itemAbove = completionBox()->item( currentIndex - 1 );
@@ -982,29 +980,26 @@ bool KPIM::AddresseeLineEdit::eventFilter(QObject *obj, QEvent *e)
         // there is a header above is, check if there is even further up
         // and if so go one up, so it'll be selected
         if ( currentIndex > 1 && completionBox()->item( currentIndex - 2 ) ) {
-          //kDebug() << "EVENTFILTER: Key_Up -> skipping " << currentIndex - 1 << endl;
+          //kDebug() <<"EVENTFILTER: Key_Up -> skipping" << currentIndex - 1;
           completionBox()->setCurrentRow( currentIndex -2 );
           completionBox()->item( currentIndex - 2 )->setSelected( true );
         } else if ( currentIndex == 1 ) {
-            // nothing to skip to, let's stay where we are, but make sure the
-            // first header becomes visible, if we are the first real entry
-#ifdef __GNUC__
-#warning Port me!
-#endif
-//            completionBox()->ensureVisible( 0, 0 );
-            QListWidgetItem *i = completionBox()->item( currentIndex );
-            if ( i )
-              i->setSelected( true );
+          // nothing to skip to, let's stay where we are, but make sure the
+          // first header becomes visible, if we are the first real entry
+          completionBox()->scrollToItem( completionBox()->item( 0 ) );
+          QListWidgetItem *i = completionBox()->item( currentIndex );
+          if ( i )
+            i->setSelected( true );
         }
         return true;
       }
     } else if ( ke->key() == Qt::Key_Down  ) {
       // same strategy for downwards
-      //kDebug() << "EVENTFILTER: Key_Down. currentIndex=" << currentIndex << endl;
+      //kDebug() <<"EVENTFILTER: Key_Down. currentIndex=" << currentIndex;
       QListWidgetItem *itemBelow = completionBox()->item( currentIndex + 1 );
       if ( itemBelow && itemIsHeader( itemBelow ) ) {
         if ( completionBox()->item( currentIndex + 2 ) ) {
-          //kDebug() << "EVENTFILTER: Key_Down -> skipping " << currentIndex+1 << endl;
+          //kDebug() <<"EVENTFILTER: Key_Down -> skipping" << currentIndex+1;
           completionBox()->setCurrentRow( currentIndex + 2  );
           completionBox()->item( currentIndex + 2 )->setSelected( true );
         } else {
@@ -1038,7 +1033,7 @@ bool KPIM::AddresseeLineEdit::eventFilter(QObject *obj, QEvent *e)
       // find the next header (searching backwards, for Key_Backtab
       QListWidgetItem *nextHeader = 0;
       const int iterationstep = ke->key() == Qt::Key_Tab ?  1 : -1;
-      // when iterating forward, start at the currentindex, when backwards, 
+      // when iterating forward, start at the currentindex, when backwards,
       // one up from our header, or at the end
       uint j = ke->key() == Qt::Key_Tab ? currentIndex : i==0 ? completionBox()->count()-1 : (i-1) % completionBox()->count();
       while ( ( nextHeader = completionBox()->item( j ) ) && nextHeader != myHeader ) {
