@@ -156,13 +156,13 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy*, Li
   // placeholder where we fill in something else (in this case,
   // the global background color).
   //
-  const QString backgroundColor = KColorScheme( KColorScheme::View ).background( KColorScheme::AlternateBackground ).color().name();
+  const QString backgroundColor = KColorScheme( QPalette::Active, KColorScheme::View ).background( KColorScheme::AlternateBackground ).color().name();
   QString cellStyle = QString::fromLatin1(
         "style=\""
         "padding-right: 2px; "
         "border-right: #000 dashed 1px; "
         "background: %1;\"").arg(backgroundColor);
-  const QString backgroundColor2 = KColorScheme( KColorScheme::View ).background().color().name();
+  const QString backgroundColor2 = KColorScheme( QPalette::Active, KColorScheme::View ).background().color().name();
   QString cellStyle2 = QString::fromLatin1(
         "style=\""
         "padding-left: 2px; "
@@ -203,7 +203,7 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy*, Li
     } else if ( !pic.url().isEmpty() ) {
       image = (pic.url().startsWith( "http://" ) || pic.url().startsWith( "https://" ) ? pic.url() : "http://" + pic.url());
     } else {
-      image = "file:" + KIconLoader::global()->iconPath( "personal", K3Icon::Desktop );
+      image = "file:" + KIconLoader::global()->iconPath( "personal", KIconLoader::Desktop );
     }
   }
 
@@ -460,7 +460,7 @@ QString AddresseeView::pixmapAsDataUrl( const QPixmap& pixmap )
   buffer.open( QIODevice::WriteOnly );
   pixmap.save( &buffer, "PNG" );
   QString encoded( "data:image/png;base64," );
-  encoded.append( KCodecs::base64Encode( ba ) );
+  encoded.append( ba.toBase64() );
   return encoded;
 }
 
@@ -504,8 +504,8 @@ void AddresseeView::updateView()
     "%3" // dynamic part
     "</body>"
     "</html>" )
-     .arg( KColorScheme( KColorScheme::View ).foreground().color().name() )
-     .arg( KColorScheme( KColorScheme::View ).background().color().name() )
+     .arg( KColorScheme( QPalette::Active, KColorScheme::View ).foreground().color().name() )
+     .arg( KColorScheme( QPalette::Active, KColorScheme::View ).background().color().name() )
      .arg( strAddr );
 
   QString imageURL = QString( "contact_%1_image" ).arg( mAddressee.uid() );
@@ -518,7 +518,7 @@ void AddresseeView::updateView()
       if ( mImageData.count() > 0 )
         Q3MimeSourceFactory::defaultFactory()->setImage( imageURL, QImage::fromData( mImageData ) );
       else {
-        mImageJob = KIO::get( KUrl( picture.url() ), false, false );
+        mImageJob = KIO::get( KUrl( picture.url() ), KIO::NoReload, KIO::HideProgressInfo );
         connect( mImageJob, SIGNAL( data( KIO::Job*, const QByteArray& ) ),
                  this, SLOT( data( KIO::Job*, const QByteArray& ) ) );
         connect( mImageJob, SIGNAL( result( KJob* ) ),
@@ -526,7 +526,7 @@ void AddresseeView::updateView()
       }
     } else {
       Q3MimeSourceFactory::defaultFactory()->setPixmap( imageURL,
-        KIconLoader::global()->loadIcon( "personal", K3Icon::Desktop, 128 ) );
+        KIconLoader::global()->loadIcon( "personal", KIconLoader::Desktop, 128 ) );
     }
   }
 
@@ -691,7 +691,7 @@ void AddresseeView::slotHighlighted( const QString &link )
 
 void AddresseeView::slotPresenceChanged( const QString &uid )
 {
-  kDebug() << k_funcinfo << " uid is: " << uid << " mAddressee is: " << mAddressee.uid() << endl;
+  kDebug() <<" uid is:" << uid <<" mAddressee is:" << mAddressee.uid();
   if ( uid == mAddressee.uid() )
     updateView();
 }
