@@ -32,6 +32,8 @@
 #include <kabc/resource.h>
 #else
 #include <kabc/distributionlist.h>
+#include <kabc/resource.h>
+#include <kresources/selectdialog.h>
 #endif
 
 #include <kabc/stdaddressbook.h>
@@ -98,12 +100,12 @@ AddresseeViewItem::AddresseeViewItem( AddresseeViewItem *parent, const KABC::Add
 
   if ( addr.photo().url().isEmpty() ) {
     if ( addr.photo().data().isNull() )
-      setPixmap( 0, KIconLoader::global()->loadIcon( "personal", K3Icon::Small ) );
+      setPixmap( 0, KIconLoader::global()->loadIcon( "personal", KIconLoader::Small ) );
     else
       setPixmap( 0, QPixmap::fromImage( addr.photo().data().scaled( 16, 16, Qt::IgnoreAspectRatio, Qt::SmoothTransformation
 ) ) );
   } else {
-    setPixmap( 0, KIconLoader::global()->loadIcon( addr.photo().url(), K3Icon::Small ) );
+    setPixmap( 0, KIconLoader::global()->loadIcon( addr.photo().url(), KIconLoader::Small ) );
   }
 }
 
@@ -129,7 +131,7 @@ AddresseeViewItem::AddresseeViewItem(  AddresseeViewItem *parent, const QString&
   d = new AddresseeViewItemPrivate;
   d->category = DistList;
 
-  setPixmap( 0, KIconLoader::global()->loadIcon( "kdmconfig", K3Icon::Small ) );
+  setPixmap( 0, KIconLoader::global()->loadIcon( "kdmconfig", KIconLoader::Small ) );
 }
 
 AddresseeViewItem::~AddresseeViewItem()
@@ -403,10 +405,12 @@ AddressesDialog::allToAddressesNoDuplicates()  const
     }
   }
 #else
-  KABC::DistributionListManager manager( abook );
-  manager.load();
   for ( QStringList::ConstIterator it = dList.begin(); it != dList.end(); ++it ) {
-    const QList<KABC::DistributionList::Entry> eList = manager.list( *it )->entries();
+    KABC::DistributionList *list = abook->findDistributionListByName( *it );
+    if ( !list )
+      continue;
+
+    const QList<KABC::DistributionList::Entry> eList = list->entries();
     QList<KABC::DistributionList::Entry>::ConstIterator eit;
     for( eit = eList.begin(); eit != eList.end(); ++eit ) {
       KABC::Addressee a = (*eit).addressee();
@@ -584,11 +588,6 @@ AddressesDialog::initConnections()
   connect( d->ui->mSelectedView, SIGNAL(doubleClicked(Q3ListViewItem*)),
            SLOT(removeEntry()) );
 
-#ifndef KDEPIM_NEW_DISTRLISTS
-  connect( KABC::DistributionListWatcher::self(), SIGNAL( changed() ),
-           this, SLOT( updateAvailableAddressees() ) );
-#endif
-
   connect( KABC::StdAddressBook::self( true ), SIGNAL( addressBookChanged(AddressBook*) ),
            this, SLOT( updateAvailableAddressees() ) );
 }
@@ -844,7 +843,9 @@ AddressesDialog::removeEntry()
   d->ui->mSaveAs->setEnabled(d->ui->mSelectedView->firstChild() != 0);
 }
 
-#ifdef KDEPIM_NEW_DISTRLISTS
+// FIXME new distribution list handling
+// should probably be moved as suggested in the comment below
+//#ifdef KDEPIM_NEW_DISTRLISTS
 
 // copied from kabcore.cpp :(
 // KDE4: should be in libkabc I think
@@ -865,16 +866,11 @@ static KABC::Resource *requestResource( KABC::AddressBook* abook, QWidget *paren
   KRES::Resource *res = KRES::SelectDialog::getResource( kresResources, parent );
   return static_cast<KABC::Resource*>( res );
 }
-#endif
+//#endif
 
 void
 AddressesDialog::saveAs()
 {
-#ifndef KDEPIM_NEW_DISTRLISTS
-  KABC::DistributionListManager manager( KABC::StdAddressBook::self( true ) );
-  manager.load();
-#endif
-
   if ( !d->ui->mSelectedView->firstChild() ) {
     KMessageBox::information( 0,
                               i18n("There are no addresses in your list. "
@@ -897,7 +893,8 @@ AddressesDialog::saveAs()
   KPIM::DistributionList dlist = KPIM::DistributionList::findByName( abook, name );
   alreadyExists = !dlist.isEmpty();
 #else
-  alreadyExists = manager.list( name );
+  KABC::AddressBook* abook = KABC::StdAddressBook::self( true );
+  alreadyExists = abook->findDistributionListByName( name ) != 0;
 #endif
 
   if ( alreadyExists ) {
@@ -922,14 +919,16 @@ AddressesDialog::saveAs()
   }
   abook->insertAddressee( dlist );
 #else
-  KABC::DistributionList *dlist = new KABC::DistributionList( &manager, name );
+  KABC::Resource *resource = requestResource( abook, this );
+  if ( !resource )
+    return;
+
+  KABC::DistributionList *dlist = abook->createDistributionList( name, resource );
   KABC::Addressee::List addrl = allAddressee( d->ui->mSelectedView, false );
   for ( KABC::Addressee::List::iterator itr = addrl.begin();
         itr != addrl.end(); ++itr ) {
     dlist->insertEntry( *itr );
   }
-
-  manager.save();
 #endif
 }
 
@@ -1044,10 +1043,7 @@ AddressesDialog::addDistributionLists()
   const QList<KPIM::DistributionList> distLists =
     KPIM::DistributionList::allDistributionLists( abook );
 #else
-  KABC::DistributionListManager manager( abook );
-  manager.load();
-
-  QStringList distLists = manager.listNames();
+  const QList<KABC::DistributionList*> distLists = abook->allDistributionLists();
 #endif
 
   if ( distLists.isEmpty() )
@@ -1059,14 +1055,14 @@ AddressesDialog::addDistributionLists()
 #ifdef KDEPIM_NEW_DISTRLISTS
   QList<KPIM::DistributionList>::ConstIterator listIt;
 #else
-  QStringList::Iterator listIt;
+  QList<KABC::DistributionList*>::ConstIterator listIt;
 #endif
   for ( listIt = distLists.begin(); listIt != distLists.end(); ++listIt ) {
 #ifdef KDEPIM_NEW_DISTRLISTS
     KPIM::DistributionList dlist = *listIt;
     KPIM::DistributionList::Entry::List entries = dlist.entries(abook);
 #else
-    KABC::DistributionList& dlist = *manager.list( *listIt );
+    KABC::DistributionList& dlist = *( *listIt );
     KABC::DistributionList::Entry::List entries = dlist.entries();
 #endif
 
@@ -1076,11 +1072,13 @@ AddressesDialog::addDistributionLists()
 
 #ifdef KDEPIM_NEW_DISTRLISTS
     KPIM::DistributionList::Entry::List::Iterator itemIt;
+    for ( itemIt = entries.begin(); itemIt != entries.end(); ++itemIt )
+      addAddresseeToAvailable( (*itemIt).addressee, item, false );
 #else
     KABC::DistributionList::Entry::List::Iterator itemIt;
-#endif
     for ( itemIt = entries.begin(); itemIt != entries.end(); ++itemIt )
       addAddresseeToAvailable( (*itemIt).addressee(), item, false );
+#endif
   }
 }
 
