@@ -256,7 +256,7 @@ bool KImportDialog::setFile(const KUrl& file)
 bool KImportDialog::setFile(const QString& file)
 {
     enableButton(KDialog::Ok,!file.isEmpty());
-  kDebug(5300) << "KImportDialog::setFile(): " << file << endl;
+  kDebug(5300) <<"KImportDialog::setFile():" << file;
 
   QFile f(file);
 
@@ -273,7 +273,7 @@ bool KImportDialog::setFile(const QString& file)
 
     return true;
   } else {
-    kDebug(5300) << " Open failed" << endl;
+    kDebug(5300) <<" Open failed";
     return false;
   }
 }
@@ -289,7 +289,7 @@ void KImportDialog::registerColumns()
 
 void KImportDialog::fillTable()
 {
-//  kDebug(5300) << "KImportDialog::fillTable()" << endl;
+//  kDebug(5300) <<"KImportDialog::fillTable()";
 
   int row, column;
 
@@ -307,7 +307,7 @@ void KImportDialog::fillTable()
 
 void KImportDialog::readFile( int rows )
 {
-  kDebug(5300) << "KImportDialog::readFile(): " << rows << endl;
+  kDebug(5300) <<"KImportDialog::readFile():" << rows;
 
   mData.clear();
 
@@ -462,7 +462,7 @@ void KImportDialog::setCellText(int row, int col, const QString& text)
 
 void KImportDialog::formatSelected(Q3ListViewItem*)
 {
-//    kDebug(5300) << "KImportDialog::formatSelected()" << endl;
+//    kDebug(5300) <<"KImportDialog::formatSelected()";
 }
 
 void KImportDialog::headerSelected(Q3ListViewItem* item)
@@ -548,14 +548,13 @@ void KImportDialog::assignColumn(Q3ListViewItem *item)
 {
   if (!item) return;
 
-//  kDebug(5300) << "KImportDialog::assignColumn(): current Col: " << mTable->currentColumn()
-//            << endl;
+//  kDebug(5300) <<"KImportDialog::assignColumn(): current Col:" << mTable->currentColumn();
 
   ColumnItem *colItem = (ColumnItem *)item;
 
   Q3TableSelection selection = mTable->selection(mTable->currentSelection());
 
-//  kDebug(5300) << " l: " << selection.leftCol() << "  r: " << selection.rightCol() << endl;
+//  kDebug(5300) <<" l:" << selection.leftCol() <<"  r:" << selection.rightCol();
 
   for(int i=selection.leftCol();i<=selection.rightCol();++i) {
     if (i >= 0) {
@@ -640,7 +639,7 @@ void KImportDialog::removeColumn()
 {
   Q3TableSelection selection = mTable->selection(mTable->currentSelection());
 
-//  kDebug(5300) << " l: " << selection.leftCol() << "  r: " << selection.rightCol() << endl;
+//  kDebug(5300) <<" l:" << selection.leftCol() <<"  r:" << selection.rightCol();
 
   for(int i=selection.leftCol();i<=selection.rightCol();++i) {
     if (i >= 0) {
@@ -659,7 +658,7 @@ void KImportDialog::removeColumn()
 
 void KImportDialog::applyConverter()
 {
-  kDebug(5300) << "KImportDialog::applyConverter" << endl;
+  kDebug(5300) <<"KImportDialog::applyConverter";
 
   KProgressDialog pDialog(this, i18n("Importing Progress"),
                     i18n("Please wait while the data is imported."));
@@ -692,7 +691,7 @@ int KImportDialog::findFormat(int column)
   if (formatIt == mFormats.end()) format = KImportColumn::FormatUndefined;
   else format = *formatIt;
 
-//  kDebug(5300) << "KImportDialog::findformat(): " << column << ": " << format << endl;
+//  kDebug(5300) <<"KImportDialog::findformat():" << column <<":" << format;
 
   return format;
 }
