@@ -22,6 +22,7 @@
 #include "kmeditor.h"
 #include "kemailquotinghighter.h"
 
+#include "kmutils.h"
 #include <maillistdrag.h>
 
 //kdelibs includes
@@ -39,20 +40,32 @@
 #include <KPushButton>
 #include <klocale.h>
 #include <kmenu.h>
+#include <KMessageBox>
+#include <KDirWatch>
+#include <KTemporaryFile>
+#include <KCursor>
 
 //qt includes
 #include <QApplication>
 #include <QClipboard>
 #include <QShortcut>
 #include <QPointer>
+#include <QTextCodec>
 #include <QTextList>
 #include <QAction>
+#include <QProcess>
+#include <QTextLayout>
+
+using namespace KPIM;
 
 class KMeditor::Private
 {
   public:
     Private(KTextEdit *_parent)
-     : parent(_parent),useExtEditor(false),findDialog(0L),find(0L)
+     : parent(_parent),useExtEditor(false),
+       findDialog(0L),replaceDialog(0L),find(0L),mExtEditorProcess(0L),
+       replace(0L), mExtEditorTempFileWatcher(0L),
+       mExtEditorTempFile(0L)
     {
     }
 
@@ -74,13 +87,18 @@ class KMeditor::Private
     QPointer<KFindDialog> findDialog;
     QPointer<KReplaceDialog> replaceDialog;
     KFind *find;
+    QProcess *mExtEditorProcess;
     KReplace *replace;
+    KDirWatch *mExtEditorTempFileWatcher;
+    KTemporaryFile *mExtEditorTempFile;
+    int mReplaceIndex;
+    int mFindIndex;
 };
 
-void KMeditor::Private::slotHighlight( const QString &word, int start, int end)
+void KMeditor::Private::slotHighlight( const QString &word, int matchingIndex, int matchedLength)
 {
-  kDebug()<<" KMeditor::Private::slotHighlight( const QString &, int, int ) :"<<word<< " pos start :"<<start<<" pos end :"<<end<<endl;
-  parent->highlightWord( end, start );
+  //kDebug()<<" KMeditor::Private::slotHighlight( const QString &, int, int ) :"<<word<<" pos :"<<matchingIndex<<" matchedLength :"<<matchedLength;
+  parent->highlightWord( matchedLength, matchingIndex );
 }
 
 void KMeditor::Private::addSuggestion(const QString& originalWord,const QStringList& lst)
@@ -184,8 +202,23 @@ void KMeditor::keyPressEvent ( QKeyEvent * e )
     else
       KTextEdit::keyPressEvent( e );
   }
+  else if (e->key() == Qt::Key_Up && e->modifiers() != Qt::ShiftModifier
+      && textCursor().blockNumber()== 0 /*First block*/
+      && textCursor().block().position() == 0)
+  {
+      textCursor().clearSelection();
+      emit focusUp();
+  }
+    // ---sven's Arrow key navigation end ---
+  else if (e->key() == Qt::Key_Backtab && e->modifiers() == Qt::ShiftModifier)
+  {
+      textCursor().clearSelection();
+      emit focusUp();
+  }
   else
+  {
     KTextEdit::keyPressEvent( e );
+  }
 }
 
 KMeditor::KMeditor( const QString& text, QWidget *parent)
@@ -205,24 +238,28 @@ KMeditor::~KMeditor()
   delete d;
 }
 
+bool KMeditor::eventFilter(QObject*o, QEvent* e)
+{
+  if (o == this)
+    KCursor::autoHideEventFilter(o, e);
+  return KTextEdit::eventFilter(o, e);
+}
+
 void KMeditor::init()
 {
-   //TODO change it.
-   new QShortcut( Qt::CTRL+Qt::Key_F, this, SLOT(slotFindNext()) );
-
-   //TODO change it.
-   new QShortcut( Qt::CTRL+Qt::Key_R, this, SLOT(slotReplaceNext()) );
+   KCursor::setAutoHideCursor( this, true, true );
+   installEventFilter(this);
    //enable spell checking by default
    setCheckSpellingEnabled(true);
 }
 
 void KMeditor::createHighlighter()
 {
-   Sonnet::KEMailQuotingHighlighter *emailHighLighter = new Sonnet::KEMailQuotingHighlighter(this);
+   KPIM::KEMailQuotingHighlighter *emailHighLighter = new KPIM::KEMailQuotingHighlighter(this);
    connect(emailHighLighter,SIGNAL(newSuggestions(const QString&,const QStringList&)),this, SLOT(addSuggestion(const QString&,const QStringList&)) );
 
    //TODO change config
-   setHightighter(emailHighLighter);
+   setHighlighter(emailHighLighter);
 }
 
 
@@ -236,7 +273,7 @@ void KMeditor::setExternalEditorPath( const QString & path )
   d->extEditorPath = path;
 }
 
-void KMeditor::findText()
+void KMeditor::slotFindText()
 {
   // Raise if already opened
   if ( d->findDialog )
@@ -259,11 +296,94 @@ void KMeditor::findText()
 }
 
 
+void KMeditor::slotReplaceText()
+{
+    if ( d->replaceDialog ) {
+#ifdef Q_WS_X11
+      KWindowSystem::activateWindow( d->replaceDialog->winId() );
+#else
+      d->replaceDialog->activateWindow();
+#endif
+    } else {
+      d->replaceDialog = new KReplaceDialog(this, 0,
+                                    QStringList(), QStringList(), false);
+      connect( d->replaceDialog, SIGNAL(okClicked()), this, SLOT(slotDoReplace()) );
+    }
+    d->replaceDialog->show();
+}
+
+void KMeditor::slotDoReplace()
+{
+    if (!d->replaceDialog) {
+        // Should really assert()
+        return;
+    }
+
+    delete d->replace;
+    d->replace = new KReplace(d->replaceDialog->pattern(), d->replaceDialog->replacement(), d->replaceDialog->options(), this);
+    d->mReplaceIndex = 0;
+    if (d->replaceDialog->options() & KFind::FromCursor || d->replace->options() & KFind::FindBackwards) {
+        d->mReplaceIndex = textCursor().anchor();
+    }
+
+    // Connect highlight signal to code which handles highlighting
+    // of found text.
+    connect(d->replace, SIGNAL(highlight(const QString &, int, int)),
+            this, SLOT(slotHighlight(const QString &, int, int)));
+    connect(d->replace, SIGNAL(findNext()), this, SLOT(slotReplaceNext()));
+    connect(d->replace, SIGNAL(replace(const QString &, int, int, int)),
+            this, SLOT(slotReplaceText(const QString &, int, int, int)));
+
+    d->replaceDialog->close();
+    slotReplaceNext();
+
+}
+
 void KMeditor::slotReplaceNext()
 {
-  //TODO
+    if (!d->replace)
+        return;
+
+    if (!(d->replace->options() & KReplaceDialog::PromptOnReplace))
+        viewport()->setUpdatesEnabled(false);
+
+    KFind::Result res = KFind::NoMatch;
+
+    if (d->replace->needData())
+        d->replace->setData(toPlainText(), d->mReplaceIndex);
+    res = d->replace->replace();
+    if (!(d->replace->options() & KReplaceDialog::PromptOnReplace)) {
+        viewport()->setUpdatesEnabled(true);
+        viewport()->update();
+    }
+
+    if (res == KFind::NoMatch) {
+        d->replace->displayFinalDialog();
+        delete d->replace;
+        d->replace = 0;
+        ensureCursorVisible();
+        //or           if ( m_replace->shouldRestart() ) { reinit (w/o FromCursor) and call slotReplaceNext(); }
+    } else {
+        //m_replace->closeReplaceNextDialog();
+    }
+
 }
 
+void KMeditor::slotReplaceText(const QString &text, int replacementIndex, int /*replacedLength*/, int matchedLength) {
+    Q_UNUSED(text)
+    //kDebug() << "Replace: [" << text << "] ri:" << replacementIndex << " rl:" << replacedLength << " ml:" << matchedLength;
+    QTextCursor tc = textCursor();
+    tc.setPosition(replacementIndex);
+    tc.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor, matchedLength);
+    tc.removeSelectedText();
+    tc.insertText(d->replaceDialog->replacement());
+    setTextCursor(tc);
+    if (d->replace->options() & KReplaceDialog::PromptOnReplace) {
+        ensureCursorVisible();
+    }
+}
+
+
 
 void KMeditor::slotFindNext()
 {
@@ -274,7 +394,7 @@ void KMeditor::findTextNext()
 {
   if (!d->find)
   {
-    findText();
+    slotFindText();
     return;
   }
   long options = 0;
@@ -292,7 +412,7 @@ void KMeditor::findTextNext()
   {
       if ( d->find->needData() )
       {
-        d->find->setData(toPlainText());
+        d->find->setData(toPlainText(), d->mFindIndex);
         res = d->find->find();
       }
       res = d->find->find();
@@ -319,20 +439,19 @@ void KMeditor::findText( const QString &str, long options, QWidget *parent, KFin
     return;
 
   delete d->find;
-  kDebug()<<" str :"<<str<<endl;
+  //kDebug()<<" str :"<<str;
   //configure it
   d->find = new KFind(str, options,parent,findDialog);
+  d->mFindIndex = 0;
+  if (d->find->options() & KFind::FromCursor || d->find->options() & KFind::FindBackwards) {
+        d->mFindIndex = textCursor().anchor();
+  }
   d->find->closeFindNextDialog();
   connect(d->find,SIGNAL( highlight( const QString &, int, int ) ),
           this, SLOT( slotHighlight( const QString &, int, int ) ) );
 
 }
 
-void KMeditor::replaceText()
-{
-  //TODO
-}
-
 void KMeditor::slotChangeParagStyle(QTextListFormat::Style _style)
 {
   QTextCursor cursor = textCursor();
@@ -355,8 +474,24 @@ void KMeditor::slotChangeParagStyle(QTextListFormat::Style _style)
   cursor.createList(listFmt);
 
   cursor.endEditBlock();
+  setFocus();
 }
 
+void KMeditor::setColor(const QColor& col)
+{
+   QTextCharFormat fmt;
+   fmt.setForeground(col);
+   mergeFormat(fmt);
+}
+
+void KMeditor::setFont(const QFont &fonts)
+{
+  QTextCharFormat fmt;
+  fmt.setFont(fonts);
+  mergeFormat(fmt);
+}
+
+
 void KMeditor::slotAlignLeft()
 {
   setAlignment(Qt::AlignLeft);
@@ -416,6 +551,7 @@ void KMeditor::slotFontFamilyChanged(const QString &f)
    QTextCharFormat fmt;
    fmt.setFontFamily(f);
    mergeFormat(fmt);
+   setFocus();
 }
 
 void KMeditor::slotFontSizeChanged(int size)
@@ -423,6 +559,7 @@ void KMeditor::slotFontSizeChanged(int size)
   QTextCharFormat fmt;
   fmt.setFontPointSize(size);
   mergeFormat(fmt);
+  setFocus();
 }
 
 void KMeditor::switchTextMode(bool useHtml)
@@ -447,7 +584,7 @@ void KMeditor::switchTextMode(bool useHtml)
   }
 }
 
-KUrl KMeditor::insertFile(const QStringList & encodingLst)
+KUrl KMeditor::insertFile(const QStringList & encodingLst, QString &encodingStr)
 {
   KUrl url;
   KFileDialog fdlg( url, QString(), this );
@@ -463,6 +600,7 @@ KUrl KMeditor::insertFile(const QStringList & encodingLst)
       if (KGlobal::charsets()->codecForName(KGlobal::charsets()->
                                           encodingForName(combo->itemText(i)))
         == QTextCodec::codecForLocale()) combo->setCurrentIndex(i);
+    encodingStr = combo->currentText();
   }
   if (!fdlg.exec()) return KUrl();
 
@@ -470,21 +608,20 @@ KUrl KMeditor::insertFile(const QStringList & encodingLst)
   return u;
 }
 
-void KMeditor::wordWrapToggled( bool on, bool wrapWidth )
+void KMeditor::wordWrapToggled( bool on )
 {
   if ( on ) {
-    if(wrapWidth)
-    {
-	//FIXME
-    	//setLineWrapMode(QTextEdit::FixedColumnWidth & QTextEdit::WidgetWidth);
-    }
-    else
 	setLineWrapMode(QTextEdit::FixedColumnWidth);
   } else {
     setLineWrapMode (QTextEdit::NoWrap );
   }
 }
 
+void KMeditor::setWrapColumnOrWidth( int w)
+{
+   setLineWrapColumnOrWidth(w);
+}
+
 void KMeditor::contextMenuEvent( QContextMenuEvent *event )
 {
   QTextCursor cursor = textCursor();
@@ -543,9 +680,11 @@ void KMeditor::contextMenuEvent( QContextMenuEvent *event )
 
 void KMeditor::slotPasteAsQuotation()
 {
-  QString s = QApplication::clipboard()->text();
-  if ( !s.isEmpty() ) {
-    insert( addQuotesToText( s ) );
+  if(hasFocus()) {
+    QString s = QApplication::clipboard()->text();
+    if ( !s.isEmpty() ) {
+      insert( addQuotesToText( s ) );
+    }
   }
 }
 
@@ -634,4 +773,112 @@ QString KMeditor::quotePrefixName() const
    return "> ";
 }
 
+bool KMeditor::checkExternalEditorFinished() {
+  if ( !d->mExtEditorProcess )
+    return true;
+  switch ( KMessageBox::warningYesNoCancel( topLevelWidget(),
+           i18n("The external editor is still running.\n"
+                "Abort the external editor or leave it open?"),
+           i18n("External Editor"),
+           KGuiItem(i18n("Abort Editor")), KGuiItem(i18n("Leave Editor Open")) ) ) {
+  case KMessageBox::Yes:
+    killExternalEditor();
+    return true;
+  case KMessageBox::No:
+    return true;
+  default:
+    return false;
+  }
+}
+
+
+void KMeditor::killExternalEditor() {
+  delete d->mExtEditorProcess;
+  d->mExtEditorProcess=0;
+  delete d->mExtEditorTempFileWatcher;
+  d->mExtEditorTempFileWatcher=0;
+  delete d->mExtEditorTempFile;
+  d->mExtEditorTempFile = 0;
+}
+
+
+void KMeditor::setCursorPositionFromStart( unsigned int pos ) {
+/*
+  unsigned int l = 0;
+  unsigned int c = 0;
+  posToRowCol( pos, l, c );
+  setCursorPosition( l, c );
+  ensureCursorVisible();
+*/
+}
+
+void KMeditor::slotAddBox()
+{
+  //Laurent fixme
+  QTextCursor cursor = textCursor();
+  if(cursor.hasSelection())
+  {
+    QString s = cursor.selectedText();
+    s.prepend(",----[  ]\n");
+    s.replace(QRegExp("\n"),"\n| ");
+    s.append("\n`----");
+    insert(s);
+  } else {
+/*
+    int l = currentLine();
+    int c = currentColumn();
+    QString s = QString::fromLatin1(",----[  ]\n| %1\n`----").arg(textLine(l));
+    insertLine(s,l);
+    removeLine(l+3);
+    setCursorPosition(l+1,c+2);
+*/
+  }
+}
+
+int KMeditor::linePosition()
+{
+  QTextCursor cursor = textCursor();
+  return cursor.blockNumber ();
+}
+
+int KMeditor::columnNumber ()
+{
+  QTextCursor cursor = textCursor();
+  return cursor.columnNumber ();
+}
+
+void KMeditor::slotRot13()
+{
+  QTextCursor cursor = textCursor();
+  if (cursor.hasSelection())
+    insert(KMUtils::rot13(cursor.selectedText()));
+}
+
+void KMeditor::setCursorPosition( int linePos, int columnPos)
+{
+  //TODO
+}
+
+bool KMeditor::appendSignature(const QString &sig, bool preserveUserCursorPos)
+{
+  bool mod = isModified();
+  if ( !sig.isEmpty() )  {
+    insert( '\n' + sig );
+    setModified( mod );
+    if ( preserveUserCursorPos ) {
+//Laurent fixme
+#if 0
+      setContentsPos( mMsg->getCursorPos(), 0 );
+      // Only keep the cursor from the mMsg *once* based on the
+      // preserve-cursor-position setting; this handles the case where
+      // the message comes from a template with a specific cursor
+      // position set and the signature is appended automatically.
+      preserveUserCursorPos = false;
+#endif
+    }
+    sync();
+  }
+  return preserveUserCursorPos;
+}
+
 #include "kmeditor.moc"
