@@ -103,7 +103,7 @@
 
 SMIMECryptPlug::SMIMECryptPlug() : CryptPlug() {
   GPGMEPLUG_PROTOCOL = GPGME_PROTOCOL_CMS;
-  mProtocol = GpgME::Context::CMS;
+  mProtocol = GpgME::CMS;
 
   /* definitions for signing */
   // 1. opaque signatures (only used for S/MIME)
@@ -165,7 +165,7 @@ SMIMECryptPlug::SMIMECryptPlug() : CryptPlug() {
 
 OpenPGPCryptPlug::OpenPGPCryptPlug() : CryptPlug() {
   GPGMEPLUG_PROTOCOL = GPGME_PROTOCOL_OpenPGP;
-  mProtocol = GpgME::Context::OpenPGP;
+  mProtocol = GpgME::OpenPGP;
 
   /* definitions for signing */
   // 1. opaque signatures (only used for S/MIME)
@@ -1053,7 +1053,6 @@ bool CryptPlug::decryptAndCheckMessage( const char*  ciphertext,
   size_t rCLen = 0;
   char*  rCiph = 0;
   bool bOk = false;
-  bool bWrongKeyUsage = false;
 
   if( !ciphertext )
     return false;
@@ -1079,12 +1078,6 @@ bool CryptPlug::decryptAndCheckMessage( const char*  ciphertext,
   err = gpgme_op_decrypt_verify( ctx, gCiphertext, gPlaintext );
   gpgme_data_release( gCiphertext );
 
-  decryptresult = gpgme_op_decrypt_result( ctx );
-#ifdef HAVE_GPGME_WRONG_KEY_USAGE
-  if( decryptresult->wrong_key_usage )
-    bWrongKeyUsage = true;
-#endif
-
   if( err ) {
     fprintf( stderr, "\ngpgme_op_decrypt_verify() returned this error code:  %i\n\n", err );
     if( errId )
@@ -1099,6 +1092,13 @@ bool CryptPlug::decryptAndCheckMessage( const char*  ciphertext,
     gpgme_release( ctx );
     return bOk;
   }
+  decryptresult = gpgme_op_decrypt_result( ctx );
+
+  bool bWrongKeyUsage = false;
+#ifdef HAVE_GPGME_WRONG_KEY_USAGE
+  if( decryptresult && decryptresult->wrong_key_usage )
+    bWrongKeyUsage = true;
+#endif
 
   if( bWrongKeyUsage ) {
     if( errId )
