@@ -59,7 +59,7 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kconfig.h>
-
+#include <kconfiggroup.h>
 // Qt
 #include <QByteArray>
 #include <QList>
@@ -265,7 +265,7 @@ public:
           for( itDN = dn.begin(); itDN != dn.end(); ++itDN ){
             if( (*itOrder) == (*itDN).first ){
               dnNew << *itDN;
-              //kDebug(5150) << QString((*itDN).first) <<" = " << QString((*itDN).second) << endl;;
+              //kDebug(5150) << QString((*itDN).first) <<" =" << QString((*itDN).second);;
             }
           }
         }
@@ -500,7 +500,7 @@ bool CryptPlugWrapper::initialize( InitStatus* initStatus, QString* errorMsg )
     /* make sure we have a lib name */
     if ( _libName.isEmpty() ) {
       _initStatus = InitStatus_NoLibName;
-      kDebug(5150) << "No library name was given.\n" << endl;
+      kDebug(5150) <<"No library name was given.";
     } else {
       if ( _libName.contains( "smime" ) ) {
 	_cp = new SMIMECryptPlug();
@@ -515,12 +515,12 @@ bool CryptPlugWrapper::initialize( InitStatus* initStatus, QString* errorMsg )
 
       if ( !_cp ) {
 	_initStatus = InitStatus_LoadError;
-	kDebug(5150) << "Couldn't create '" << _libName.toLatin1() << "'" << endl;
+	kDebug(5150) <<"Couldn't create '" << _libName.toLatin1() <<"'";
       } else {
 	/* now call the init function */
 	if( !_cp->initialize() ) {
 	  _initStatus = InitStatus_InitError;
-	  kDebug(5150) << "Error while executing function 'initialize' on plugin " << _libName << endl;
+	  kDebug(5150) <<"Error while executing function 'initialize' on plugin" << _libName;
 	  _lastError = i18n("Error while initializing plugin \"%1\"", _libName );
 	  if ( errorMsg )
 	    *errorMsg = _lastError;
@@ -669,14 +669,14 @@ Kleo::KeyListJob * CryptPlugWrapper::keyListJob( bool remote, bool includeSigs,
 
   unsigned int mode = context->keyListMode();
   if ( remote ) {
-    mode |= GpgME::Context::Extern;
-    mode &= ~GpgME::Context::Local;
+    mode |= GpgME::Extern;
+    mode &= ~GpgME::Local;
   } else {
-    mode |= GpgME::Context::Local;
-    mode &= ~GpgME::Context::Extern;
+    mode |= GpgME::Local;
+    mode &= ~GpgME::Extern;
   }
-  if ( includeSigs ) mode |= GpgME::Context::Signatures;
-  if ( validate ) mode |= GpgME::Context::Validate;
+  if ( includeSigs ) mode |= GpgME::Signatures;
+  if ( validate ) mode |= GpgME::Validate;
   context->setKeyListMode( mode );
   return new Kleo::QGpgMEKeyListJob( context );
 }
@@ -774,7 +774,7 @@ Kleo::ExportJob * CryptPlugWrapper::publicKeyExportJob( bool armor ) const {
 }
 
 Kleo::ExportJob * CryptPlugWrapper::secretKeyExportJob( bool armor, const QString& charset ) const {
-  if ( !_cp || _cp->mProtocol != GpgME::Context::CMS ) // fixme: add support for gpg, too
+  if ( !_cp || _cp->mProtocol != GpgME::CMS ) // fixme: add support for gpg, too
     return 0;
 
   // this operation is not supported by gpgme, so we have to call gpgsm ourselves:
@@ -782,7 +782,7 @@ Kleo::ExportJob * CryptPlugWrapper::secretKeyExportJob( bool armor, const QStrin
 }
 
 Kleo::RefreshKeysJob * CryptPlugWrapper::refreshKeysJob() const {
-  if ( !_cp || _cp->mProtocol != GpgME::Context::CMS ) // fixme: add support for gpg, too
+  if ( !_cp || _cp->mProtocol != GpgME::CMS ) // fixme: add support for gpg, too
     return 0;
 
   // this operation is not supported by gpgme, so we have to call gpgsm ourselves:
@@ -799,7 +799,7 @@ Kleo::DownloadJob * CryptPlugWrapper::downloadJob( bool armor ) const {
 
   context->setArmor( armor );
   // this is the hackish interface for downloading from keyserers currently:
-  context->setKeyListMode( GpgME::Context::Extern );
+  context->setKeyListMode( GpgME::Extern );
   return new Kleo::QGpgMEDownloadJob( context );             
 }
 
