@@ -24,8 +24,9 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kconfigbase.h>
+#include <kconfiggroup.h>
 #include <kconfig.h>
-#include <kstaticdeleter.h>
+#include <k3staticdeleter.h>
 #include <kconfiggroup.h>
 
 #include <QLabel>
@@ -54,7 +55,7 @@
 namespace Kpgp {
 
 Module *Module::kpgpObject = 0;
-static KStaticDeleter<Module> kpgpod;
+static K3StaticDeleter<Module> kpgpod;
 
 Module::Module()
   : mPublicKeys(),
@@ -64,7 +65,7 @@ Module::Module()
     passphrase(0), passphrase_buffer_len(0), havePassPhrase(false)
 {
   if (!kpgpObject) {
-    kDebug( 5326 ) << "creating new pgp object" << endl;
+    kDebug( 5326 ) <<"creating new pgp object";
   }
   kpgpObject=kpgpod.setObject(Module::kpgpObject, this);
   pgp = 0;
@@ -109,28 +110,29 @@ Module::init()
   pgp=0;
 }
 
-
 void
 Module::readConfig()
 {
-  storePass = config->readEntry("storePass", false);
-  showEncryptionResult = config->readEntry("showEncryptionResult", true);
-  mShowKeyApprovalDlg = config->readEntry( "showKeysForApproval", true );
+  KConfigGroup grp(config, config->group());
+  storePass = grp.readEntry("storePass", false);
+  showEncryptionResult = grp.readEntry("showEncryptionResult", true);
+  mShowKeyApprovalDlg = grp.readEntry( "showKeysForApproval", true );
   // We have no config GUI for this key anymore, and the KPGP backend isn't ported,
   // so let's just use Auto all the time.  See #92619.
   ///pgpType = (Module::PGPType) config->readEntry("pgpType", tAuto);
   pgpType = tAuto;
-  flagEncryptToSelf = config->readEntry("encryptToSelf", true);
+  flagEncryptToSelf = grp.readEntry("encryptToSelf", true);
 }
 
 void
 Module::writeConfig(bool sync)
 {
-  config->writeEntry("storePass", storePass);
-  config->writeEntry("showEncryptionResult", showEncryptionResult);
-  config->writeEntry( "showKeysForApproval", mShowKeyApprovalDlg );
+  KConfigGroup grp(config, config->group());
+  grp.writeEntry("storePass", storePass);
+  grp.writeEntry("showEncryptionResult", showEncryptionResult);
+  grp.writeEntry( "showKeysForApproval", mShowKeyApprovalDlg );
   //config->writeEntry("pgpType", (int) pgpType);
-  config->writeEntry("encryptToSelf", flagEncryptToSelf);
+  grp.writeEntry("encryptToSelf", flagEncryptToSelf);
 
   if(sync)
     config->sync();
@@ -141,7 +143,6 @@ Module::writeConfig(bool sync)
   pgp = 0;
 }
 
-
 void
 Module::setUser(const KeyID& keyID)
 {
@@ -201,7 +202,7 @@ Module::prepare( bool needPassPhrase, Block* block )
   if(needPassPhrase && !havePassPhrase) {
     if( ( tGPG == pgpType ) && ( 0 != getenv("GPG_AGENT_INFO") ) ) {
       // the user uses gpg-agent which asks itself for the passphrase
-      kDebug( 5326 ) << "user uses gpg-agent -> don't ask for passphrase\n";
+      kDebug( 5326 ) <<"user uses gpg-agent -> don't ask for passphrase";
       // set dummy passphrase (because else signing doesn't work -> FIXME)
       setPassPhrase( "dummy" );
     }
@@ -237,7 +238,7 @@ Module::wipePassPhrase(bool freeMem)
     if ( passphrase_buffer_len )
       memset( passphrase, 0x00, passphrase_buffer_len );
     else {
-      kDebug( 5326 ) << "wipePassPhrase: passphrase && !passphrase_buffer_len ???" << endl;
+      kDebug( 5326 ) <<"wipePassPhrase: passphrase && !passphrase_buffer_len ???";
       passphrase = 0;
     }
   }
@@ -526,13 +527,13 @@ Module::getEncryptionKeys( KeyIDList& encryptionKeyIds,
     recipientKeyIds[i] = keyIds;
   }
 
-  kDebug( 5326 ) << "recipientKeyIds = (\n";
+  kDebug( 5326 ) <<"recipientKeyIds = (";
   QVector<KeyIDList>::const_iterator kit;
   for( kit = recipientKeyIds.begin(); kit != recipientKeyIds.end(); ++kit ) {
-    kDebug( 5326 ) << "( 0x" << (*kit).toStringList().join( ", 0x" )
+    kDebug( 5326 ) <<"( 0x" << (*kit).toStringList().join(", 0x" )
                   << " ),\n";
   }
-  kDebug( 5326 ) << ")\n";
+  kDebug( 5326 ) <<")";
 
   if( showKeysForApproval || mShowKeyApprovalDlg ) {
     // #### FIXME: Until we support encryption with untrusted keys only
@@ -821,12 +822,12 @@ Module::rereadKey( const KeyID& keyID, const bool readTrust /* = true */ )
   if( ( 0 == oldKey ) && ( 0 != newKey ) )
   {
     mPublicKeys.inSort( newKey );
-    kDebug( 5326 ) << "New public key 0x" << newKey->primaryKeyID() << " ("
+    kDebug( 5326 ) <<"New public key 0x" << newKey->primaryKeyID() <<" ("
                   << newKey->primaryUserID() << ").\n";
   }
   else if( ( 0 != oldKey ) && ( 0 == newKey ) )
   { // the key has been deleted in the meantime
-    kDebug( 5326 ) << "Public key 0x" << oldKey->primaryKeyID() << " ("
+    kDebug( 5326 ) <<"Public key 0x" << oldKey->primaryKeyID() <<" ("
                   << oldKey->primaryUserID() << ") will be removed.\n";
     mPublicKeys.removeRef( oldKey );
   }
@@ -1013,7 +1014,7 @@ Module::getKpgp()
 {
   if (!kpgpObject)
   {
-      kError(5326) << "there is no instance of kpgp available" << endl;
+      kError(5326) <<"there is no instance of kpgp available";
   }
   return kpgpObject;
 }
@@ -1192,9 +1193,9 @@ Module::getEncryptionKeys( const QString& person )
   // First look for this person's address in the address->key dictionary
   KeyIDList keyIds = keysForAddress( address );
   if( !keyIds.isEmpty() ) {
-    kDebug( 5326 ) << "Using encryption keys 0x"
+    kDebug( 5326 ) <<"Using encryption keys 0x"
                   << keyIds.toStringList().join( ", 0x" )
-                  << " for " << person << endl;
+                  << "for" << person;
     // Check if all of the keys are a trusted and valid encryption keys
     bool keysOk = true;
     for( KeyIDList::ConstIterator it = keyIds.begin();
@@ -1237,7 +1238,7 @@ Module::getEncryptionKeys( const QString& person )
   KeyList matchingKeys;
 
   // search all keys which match the complete address
-  kDebug( 5326 ) << "Looking for keys matching " << person << " ...\n";
+  kDebug( 5326 ) <<"Looking for keys matching" << person <<" ...";
   for( it.toFirst(); (*it); ++it ) {
     // search case insensitively in the list of userIDs of this key
     if( (*it)->matchesUserID( person, false ) ) {
@@ -1245,8 +1246,8 @@ Module::getEncryptionKeys( const QString& person )
                                          // the trust info for this key is read
       if( ( (*it)->isValidEncryptionKey() ) &&
           ( (*it)->keyTrust() >= KPGP_VALIDITY_MARGINAL ) ) {
-        kDebug( 5326 ) << "Matching trusted key found: "
-                      << (*it)->primaryKeyID() << endl;
+        kDebug( 5326 ) <<"Matching trusted key found:"
+                      << (*it)->primaryKeyID();
         matchingKeys.append( *it );
       }
     }
@@ -1254,7 +1255,7 @@ Module::getEncryptionKeys( const QString& person )
 
   // if no keys match the complete address look for keys which match
   // the canonical mail address
-  kDebug( 5326 ) << "Looking for keys matching " << address << " ...\n";
+  kDebug( 5326 ) <<"Looking for keys matching" << address <<" ...";
   if( matchingKeys.isEmpty() ) {
     for ( it.toFirst(); (*it); ++it ) {
       // search case insensitively in the list of userIDs of this key
@@ -1263,8 +1264,8 @@ Module::getEncryptionKeys( const QString& person )
                                            // the trust info for this key is read
         if( ( (*it)->isValidEncryptionKey() ) &&
             ( (*it)->keyTrust() >= KPGP_VALIDITY_MARGINAL ) ) {
-          kDebug( 5326 ) << "Matching trusted key found: "
-                        << (*it)->primaryKeyID() << endl;
+          kDebug( 5326 ) <<"Matching trusted key found:"
+                        << (*it)->primaryKeyID();
           matchingKeys.append( *it );
         }
       }
@@ -1346,7 +1347,7 @@ Module::checkForPGP(void)
     path += "/gpg";
     if ( !access( path.toLatin1() , X_OK ) ) // ### PORT: use Qt
     {
-      kDebug( 5326 ) << "Kpgp: gpg found" << endl;
+      kDebug( 5326 ) <<"Kpgp: gpg found";
       havePgp=true;
       haveGpg=true;
       break;
@@ -1361,7 +1362,7 @@ Module::checkForPGP(void)
     path += "/pgpe";
     if ( !access( path.toLatin1() , X_OK ) ) // ### PORT: use Qt
     {
-      kDebug( 5326 ) << "Kpgp: pgp 5 found" << endl;
+      kDebug( 5326 ) <<"Kpgp: pgp 5 found";
       havePgp=true;
       havePGP5=true;
       break;
@@ -1376,7 +1377,7 @@ Module::checkForPGP(void)
       path += "/pgp";
       if ( !access( path.toLatin1() , X_OK ) ) // ### PORT: use Qt
       {
-        kDebug( 5326 ) << "Kpgp: pgp 2 or 6 found" << endl;
+        kDebug( 5326 ) <<"Kpgp: pgp 2 or 6 found";
         havePgp=true;
         break;
       }
@@ -1385,7 +1386,7 @@ Module::checkForPGP(void)
 
   if (!havePgp)
   {
-    kDebug( 5326 ) << "Kpgp: no pgp found" << endl;
+    kDebug( 5326 ) <<"Kpgp: no pgp found";
   }
 
   return havePgp;
@@ -1402,45 +1403,45 @@ Module::assignPGPBase(void)
     switch (pgpType)
     {
       case tGPG:
-        kDebug( 5326 ) << "Kpgp: assign pgp - gpg" << endl;
+        kDebug( 5326 ) <<"Kpgp: assign pgp - gpg";
         pgp = new BaseG();
         break;
 
       case tPGP2:
-        kDebug( 5326 ) << "Kpgp: assign pgp - pgp 2" << endl;
+        kDebug( 5326 ) <<"Kpgp: assign pgp - pgp 2";
         pgp = new Base2();
         break;
 
       case tPGP5:
-        kDebug( 5326 ) << "Kpgp: assign pgp - pgp 5" << endl;
+        kDebug( 5326 ) <<"Kpgp: assign pgp - pgp 5";
         pgp = new Base5();
         break;
 
       case tPGP6:
-        kDebug( 5326 ) << "Kpgp: assign pgp - pgp 6" << endl;
+        kDebug( 5326 ) <<"Kpgp: assign pgp - pgp 6";
         pgp = new Base6();
         break;
 
       case tOff:
         // dummy handler
-        kDebug( 5326 ) << "Kpgp: pgpBase is dummy " << endl;
+        kDebug( 5326 ) <<"Kpgp: pgpBase is dummy";
         pgp = new Base();
         break;
 
       case tAuto:
-        kDebug( 5326 ) << "Kpgp: assign pgp - auto" << endl;
+        kDebug( 5326 ) <<"Kpgp: assign pgp - auto";
         // fall through
       default:
-        kDebug( 5326 ) << "Kpgp: assign pgp - default" << endl;
+        kDebug( 5326 ) <<"Kpgp: assign pgp - default";
         if (haveGpg)
         {
-          kDebug( 5326 ) << "Kpgp: pgpBase is gpg " << endl;
+          kDebug( 5326 ) <<"Kpgp: pgpBase is gpg";
           pgp = new BaseG();
           pgpType = tGPG;
         }
         else if(havePGP5)
         {
-          kDebug( 5326 ) << "Kpgp: pgpBase is pgp 5" << endl;
+          kDebug( 5326 ) <<"Kpgp: pgpBase is pgp 5";
           pgp = new Base5();
           pgpType = tPGP5;
         }
@@ -1449,14 +1450,14 @@ Module::assignPGPBase(void)
           Base6 *pgp_v6 = new Base6();
           if (!pgp_v6->isVersion6())
           {
-            kDebug( 5326 ) << "Kpgp: pgpBase is pgp 2 " << endl;
+            kDebug( 5326 ) <<"Kpgp: pgpBase is pgp 2";
             delete pgp_v6;
             pgp = new Base2();
             pgpType = tPGP2;
           }
           else
           {
-            kDebug( 5326 ) << "Kpgp: pgpBase is pgp 6 " << endl;
+            kDebug( 5326 ) <<"Kpgp: pgpBase is pgp 6";
             pgp = pgp_v6;
             pgpType = tPGP6;
           }
@@ -1466,7 +1467,7 @@ Module::assignPGPBase(void)
   else
   {
     // dummy handler
-    kDebug( 5326 ) << "Kpgp: pgpBase is dummy " << endl;
+    kDebug( 5326 ) <<"Kpgp: pgpBase is dummy";
     pgp = new Base();
     pgpType = tOff;
   }
@@ -1743,9 +1744,9 @@ Module::readAddressData()
     data.keyIds = KeyIDList::fromStringList( addrGroup.readEntry( "Key IDs" , QStringList() ) );
     data.encrPref = (EncryptPref) addrGroup.readEntry( "EncryptionPreference",
                                                           int(UnknownEncryptPref ));
-//     kDebug( 5326 ) << "Read address " << i << ": " << address
+//     kDebug( 5326 ) <<"Read address" << i <<":" << address
 //                   << "\nKey IDs: 0x" << data.keyIds.toStringList().join(", 0x")
-//                   << "\nEncryption preference: " << data.encrPref << endl;
+//                   << "\nEncryption preference:" << data.encrPref;
     if ( !address.isEmpty() ) {
       addressDataDict.insert( address, data );
     }
