@@ -93,7 +93,7 @@ class Formatter : public KMail::Interface::BodyPartFormatter
       if ( !writer )
         // Guard against crashes in createReply()
         return Ok;
-      CalendarLocal cl( KPimPrefs::timeSpec() );
+      CalendarLocal cl( KPIM::KPimPrefs::timeSpec() );
       KMInvitationFormatterHelper helper( bodyPart );
       QString source;
       /* If the bodypart does not have a charset specified, we need to fall
@@ -119,12 +119,12 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
   public:
     UrlHandler()
     {
-      kDebug() << "UrlHandler() (iCalendar)" << endl;
+      kDebug() <<"UrlHandler() (iCalendar)";
     }
 
     Incidence* icalToString( const QString& iCal ) const
     {
-      CalendarLocal calendar( KPimPrefs::timeSpec() ) ;
+      CalendarLocal calendar( KPIM::KPimPrefs::timeSpec() ) ;
       ICalFormat format;
       ScheduleMessage *message =
         format.parseScheduleMessage( &calendar, iCal );
@@ -206,7 +206,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
                                 true, // RSVP, otherwise we would not be here
                                 status,
                                 myself ? myself->role() : heuristicalRole( incidence ),
-                                myself ? myself->uid() : QString::null );
+                                myself ? myself->uid() : QString::null );	//krazy:exclude=nullstrassign for old broken gcc
       if ( myself ) {
         newMyself->setDelegate( myself->delegate() );
         newMyself->setDelegator( myself->delegator() );
@@ -226,12 +226,12 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
     };
 
     bool mail( Incidence* incidence, KMail::Callback& callback, const QString &status,
-               Scheduler::Method method = Scheduler::Reply, const QString &to = QString::null,
+               iTIPMethod method = iTIPReply, const QString &to = QString(),
                MailType type = Answer ) const
     {
       //status is accepted/tentative/declined
       ICalFormat format;
-      format.setTimeSpec( KPimPrefs::timeSpec() );
+      format.setTimeSpec( KPIM::KPimPrefs::timeSpec() );
       QString msg = format.createScheduleMessage( incidence, method );
       QString summary = incidence->summary();
       if ( summary.isEmpty() )
@@ -274,7 +274,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       // (https://intevation.de/roundup/kolab/issue758)
       QString error;
       QString dbusService;
-      int result = KDBusServiceStarter::self()->findServiceFor( "DBUS/Organizer", QString::null, &error, &dbusService );
+      int result = KDBusServiceStarter::self()->findServiceFor( "DBUS/Organizer", QString(), &error, &dbusService );
       if ( result == 0 ) {
         // OK, so korganizer (or kontact) is running. Now ensure the object we want is available
         // [that's not the case when kontact was already running, but korganizer not loaded into it...]
@@ -287,17 +287,17 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
           DCOPRef ref( dcopService, dbusService ); // talk to the KUniqueApplication or its kontact wrapper
           DCOPReply reply = ref.call( "load()" );
           if ( reply.isValid() && (bool)reply ) {
-            kDebug() << "Loaded " << dbusService << " successfully" << endl;
+            kDebug() <<"Loaded" << dbusService <<" successfully";
             Q_ASSERT( kapp->dcopClient()->findObject( dbusService, dcopObjectId, "", QByteArray(), dummy, dummy ) );
           } else
-            kWarning() << "Error loading " << dbusService << endl;
+            kWarning() <<"Error loading" << dbusService;
         }*/
 
         // We don't do anything with it, we just need it to be running so that it handles
         // the incoming directory.
       }
       else
-        kWarning() << "Couldn't start DBUS/Organizer: " << dbusService << " " << error << endl;
+        kWarning() <<"Couldn't start DBUS/Organizer:" << dbusService << error;
 
       return true;
     }
@@ -368,7 +368,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         // check if we need to inform our delegator about this as well
         if ( newMyself && (status == Attendee::Accepted || status == Attendee::Declined) && !delegator.isEmpty() ) {
           if ( delegatorRSVP || status == Attendee::Declined )
-            ok = mail( incidence, callback, dir, Scheduler::Reply, delegator );
+            ok = mail( incidence, callback, dir, iTIPReply, delegator );
         }
 
       } else if ( !myself && (status != Attendee::Declined) ) {
@@ -383,10 +383,10 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
                                     true, // RSVP, otherwise we would not be here
                                     status,
                                     heuristicalRole( incidence ),
-                                    QString::null );
+                                    QString() );
           incidence->clearAttendees();
           incidence->addAttendee( newMyself );
-          ok = mail( incidence, callback, dir, Scheduler::Reply );
+          ok = mail( incidence, callback, dir, iTIPReply );
         }
       } else {
         ( new KMDeleteMsgCommand( callback.getMsg()->getMsgSerNum() ) )->start();
@@ -408,11 +408,11 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         incidence->addAttendee( delegate );
 
         ICalFormat format;
-        format.setTimeSpec( KPimPrefs::timeSpec() );
-        QString iCal = format.createScheduleMessage( incidence, Scheduler::Request );
+        format.setTimeSpec( KPIM::KPimPrefs::timeSpec() );
+        QString iCal = format.createScheduleMessage( incidence, iTIPRequest );
         saveFile( receiver, iCal, dir );
 
-        ok = mail( incidence, callback, dir, Scheduler::Request, delegateString, Delegation );
+        ok = mail( incidence, callback, dir, iTIPRequest, delegateString, Delegation );
       }
       return ok;
     }
@@ -447,7 +447,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         QString fwdTo = dlg.attendees().join( ", " );
         if ( fwdTo.isEmpty() )
           return true;
-        result = mail( incidence, c, "forward", Scheduler::Request, fwdTo, Forward );
+        result = mail( incidence, c, "forward", iTIPRequest, fwdTo, Forward );
       }
       if ( path == "reply" || path == "cancel" ) {
         // These should just be saved with their type as the dir
